(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 13.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[   4457897,      75814]
NotebookOptionsPosition[   4455683,      75775]
NotebookOutlinePosition[   4456102,      75792]
CellTagsIndexPosition[   4456059,      75789]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[TextData[StyleBox["Last checked 19 April, 2023",
 CellFrame->True,
 Background->GrayLevel[0.849989]]], "Text",
 CellFrame->True,
 CellChangeTimes->{{3.851321730299733*^9, 3.851321747924562*^9}, 
   3.8513218075505953`*^9, {3.890897811719871*^9, 3.890897826726935*^9}},
 TextAlignment->Left,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"6e0b646a-4282-44bb-8438-edf0f956b79a"],

Cell["Chapter 3, Section 3.3, Figure 3.2", "Section",
 CellChangeTimes->{{3.853505031176162*^9, 3.853505046759624*^9}, {
  3.853661724225806*^9, 
  3.853661727753392*^9}},ExpressionUUID->"64a886da-fb90-4218-9aec-\
9c7c4677de10"],

Cell[TextData[{
 "The existence of the Jacobi constant in the circular restricted three-body \
problem and the use of zero velocity curves can define regions in x-y space \
where motion is impossible for given values of the mass  ",
 StyleBox["\[Mu]",
  FontWeight->"Bold"],
 " and the Jacobi constant, ",
 StyleBox["CJ",
  FontWeight->"Bold"],
 ".  "
}], "Text",
 CellFrame->True,
 CellChangeTimes->{{3.85262176468622*^9, 3.8526217661887817`*^9}, {
   3.853052679072712*^9, 3.853052704798706*^9}, {3.853052739710747*^9, 
   3.8530527427191877`*^9}, {3.8530528820446367`*^9, 3.853052888291986*^9}, {
   3.853055142588128*^9, 3.853055147300077*^9}, {3.85350507280801*^9, 
   3.8535052184222*^9}, {3.853661821516285*^9, 3.853661934631201*^9}, {
   3.853661965040538*^9, 3.853661968528668*^9}, {3.853662178057679*^9, 
   3.853662182259986*^9}, {3.853662278482994*^9, 3.8536623009341516`*^9}, 
   3.8536633876854067`*^9},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"fcfaeef7-9023-4cdf-905a-4ab0a651e4f0"],

Cell[TextData[{
 "To generate ",
 StyleBox["Fig.3.2 ",
  FontWeight->"Bold"],
 "we first need to set up a number of points (the locations of the two masses \
and the Lagrangian points) that will not change for a given value of the \
secondary mass, \[Mu]",
 ", in units where the sum of the masses is unity; in this system the two \
masses are \[Mu]1 and \[Mu]2 where \[Mu]1+\[Mu]2 = 1.  This is done by \
defining the function ",
 StyleBox["Setup ",
  FontWeight->"Bold"],
 "which returns (but does not plot) points defining the locations of the \
equilibrium points (",
 StyleBox["lpts",
  FontWeight->"Bold"],
 ") (if needed) and the two masses (",
 StyleBox["mpts",
  FontWeight->"Bold"],
 ").  In our rotating coordinate system the mass \[Mu]1 is located at \
(-\[Mu],0) and the mass \[Mu]2 is located at (1-\[Mu], 0).  The locations of \
the five Lagrangian equilibrium points are given by the equations in Sect.3.6."
}], "Text",
 CellFrame->True,
 CellChangeTimes->{{3.853052865141131*^9, 3.8530529122997*^9}, {
  3.8535052443659163`*^9, 3.853505274229672*^9}, {3.853662306291526*^9, 
  3.853662414697176*^9}, {3.853662579791235*^9, 3.853662700373705*^9}, {
  3.853662744034984*^9, 3.853663110086424*^9}},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"0d9a5a7d-b3a0-4afe-ba0a-9d017a279b2e"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Setup", "[", "\[Mu]_", "]"}], ":=", "\[IndentingNewLine]", 
  RowBox[{"Module", "[", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
     "r2", ",", "L1", ",", "L2", ",", "L3", ",", "L4", ",", "L5", ",", 
      "\[IndentingNewLine]", 
      RowBox[{"\[Alpha]", "=", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"\[Mu]", "/", 
          RowBox[{"(", 
           RowBox[{"3", "*", 
            RowBox[{"(", 
             RowBox[{"1", "-", "\[Mu]"}], ")"}]}], ")"}]}], ")"}], "^", 
        RowBox[{"(", 
         RowBox[{"1", "/", "3"}], ")"}]}]}], ",", 
      RowBox[{"\[Beta]", "=", 
       RowBox[{
        RowBox[{
         RowBox[{"-", 
          RowBox[{"(", 
           RowBox[{"7", "/", "12"}], ")"}]}], "*", 
         RowBox[{"(", 
          RowBox[{"\[Mu]", "/", 
           RowBox[{"(", 
            RowBox[{"1", "-", "\[Mu]"}], ")"}]}], ")"}]}], "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"7", "/", "12"}], ")"}], "*", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"\[Mu]", "/", 
            RowBox[{"(", 
             RowBox[{"1", "-", "\[Mu]"}], ")"}]}], ")"}], "^", "2"}]}], "-", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"13223", "/", "20736"}], ")"}], "*", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"\[Mu]", "/", 
            RowBox[{"(", 
             RowBox[{"1", "-", "\[Mu]"}], ")"}]}], ")"}], "^", "3"}]}]}]}]}], 
     "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"r2", "=", 
      RowBox[{"\[Alpha]", "-", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"1", "/", "3"}], ")"}], "*", 
        RowBox[{"\[Alpha]", "^", "2"}]}], "-", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"1", "/", "9"}], ")"}], "*", 
        RowBox[{"\[Alpha]", "^", "3"}]}], "-", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"23", "/", "81"}], ")"}], "*", 
        RowBox[{"\[Alpha]", "^", "4"}]}]}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"L1", "=", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{"1", "-", "\[Mu]"}], ")"}], "-", "r2"}], ",", "0"}], 
       "}"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"r2", "=", 
      RowBox[{"\[Alpha]", "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"1", "/", "3"}], ")"}], "*", 
        RowBox[{"\[Alpha]", "^", "2"}]}], "-", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"1", "/", "9"}], ")"}], "*", 
        RowBox[{"\[Alpha]", "^", "3"}]}], "-", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"31", "/", "81"}], ")"}], "*", 
        RowBox[{"\[Alpha]", "^", "4"}]}]}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"L2", "=", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{"1", "-", "\[Mu]"}], ")"}], "+", "r2"}], ",", "0"}], 
       "}"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"r2", "=", 
      RowBox[{"2", "+", "\[Beta]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"L3", "=", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{"1", "-", "\[Mu]"}], ")"}], "-", "r2"}], ",", "0"}], 
       "}"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"L4", "=", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"0.5", "-", "\[Mu]"}], ",", 
        RowBox[{
         RowBox[{"Sqrt", "[", "3", "]"}], "/", "2"}]}], "}"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"L5", "=", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"0.5", "-", "\[Mu]"}], ",", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"Sqrt", "[", "3", "]"}]}], "/", "2"}]}], "}"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"lpts", "=", 
      RowBox[{"Graphics", "[", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"PointSize", "[", "0.007", "]"}], ",", 
         RowBox[{"Map", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"Point", "[", "#", "]"}], "&"}], ",", 
           RowBox[{"{", 
            RowBox[{"L1", ",", "L2", ",", "L3", ",", "L4", ",", "L5"}], 
            "}"}]}], "]"}]}], "}"}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"mpts", "=", "\[IndentingNewLine]", 
      RowBox[{"Graphics", "[", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{"PointSize", "[", "0.05", "]"}], ",", 
           RowBox[{"Point", "[", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "\[Mu]"}], ",", "0"}], "}"}], "]"}]}], "}"}], ",", 
         
         RowBox[{"{", 
          RowBox[{
           RowBox[{"PointSize", "[", 
            RowBox[{"0.05", "*", 
             RowBox[{"\[Mu]", "/", 
              RowBox[{"(", 
               RowBox[{"1", "-", "\[Mu]"}], ")"}]}]}], "]"}], ",", 
           RowBox[{"Point", "[", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"1", "-", "\[Mu]"}], ",", "0"}], "}"}], "]"}]}], 
          "}"}]}], "}"}], "]"}]}], ";"}]}], "\[IndentingNewLine]", 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.853660263534314*^9, 3.8536602845095863`*^9}, {
  3.853660320060854*^9, 3.853660329079035*^9}, {3.853660503772752*^9, 
  3.853660504481543*^9}, {3.8536605483838654`*^9, 3.853660591335475*^9}, {
  3.853660634030237*^9, 3.853660634518878*^9}, {3.853660685461603*^9, 
  3.853660722579953*^9}, {3.853660959182392*^9, 3.8536610138329782`*^9}, {
  3.853661347312673*^9, 3.853661367007408*^9}, {3.853662009042584*^9, 
  3.8536620595774727`*^9}},
 CellLabel->"In[1]:=",ExpressionUUID->"678bc441-9b7e-4718-83d3-5d40f8f8781e"],

Cell[TextData[{
 "Run the ",
 StyleBox["Setup",
  FontWeight->"Bold"],
 " function for the value \[Mu] =  0.2."
}], "Text",
 CellFrame->True,
 CellChangeTimes->{{3.85262176468622*^9, 3.8526217661887817`*^9}, {
  3.853052679072712*^9, 3.853052704798706*^9}, {3.853052739710747*^9, 
  3.8530527427191877`*^9}, {3.8530528820446367`*^9, 3.853052888291986*^9}, {
  3.853055142588128*^9, 3.853055147300077*^9}, {3.85350507280801*^9, 
  3.8535052184222*^9}, {3.853661821516285*^9, 3.853661934631201*^9}, {
  3.853661965040538*^9, 3.853661968528668*^9}, {3.853662178057679*^9, 
  3.853662182259986*^9}, {3.853662278482994*^9, 3.8536623009341516`*^9}, {
  3.853663168966022*^9, 3.853663195805511*^9}},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"e869e382-39d5-48dd-815b-0348c126775d"],

Cell[BoxData[
 RowBox[{"Setup", "[", "0.2", "]"}]], "Input",
 CellChangeTimes->{{3.8536610400223303`*^9, 3.853661046532539*^9}, {
  3.853661260897415*^9, 3.853661262711452*^9}},
 CellLabel->"In[2]:=",ExpressionUUID->"e445a296-8c34-42c9-8735-6191acbcbf72"],

Cell[TextData[{
 "Define the function ",
 StyleBox["CJzv",
  FontWeight->"Bold"],
 " used to calculate and display any region(s) where motion is impossible for \
a given value of the mass, ",
 StyleBox["\[Mu]",
  FontWeight->"Bold"],
 ", and the Jacobi constant, ",
 StyleBox["CJ",
  FontWeight->"Bold"],
 ".  The shaded regions in the plot denote regions where motion is not \
possible.  If ",
 StyleBox["Lplot",
  FontWeight->"Bold"],
 " is set to True then the location of the Lagrangian points (calculated in \
Setup) will be displayed; if ",
 StyleBox["Lplot",
  FontWeight->"Bold"],
 " is set to False then they will not.  Note: There can be values of ",
 StyleBox["\[Mu]",
  FontWeight->"Bold"],
 " and ",
 StyleBox["CJ",
  FontWeight->"Bold"],
 " for which there are no shaded regions and therefore no regions from which \
the test particle is excluded."
}], "Text",
 CellFrame->True,
 CellChangeTimes->{{3.85262176468622*^9, 3.8526217661887817`*^9}, {
  3.853052679072712*^9, 3.853052704798706*^9}, {3.853052739710747*^9, 
  3.8530527427191877`*^9}, {3.8530528820446367`*^9, 3.853052888291986*^9}, {
  3.853055142588128*^9, 3.853055147300077*^9}, {3.85350507280801*^9, 
  3.8535052184222*^9}, {3.853661821516285*^9, 3.853661934631201*^9}, {
  3.853661965040538*^9, 3.853661968528668*^9}, {3.853662178057679*^9, 
  3.853662182259986*^9}, {3.853662278482994*^9, 3.8536623009341516`*^9}, {
  3.853663168966022*^9, 3.853663270909032*^9}, {3.853663327908791*^9, 
  3.853663356156335*^9}, {3.8536634214515543`*^9, 3.853663539018478*^9}, {
  3.8536636280261993`*^9, 3.8536637410405416`*^9}},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"ed59d7a2-3bf5-4ff1-9a83-1961704d0a53"],

Cell[BoxData[
 RowBox[{
  RowBox[{"CJzv", "[", 
   RowBox[{"\[Mu]_", ",", "CJ_", ",", "Lplot_"}], "]"}], ":=", " ", 
  "\[IndentingNewLine]", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"rp", ",", "tmu", ",", "tcj"}], "}"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"tmu", "=", 
      RowBox[{"Graphics", "[", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Text", "[", 
          RowBox[{"\"\<\[Mu] = \>\"", ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "1.8"}], ",", "1.8"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "1"}], ",", "0"}], "}"}]}], "]"}], ",", 
         RowBox[{"Text", "[", 
          RowBox[{"\[Mu]", ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "1.6"}], ",", "1.8"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "1"}], ",", "0"}], "}"}]}], "]"}]}], "}"}], "]"}]}],
      ";", "\[IndentingNewLine]", 
     RowBox[{"tcj", "=", "\[IndentingNewLine]", 
      RowBox[{"Graphics", "[", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Text", "[", 
          RowBox[{
           RowBox[{"Subscript", "[", 
            RowBox[{"C", ",", "J"}], "]"}], ",", 
           RowBox[{"{", 
            RowBox[{"1.4", ",", "1.8"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "1"}], ",", "0"}], "}"}]}], "]"}], ",", 
         RowBox[{"Text", "[", 
          RowBox[{"\"\<=\>\"", ",", 
           RowBox[{"{", 
            RowBox[{"1.6", ",", "1.8"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "1"}], ",", "0"}], "}"}]}], "]"}], ",", 
         RowBox[{"Text", "[", 
          RowBox[{"CJ", ",", 
           RowBox[{"{", 
            RowBox[{"1.7", ",", "1.8"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "1"}], ",", "0"}], "}"}]}], "]"}]}], "}"}], "]"}]}],
      ";", "\[IndentingNewLine]", 
     RowBox[{"rp", "=", 
      RowBox[{"RegionPlot", "[", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{"2", "*", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"x", "^", "2"}], " ", "+", " ", 
                 RowBox[{"y", "^", "2"}]}], ")"}], "/", "2"}], " ", "+", " ", 
              
              RowBox[{"\[Mu]", "/", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1"}], " ", "+", " ", "\[Mu]", " ", "+", " ",
                     "x"}], ")"}], "^", "2"}], " ", "+", " ", 
                  RowBox[{"y", "^", "2"}]}], ")"}], "^", 
                RowBox[{"(", 
                 RowBox[{"1", "/", "2"}], ")"}]}]}], " ", "+", " ", "\n", 
              "     ", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{"1", " ", "-", " ", "\[Mu]"}], ")"}], "/", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{"\[Mu]", " ", "+", " ", "x"}], ")"}], "^", "2"}], 
                  " ", "+", " ", 
                  RowBox[{"y", "^", "2"}]}], ")"}], "^", 
                RowBox[{"(", 
                 RowBox[{"1", "/", "2"}], ")"}]}]}]}], ")"}]}], ")"}], "-", 
          "CJ"}], "<", "0"}], ",", 
        RowBox[{"{", 
         RowBox[{"x", ",", 
          RowBox[{"-", "2"}], ",", "2"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"y", ",", 
          RowBox[{"-", "2"}], ",", "2"}], "}"}]}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"If", "[", 
      RowBox[{"Lplot", ",", 
       RowBox[{"Show", "[", 
        RowBox[{"rp", ",", "tmu", ",", "tcj", ",", "mpts", ",", "lpts"}], 
        "]"}], ",", 
       RowBox[{"Show", "[", 
        RowBox[{"rp", ",", "tmu", ",", "tcj", ",", "mpts"}], "]"}]}], 
      "]"}]}]}], "\[IndentingNewLine]", "]"}]}]], "Input",
 CellChangeTimes->{{3.8535085179004383`*^9, 3.853508517902989*^9}, {
   3.853508645852294*^9, 3.8535086497711163`*^9}, {3.853508756712728*^9, 
   3.853508779360124*^9}, {3.853508830831367*^9, 3.8535088331350603`*^9}, {
   3.853508890734696*^9, 3.853508916116661*^9}, {3.853655288624743*^9, 
   3.8536553863097982`*^9}, {3.85365545747815*^9, 3.853655461762342*^9}, {
   3.8536554948846083`*^9, 3.853655682999689*^9}, {3.853655796720139*^9, 
   3.853655869507803*^9}, {3.853655905003365*^9, 3.8536559143708067`*^9}, {
   3.853655956922468*^9, 3.8536559575532217`*^9}, {3.853656000864807*^9, 
   3.853656007304482*^9}, {3.8536562995506687`*^9, 3.853656334336336*^9}, {
   3.853656385142602*^9, 3.853656481820491*^9}, {3.853656622792129*^9, 
   3.853656629121051*^9}, {3.8536566599624443`*^9, 3.8536566802787724`*^9}, {
   3.853656943905464*^9, 3.853656955644483*^9}, 3.853656991442079*^9, {
   3.853657147139406*^9, 3.853657168539218*^9}, {3.85365751748169*^9, 
   3.853657579095861*^9}, {3.8536576929685287`*^9, 3.853657704196725*^9}, {
   3.85365774797246*^9, 3.8536577486920223`*^9}, {3.8536578061636457`*^9, 
   3.8536578114282093`*^9}, {3.853657881727672*^9, 3.853657885613453*^9}, {
   3.85365797820006*^9, 3.853658190523151*^9}, {3.853658345752336*^9, 
   3.853658446933914*^9}, {3.853658499100828*^9, 3.853659059034169*^9}, {
   3.853659102201028*^9, 3.853659128928197*^9}, {3.853659160736636*^9, 
   3.853659165095941*^9}, {3.8536592749217176`*^9, 3.853659285918479*^9}, {
   3.853659369389782*^9, 3.853659372284491*^9}, {3.853659942000952*^9, 
   3.853659977143712*^9}, {3.8536600641348963`*^9, 3.853660067309*^9}, {
   3.853660242546678*^9, 3.8536602436816263`*^9}, {3.853661145148959*^9, 
   3.853661165897913*^9}, {3.8536612369142857`*^9, 3.8536612478648357`*^9}, {
   3.853662066728804*^9, 3.8536620850014477`*^9}, {3.853664304462146*^9, 
   3.8536643100448637`*^9}, {3.8536643724742737`*^9, 3.853664378856969*^9}},
 CellLabel->"In[3]:=",ExpressionUUID->"7431dd3e-676f-4bef-befb-caef1062bcaf"],

Cell[TextData[{
 "Now generate and then animate a series of plots for \[Mu] = 0.2 and values \
of the Jacobi constant going from 5.0 (where there are lots of excluded \
regions) down to 2.8 (where there are no longer any excluded regions). Note \
that the curves for ",
 StyleBox["CJ",
  FontWeight->"Bold"],
 " = 3.81, 3.56, 3.20 go through the points L1, L2 and L3. "
}], "Text",
 CellFrame->True,
 CellChangeTimes->{{3.85262176468622*^9, 3.8526217661887817`*^9}, {
  3.853052679072712*^9, 3.853052704798706*^9}, {3.853052739710747*^9, 
  3.8530527427191877`*^9}, {3.8530528820446367`*^9, 3.853052888291986*^9}, {
  3.853055142588128*^9, 3.853055147300077*^9}, {3.85350507280801*^9, 
  3.8535052184222*^9}, {3.853661821516285*^9, 3.853661934631201*^9}, {
  3.853661965040538*^9, 3.853661968528668*^9}, {3.853662178057679*^9, 
  3.853662182259986*^9}, {3.853662278482994*^9, 3.8536623009341516`*^9}, {
  3.853663168966022*^9, 3.853663270909032*^9}, {3.853663327908791*^9, 
  3.853663356156335*^9}, {3.8536634214515543`*^9, 3.853663539018478*^9}, {
  3.8536636280261993`*^9, 3.8536637410405416`*^9}, {3.853664484906479*^9, 
  3.853664603898616*^9}, {3.853664674731799*^9, 3.853664803240361*^9}},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"c5367ab1-de0c-4f31-97c0-7402b306af75"],

Cell[BoxData[
 RowBox[{
  RowBox[{"plots", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"CJzv", "[", 
      RowBox[{"0.2", ",", "iCJ", ",", "True"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"iCJ", ",", "5.0", ",", "2.8", ",", 
       RowBox[{"-", "0.01"}]}], "}"}]}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.853508849286537*^9, 3.85350887184579*^9}, {
   3.853509169111987*^9, 3.8535091877202663`*^9}, {3.853509223808661*^9, 
   3.8535092444254723`*^9}, {3.8535092952181997`*^9, 3.853509299930046*^9}, {
   3.8535093321054688`*^9, 3.853509369784053*^9}, {3.853655880149417*^9, 
   3.853655881733783*^9}, {3.853656015199608*^9, 3.85365603773811*^9}, {
   3.8536560786838703`*^9, 3.853656081586224*^9}, {3.85365648991245*^9, 
   3.853656491507249*^9}, {3.853657646238215*^9, 3.853657651733629*^9}, {
   3.85365771307416*^9, 3.853657714699946*^9}, 3.8536578596175833`*^9, {
   3.8536592549176483`*^9, 3.853659255636647*^9}, {3.85365931990833*^9, 
   3.85365932086753*^9}, {3.853659377571581*^9, 3.8536593783466682`*^9}, {
   3.85365999326917*^9, 3.8536600125927563`*^9}},
 CellLabel->"In[4]:=",ExpressionUUID->"5d375416-a2b6-4b75-a64e-5288c03af743"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ListAnimate", "[", "plots", "]"}]], "Input",
 CellChangeTimes->{{3.85350925454629*^9, 3.853509288944725*^9}, {
  3.853659294342605*^9, 3.853659297932522*^9}},
 CellLabel->"In[5]:=",ExpressionUUID->"51f1a70d-47d9-4d3e-bf66-f809b969292d"],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`i895$$ = 29, Typeset`show$$ = True, 
    Typeset`bookmarkList$$ = {
    "\"min\"" :> {$CellContext`i895$$ = 1}, 
     "\"max\"" :> {$CellContext`i895$$ = 221}}, Typeset`bookmarkMode$$ = 
    "Menu", Typeset`animator$$, Typeset`animvar$$ = 1, Typeset`name$$ = 
    "\"untitled\"", Typeset`specs$$ = {{{
       Hold[$CellContext`i895$$], 1, ""}, 1, 221, 1}}, Typeset`size$$ = 
    Automatic, Typeset`update$$ = 0, Typeset`initDone$$, 
    Typeset`skipInitDone$$ = True}, 
    PaneBox[
     PanelBox[GridBox[{
        {
         ItemBox[
          ItemBox[
           TagBox[
            StyleBox[GridBox[{
               {"\<\"\"\>", 
                AnimatorBox[Dynamic[$CellContext`i895$$], {1, 221, 1},
                 AnimationRate->Automatic,
                 AnimationRunTime->1.9685659408569336`,
                 AnimationTimeIndex->0.6561085972850678,
                 
                 AppearanceElements->{
                  "ProgressSlider", "PlayPauseButton", "FasterSlowerButtons", 
                   "DirectionButton"},
                 AutoAction->False,
                 DisplayAllSteps->True]}
              },
              AutoDelete->False,
              
              GridBoxAlignment->{
               "Columns" -> {Right, {Left}}, "Rows" -> {{Baseline}}},
              
              GridBoxItemSize->{
               "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}], 
             "ListAnimateLabel",
             StripOnInput->False],
            {"ControlArea", Top}],
           Alignment->{Automatic, Inherited},
           StripOnInput->False],
          Background->None,
          StripOnInput->False]},
        {
         ItemBox[
          TagBox[
           StyleBox[
            PaneBox[
             TagBox[
              PaneSelectorBox[{1->
               GraphicsBox[{{GraphicsComplexBox[CompressedData["
1:eJx1W3l4zFf3z2urIvYqU/sSU6pNvcZWHO2UllqGN61UvaO0UhpaPxSjqkrk
Ld2UsfupUGtJ1FbSqYOSSFBBGNK3QUxIbImJLLLM903n+tx5nuOJf+7zyb1z
7/mcc+45597v1Wrsx8PHVQoKCnqnSlDQ321RfI1vor3xfP232YmGYbBLYQKe
996EXy3Om/xlxJ/5sTGlfGpvSGOn+6rGHWudyPZYUjXGfMCYD7ipGq/xMTWf
xrPUehrPeLdwrivay53q9Gxrtz7k7vV32N22expDPmDIBwz5gCEfMOQDhnzA
kA8Y8gGHKnk0nqrk1fjcLyuHB2fm6xZ8gMEHGHyAwQcYfIDBBxh8gMEHGHyA
wQcYfIDBB/gP1WoMnpIXsGzBFxh8gcEXGHyBwRcYfIHBFxh8gcEXGHyBwRcY
fIGfVXypIr+UdpW8ZQv+wOAPDP7A4A8M/sDgDwz+wOAPDP7A4A8M/sDgD4x9
Kveh9GNpZ8kbWLbQBzD0AQx9AEMfwNAHMPQBDH0AQx/A0Acw9AEMfQBHKX1Q
RXFTxim5z+U+kH4h9SJb6AcY+gGGfoChH2DoBxj6AYZ+gKEfYOgHGPoBhn4q
yiMybsu4J+OC3CfST6RewB8Y/IHBHxj8gcEfGPyBwR8Y/IHBv6K8KfOUjPMy
Dsq4IPcF+AGDHzD4AIMPMPgAgw8w+FSU92WelXlKxnEZ1+S+Bh9g8AEGH2Dw
AQYfYPABBp+K6hZZJ8g8K/OQjMsyLsl9KHnKFnyB4Z/A4A8M/sDgDwz+wOBf
UZ0m6yJZV8i8K/OQjMMy7sh9KP1W2l3qRbbQDzD0Awz9AEM/wNAPMPRTUd0q
60RZZ8k6ROZlmZdkHJZxCfoBhn6kX0g9AMsW+gGGfoChH2DoBxj6qahOlnWm
rMNkXSLzssxDMi7LuCbjgtwn0i+kHmQLfQBDH8DQR0XnAllXy7pT1mGyDpF5
V+YhGcdlHJRxQe4DaXfJW7bgDwz+FZ0bZF0t60xZZ8m6QuZZmadknJdxT+5z
6dfSrpKnbOW5QNbJsk6UdZGsE2SelXlKxm0Zp+S+lH4p7STrVlmnybpF5n2Z
N2UekXFTxglx/0Di/oHa++fzcFc/Dx//5e+/xWn+tpgz/G2a7s/242SNTypM
wOfUeI1bqPk1vqDmJ8yf7Jc/V6/X1j/+Ac/18yjU9Rf6E9R4/fuWajxhPFrM
M1thApbrXlSYpBzQA/qBkY+AwQt66qIwVaQ3/B2t/HuQ/98hl5xP6h3jYD/0
w7+A0Y/xsBf6gdEPe6Ef9gJGP8ZDPmDpF1gfWLaYDxjrAWP+ivwMegKGf0te
6Mf+kPOjHzyB9TnhEYZ/SD+GX8Jf0I99CIx+jIe/wo/hr8DSj+U46cfSbyta
Fxj2kX4r/U7aQeoNGPYElvsG/gk7Iv4BI74BI77J+IH5EH9hB7SIG+AJDHvI
/Qu5IHdFcqKV+xh/h7/I/Yx+zC9543ewBzD8We5XWZfK/Yl+rAeM9TAv1pP7
BhjzAWM+YGk36A3zQA/ohz6AMV9Fdtf3FMLP5PlA7kf4Bewv61+5X+AX8ndy
H0s/kXaVvCAncLTfXm5GO8tfL2RwZ//vjvEpf92TScDr/OtvpyP+eVJoZ92p
R0zJJTTPL88d3eLvGFdrfMOlkWaDFql+/ln1c4rq50f9LMaz2V+3ZNNol7WD
1VHGmB+/R4t5sS5wbz/PdL1Oo1/98mu+4IP+hoqn5ov1gaEfjJMt9AWM3wND
HvCEHDNUS5APGPzAW/LE/KOUfkjoU+cXLf8jDHkwDnIAYzww9AQs5Ye9IDdw
J8VXY7Tyd3I96RdyfeipAr95jB/kEvJpueR6cn4xn+Yp9Yb9B4z9Byz0Icez
GP/YvPAvxE/063vfR/2Ih+iXGOsgPiHuIn4BY9/B79HCHsjfiKOYD3Ea8wFj
PsgJnKowyzoAcQ4Yfo7xwJALekP+gV2lv0Fe/E7aG/kC8k1R47Rfwv7wW2DI
D76QHxjyYj5g6AP7G3rD/keewHic45CfwANxXepD1gvQB+QHhh9JfeHv2AfC
/3S+Rr/wt8fqKPCHvFIfiFPgL/Ml4h/+DizrflkXyH2MehV1L873wEP2j95n
s+fxWwfP5iRFFulzHFrcdwBvC/7Hf2JcBVwyJrS5Izhfz4N1cD8EXGXchnCv
qZjX1/hukDnuvq7b4b/gB4w8ALthPPwV44ExHrwhD34HeYAhz1oljx6PewTo
YaDSiz4P4BwAfQBDH4VKH/qcgPWAMf9wNT/J+XH/Ar1uUvPq8wbmgf2AYT/M
C7lki/khp5wf9yewU5DS02M8gDEeesR4xLGK4pyMa/JcK+tomTcRZyqKQ4gz
mF/W4WK+x/wc+odd5b6Bf0Dvsk6XeRn8K8pDkL+ivCL3FewDP5bnWun38Dv0
w+/AQ557pZ/Db9APv4Ge5LlY+in8BP3wE/BAv86zj/rhV1gfcmF9+DH4YV3w
w37AOuALudHi71Kv6f77uhy9vzEv7A45YDfkK8Rz+Dl4wQ8xL/Ix8lhFdQP0
IOMW5IYeZBwCP+hBxgkZj+HHkA9+DH7yPgbnLPBFfpP3mPBjYPDCOQHjEf8x
HhjjUZdgPOIGxgNjPPSL8cgXGC/rH/BFP/iiH/UP8jbmhb2gB5xfwRdYf89/
lK/AB/rHeGCMhz0wHvsY8wIjL8Iv8DvsW8wLjH0DP4F/Y59ivwFjH8Jv4P+w
E+IxMOIx4q2M9xgPjPGwG8ZDL1rfj+4DgLF/oH85Dn+X/gb9ynM6+rFf0S/9
CfsF/fAf6fdYF+Ow7q6Oa+JN2w3uWTLirCn5qH6fiDqyerUaJ4w4g23NEv/l
Tbuj/fKZSW80cK7Ie+yd1sqkiWPdoYH7uYIhezbZ+pRyUUzuRYMKdX7zHrB+
EVMaeN82K9Hewl659LH3T13vTd9jaXiHW/7Ub6NtXRnL7yqHIlp3sl6+zSkN
PI0dwZc0r5QTtgXRwwPnue/toZ+4F1/T+vyg3eTazhE3dDzccmjlj7b0Oxo/
0ovG+D30jd/L76BHD/zNb4GeD/2YT74TGvYgfKx39TGC/PK9Qtcfgu8lRSbp
/T7qhauppuTDBH7ync3EzsPrON0XtNyDlq191fzCRYL+9HfpR/qG3LCHfGdZ
c9OY5+3z8wj2w/5DvkQ/7LrBs3Smq38hwT8wDr/zhfY2YocF8nLx3E4R7rrF
BP+CXSFHeLVp22zNiwPnsJeaTHIllNGEp5qeNyUf0d+3wGvp4dG7LKll9GlW
q8XRnbO5yrZu77onl8fVvk/ut/m8nHzvjbe98Q8576cFQXErCnRr/ejL6s64
h/wN9xvn9Xr5gWV6v+A3y3hkpR9GeouzuHvEoB8jx1/Qbcifu3pbHUc56OS/
Mz37LnLEpy3/7Q4tt0ejHkujp7g5+auDT8aNucaZU2Ka2K3Ms7++mGSqcZOA
K7VedsGzyaB5vY5eMA08zNfabNoemXKN673y9MOkjnuo9vV3DpkW3aWdLy9c
FOPaS9VPT6zp2GnQwx01T5mS91F6kjvEOsGg6r26fOBNO0v9++08bOpZSnvP
DH0Q+8VdGtJjzavBZ+9Sg+JzWUljyuvRnNhJ7pQLXFplfoh1lUHJrpR9tubn
qfatOfGmeIO6jn8n2RidTt/1Doq1PGdQrw5jelrf9nDfmKLo6LE+Ljuz7HVz
znUeFNovzjLNx92e7zbR1T+da7ww46KnncHCHjpv9jld2s6aWR5fjlc/akm9
Tlv3feWN/cLHS+K2fOaK8FDu9TVm6wQfp17ZMCi4XzbtbTvzkGlWGQc7Gu6I
DLrPzT4vaml/poRHVP6rZlzHXB48MWxV5LoS9j6R39/85wMeMnp5Y0eP8rqp
wVpfUs3yum3Uss22Q+Xn+PBqOyKr36dB9lst7W1KeOlv9QqSrj2g+w33JJr6
Fuk4tFn5Kw8saPGRe3HgHJn+oSnE/s8ijmrgCAu+8ICfuHR2h61rEf08N/RP
w/1Ax706yv856oM+NZy/BM6tE8Kvfh1do4TfHl76tDMnl29bPHNiwkr4YI/B
IY5Pcrnr7q8GBFctoQ47tqSabuXy7gmT0zyZge+LLR/Ur+3o5ONhrxcvipnt
4b2bMzKTavqo7fWRfxrs4eaqn2CXxA8XvhJc5uMOzeY2tW/8i9/7xx+1HJk+
WjtjSb/gfn/xlKhOdRzf/MVV2289YWmYwsOHfvlGcOY2ivigIMezL0XnqY9V
POKEcdzY/vsVbcfdXbYsjOl1nH5o/G2w071Z4/YK06INx2e7bnjo8Ondo72m
5Voek5KHsH5BiH99Gn955vwY1wF9fr5o6rjB1sfH9mYJk911PQR++YofgX9T
xZ+gz31KnwR9v6n0rePIfpUfaENam92W1MD3uFE1BhTFvlxCfcdl7Yj8Mpdg
77nK3vRc9y2drQcD51j420Dlb7Tx04ifbesC52z4axPlrwR/LH3H748E/96t
/Jsiqk1NsITd1+dH7Lc+ar+R2F8k9hOJfK31ODfsyPeRWeX9j/bbZrXf6Naq
/j2sDwPf5/Q7YRVPGX4l3wM0ze3NphplLObXeWSZireM+eX3ulmfRFVyPl2m
87xPxXu291l4zaD7j33/z7gTNTj4eJHOQ6NU/GfoC+Nnvn/qjGl7ns5TsFOf
KScXR58r0vt4zZ7Zp0yLAufHSi/68w/DfhhXd/2UWNvAQp3H9DnuUVzAuqv/
GpTjeSpwXsT+h7+AxytZaeHe4sB7dtg5y/xxqqnGfYY/Qs/1/PE+cN+YvKa2
2Xow8H0S9VxESptfbPZz/Gy9v+u4NbreQf3aK+Tr2x7LeV2nhKn6gbHf5Pf9
hNVjGzndRzTeqjBh/8vveW+p9Qnry+97ndT6BPlxPgM/+f9Qnlf1HSH+ye95
y5W+CfqEX0CfHqVPQvyV70JWKPsT7As/gH37K/tqO8t3I+nKHwn+BrtjnZ7K
3wj+DLl6bJuzInLrnce+OzdW+0nHoelqf+i4Lr9D95r51cyYO4Hvia+0eS/W
8qA8rv/x43HTh9m8ddS3lz3jyjjszssfuZqXcf+43msji7J1fA9X8Z2Qv3aq
/EXIh3dVPqS802da2H8/SXOeaXvBUx5frrYP3mg7dJdH3a+5MjK8lFMiWg00
1znP3zRc+oNtv8FtZz1fGHvtJJf26x5vyjBY1BMs5uOUSePPl0cxqvHNjuHe
8vyO+uRpVZ/woXk7RgRXzaOZL+YUxx55yEvMVfOS1hTQctVyh7BP29jjHtLM
Td3nusrrsyG5UQWxL5fysXbGaPfiu4z6x6XqH3bueqGS87UyWldYL9W4ksXj
p5W96w4qo0Y/JOy3dLnF9hEbV0R793K9zFY3Pfsu8IOpA+e5Eo5Q/Wn+lr8s
WNTZmpRFv2yr2cYx+CjXPfHP46bt2bTYfG2cd/VRXd9tU/Uc4fdoUe+hH/Ot
UvMR5pui5iPUlc+qliBfZSUfoR4drupRgr37KHsT+C5XfAl8ayu+BH25lL4I
9e5CVe8S9DtN6ZdQF+eolmAPtKinE1Q9TbDfNGU/7T/hyn90PV5J1ePafzcr
/yX4R3XlHyT8jYS/Bd7XqvMQv+Gob7JXNnScqps2pJajk0FLOv5rfeRWN3tj
z8ebFgXyaJvEsTNinAbdqPJSLeeKRH6u2ec9rJcD75tQz6Sc8tcz9JzfLpk0
7NbNAzb7zzSzeEG8qVwujJ80yUg09hk0tFnYFePzJYT1ED+zwtsO9c4yaH3G
6aFe0xmCvLjfQb32tarXaNrEGTZvvI9eDVrcxV75qr6/XfnpB87I8YH3Or6P
Np0wRgTmuZQ5tot5dOB+eq8jO9I1xad/v1r9nhcO6Pr/0cnX2Pnff8bYkgPv
2B7NxwPSllmDx6Vz9YLLTextDBbnB+7VtGk7+++XuGejL3Zaphks1td+u/21
kBPGDwYvXuAe6U27REtyc+JNswwW5w1+7XyV2g5LOiV069Pe+oKh75/3K/m5
euUV2yMvXaPwHp721rM+Tk+sdz+2XE7yTLWa3Rc52fPnksjXDZ7z1n/iLQ0v
MfQ3SOmPR5VWvp70U+BcYnKczEg6afDKJ1pc8lgO8f46dXda9hr82YBNBy3O
E4zzVSN1vmLY75CyH0/31QuxXg5833ytRcsQ61mDS1L6znBVO0Do//e+v++z
5mv/+Ub5D+M8Z9npP88x/Iea+/1Hywv/uddr1cvBCwweWL3nOdPAc7Rj7u9R
0RsM/urH1A229NOE8+T76jxJ8O8Tyr+p6zuOJOOKj6P7NV4QPeUK4bxaW51X
CftlvtovJOxPwp4k7EmwzwhlH8L57p463+n1l6v1GXzeVnwYfLYpPgx9djvr
16fWd+9f/PrU9hul7Eew32hlP4J/hCr/IPjHR8o/9LlpoDrPktgPJPybxH0Z
ifsxEv5brg+Xyb4x8P4A+byPyucs8jmL8VzlpXMW83c+muSve69x7e+/iLGt
C9QFuO+tXPC9EdvqF40T8/2Y8Ptx6veE32PdrIgJ77vrluh7VZyHXlXnIe47
rHpL+8YSqkVboqJ35/C5rblmaw+f/m6E81qEOq/pfTVv6xi3YVzkK94Wxy0N
M/T+6HDqiRftlTN41yf1vo1xbdD3Thn7/fdldCVsaJBzxL3Au81H6yEO4Dw8
QJ2HacmQdt3MZ8q4y3/fmehefEPzwf0yztch6nyteQ7fu+rr6M6Bcbt6XD1j
UIl+X2KdGNrEPj/wfuT9J29cT+po6N+/pX7P8/znoBzGfQPm26vm46jrwfGm
4hxasPHXnubEEl6zrVY159Ml+jvag6U/HTFtL+EPj91NNDiHwaeX4sMrpw79
zdQ6ELfX1p+/y3K4jN58/+nR3ik3dFxG3IbfhD3VbL/FmcbmrCV9rA/P8vOh
Zc7oKRd5u/88msLvHk2PiTxxkVusyY1y9b/K3cM69zXHndD3wzUzWycbn/+h
76MGq/sohv3M0/3243tNu1eKizmu7fXtf7PTDOMYlZZ+P8xrimXgKIX1fVa2
us/S8iNvQP5Xlfw6T09T/kTg01zxIfAZrvgQ7uPuJ/vv42jk+JE3PcuO81jL
epfFc5GgT/gT9DlY6ZNgH9gR9hmr7EOro6b1Dz5eSkZBr+etPW4T9kcVtT8I
9v5C2Ztw//S6un+ihal9W9rn32b71OlsulXKOB/gHIT3KF26vdrcvrGUQ2f3
6mmuU6rv1XFvf85/75ujv0uMTdiTm3T7Jtf3xw8fL1jef3HM7Gv6HH9u6Xtb
Irde583WYY6Y2Y+/X/m/fz0111XtOmd3P+aNHRN4z4K8Lt+zzFL3ywz9TlH6
1ffqI9V9My9qnVGQFBnFzUvqro5ecp6reqrWcLq36u9Hxwd0qek4HXjv8kZh
8trIrQcp9PKtho7Bybxs1IQJ3tWHH3sPWdokIdHiTOGiw3desjp+J/leBvkU
8+McjPHy/QzuU8EXcR3y11by6+9By/1+nUrgg/dw0P9nSv/6HiRZ6Z+gf/ke
Z4LSP0H/8n3OSGVf+nF8dnfzmVKuySENHINvU+KMy7NjZpfq73jwF8RV+Euy
8hfC/ekAdX9KiF+4n4KfOdX3G0Jcwnsf+O9I5b+B7wbq+w6dy1+SkXQ7R78P
qpX/SWu7NZmea9ch3nTL4DEvTJ0T47xNf6z/7iOXt5Q3r/dNdufmcezGyT/Z
fEUcsbqoi3VCIR+41/6UKT6f56VEnjVGF3PL6eHHLQ/uM/g3UPwZ+/GJQv9+
5Ju1MrfZ0i9zqH1DtbhW57modVF20q+3qYavZ7xt3WGN75T5MSH+mVT8I/y+
lfo9wR/rK38kyNNUyUOjm90+b+QX8XCTY1V0Vh5B/r1KftpctPITV0ERrc0P
ecmanUd1Fz9s6vgtn+NfSl4QM7GQwH+74k8HVhn/iDuSTxH9Uj50Ty6kPjca
NnJW9vK6vubW9o+LCfpLVvqjOVcalCTV9FJGj/ZPOGcUU8aTVbtaz97g9zMf
PmPPKaPJt7LWRJqTOXV++ATXDYMOdFztNq7coOHTj010FTzWz5DvkJKPwe8t
xY+FPbV8G5R8bLseU99ZmEf2Gw0GB1d9yHV/9DVxTCqkiKJOP9sO5bN5fLfe
5tHFlBzc9kV73n2NExQmjB+rxhPmG6nmoy/3fBZnCbtHaZf+3oc9GXzCFB+G
Pm4ofTD0+aHSJ8Me65U99Htj3Mf+D8bpNms=
                   "], {{
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[0.3], EdgeForm[None], 
                    GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxNm3f819MXx9/33o9S8iNkVSoVEUpKqaRIycoeFSJki4wQUkh29iYyfvbe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                    "]], PolygonBox[CompressedData["
1:eJwtl3fcl2MUxn/3c56oXilSGryVejVIVlaSIrNtb9l7kxVCVioNhUI7lKKU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                    "]]}]}, {}, {}, {}, {}}, 
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwl1GmYjWUcx/FnxgiDhCQhzNha7UuiMZam7IYs9c6LZM96lV60KEuN3ViL
oij7vle2SLKVNbIv9dKVEtk+/6sX3/n+fv/7Ps+ccz/POVV6DcodmJIkyWB/
UjnyIaFtWpIc5o4FkqQDPpEn8ETk4aA+nnfEGg7oH/N+LsZFsUnO4eJIdb00
FEB7fZK1s3yMz/BRLs0drZfizfpE1NMf1o/Lp9FOP8VbMAX19XLWf5fPob1+
lrdiKhroj1s/L1/gC3yRHzAviO5yvllD+RK/pH/L03FJvswH4vOiiD3pKIxq
+mr8Yf1qGDMxIz6v9TW8FrPxKeagtPk6Xo95+AKfo5z5Bt6Ir7AIC1HBfFOc
Ba7jL1zz/xZzHVS2noEquG5+NM4zzgqL9de5N+qjuj31uAb35Zr8BO7IN+y9
zf/GefEL5kvlfvIyztIby7fl57i5vlweIK/kFnpT+a7cjFvqq+RB8hpurTeX
E/yGJ/Wn8AyexmCzbDwrt+ChGBLnFPfDrJWchtHYgq1oHe8NBTEm7hlO4yev
+Y6HY0TcZ7wc52texMOdjkLxTMd95HbYZ+17Xo4VGItt8UzhZ2vb+cX4rPEM
YBxWIR1tXGejPcPk1+TU+PyxX15rvhe15NpIkGLtFFLiu8A58UzY82acO17R
s7gt7pm30lfzQL0JuurPx//FHfNsfQX31xuii96IT+IE/rN2j5fwj7iJu/ot
7sNvoJrX1I29+Mf8Fv/NmeZVsTfOFR/hQ4zC0rhmPKv27cEH8vv4Bl9jvtlu
vCe/iy+xAJ+Z7cQ78kjMjRlmmW3D2/Jb+FOexbvxA4p5H0Vx1fyyfoWvcFUU
Mu/JryITjfQZ1nvI03h/3Me4z7ioZ3BufG+4GyrFa/XKfMZ6Re6sV4j7gcfQ
Uy8fz6/1R7mTXjbuB8qgh/5InHv8DsXZ83mezF14Ate1p6R8RM7lEuhu9hD/
apbPv8RvD+/ELkyNz4BJmBLXw3h7OsV7xIOo4xp5qf//ft8HeSy7Cw==
                    "]], 
                    LineBox[{976, 1002, 1001, 1038, 702, 664, 1080, 806, 746, 
                    1004, 749, 1003, 748, 705, 666, 1005, 1006, 977, 978, 708,
                     670, 863, 675, 1083, 813, 754, 814, 1084, 676, 868, 680, 
                    1014, 1015, 1013, 1017, 1016, 681, 869, 1054, 815, 1053, 
                    816, 1055, 841, 755, 1085, 677, 864, 1050, 1051, 1009, 
                    751, 1007, 750, 1008, 1048, 1047, 860, 1045, 809, 1044, 
                    810, 1046, 747, 1042, 808, 1041, 807, 859, 1040, 703, 
                    1039, 976}], 
                    LineBox[{811, 862, 861, 887, 706, 667, 967, 930, 752, 892,
                     893, 894, 968, 671, 865, 678, 866, 867, 812, 1082, 673, 
                    709, 979, 980, 1110, 672, 1010, 668, 1081, 
                    811}]}}], {}}, {
                  InsetBox["\<\"\[Mu] = \"\>", {-1.8, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["0.2`", {-1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {InsetBox[
                   SubscriptBox["C", "J"], {1.4, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["\<\"=\"\>", {1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["5.`", {1.7, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {
                  {PointSize[0.05], PointBox[{-0.2, 0}]}, 
                  {PointSize[0.0125], PointBox[{0.8, 0}]}}, 
                 {PointSize[0.007], PointBox[{0.4463998339305619, 0}], 
                  PointBox[{1.2771956561278897`, 0}], 
                  PointBox[{-1.0806611991222994`, 0}], 
                  PointBox[
                   NCache[{0.3, Rational[1, 2] 3^Rational[1, 2]}, {0.3, 
                    0.8660254037844386}]], 
                  PointBox[
                   NCache[{0.3, Rational[-1, 2] 3^Rational[1, 2]}, {
                    0.3, -0.8660254037844386}]]}},
                AspectRatio->1,
                Axes->{False, False},
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                Frame->{{True, True}, {True, True}},
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLines->{None, None},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None, "TransparentPolygonMesh" -> 
                  True, "AxesInFront" -> True},
                PlotRange->{{-2, 2}, {-2, 2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.02], 
                   Scaled[0.02]}, {
                   Scaled[0.02], 
                   Scaled[0.02]}},
                Ticks->{Automatic, Automatic}], 2->
               GraphicsBox[{{GraphicsComplexBox[CompressedData["
1:eJx1W3l4zNf6j+VeGtLbkmuZKmLroNVURaPFWx1crSJXe1HLUEXV1NJa42qp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                   "], {{
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[0.3], EdgeForm[None], 
                    GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxNmwf819P3x9/33k+JdiilKe2lPVQKDZRSQqmkUJpCIU3xs2XPMrI3kRlR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                    "]], PolygonBox[CompressedData["
1:eJwtl3ccV1MYxn/nvldR0V4SDZWRSqSMIjNpECoy+5gfe28+VgulkJZK0hYt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                    "]]}]}, {}, {}, {}, {}}, 
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwl1Hf0T3Ucx/HLT0a27BzndE7nZGdmRBEpK2WTPapjdU7LCFH2DFEyCsfe
VFYpm7KqnxmFBrJ3RunxPv54/p6v1/vz+X3v/d7vvfeRjq836pkmSZJ+/vRL
SZKZnIpVaZNke2C2EqvQHztwJmxtJ3+BLzEA3+MHVMNXSPAeViMNGqez3/+9
Kr+GKnjRbLnZFlSRn0QW3NX/sp5V/ld+iVdwJ7MKaK0/wc/gtvkL+lLuoJfB
y3pZroF/zOvpi7idXhKt9FL8B37HDWuZzebxZlzDg/p1bh2fh9J6Uc7Al83T
8yUuxY8j1dp+9EYvvIML1pfwz5gtb8Lb8ltYhIWYYbYRb8pvYC7mYIrZBvSU
e+BzfIZJZvu4O7qha3wHs6m8F3uQz/nkxQnzy/pxvsIPI5d5fW6AgnGN9Ilx
jeQP+RAfxAEc0wtwS3vycx3kRQc9Hx+ynptb6A/x88iJ9nouTrWenZvr2fg5
ZEE7PWtcF+vn+Cc+z2O4No/kqvZklJ9FLaRHW7MM8R2tf8y7+ZMwJmOXPjGu
ET7CCH08T8DY+H4Yh+HmY3hUXGv3+zB9tDyUR8TxI8c+DMMQ88FhvB/3uf5B
HA+D4t7XB/JOTuG08VzIT/EDyOa803F2rsmjrZ3lffx3/G5xv3Ez65ni+dFH
oZqeWf9RPoAm+n5ejbHx+XqO+L3kI2iqH+Y1GIen9TzWf5Ev8FG+GL9R/B/q
yuPNqsu/xn59LU/AJfk3PsxHkDs+K35nFNLX4KT1q3wNn8Y9i/zW1/I6TIv7
G9NR2Hw9f42Z8TxgFh41/4Y3YB4WYD4eM/+Wv0Mi3+OzjreYi6C4WUmUwEXz
42Yn4pziGdJbcqvYhzL2FOOy3IbLcfm41rhib0a+yiXiHpbny23jXLhOPN/y
Tbk019UXyu3lxVxfLyffksvHc6UvkTvKy7ihXlG+I//JFeLdhUoxR2ezSqgs
V+ZX0AUr7W8U70T5P7kPb8QmVMVS3DPvy5txClvjXRrHxXK8GzOcxjZr23hF
yv13/f90VMfs
                    "]], 
                    LineBox[{987, 1014, 1013, 1049, 698, 660, 1090, 797, 740, 
                    1016, 743, 1015, 742, 700, 662, 1017, 1018, 988, 989, 703,
                     666, 850, 671, 1093, 804, 748, 805, 1094, 672, 855, 676, 
                    1026, 1027, 1025, 1029, 1028, 677, 856, 1065, 806, 1064, 
                    807, 1066, 832, 749, 1095, 673, 851, 1061, 1062, 1021, 
                    745, 1019, 744, 1020, 1059, 1058, 847, 1056, 800, 1055, 
                    801, 1057, 741, 1053, 799, 1052, 798, 846, 1051, 699, 
                    1050, 987}], 
                    LineBox[{802, 849, 848, 873, 701, 663, 977, 932, 746, 879,
                     880, 881, 978, 667, 852, 674, 853, 854, 803, 1092, 669, 
                    704, 990, 991, 1117, 668, 1022, 664, 1091, 
                    802}]}}], {}}, {
                  InsetBox["\<\"\[Mu] = \"\>", {-1.8, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["0.2`", {-1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {InsetBox[
                   SubscriptBox["C", "J"], {1.4, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["\<\"=\"\>", {1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["4.99`", {1.7, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {
                  {PointSize[0.05], PointBox[{-0.2, 0}]}, 
                  {PointSize[0.0125], PointBox[{0.8, 0}]}}, 
                 {PointSize[0.007], PointBox[{0.4463998339305619, 0}], 
                  PointBox[{1.2771956561278897`, 0}], 
                  PointBox[{-1.0806611991222994`, 0}], 
                  PointBox[
                   NCache[{0.3, Rational[1, 2] 3^Rational[1, 2]}, {0.3, 
                    0.8660254037844386}]], 
                  PointBox[
                   NCache[{0.3, Rational[-1, 2] 3^Rational[1, 2]}, {
                    0.3, -0.8660254037844386}]]}},
                AspectRatio->1,
                Axes->{False, False},
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                Frame->{{True, True}, {True, True}},
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLines->{None, None},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None, "TransparentPolygonMesh" -> 
                  True, "AxesInFront" -> True},
                PlotRange->{{-2, 2}, {-2, 2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.02], 
                   Scaled[0.02]}, {
                   Scaled[0.02], 
                   Scaled[0.02]}},
                Ticks->{Automatic, Automatic}], 3->
               GraphicsBox[{{GraphicsComplexBox[CompressedData["
1:eJx1Wnl4zFf3V1RbFfp6aQlV1DLWtkhofzhlVFUtefGqooO2FNFSUjpatBpT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                   "], {{
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[0.3], EdgeForm[None], 
                    GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxNmgf0VcURxu/uPgXBgigWVJoi0hXpiqAigljArihiw4YiGFER0Ni70dhr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                    "]], PolygonBox[CompressedData["
1:eJwtlwn4FmMUxb937kil7U+ipLQRhSJKm12LhJJ9SZbHnj072ZIiQrtSKSlR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                    "]]}]}, {}, {}, {}, {}}, 
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwl1Ge8znUYx/H/OYfsUVSPeoCSdbKP7P0sxbFKRMd4ULKiQsneZGW9JJvo
HCszq4ysslVGJQoRaSgUva+XB5/7c32v63f/x+/+/+8SWT0ze6QkSTLYR8Fc
SXI3NUky0pJkJReQ/+UL8k7+igvr1UN97JR34a2w+Zs8AP0xRH6b38FAvItB
GKo/JIzBGI5hgf5IHoURGIPRMdcfx+MxFrvlCWG8hz3yRP6CE37Zdd1T11HX
RQoa6I3QqxfH5Et8gC/yQX6As6zJzfWRB+3kvPxl7AN3lvPHsVAQL8qF+Ih5
Ue4iF+GGeBDt5Yf4pPkhPhxrMU5uzBO5qTXF1E3RJL4X38Gv6m/Nr/IpfkTv
4bjXuE9MwRn9rLiuODf2YpLedJ6BruiGjXrTMEf9AV7Bq/hUbxbmqxegO17D
Fr25OKBehIvqHtwTvWI/Ys9QEumu67J5Cv/CqVwRT6GleStc088d98RbsSD2
W77OZ8zP4kl00CvNbbHE7Dn5BteUy+MluRy/gI/0M+U/uJZcER3jvPG74GP9
1vJNzsvf6/2lzqOuhZrYJq9AK3VV805xDOTotdG7wyvlN3BbncPV8Tk+Qz9k
x7mwI/rWnOft6IsVWI5tsd7sR96K1+P6sSz2Or5rdi5+D/TB0rh/bI5jmf3A
m9Abt+TFXA21XWNd1ME/+vn4b87P2dwh9gxV8LRe5XgmkaGugeqohu/0/rS+
EreUl6vbxfVxCzld/bu6AjeXl6qfVy/mZ+Wy6t/UZbiZvCj2T72Qn5GfUF9V
p6mvcK7Yb1RBa7PKXIor8eOciRaYb+3peP7jXcAlubw1FeI5QIk4By7o3+Y7
8axjA0qbf8jzMBfrsQ6l9GfxbMzEJ1iLx/Sn8fuYijVYjUf1J/FkXI9nGaed
bxUXR7F4L1Ecx+Sj+Mb8Ck/gtaih/pqbWDOeG8lF1EXjnVGf0LvMx7kwN9Yf
q16Do7HXcWw+HL+xeSN5jHp1/B+jrXyI98femjeUR8Y1xvsY74ucxnvln3gf
/8yjuDYXMv8v9f5///+6e8ag
                    "]], 
                    LineBox[{980, 1009, 1008, 1048, 692, 655, 1094, 790, 733, 
                    1011, 736, 1010, 735, 694, 657, 1012, 1013, 981, 982, 697,
                     661, 842, 666, 1097, 797, 741, 798, 1098, 667, 847, 671, 
                    1021, 1022, 1020, 1024, 1023, 672, 848, 1064, 799, 1063, 
                    800, 1065, 824, 742, 1099, 668, 843, 1060, 1061, 1016, 
                    738, 1014, 737, 1015, 1058, 1057, 839, 1055, 793, 1054, 
                    794, 1056, 734, 1052, 792, 1051, 791, 838, 1050, 693, 
                    1049, 980}], 
                    LineBox[{795, 841, 840, 865, 695, 658, 969, 923, 739, 871,
                     872, 873, 970, 662, 844, 669, 845, 846, 796, 1096, 664, 
                    698, 983, 984, 1120, 663, 1017, 659, 1095, 
                    795}]}}], {}}, {
                  InsetBox["\<\"\[Mu] = \"\>", {-1.8, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["0.2`", {-1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {InsetBox[
                   SubscriptBox["C", "J"], {1.4, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["\<\"=\"\>", {1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["4.98`", {1.7, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {
                  {PointSize[0.05], PointBox[{-0.2, 0}]}, 
                  {PointSize[0.0125], PointBox[{0.8, 0}]}}, 
                 {PointSize[0.007], PointBox[{0.4463998339305619, 0}], 
                  PointBox[{1.2771956561278897`, 0}], 
                  PointBox[{-1.0806611991222994`, 0}], 
                  PointBox[
                   NCache[{0.3, Rational[1, 2] 3^Rational[1, 2]}, {0.3, 
                    0.8660254037844386}]], 
                  PointBox[
                   NCache[{0.3, Rational[-1, 2] 3^Rational[1, 2]}, {
                    0.3, -0.8660254037844386}]]}},
                AspectRatio->1,
                Axes->{False, False},
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                Frame->{{True, True}, {True, True}},
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLines->{None, None},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None, "TransparentPolygonMesh" -> 
                  True, "AxesInFront" -> True},
                PlotRange->{{-2, 2}, {-2, 2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.02], 
                   Scaled[0.02]}, {
                   Scaled[0.02], 
                   Scaled[0.02]}},
                Ticks->{Automatic, Automatic}], 4->
               GraphicsBox[{{GraphicsComplexBox[CompressedData["
1:eJx1W3tY1NXW9piZR8XMvORohh3TKU/KUcZb5tLGQ37mZfQjs7SxLI0c80Jl
jmmSGpnlHbWyDFCzSNG8VTa51BSBvOCNQVS8MCACCowod36fzfbd83zLZ/xn
Py+/PXuv9a7LXvti+/FTR06oW6dOnSn16tT5u533xtu/W2Ku8sKJ524lxlXz
kZ0dH4lxX9K4c+Pkax7LaY3L9zRcHO3do7FLYQJuq/prfFCNp/EsNZ/GH7xW
FuWK9vLTD/bpYLdWcK9mm+1u2w2NIR8w5AOGfMCQDxjyAUM+YMgHDPmAQ5Q8
Gr+r5NX45C9fjgzKuaVb6AMMfYChDzD0AYY+wNAHGPoAQx9g6AMMfYChDzD0
AT6mWo2hp9QLWLbQFxj6AkNfYOgLDH2BoS8w9AWGvsDQFxj6AkNfYOgL/KTS
lwL5pbSr1Fu20B8Y+gNDf2DoDwz9gaE/MPQHhv7A0B8Y+gNDf2DoD4w4lXEo
/VjaWeoNLFvwAQw+gMEHMPgABh/A4AMYfACDD2DwAQw+gMEH8ALFBwXKmzJP
yTiXcSD9QvIiW/ADDH6AwQ8w+AEGP8DgBxj8AIMfYPADDH6AwU+gdUTmbZn3
ZF6QcSL9RPIC/YGhPzD0B4b+wNAfGPoDQ39g6A8M/QOtm3Kdknle5kGZF2Rc
QD9g6AcMfYChDzD0AYY+wNAn0Lov11m5Tsk8LvOajGvoAwx9gKEPMPQBhj7A
0AcY+gSqW2SdINdZuQ7JvCzzkoxDqadsoS8w/BMY+gNDf2DoDwz9gaF/oDpN
1kWyrpDrrlyHZB6WeUfGofRbaXfJi2zBDzD4AQY/wOAHGPwAg59AdausE2Wd
JesQuS7LdUnmYZmXwA8w+JF+IXkAli34AQY/wOAHGPwAg59AdbKsM2UdJusS
uS7LdUjmZZnXZF6QcSL9QvIgW/ABDD6AwUegfYGsq2XdKeswWYfIdVeuQzKP
yzwo84KMA2l3qbdsoT8w9A+0b5B1tawzZZ0l6wq5zsp1SuZ5mfdknEu/lnaV
espW7gtknSzrRFkXyTpBrrNynZJ5W+YpGZfSL6WdZN0q6zRZt8h1X66bch2R
eVPmiQu+3+dzpq+t5Cu+NpN7+OSu5Ws+nKpxHd+/vS7gv9R3Aj6pfq/xGTU+
YfxUnzzFer4OPnlLOconV5mup/A9SfXXvw9W/Qn90WKc2QoTMH4HPdMV1npj
/QCG3OAhVGEKxAv+jlb+HXzJ8QLx2sknt0ePA38Axnf0B//4Dozvj6n++jvs
AYzv6A/5AtkZ8wPLFuMBYz5gjB/Ib8ATMPxb6oXv8Gc5Pr5DT2Bd19/F8A/I
Cf8ARpwAw9/gh/A3YOmHsh/8X/qhnBcY/g8cyI+k3STPkhdgGQfwN9gF+QcY
/AHDPsDIP8DIPzIfYD7kR9gBLfIA9AaWeQvjQm7oFUgPtDJu8XfoJ+MX3zF+
IF4QH8DgR8anrBtlPOI75gvEO+aTcQKM8YAxXiC7gTeMAx7wHXwAY7xAdtfn
CMLvZP0u1wn4Bewv61MZP/AL+TsZx9JPpF0l75I3qTf0AI722dPNaGf51vsr
3M33u4N8xFe35BDwOt/4CbTfN04abWn67n5TahXN88lbqFv8fZHC/LPCjO/A
aNFP/u5Zn5xZnKbm45a/++bX8kIefG+u5NTymn11yzWNoR/6yRb6AuP3wJAH
+kOOD1RLkA9Y6i31RDxp+e5izNc4ovlKh9nQ34GhN7CU5+7fNW/AYhzNJ7AY
l4UcWm9g6AmMVsoh5ZdySX2kXGJezY8YR/7uHh6FvBSIJzm/5AHjCD11fAay
G+I1kB0Rv9KuwIjnAPOxGJ/FeCx+f4/c8H8ppz4Xvvtdyikx5kG+R54ERh5F
vsd3YHxH/YI6BPtj4HoT4kd7TZWc+8fsw4ZRFHAe4HEu61NWZ43OA2hhB9Qv
WDcCyQWM8cAL5MU4kBcY8n7TcOkQ89YSOq1+p+WKVPLocTEe9o2jfjtRlOIo
52G7x+2y2W9qjDoO48eq8VnWcdjHAddR/Qn9gcEn5ICcWKfAJ9Yp4LGqv9YL
GDzD71A/IO5kvgD/+J2MR6z3kjeMh/hE/AFDftgP8gNDXowHDPuC3yzFj66T
YV/wq/3oLp/oDwz7g7dAvAbiERhyB9IrkB7A2M/LuJC86rr17u91/7vrFTD4
gL+OVP5J8Fdg+CvGlf4h61/4B+wJjLwk/Qd/R94OlBfxPVCehHzgAfUc1m/U
b3o9v6sH6iv8DhjfMS7iUMY5cKA4R4vzMuAfg/7xaZzrNle9HtLOGXRL5x3E
G+QFRl0CXtEf8YX+wOgP3iAnzokg52Alt7Yz9pWQFxjylil5dTxhPPiLHA/n
adBzoxpH5zXph8DSDyGHbDE+5JLjI85l3gR/gfIC4h79wRfGkXaFfuBJroP4
HfIS5gu0DoFXfAevkEOeC0i7gRd8By+QE9/xO3wHj5gf/GB+2AP6QB6MK3nA
72BPzIN8hHUb+Qp1OP6OvIe/I8+CL+QL5G2sP5gf88o4hX3lOg99wIP0e+gn
eYA8yE+QB/GH/a7W9+5+ERj5Ruovz5OwL0Q/5C3oJ8+TkBegF+SS57Kol4Cx
TmAfhf7IR+gPjP5Y19Ef9QH6A6M/7IX+yF/oL+sH8Inv4AffUT/APsgr4AX6
Aev3BXfzJeSHPdEfGP3BI/ojztAPGHEEv0E8ID8g/oARl/ArxIu0E+wi/QV+
hb9L+0F+fJf2Qjzhu7QP/BvfYQ+Me2hA21Dzp/51/aM2Hc54cvzr+On5o992
5frXbW/iqT2mRQaHfTR4TlzfQm3XyujkC8a4m/e8w4rq/dWXjgb+872svRfP
eVrcwcedDnfTMp2PM4pOViae8L9fG9/z8xe9mVX3vG+a0/ilZ8xTC7hBm8iz
nvdrWN6bJEy/nZ/SuYDrhH6+2WbP0Py9+c/c7JTO/v1Y6eGCBMcPl7XenyyP
vZlizdX5qcHu1q+7iws1tk4OaW2f79+v4ffgCb+X95xdKh9r5Qz6So+H7xhP
vgNqM8/9s81+iCC/fI/Q+5UWJw0jRefjqE+/ne+qv5+gn3xHc+X5yW2dQela
7mYRD2+z2dMJ/GEc8A25YQ/5jjJ3yIa5rrCbBPvB/7EOv/34sq+jB9/03y8P
2OnxtCgj+Af64XeLwvcl2tr564kewSXvunIrCP4Fu0KOmI09f7GU+u/LUne+
sDA6vsZ/fx7yRW7KTzV0/6kH5sdV5/HgdQlnPS/WsCnY29ea4+W0Y6GXPHEV
nOnJ3Gr76LZuG9QZfMmzqoJHjnjgWetZLz9Ydqw0sXcNL1lg+81yMI8rwoc9
6lx8RrcNt1kKPWcOcKQl1mXxpPOkLw/+aou8zFnuiuWOZOYjTVc73HWu0kTb
xkbOxcz9K299Z/vIoNWzfp/nit7P7eq1G2Iuusyd+tuueyzbKeL2WwujV1yn
qPPXMg1jJw1q1WC4d5FBdUfsu39r3A5K9Zxb4Rhk0K+bBraKeekELeoT3Mf8
WDX122O5mvLCdZqSeX5W3DfXKT715n0xz1fT57usGcbcdP7i1IVGzncMen16
xOw4l4tnX4l+xJ5tUPe3yk4ac3+jnxaeG+POMyiq8ajRQRtPUvWzwdkpaw16
at6SYya7hy3uQZNdfWs57LEl49xpF3hYwZCVjgYGlzzZJjel4AJVP10can7w
Tn74evE0d4iHQs82ibcNq+XTDdPnu3KL2dN0T3niP6o4Pr9LsWdVMdf9pO4u
S2gVH9vx531b95eyudGEM8Zjd9a5qn9/4J5WTAferdfF+nIV9+9V1M1eVEzh
/U5tsjWs4pm3J250JJdSxtAGH7g6luu8Ear8i0ftLvnQZb+l64ZZyfu7W1vf
qbumB4/37rlT1769ckFc23Ka0cy73ba3VOepfOXPHDEh5LBpkX8fELWp9oAp
v5I7JHe7Ylws5qSo3C7Ws5WUeWPwDHdxMY/c/PEuS2ElhX3/bX/riWK+MeDE
Btte//1h+LOdtllKa7hw14kwc5GHV3x64GbiiRqa1H4tW0JzuPGgnT3MD9ZS
xgcZX0Vvz+ZL3oEW88VaXvzslKspnS/wfxLPvepOqqVTT6V8Fp16nhf4/PoC
tzpVPza6WxqbNxbPjXMlUPvI+TPcaWl6Hemt8gc/8+HZJ6wVF/V6/+24c+sd
Pxwi7+Q/NjjMGzWepTCZfxq4z3LaQ9surzxuSl2p5Zmj5CHM30DNT9T18i+W
mN/0/mVU/a8aO+8zaHj+qDNGpwwyNV3Xxv6vWr72wOY3vJnZBH3TlL4EPsYr
Pijj43fSjKI79dKHn40JOlOs4z5e5XMqv79rO/tW//0b+H9O8U+wT7qyD8H+
bZX96WTwgzWJi/37EvhfB+V/9PTEIRscEf59Evz3kvJfgn/uVf5JLQbULotr
XqLPBxAv3VW8UNjM8mOmxz08cNDAEd6wO/j/xw8hXrqpeKEnivueN8hDIbHT
c1JeqCX/+1JffuOMiJBprvqF99xTb397WqYnx//uaY7Kf7peOha7dIrL63+/
30flV/58vXl5XPW99+9J+TMaxqwp13n/S5VvGfqi/+QvR811Rd7U64Le30z7
Y2jQxnIdh0+sG8+WcP/+ZYnK9wy+0e/cQ48GxbQq0+uGtsOl+1/3vnKLYT/I
+UhhxDRXbtW97wSeK1wXfdJ/r9piSZMFrqRihv+At51z3nd7Vt17XzjvnbMf
u+pf0XX1+ZxnD1piTnJwk7/rutW6nkBdvP2Z78tTHKd0HfCSWp8Z8SHv2/tu
m/0vZ9ABjdspTIhXed92RM1PmF/ev8Wr+Qn6yHuoWUofXae9r+onQr6CHOBT
3sMeUHxqP39I8UnIl/IdRntlb4I9YXfYM03Zk5Cv5TuNA8r/CP6FekGfIyj/
Ivgv5EJ8yHvhRBUfOm+kqnjQ9VbH9i86XEn++7uXens6WU/U0n9nxF703LrG
pxcuO2I8dmcfs7puXoq7mg+Pcf1gi87X+beZyr+E9SVSrS+E9eq0Wq+oZfaY
vaZF1/n2sB0bbf2q2Z66kMwPXqPK1gU9zeNqeMb6J99zJV2jXt4X6sb0rGGs
59+r9Zzr/exaHFfopb3jjBDrjxWcnb22jXP+bbqqWq6n6hdC/bIip2yqq2M1
D2+aM9L7ynVGvRCm6gXeMn3hz5Z/19BJ55/drD/mcb9ef7FpTzVNatW5InF/
Pjf9c8fz5qk7uUPqox+60s8w/BT+G/OJ+xVvZh5d8fnnAbY/PCrBtu4aja56
6YQp9YCuh+JVPaT9HC3qo6dUfUQY76AajzBeHzUeoe7KVy1BvpZKPkK9Fq3q
NYK9WNmLoG+q0peg73ilL4Gv5xVfhHpwmOKTwC8w6sZ01RLsgRb15hFVbxLs
t0fZT/uDV/mDrlfDVL2q/S9N+R/BX24rfyH4S6jyF13/rlP7Ae4xxpliXPS/
V8L6PE6tz/z9od9jbU0M8p6t703p7OaxpQWNnBMMna82jHtikivSoBvJw+Md
C5P42Jpet1P+8r8PQr2w75KvXqC+33hWR9tzKL13xw7OLT9TbMmMse5lhu5f
Gtwk1LzUoA7PbDrnsXxDmA/5btZrbUsSRxiE+gLy47wA9dCfqh6iUeVdYhwL
aykqL3iLI+KS1rPZkM8+ie7m1yPi4PXDBvvl6LLmze7mIv+8k3qYBwQdMvQ8
+5f8u5O1tyHH4wlPTC9JbH+Rn/vXG4mW0loW9TUfvWLvbh2RwVmHHypJfMl/
D3N3fu42LHJ00KqTPHFYp+yUNQYvebmiNLH9UW6S/9Ee0x6DRX3OIc/byNw1
hSdPPVSz8rD/3uau/Hy/6XCCzf4bY39+q8XfeXsKZ751dIy72GBR3/P7TXzf
Cd+F/tz4csx2S4yLsP8/OuLCIdPgFDrYdM0wb6rBYn/A9RunHDGMI+S6ueA7
216DBX+8P2H3iKAJ6dSn5cdbLO8Z/N2MLsOCJmRQ+uZDH8SNNfjZVd92slZk
0aAHMmJttbX8a685v5ueMtgdnNTauditseX7xq96v3Yz7L1Q2ZvDsiatcCz0
85xxfVYj50aDMy+s7Ogcuo+HHLi4IHrFHR6zHp/pij7M2D8lq/0Tw99QT8+s
/GSPabef5wZHJzdybjG4YnOjI6bUXfTOO8ZhY5fBwx8Nv2jMXaH9vVkfn78z
9mv91H6N4e/N+/r8XcsL3s8v6zPJNdHguqP5PXfaCRoZn9zI6TR45JqfJrk6
HifsF2eq/SIhHtNUPFJRwQ5j5dZaHvmPVukm0yVCPHtUPJPwVxL+R8L/SPgT
CX8i4R8k/IOEvUnYW8v7ipKXoX9TpT9D/2lKfwb/li0+/hn8Uzsf/9reLmVv
gr2bKXsT/CdZ+ZPGHZU/kYhXeR5GIv5InI+RiCcS52Uk4oPE+RmJ/TOJeKDl
9pD33csu8yNXQ4KcW/x1aidVr3Bu9oxfbesuU9KTpxMtO/1132hVv7B3ybt2
97RaGpS4q1VMqzvrcMOdLtMs/3s4vCfocvj4UVOq/33C0flNhwfl/KLxcoX1
+4Ng1Z8wfn81PmF8yIH71hvfR9aJsdbqe/2saZlBzqG1PK91777mIv87YOz/
ktX+jzueropxNK/V7wuwnyxR+0kd9zfeOjLT1dHN+6OLLhqdrvjfJceUtIhp
dYUjb285bxjr9blWvwrfeRz1zVxlDZpwQ68LmA9yYv/uUft3mnfujbb2HTXc
7HZGD+vLuQT59b3Q3fOCYHVeQKm1Hz4Q83wlj98QUZVyrkSfF/fpkHTA1LBK
31+t+bFx/ZhWVfq9S5dha5KNcf73Le994d5sOe1/z4L1C+9Xxlbfl53yk0Gj
My9YzWtzOXZobrztdI3mtZ+ajxvTpgXR24t44IgGwfb1VVrutWp+bvrA8rdd
SUU02DKnmXNLFYeN6j8/7nw59/3fY4PMx/33pDmVKeO9r5Qy9Juo9OO09FVf
O/IqtZ4HD2UNDvpvJb3p+Kuf9WwJgz+T4o/rRKWO8FbWaD8JfjSqrX19DY11
PtTT2juXv+kxdWZctf/9tX7PdLPvJ3EuN+84OfM/9j9P8Pr/top3/JCuz0WO
fvw/VnNROs8O7plsCb90p/4fMjQoJ1mfq7/26qeNnUHH9fnbG+r8jeEv+cpf
eM6BJ84axiHtH3url01x2w7R3jldYm32rQwcprA+v3Op8zstP9ZFyL9Uya/r
k0vKfwn6xCh99Lq0V+lDOG8cr84bKf2RtrNdYYe446vkTWnkJvAJ/wWf4YpP
gn1gd9jnNWUfgv3DlP0J5282df6m7VSo4ln72zrlb3re8yq+6bmWUammhFz6
0tEzN+VcDY38hvubx+Xpe6eHuePDzqEFvCHiWi/z8Wr9TrHtpmnh3lnVjPOT
MHV+wg8PzKq3tb3nnncD2xs9Y3cvq2Wcn3RT5yeM+b9W8/M+374yT987Paf8
m+Df2Ge+o86v+b289suiu1Xcc6+dN7neeWNcKXfMPdLCedT//89x7xzq8yMv
l49cWJr4uv8dCN6FXL213Ehsf5XdYy5ZzJ/WcpNBS5MsAy/rdwsDuk8p9Oy6
wn3+mB/jGO1/v3Ha1Dne1s//zuHoqJaNnUPvfc9RrM77Gf4RqvxD33M8rs7/
+QD/fR82l0NbJ+R7dp3i7UvTI13R/vee2zqv3WNK8N8LxU7tetFj2UNjWzy6
2xKTyicGVl42jH33vF+N7HrptCk1jbMLgkcF5fxJ8r1Icl7EYdOkX/X4WDfR
X74f+UL1J+iLdRTyd1Dy63vk+b3WZxqdzhD0QZ4E3/UV39qPeiu+CXzDr8A3
MOyJfRbseVHZk+APODeDP4QofyCcf9cu8J1/E/Jxf5WP9T3XbHVfRnsTfgk1
dy3S72EQL7EqXvR6lqnu06jzvhMDgiYU6fcyqB9aqvqB4l2ffeTKzWb5XgZ1
tagnCPEm39tsU/Gmx5PvjEar8Xjy7k3HjXEFFO55co0jo5o3R10tS3Hf5N3z
X+5mzSnnOuXfPWceXsYjhxw/a3x3i199ofbz6EVVNLD7yrHuqCLOe3XsdsvO
al7nW58KOMt5lU0J1bTi8uPt7fcVcHyryBBrxVnOj+i6OK7vKQ6fGjfNlVRA
s3z+t0/jsQoT1oNlaj0g/P68+j3Bv/sp/ybI01fJQ1gPe6l8QZB/mJKfkE/w
PeF67FP29bc4/KvpK6NHlhH03670p/CQgUdMCbeo7vnmFuvLZWRakX3SlF/C
MwtvZ3lerCTwZ1P80YfdZiyN85ZQ1hefrXXYK/X4o9X4mp9Fih893mw1Hq9+
aPsg88WbtKF5h/lxheXccsHVWEd4GU3OaNnLuvEW9/qs3TPmpVVc6qtPizQu
VJjQP0L1J4wXq8ajZf98uo39jRvU482//WA8Q94rSl6GvvWVvtq+q5V96f8A
OkoVFw==
                   "], {{
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[0.3], EdgeForm[None], 
                    GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxNmgkYl1P2x997788W2bK10GJJmxCpSCqkBSNCYlI0smQpS0RIjV2MdTBD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                    "]], PolygonBox[CompressedData["
1:eJwtl3nY11Maxn/nPN+kfTMp887kfS29pEI0ldC025VmXIxlRIYKwzCbJXuL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                    "]]}]}, {}, {}, {}, {}}, 
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwl1Xe4z2UYx/Ev55CRPdJQSFmlbStkFCo0ZHPSvERGURoaRrZkXaRhnjrH
QVZb51TI1kB2FNlpGCle99Uf7/O+P/f9nN/5Pr/n+V6nfFqvNj1zJUky2I/C
qUmSOyVJamFR7iQpJCfqvVgpr+Gies3RAsvlL/EsVpkP4IF4DkPkF/hFPI9B
eAlD9V/hV/EyBuM1DNMfGo7fxXC8HuiP5FEYgW/l0ZyDbBT3HMWwWn+tXEJd
EinqUnwr34ZUtJSHW9cgPo/383r+lTdwfu5hTT5uiAJ4WC7IG80L85NyIW6E
InhELso/mF8cz6IuzWVwEW6XL+FLcVi91bpD/BOX5Hv0x6qbqMdza7mUuhma
4jK5LI6pd5gf5Z1cPj5f/RW+xjjs1u8ezxzPhW8wQW8CT8SjeAyf6U3BVPW0
2HPsC8v1puMd9bvoiV5xxnozsEo9A4fUT3Fv9MHqOBdUjLvjuY6Yp/BRTuU6
qI37zR/A7/oPycc5G3PwoFzF7IQ6j/oPzsv1UBftzD7Q66D+i+vK1+Jx+Rru
gHn6neWTXE++AU/I13MnLNDvJp/hfLxT77T6gjgnNEKOPB9d1beYp6EbPtS7
UO8cF+T/+A6+E81Q05ov8Dn6IyOeN75rrLD2Z/4Uz+B9pOOTOCOzPfwxnsZc
zMFHca5mu3kZ+mE2ZmFpnLvZLl6CvvhXnsk10NjzNEUTnI17zf9wAV7IXazp
ipvjnuvdxJ3jPVE3iHcG9bFD75T1N3IXOUvdUZ3JneTr1H+rq3NHOUPdPvYX
lqup/1RX5XZyepxz7JG387Z4D3BMrhx305pK3BZXxf2Tr+b7cG/s37qtvAWb
cViuEd99nBWu1HsPB/TPxneCxVgUd8F8Or+Nt+I8sRDV9SfzFEyKO4L5qKw/
nt/EG8iK+4UK+mN4bNxjHMcufy+TS+Ny83K4AhvlDdhufiQ+h5ehduydW1kz
jhvLxeP9lEvweqyLfZod5DG8FD/iQOydf+Pv407y3X5vtHoJNiFN/o7Xxd02
v0seoV4c75bcXc7La+R9vJZ/4ZFcn4uY50r5///BeSvfyI4=
                    "]], 
                    LineBox[{978, 1011, 1010, 1059, 697, 660, 1106, 792, 737, 
                    1013, 740, 1012, 739, 699, 662, 1014, 1015, 979, 980, 702,
                     666, 844, 671, 1109, 799, 745, 800, 1110, 672, 849, 676, 
                    1023, 1024, 1022, 1026, 1025, 677, 850, 1075, 801, 1074, 
                    802, 1076, 826, 746, 1111, 673, 845, 1071, 1072, 1018, 
                    742, 1016, 741, 1017, 1069, 1068, 841, 1066, 795, 1065, 
                    796, 1067, 738, 1063, 794, 1062, 793, 840, 1061, 698, 
                    1060, 978}], 
                    LineBox[{797, 843, 842, 867, 700, 663, 967, 922, 743, 873,
                     874, 875, 968, 667, 846, 674, 847, 848, 798, 1108, 669, 
                    703, 981, 982, 1131, 668, 1019, 664, 1107, 
                    797}]}}], {}}, {
                  InsetBox["\<\"\[Mu] = \"\>", {-1.8, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["0.2`", {-1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {InsetBox[
                   SubscriptBox["C", "J"], {1.4, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["\<\"=\"\>", {1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["4.97`", {1.7, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {
                  {PointSize[0.05], PointBox[{-0.2, 0}]}, 
                  {PointSize[0.0125], PointBox[{0.8, 0}]}}, 
                 {PointSize[0.007], PointBox[{0.4463998339305619, 0}], 
                  PointBox[{1.2771956561278897`, 0}], 
                  PointBox[{-1.0806611991222994`, 0}], 
                  PointBox[
                   NCache[{0.3, Rational[1, 2] 3^Rational[1, 2]}, {0.3, 
                    0.8660254037844386}]], 
                  PointBox[
                   NCache[{0.3, Rational[-1, 2] 3^Rational[1, 2]}, {
                    0.3, -0.8660254037844386}]]}},
                AspectRatio->1,
                Axes->{False, False},
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                Frame->{{True, True}, {True, True}},
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLines->{None, None},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None, "TransparentPolygonMesh" -> 
                  True, "AxesInFront" -> True},
                PlotRange->{{-2, 2}, {-2, 2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.02], 
                   Scaled[0.02]}, {
                   Scaled[0.02], 
                   Scaled[0.02]}},
                Ticks->{Automatic, Automatic}], 5->
               GraphicsBox[{{GraphicsComplexBox[CompressedData["
1:eJx1W3t8jNfWjlIcx6BtSjt1qTZ1xq1URVG61LTunKHa4xSDti4945SqhmgO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                   "], {{
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[0.3], EdgeForm[None], 
                    GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxNmgkclsP2x5+ZebMkpIRkqbTQrpJudiqyV7akJNQV105JdiH7zr3W7Psu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                    "]], PolygonBox[CompressedData["
1:eJwtl3f8V1Mcxr/nnBu/huqXSCSaspIULaWirIzKJpGRTciI9hSJlrSHJLRE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                    "]]}]}, {}, {}, {}, {}}, 
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwl1XmUT2Ucx/E7C8MQlSVkmyYlZM/SWEfa/rMTbdN2TmRpUQkJYyuMapx2
EZIttFhSiUoYyRItRNmXaKWh7fU9/njP+/v5Ps+9v+c+97lnsvIGdR2YkiRJ
vj+Z6UlyNjVJmqYlyXwuLf/FP8of80Yuq9cJ12G1/CEexRrjQ/lxPIaR8hM8
HMMiYwSe1B/FT0WNMRiNUfr5PA5jMQHjY57+JH4aE/GJ/EysBx+hnHVcgLX6
m+Ty6gtxTr6IW+tdi7/lzvJozpHz+SB/zgd4PafwPeYk3AapuE1O4y+Ml+R7
5RLcFhm4XS7FRcYrqUurL+aKqIB2cmW+BMfUX5l3lLdyWb5Rf4K6Qzwj3xzP
o85FR1SRq+Jn9Q7jJ/hrrh7PGfsee4Ip+EY/j+/C3ViLdXgWz8WzxfrxjnkF
eEH9Iu5Hf7yvV4hX1a9hAB7ACr31sVd4HfvlgTwIg7Eh9gc10cS6Dhr/T32I
E7kZmqKbXncc1e8nH+GV8XvoImcbOxbvQX2cU/kaNEcvYzP1usdecAv5SuTJ
V3AfzNbvJZ/ilnL92Au5HvfFm/q3yL9xOu/W+1Wdpm6DHKyS56KPupHxO+Id
4y29UnpnOINPc0fORQc0MecDrMIjMR/zsDLOqbn7Yh/xcKwDc7E8vh9je2Pv
8RDmxHPgPaw29gO/iwfxBmbF+4vfMraHl2EI/pRncuM4m9bTPs4e/tAvwb/H
+eV5fGucazSMb0Pvau6HVvG9oCVa4Hu9X8xvwL3lObF/sQ7uKV+lPqmuyz3k
WerecUa4m1xHfUJ9OXeVZ8R1cbb4O/42ziwOy5fxneZkxb1QC/fJteNadMEr
5u3infEN4IDc2Jwa6kZcnWdgn34x7+Wl3MBYfbwc98BLWIK3UVe/kKfjeSzG
ImTrF/A0TMVCLEAN/ZqYrN7l/idjPTyfy6GasfJ8KW/hL7Hd+HGexIvRTL2N
bzJnIreXM+OsyWV4M4qwxdgRHs+LsBmH4p58mDfFOeYbXDdOvRAb0FfeyJ/F
d4jr5TG8AP/E+5f/5XX4yfWf8n4ey624jPHi1PP/D/4HARnIcw==
                    "]], 
                    LineBox[{976, 1008, 1007, 1055, 687, 652, 1099, 785, 729, 
                    1010, 731, 1009, 730, 689, 653, 1011, 1012, 977, 978, 692,
                     657, 842, 662, 1102, 792, 737, 793, 1103, 663, 847, 666, 
                    1019, 1020, 1018, 1022, 1021, 667, 848, 1070, 794, 1069, 
                    795, 821, 695, 820, 738, 1104, 664, 843, 1065, 1066, 1015,
                     733, 1013, 732, 1014, 1063, 1062, 839, 1061, 788, 1060, 
                    789, 837, 836, 838, 787, 1058, 786, 835, 1057, 688, 1056, 
                    976}], LineBox[{790, 841, 840, 865, 690, 654, 964, 919, 
                    734, 871, 872, 873, 965, 658, 844, 665, 845, 846, 791, 
                    1101, 660, 693, 979, 980, 1124, 659, 1016, 655, 1100, 
                    790}]}}], {}}, {
                  InsetBox["\<\"\[Mu] = \"\>", {-1.8, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["0.2`", {-1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {InsetBox[
                   SubscriptBox["C", "J"], {1.4, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["\<\"=\"\>", {1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["4.96`", {1.7, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {
                  {PointSize[0.05], PointBox[{-0.2, 0}]}, 
                  {PointSize[0.0125], PointBox[{0.8, 0}]}}, 
                 {PointSize[0.007], PointBox[{0.4463998339305619, 0}], 
                  PointBox[{1.2771956561278897`, 0}], 
                  PointBox[{-1.0806611991222994`, 0}], 
                  PointBox[
                   NCache[{0.3, Rational[1, 2] 3^Rational[1, 2]}, {0.3, 
                    0.8660254037844386}]], 
                  PointBox[
                   NCache[{0.3, Rational[-1, 2] 3^Rational[1, 2]}, {
                    0.3, -0.8660254037844386}]]}},
                AspectRatio->1,
                Axes->{False, False},
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                Frame->{{True, True}, {True, True}},
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLines->{None, None},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None, "TransparentPolygonMesh" -> 
                  True, "AxesInFront" -> True},
                PlotRange->{{-2, 2}, {-2, 2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.02], 
                   Scaled[0.02]}, {
                   Scaled[0.02], 
                   Scaled[0.02]}},
                Ticks->{Automatic, Automatic}], 6->
               GraphicsBox[{{GraphicsComplexBox[CompressedData["
1:eJx1Wnl8zNf6DlVtkdZaDFVX0RH0KibFVW8ZXHuHq71XkF4trmtsVaqjWmuH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                   "], {{
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[0.3], EdgeForm[None], 
                    GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxNmgcUVcXxxu/uPntXVEBEwIIUAVFURAyKggqCimJHpPzBhkjRqIhoYuw9
ltgxGrsRS+yKGIwNjbEbbNhi773wnx/fd8/jnLdndvfu3Z3Z3Zn5Zu5rP+rw
3Sbkqqo+alRVCXp+qqoBUZaOclGUHaIsG+WCKAOjLBNllRi3ZJSlKNGOX7Vc
lN2y5lghyl+ic8coy0VZKdoxfbVElN1jzLAo90T/yu5jrv7Rt22U+6K/baVn
rDM92oOjrBClRTxfLcqKUd8z6PAoD0R9xUrrskYr87J8lNam8LOWKWPbmMLX
2qasd2iUvaPsE2Udr79qlEGxzmZRNo2yZpQ1oqwa665OPZ6vH2WDSvU1o3T1
Gsy9kSkydTJ/8NXRY1tG6WL+eGdD9zFujyxZaHfzHPC1hd9nbI8o7aK0j7Jz
jN8yyhZRHgr+1ou+Tf0cOVaL0t1z0Le5+WauXpXGI0tvzw2/my0mX2fzDq9b
+jl9W1kG5N7aMsPvblH6RdnGBV43jtIieNsk6HZRhgSvL0b7hSi/83vwuH2l
MfA/wLSX5+vuuQa6Dx53MEWmIeapL3sSpY/bg8037WHmadsoQz0W3netxAfr
7OS9Zj929Ny0d/FYxj2SJMfwKHtaJngfGnK9Fs9ejXKgeWKdvfwcmfY2RY59
TJFjX1PW3M8UXvY3HRRlhCkyHWBay9rZ5zHSfUMsX1efzWjLgKxjTDmrsabs
zSjzy7iRIcsB3P2QZUSWrOOjHLSY3AebIt8hpsg3NcofopwY5TDLiXy7x1xr
Jcl0uOVBjjZJ9QnwGWuNitIq+o6wPOzlEVkyTI4y0e+N9FpjLAdGDRkmRTnS
ff/H+1m8/z5Ky6w5ZkQ5ejGZjjFFpmNNkWmK94412gVP6yTJ1CFJhuOiTLc8
8LUvOmjeJyJHlPWjvVuU1klne4LlmOJ9mmp+/y/Gjo3SNsaNyeL3pCh/Mu/w
OzeJ9zOjnGU5mO9U8z0tyskei0ynL8bjKe6rxyEf9u9sz8F5ncTaUTpFOYh9
i7Jh1Mdl8XJelPMX4+tEy4EM57iNTBd6Pfj6s8fCV+eY67Sgf4lygfsYd0ml
fvg9Ocb0jNIlytqxbpsoXaM+K55dEeVK03oPrjRFjqtM4eWQeO/gKN3i3b2y
eL86yl8Xk+MaU3i81hS+bve8zPc39yHTaexLlO5RbrYc8H5TlIvd3jipfmOU
6/zeRVFu8dhLo7wbY3pF2TTKre67LMrfTS+PcpspsqL32CRs2WNJctwZ5f2o
v5fE78OVeGKdf1hO5LvbFPnuMUWme03h8T7T66Pcb3pDlAdMkeVBU2S9a7G9
fMh9rL1W1rnA9yOVZEOmOabI9Kgp5znb/DJusySZ5kbZN2uNx6L8y+sh0+Om
yPSEKTI9aYpMT5ki09OmyPSM5UGOBVGei/If04fNy/Pme46fzXb7Wb+HrC/4
OXI8kcTjS1H+7efMNSWL75ejvGIZ4P2NKPPMy+vmj/Z88037Ha8NL296LOu/
7TXg9zXLj9yvem7ab3ks4z4O3j5K4neb4GddcEK0P4vyQfR9E+Vzr8F7HbL4
fb/S85r3/5myzoemrP+R6X9ZyxQ5PjFFvk9N3/DzJy3nZ+5j7Z89jr4vLSfn
s1Xw0yVrPzqBc5J4+8L8Mu5b8wqP35nC4/em8PiDKTz+aAqPP5my9i9en/0A
962ShK92MJ4Fs26NLcnicauktRdG+SppbUBxcp31cxJl/ZJEWb+RRFl/iSTK
HoCdl0/Cxt8l8bQkmDnW/DbopChHRtk2aY6pUbZJmntKlH5Ja06M0jfKr/H+
UUH7J60zGbxlHrc33icOGGCMD54eaOwPrgbzgnfBiL9E37woO6UmngYTrmY8
Dg4G3y+nbViE94kNwOLMyztgceZdyW32dGW3kXkVt+9zvEGsQXxAHACWXSkp
9li2UnywchK+/dXnxr1gfXA0+LmOB1pVzXiANjEEOHvNqhkPtPHabd1m/XXc
Zu12bhMPUGfddZN8K34L+cHL4GZwE5hpnPkAV4O3wehg2PbmBbzWuWrGDHUM
0dXP4LuT34ePbh4HH93dbu05OpnHHn5GTLBaEvZetHYlLPtwUpwAzuZcwdLg
bGwQNvIBz4Wf6W0+wNF9zEdvzwWPff2ss59vaf629jP46FcJM9MHrhzqOfBn
O5nfbTyOeIA6PK+RFDP0r8Qr+Hm7qhkbbG/eB7pdxwMDLeeObq/vZ73M905+
1m0xvuAdzDzY8gxxu6/5HWLZBptv3tvV8sD3bm7D+zC3V0+qE2vMSYoZ9vAd
2dw8IQ/4ebjl2cvtGuuDk98wdgQ313HCPlUzTtjXvI6shInhFwx8YNWME5jr
xCT8DdYe4ucj/QzsOqFqxhv7Vc04YXTVxPc13ofWcQB0vPditNcmBjjU77Q2
XoZP4qKxi+3RWK+BPIf5HXSyo/cJ3ieavz/Eu3sn4W7WAXNOrprY/WjLc4Tf
IRY4wnKyDvgajEpsQTxwlNee6rnq2AxZWybjca8NdkbPiUEmWcY6TmBt8P50
r4vM0/yMWGGa5RpvHsHxxATEIcd7bTAz+PuPSfED8UIdH+5tOXk+I8raSfh6
UXyTFSf80fOCsU8yT2DqOg442c86JuFi3m+fhM3hb4Mk3D3dfJ/q91kTLH2W
5WfMaeb3HD8jPiA2OLcSTgf/XWY+wNXnee0/uw0vF7g9w3ODF4k3LvTaPZLi
hIu9HpgZXE08cIn5ID4gJgA3g3HACM97LvDy5VUzHgDHb5RUh29iAuKBmeYP
DAuWPch4HOwLNgfH32B+wcnXVs2YgXeIAcDMF1XN+OEa792Ffg8ZwMbg5k2M
06+yTOBeMDMy3Op2HQPcWjVjmyss/82eiz7mmVU14wTe+VdSbHCH35nlZ8gG
fr7TfP/D7To2oF1j5aeqZmwAnq5jA9p1bEC7jg3ur5qxwQPm7yG34fdht5Ft
ttu8M8/rIecjflbHBnPMH5gZbE0sMNf8nxHyHZIUK9RxxSNVMzbgHeKhRy1/
HSc8XjXjhCeqZpzwpM/qOsuNDM+YPwoY9XW/D+59xfKAr5+1PM+5jQx1PAFP
z7sNjy+4vbnxOPw9mRQ/vFgpXnjJ8j7ouZ+xPKwJFq/jt7vNN3j6Ncsx3+2n
ze98y/ma+WauNy0Pc7/lNny/7TZ8L3Abvt9xe1SS/qA75wUd53YdG3xQNeOB
Oj740M+6GC8vqJqxwcfmA7z9adWMHz4yH+C4z6tm/PCJefrSz/pmxQa9k8aB
/8DKxAjENl+bJ/D5N1UzNvjWMn/utevY4PuqGRv8UDVjgx+9/s9uf+Z1fvZ5
sAbxCDHBr+btzFh/QlJ8QFyw0OuyPrgbcFzHBrRnGpeD3a82jgfT17EBOL+O
H7JxPTHBL1UzluBZHfOwzl+TYgPiBHA1MQVY+rig2xlDH51FwctHZcUC4PTf
ZcU5faJ9TVK8sSh+qBQHMR/jiBfA8oOS8PnSldrLeiyYeQXj857O34ORn03C
8WD4EUm5LvzXYM7TcdeOQXeI8m/2K+jCJCx7fJSdjQu3y6YxZEgS3gJrlejP
We1dk/KX4HDwBf4YX7xLko/Hv++ZlGsED4CFwEdgIAqYCyz0+6DDkrDMtZ6X
d/ZIGg92YhzPwTnDk/w0Pvoc5nP7b0nrITOxOPH2ezHm6GjvlcQftghfiE/h
PXw2/prn+Gz89T+DHuA2+KSDedgnqY6vHpkUn+A/wUFgFPDJMciU1D7cuUme
n5CU32SfeA4mAA/sFGN6ZcVa1yWdGfnA0ab4fXiBZ3z3uUn2Ar7/lMRH7cuh
+LEDk3w5fhw/SB0fSMGn4wOJBV70mY5PyuHNrDT3VUn253TOMMlPY7/xx/io
Q5P8w1zP3dPzY7fwwVdV8l+8h+/C5+Pv6Ts76Cl+B3/DPPjTtlm2G7vdHR1J
0vlj2bOkZ+2JDZ1jWd/2CRt6vddg/q7WrS9tF7AT2KjDk+oLbc/Qc3R8GueT
1P57lFuTdBLbQSyPPUH/sRnYB+zBtu7DfvR3H7qO7ifrKHkN9PR2zsbt26L8
OSkf8HNSjoD8wCzuZVJuYGk/xwZsGA87Oi+DbSB/gX0gh4+OjLPtIWewlO0B
cTs2Ad1FlzexLexnme6Iconnmp+kq+jpy0l6zn1YKksniYv4TjE0KbZay321
Lg7zfV4G+5YV/9zt+8M9wgagq+jpsvH80iT9JA8PPco2A92bZj0jBkHXlsuK
SdC5dU3Ru7OSdAwcv2KMuTJJV9Z3H7qGLUC3axyO/qA75NvRL+zh8lG/PKmN
rqKT061D6BR6fVfQKzwX+opeoVP/SMqh0+5oWc+xzeYMsdPkxuEL/b0h6PVJ
fog7OMF38tSgY5NsEbqCrqHH6B66hB4tSNLPmdY/MDT3HT07OAmnokNgNvTo
wyT9nGs7N8bzoz/o0Qu2wZwVNhg9I59V6wS6gP/j7pMP40KvlKUnE32PJvsu
3RTlxtT0qVDu2i1Rbk5NHwlFX15Ksjk9K8nd3bxxp7hvrX2Gx/hMsJfY7nV8
/twH7gj+DV+LzpHHwG+1MH/w2dd38wTfT3wo37zRD3wKsXob3wu+x3TyeWKb
sEvER9jWzj5jntV2DtuFDUVXZiT5QWQ5zfJg57CbG/scwNOcD/bnTJ8/cehZ
lvWHpBwitgS9xz5wj7AX2I1a79FZdB29QY/wj+jWZUn3/c0k/4fvezvJl9R+
5ErXueuXe8zrSb6Webjf3HPuMvflVJ8L53y97wL/YbjNPE7xudeY6ib3TfW5
cxfQA2wathAMhg4wH5gHO4uNBUfd4vf4L8Qsv8cz7DB3h/9L3O794P8Pd3g/
uCN3JuntsVn5n+H2j9ggdPLepJxpqoTDqJOzfNrP6Oe/E9Sxw/cn5UaxpeQn
qYOzyMve7/5Hk/JN2EP+X0E/2AzsRZ6W/Ao2lxwgubSNjbNo8/+KB5OwGZTx
y0R9dlLekPeeSXq2jN+lf91Ktny2x2yfhc+Qub/3Cx9EP7z19/qsSw5y/6xY
CJswMOoDsr5z7mJKTL9P1PfOzfgWin9+PCnuvcNjqM/0nPtlxVftTImv8BWP
en+eSlqX+AucdpfvGv5qnvcTWZ/1njxnnpH3p6Rz4ozAqzzj/yHQ/7jO3jzv
8WBYMA25zW2Mb/Bl5PnRLWIKbM/L7h8TDvbWLFsH/gKHtaj0bWKQ62CMDYwz
ermf/DS5X/4X0sE87+gzBl8Pdj9r8T8MbB35E+YCqxA/ELfU31WIp4hx+P7w
dZK9/SbGLhNO5Iuofxnl8+RvSUl9xF+M/crjJ3gcY3qbty2M8eFtVe8rbe4D
+J3/UpAvrO/BGZX+W0H/7j4X7it39JisnP6yvuPUuefQPd3PPNyrGZUo94z8
2xzfS+7qGuYJfhb9xyMrvqjjjf7WQfQK3VvoPXzBe/CZZWzpO8z8vLe93/3M
4772HrNHC71X37jOOXAe71byhdTJG/Cd939R/um+jz0G24k9xX6yX+wReAk/
/E4S7uSOf2j9wid/kOSXKeRKyJOAucndkU9KGJusmOvQLBnrGGyh7zBzvO95
yK++6nXBye+Zz/c8hjp5NnJu5/p8GU8e+L/mmTP9Mej3SXcemwcGhRX8/Le+
Szz/wTrDWfyaZN/ADp8k7Rl9v7n/F+sY+sW733n+7zwX8+Cv8DetzMt8ywLu
eysJo+GX8GF17LaecT72Bgw0s9KZfOpz+cRnBD/4Y3Kjl3kPsGOMh+7j+uZZ
uo1eb+p6+0p6gj6z54Mci9V2gHeIl3t4HGP6eHwH69oWnoe+Pj5T7nm/rG97
2I6trPvkaqh/Velb0qZ+l3iFnAAxC5QcwW+V9oHvytjVnvWclfS7t3mAv96e
5/ugyzWE6bYM+lHWPfo1bN351pcPov54lp/pGWM2ibJCtEvQ3ND/Jn6LMe9m
xYQLgv5UhMGfjnqjKFZ9I+rfF2Gsp6L+ofvXDXpIQ3j0q6i/mnUHv476f7Py
Bd9G/Zuiby9vRd93RViPvenr/TkNPS2KZz4P+mIWfiQXtLX3h/U4L+KdXrbN
1Pk2il/nbv8+q00d3883U75VggX59skdbud95r71yIo/mf8+jwEDgB2YZ3nP
SU6HubCN5Hr43onP5M5dXem9/p4fW8lzvlWid/B2j+/srll2oZvX/dV2ApuM
X97FY87wfd7L83f3O7+5Dt+ce+esPB02EEqb+HGjrNj4K9tJnuF36nu5oJKv
wz6iX4zt4vHkUYhDyaUwV0e/C93Q/fhi8EqNO6jjl9EB7i74aBPXV/d9pk3e
inuPLF+Yl67WBSh8ox8EVakhm8v3ndZZMd/krDbfjaZlYcERvmd8JyZG5jsO
MSfx5nF+Pt7jGQNWqePStn5vpPtPDHpC1jcYMA6YhxwyNn9/92HXRnn+GVnr
UWcsY/ALzEs/sef0LD74TgZeGml+j3cf35qw46yJXedbG7kkYlvoBMsLb+M9
J/6JOu9BD3I/vgUf09O28WCPQbepYxuJCxjPHJXH44fI9R2W5U/wuZOyvpWN
Mk8HVsILjMG/TDSfk8znRJ9RK9fpZy/5psb3K74z8s2P+Zj7CM/PHh7vceQ5
yHfUezzaZ0o+f2qWbYTSJmeMXqKf8VuU25/i8+rg8S/brh6Z1Xegz2K87Qbv
otd1Dhdsw32Y5ntD3zHuH+46ug2eOdZ3ZoTvIfHIsX53D/N5pHke4XXH2TYw
LzEK8Rq5A84HPpCn+N5O9/hxvpPs4cjQiYVZuSf6TvS5j3d9nPd1kvefOUZ5
nkXn6f4xnvOPrh/vewid4fs8yjwc6HK8+9cNHlYrusujo75iUbzSyvNzd8hr
HeVzGes5WadfjE1FMTp2Dnu3lu/pIb6rHwddoiF8xl0bmps5aCg4Z4ms+0rf
erY7/DeBGH0J9/O84bt6mMdTxw+R8yIPQV6EXBa5LuJp8lZ7GiutmpWzw2bx
vxxsGrkE8l+894D7id3w1YtsXVZfC/cTl5N7QueIv5f0HQcXgxvW87uL/htU
CeOB+ciLsj/4DHwBOspmotfYQvYa/z7ZZ93SY9f2+AHum1EJW6ED2O0jXX/J
9anWC9Zf0zzgG9t5TB3vEdPB1zpZuSUobbAo+HGVrLxGR8/3vv1se79LfgXc
MdIYD5yG/+S7JN8jiT3BEesVYYneQT/Iys0cGv0bF8U9u0W9TVHeYnLQKUW5
sUHRf2pWrmj3qF/md78O2rc4Rxz1rYow2qFBDyvK820U41sV5SLHBR1flMsE
p7yZhVWGxJizsvJPzwf9pCguPSvoY1m5mi2i/rLHgKHezsJRm8W76xTl+8BN
4CqwzHJRfy4LQ74S9ItovxL1wUHXLMpdPRv9T2TdwaExz+pFua55QTsUxR/4
HfYQuzc8xnQswu8tGN8Qfh/NPhXlpfaPvk2Lcn+dgn6RhYU+D7pUQ5h7o+j/
Ksv/vx3177LwxpFR/ykrR7Rk1OdlYdIXgn5aFJ/DCzzhB9+Pvn9mxfY9is6S
czwp6n8qyhltAM8N6Ubbov1ir9izLb1vw4Nu3lCurRf8N5QPPi36Ty/KnbUI
Orcox70ycmflFVaL+qoN/efuw+jr3VCM0T7GbtFQvvU17EdDsUrLojvBfSCe
5UyIN+dn4Vp8N+fTpaEzOjPqZxTlq7hHg3yXesTz7g3ltneOvm4N5TRfz7pn
3LEZYOqiPOBK8JgVt13A3hTFUn8IemJRzuzmoDcV5dJuDXpLUY7txqA3FOXn
ZgW9rcjecJ5b+0ynR99xRbm9d7J0gPvPvRjX0N14LysewB/9luVv8DV3RN/t
RTayHWsW7dv1Qa8ryvm1irFrNWSnTom+k4vyeasW+Qz8RWvmK7JjbaK+fFF8
/Dhji/KbN2XdUe5nH86hyM7gE7ayX/hflv6j+ysU+SF8ULeojyzCycjU03ce
p7pGQ3Es57aG9euHmGeFhvIFOwY9Ocs3tWwodiJuattQTEI8ckY8vz0L654e
dJZt5tLxvH9RjMYdfMz38Fx4L8qBPRJ0TpFP+XvRvrAnw4LuXpRrPjvmuyPr
vnVoKKYinlo5aLuG/NnFUe6znWfNZb3uzvH8zKxc9YDoG1jkD0+Jvtvsj0r0
bVsU8x4U9F9FeWX0oJ3P9BrsSZHd/lvQXkU5g+1izGZFdn5M1NcvynmfHfSc
opz1LfHuqKLcy3WcY5Hf6Rx0RFF8MZV9te3CNncvss83xvgDimIZeFzCfP4b
u1SUR2Lv/+P9fxSfVpQ7vivonUX+tk/Qh7K+JYKVNi+6w+zBmg3tA3ZrmSLb
hU/oUuQXOM9nfKbY3Vxkezcokhl5hwW9NOs7wNVZNhd7+1aMebMoDzo7+hcU
5dPnRP3dolz560HnF+VZL8qK1fHj3JFHfU/2DHpVVg6Wc/irfegjQd8pysW/
EvTerG/X2OmuRbb6QWxt0f9K0JuZtY+O+o9F+Rd87F5FfvaueN6pIQzE3l+f
tf+czzyfEXft1aL7th82ICtmnBj1+7Ny8JztDVnne3nUryj6xoBv2bDIvwwN
OqToewj6cb51BHuwdkM2Ad29OUt/D4n6PVm55EuifmlR3gg7cbFtBffrWmOb
q9mrou+R7P3d3v9JRfvCnuwQ9fYN4UD28l7v51PMU/Qd7smgF2Z99wOrYhew
CZdk4Q+wx1zuVxHOfTILf4A9uI8P+k5uH30DGsJG52T5b3z3VZxLUa5xYPTt
0BDW7NvQ/rK360X9xaLcer+o/66h73Lo4jYN6WP/oNs29H/2lYr0H90Hg4BX
wCFgKPAQWIg7eL/vIXo827qMTZpmu0Q+CX+Prz8P7FH03WXtonvPnQc7jC2y
zw8HPabou8T/A1tQnlU=
                    "]], PolygonBox[CompressedData["
1:eJw1l3cYUFMYxu8555ZKW0sJbUIaelKhEgmhssdjhOz52HslDS3atPewGiSE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                    "]]}]}, {}, {}, {}, {}}, 
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwl1XfUznUYx/Gfx8hOSBTyyCYyKjKyokJ/dI490iMpOmgPmXmyZxrqlL33
KjNpoJKtosiWmVGU/bpOf7yf9/W5vtd939/7+/ve50lN6/Fk9wxJkqT70zFT
ktxISZIHMybJAs4jX+Oj8re8hW/Ta4xHsU7+Gm/jO+u9uA964x25H/dH38gY
gIH66fxu1BiMQUjXH8rDMAQjMDzm9EfxaIzEenlM7AffIJ995MUG/a1yfvXt
SNQF+GGuiwx4TB5krp56KJ/gH/k4b+JM/LyZjFwfmfG0nIV/sp6Nu8pZuQGy
I03OwdusF1bnVBfiu3AnGspFuCj+Uu8yd4Z/5lu5mf4IdSN14zhf3K2Xh4vF
OXMqF8d59W6z53gPl9TLH2cf54L3sFe/Cz8X3wUbsBEf4qPYP7phublx+FT9
GXqgJ1bpjcdk9RS8iJewRm9TnBem4U/5ZX4Fr2JznBGK4yH7OhHnySc5M9dC
TbS2Pkmvufo015S/jM9DC73S8hl1ljgvvoXroDbaWZuu11p9jmvJ5dFZLscd
MEu/nXyBa8uV8KxckTtirn4H+RLn4AN6F9XZ1XXjvmCtPAft1dXi/fEM5scz
07vKufkKP8KN4jnjATNfYS3einnMi+8Xd9XskThHvBn7wBysjt+QtcNx9ngD
s+N7YCXWWTvEK/A6ZmJGPL/4LGsH+Qu8hsvydL4f9eynAerjP/2c/C/n4nmc
ZqYTqqKLXpW467gPL8iV+R9zWdV/x93n2fxU7IHbyveqz6srcBt5RpxZ3A9u
JZdVn1WX4Zby1Hhd3Cvez39gH07JpeKMzZSM98I9cU/lEtwqXo+J5vby7/gN
x+UaZlLV1bkYT8UR/et8mD+P84jniIlx9zABy7AUlfU/5k8wHkuwGBX03+cP
MA6LsBCl4o5ibOzD+1+IvfACzhv7tpaPS/Au3olfrZ/lUbwE1dW/8BNmRsYd
knPF85Bz8w5sj9daO83DeTG242Ss8yneGr8Pbup1w9SLsDmekbyFv0eK9cfl
weqFuENdEMf0N8rb4reMH9RN9IdwHfl6yv//D24CUzPKQA==
                    "]], 
                    LineBox[{982, 1013, 1012, 1064, 692, 656, 1103, 789, 734, 
                    1015, 736, 1014, 735, 694, 657, 1016, 1017, 983, 984, 697,
                     661, 848, 666, 1106, 796, 742, 797, 1107, 667, 853, 670, 
                    1024, 1025, 1023, 1027, 1026, 671, 854, 1079, 798, 1078, 
                    799, 826, 700, 825, 743, 1108, 668, 849, 1074, 1075, 1020,
                     738, 1018, 737, 1019, 1072, 1071, 845, 1070, 792, 1069, 
                    793, 843, 842, 844, 791, 1067, 790, 841, 1066, 693, 1065, 
                    982}], LineBox[{794, 847, 846, 870, 695, 658, 969, 924, 
                    739, 876, 877, 878, 970, 662, 850, 669, 851, 852, 795, 
                    1105, 664, 698, 985, 986, 1128, 663, 1021, 659, 1104, 
                    794}]}}], {}}, {
                  InsetBox["\<\"\[Mu] = \"\>", {-1.8, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["0.2`", {-1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {InsetBox[
                   SubscriptBox["C", "J"], {1.4, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["\<\"=\"\>", {1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["4.95`", {1.7, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {
                  {PointSize[0.05], PointBox[{-0.2, 0}]}, 
                  {PointSize[0.0125], PointBox[{0.8, 0}]}}, 
                 {PointSize[0.007], PointBox[{0.4463998339305619, 0}], 
                  PointBox[{1.2771956561278897`, 0}], 
                  PointBox[{-1.0806611991222994`, 0}], 
                  PointBox[
                   NCache[{0.3, Rational[1, 2] 3^Rational[1, 2]}, {0.3, 
                    0.8660254037844386}]], 
                  PointBox[
                   NCache[{0.3, Rational[-1, 2] 3^Rational[1, 2]}, {
                    0.3, -0.8660254037844386}]]}},
                AspectRatio->1,
                Axes->{False, False},
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                Frame->{{True, True}, {True, True}},
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLines->{None, None},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None, "TransparentPolygonMesh" -> 
                  True, "AxesInFront" -> True},
                PlotRange->{{-2, 2}, {-2, 2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.02], 
                   Scaled[0.02]}, {
                   Scaled[0.02], 
                   Scaled[0.02]}},
                Ticks->{Automatic, Automatic}], 7->
               GraphicsBox[{{GraphicsComplexBox[CompressedData["
1:eJx1W3l8jNf6jypt1dguxVRDa+kIRXPF9lMPBpfUZagqGoNaGpkWVVRctVWH
a2ktoUovYquiia2xjTzElsQWWgbV2Ca5kSDJxJJEMvPTOfmeuZ+nn8k/5/Od
c97zPt9nO88578nrH43vP/q5oKCgSc8HBf3Zzhk59lBYzH95/pjfH8XFlvCZ
vU3qxDhvatyscvJdV9hvGhcerLTY7j6osUNhAq6nxmt8XM2n8TT1Po2/GP5k
lsPu5reqdmhkNRdxuxo7rE7LA40hHzDkA4Z8wJAPGPIBQz5gyAcM+YBbKXk0
/lzJq/HFfav6GzIe6RZ8gMEHGHyAwQcYfIDBBxh8gMEHGHyAwQcYfIDBB/ic
ajUGT8kLWLbgCwy+wOALDL7A4AsMvsDgCwy+wOALDL7A4AsMvsBNFV8K5JfS
rpK3bMEfGPyBwR8Y/IHBHxj8gcEfGPyBwR8Y/IHBHxj8gRGnMg6lH0s7S97A
soU+gKEPYOgDGPoAhj6AoQ9g6AMY+gCGPoChD2DoA3iu0gcFypsyT8k4l3Eg
/ULqRbbQDzD0Awz9AEM/wNAPMPQDDP0AQz/A0A8w9AMM/QRaR2TelnlP5gUZ
J9JPpF7AHxj8gcEfGPyBwR8Y/IHBHxj8gcE/0Lop1ymZ52UelHlBxgX4AYMf
MPgAgw8w+ACDDzD4BFr35Tor1ymZx2Vek3ENPsDgAww+wOADDD7A4AMMPoHq
FlknyHVWrkMyL8u8JONQ8pQt+ALDP4HBHxj8gcEfGPyBwT9QnSbrIllXyHVX
rkMyD8u8I+NQ+q20u9SLbKEfYOgHGPoBhn6AoR9g6CdQ3SrrRFlnyTpErsty
XZJ5WOYl6AcY+pF+IfUALFvoBxj6AYZ+gKEfYOgnUJ0s60xZh8m6RK7Lch2S
eVnmNZkXZJxIv5B6kC30AQx9AEMfgfYFsq6Wdaesw2QdItdduQ7JPC7zoMwL
Mg6k3SVv2YI/MPgH2jfIulrWmbLOknWFXGflOiXzvMx7Ms6lX0u7Sp6ylfsC
WSfLOlHWRbJOkOusXKdk3pZ5Ssal9EtpJ1m3yjpN1i1y3ZfrplxHZN6UeeIP
3/PZfM3XFvNtX3uN2/jk9vBdH07VOMj3l+gAPq36Cfiiel7jS2p+wvyNfPI9
5Fk+OZ7o+gn9DVQ/oR8tnpuuMAHjOfC4rLDmBTnAq7XCFIgnfkcrfwd/OV8g
Pb3pk9Ol54F9gdGP8dAn+oHRX1+N1/3QLzD6MR7yBbIb3g8sW8wHjPcBY/5A
fgA9AcNfJS/0wz/l/OgHT2Bdp5dh+APkhD8Aw5/gZ/AnYOlncpz0M/meQH4h
7SD1JnkC431yHws9Iz8AQx/A0Dcw8gMw8oOMV7wP+Qt6RYu4BW9gzAM5wSOQ
3Ghl3OF38JHxh37MH0gP8G9g6EPGl6zjZDyhH+8LpGe8T/o5MOYDxnyB7AS9
YR7oAf3QBzDmC2Rnva8XfoZ+2Bd2h31lfSjzLNYT+Rz8Sa5v0m5Sr1IvkpeU
G9jus5+T0U7zrbe3OdT33HE+46sbMgj452qfHzWmPqU5Pvnu6Ra/L1CYdynM
6AdGi3HyuXd8cqVzmk/ONH7l0J98tmn5aio5tDwmX11wV2PIj3GyBR9gPA+M
9x9V79f6+UK1BHmAJU/JC/Gh5SvDeF/lyJrLbSav7gde67PjNv3+st+1XoDF
c1pfwJgHWLxX8wQGL+BA7xHzknyvmFfzFfLL5/6iFyEPBdKDfD/mEfrT8RNI
74gnaQdgxBew5Il4C/A+FvOzmI/F8zr+pFz6nLSsX8ol8yvyFDDWK+RX9AOj
P9XHL0/XlcDYJ55UWNcJwOgP9Bzw86M3DHIbiznz8PRTXm9uQDmBhznMIebo
Uh3naGEnvB95PhAvYMwHPQbiAQx5f6j0bW9TfD79pp7Tck1U8uh516txf+EJ
nK6wnhfvxz5t4IELuSm2Qu6TMOwXi7VAP4d5UWdBn9gnAQep8YTxwFLf2Fch
n7VSeVFjrFvgBd5Yt2AfrFvAEWq81hMw7AY/R/2AuJZ5D/bEczLesd5LO2A+
5BHEOzDkhz9AfmDIi/mA4S/SjrAH/AX20H5Zpn+MB4Y/wW6B7BrIjsB4TyA5
Ar0XGHYLZNdAdgSG3gLpNZAegeGHMs6lXXXdXPa8Hl+2vgKDH+yE8wTEWbiK
K0KcYf8CDD0iHvur3wnxCJ6QG+s+4kfXeWUY/Ygn+K+s7+H/8Fdg5H0ZH/gd
616gdQb9gdYd6Ae8oR/whn6AYR/Uk7APMPphL+gR+oceoW/sJ9HiPA74J0O5
ebGOx/x0RKvgaMMjnZeRP1BPA6Mugx4xHvkC44ExHnpCfoRfIR+iboT90Q/7
oh88oVfwhF7BC3oFX2DwfaL4artgPthBzofzPuhps5pH+zHmgf6lfWWL+SAH
5kN8gRda5CnoC3lD2hXygac8V5B6gRzohxyYB/14Dv2QG+Pke6E/2BF2R34B
D/gP4gv5FOsR5oNepZ/jPfK9GAc5pd0hL+wE/cLfoF/Ih/iGfPBn7Ic1v7L9
pfbzsniV6748fwTG+gO7Yx55voR9J+ZFnsA88rwJcYl5wUOeu6KeA0bexz4O
45EPMB4Y41EnYDzqDYwHxnjYG+ORPzBe1iPQP/qhH/SjHoF9Ead6v122vkBP
4Aus7xOU5S/wgT9gPDDGQ68Yj7jCOGDkG/ih9Fv4CeplYKy7WP+k3WAn6W+Y
B/tp+AHmw+/SjzGPtD/4ol/aG/GMfmlfxBP6YU8ZF5AT8uG914KD8uNG+Nfp
yOP3T3n5f9blcwU7wo771+H5IzYus0V6OTvr14X2DTnab2Z5P//A0LjgL/e4
In86cc5746mOm4neSR1MuU85sdlqp/fGY51vawwsetew2X//LfzHfQvtu5/q
c6qIHl92N/Qr1fuB9JWXbrl+uaJ5xF+c+rb12C3No8+KH7qZWmbqfMh9Phnn
qHhf4xZ9vkv2DvPvV/E8eON5+d0z78aQUKs5Vs+Hfswn7wUtKunV1lz3JEFe
eT9hzeqRRXGxqTq/9+7071vPdu86Dja2GbfCHnpZy/nrwFpNrV9dJuhD3vOs
krX8desx/zmda/uIWbHTswn6BA/oW96z7JZ6McdlKCDYB+sW6vRxnnu/WKoU
6HVvTMlzQfG3HhPsj3F47tjsXmZTrn99NwbfaWU+UETwH8gJOaZubDrJcdL/
PW3v0Fr/ip1eqvUzpkbBCtv8Uvr28P3JjpNZvGT5a++5O5Ty49NHilJOu3nH
tPL/sc0v4pvHj7Uxj36s2wrv7ZjkmF7EfTeNvWA84ubW3eNW2oJL+UqDqqVx
i7P45XI/P0zZfkm37siWi2M7HuOM6q8ZYmo7+eZP/YcYvr7Fp94O62tqeYQn
HL/ncj3KpO57cjsbMphNUW9cdr3vpUFPP7hgTE3iq1W2XzRWus39sv+732Ld
Rcbt3Tda1t4nwxznLov1F7q+pEOUY4yX0F9nYfMZsY7tlPYgfIozL43SWi7f
E/Z8CSVvevWaq9Z92rSi2Upb5H3qZFpTPfqtEur1rytdTS2dXG9Du/y4Ll4a
P3Re5WgDs6Ng7jpLopdWL3H3NYzeR13+b/vfTae8tGjhxIvGkIvEQ3/sYvjS
S8dzRy+ITXPxxw2GVoku7+GBc+qf8Q77g//W7bO4sHse3tFoaqJx2h+045MX
bA63h5tkNaoQX3SHOswa8okj1MNj3vvqgKViPneqF5eTcqyYs38+MN659SF3
r/BhF9MLhdwhfc+HhsN5Ok8ZXYdzXZfyqEV27ChnXjGvyIuoHhP/kAr+4bnt
MhTqPBCl/Ik/eqfJWWPII72eH3l8YawzqJDHrGu1yr7hId8d+e+8lPKFtLxy
VnD05oc67/RU/stLLrgnOqYUc821nUKt7+Xz83WWjXZGPttXfrCOzCPyOelS
laK4C8WUcD5kriMhT+f9V1T88OVdpddcK0p03m8V/EKi8WAphz6s3sw6MoOT
vmt/1bWilF7w+UsGX1h/pZ/bXUrDm76eZpx2h8/1yBzqPOLh7osL/m3ffZ3d
azdWji718IN5zS956QpHblpsc2zx0M7yS48Yw69z10kJTc0pf/Bvr7x9x9s3
jYd/tz3K0cRLr0/8aoozLU2vI9tUPuFBydF1Y2r7vz/ebHarSkztk5T5f1sK
U2wbNR6nMDV4f8UAwwkXLWrw02BDxlItT7qShyBvmJKXIM9JJQ/V+rrXvRSb
/ztI/LVfpsb+5qHsVXcaWe9coRdHUTdDBQ8fj3+w17L2DkEfg5Q+CPryBvn0
RZNu1Ex3XSrm4VdbjXUfzKOH30a2N80r0d8ZYJ/dyj4E+61S9iP4w0fKHyj8
B+5sGubfJ8Afuyh/pFFD2k13tPHvU+C/HZT/Up2gXqUpp/O4UcW3Jjoyiwn+
GqL8laKizKfC0vMotMKDP1w5xTp+Rqv4oT6L3VtsWXc4uX+Xw8YQDyGeaqh4
IsRPOxU/z+Kw5ir7bheNuvv1PHsNj853CSrfcb916/aGfZKj/RJ++KDLhU2W
RP89qUiVD3W91ftU7ayU0yW6XvLUDlpniyzkpK731tov5uk6Nf3xw7/FtC3Q
eR96i/hPj9uuyYU67nbO77nbEuzfv5xS+ZyhT4yrSVtibVmP9boAPVtP57xn
aPyIgyJWbLEkPv3LPQFrfsuX4xfn6fOKzgerfeGclafPJ+6p9YvhH9BDz8RK
bUzjPX/5jvrKttuTnI5bet+/u+BspNt9U9d3/Xz5+SI3v/nnOr5U1w+oo4Of
VlttX/arrgMOqPWZ4f/ye/2uEytbWc1JGi9XmBCf8ntfV/V+wvvl978q6v0E
fvK7bhXFT59jbFP8CPkKckDf8rvvEKVvfT7QUembYpcd+NA9pPAv9zZ2KPsT
7As/gH2HKPsS8rW811Gs/E/H5SDlX7quG6XqQ8J6Abng//J+S7byf13HjFP1
JMG/5ffKnioedD1WrbzDaN3o/95oeyXZlbLdQz3403DD19k8wNX0O9uVErb0
2nwgLGY/zf788OO4189QjX+GPnD9EksTk8r1NnkvUI1jT0c4J5TQwXKpe8MG
5BDWo2/VekRY33LV+kbrz3bZFTbgPnfs1qS+tWEJZ+0dF2q+mkWdq1p3hXUr
5TOvfpMQNiCbqiTUHeHMK2Gs913Ves/rq4xaY7/opiGHt3QyfVvEqfXyU41R
z+yhWg5/5BjsnlZEq3pMS7AkuvnKtai7KS+X8LXi1O6Gxvf5YsUmmy3flHD4
tMktzHVzGPVFmqovGHySFB+u99HUdqaqpbRzyMbOpvFZXP1eg4GGjD3smjmn
rbnoEqNeuanqFa2vdUpfDH3NUfriPmkN91msSfSJavmH3+0njdlZVLHT04nO
tCQu903Vj51L7tK5ahPTvd4kXW/9pOotwvNoUX+9pOovwnxZ7/jmI8y3U81H
qOtKfOvPJQKfy4oPoR5MU/Uggf9WxZ+gz4tKnwR9dlX6JNSX76r6kmCPGGUP
Qh16XbUE+6FF/bpV1a8Eew9U9tb+0075j65/F6n6V/uvRfkvwb86Kv8i+Fcl
5V+6no5S+w1OXlPFZD7gv0+F9b1Yre+87CZXjr7voY3da2+wbb3MEy6cT/aS
V+fDqW/ObG3q66WVLwQ/SrGd4LzJGwcYDvvvL6H++KG+r/6gSWeLVtr7Z1CV
ndMbRht20+N6c5K9Nq//Xk1o5UPGKC/tnFz9m1jHBsL7kE9RH9VQ9ZHGE56k
HLCkpxH44DwD9dZ6VW/R7Vd3mw3veygq1tjHdP6m5l3yVl5rU1U/L8+Uw+ss
a/1ynejV+uXos345dsw6Nte+wavf80GXEs/y2l45H18LP7QjzHWDM79f4l1+
zMOifueK50Nbm686+V5Sj/y49v7vTmXv5zvu+ifCal7kZfv6e5Z/4WXLtRVm
w+hz/Hjw9ry4pV4W9T8vC/5snc2UzIMWpIx1bPF/pyqTnz81J71pNe/jqDam
LoYTXn47o0KlGOd8Nu6OXGc552Wxf+Ax+/88P5hPE4z/+bvpvP+7Vhl/Np7d
09WQkUiJzd+IcB7xcsumnsZWczLtbLbmoHGbl8X+g5MXjX7Vaj5Hm0buuuRa
4WWhP5414V1HWE0npbp+X2br6eWBJ/fkpeQ46XjQx+stnby8c3Z4E/OBG9T8
TPNYyzkPWxpl93VX8nLMgCNxlmAnw74TlX31OQf02rn40TrLDC+vnHZojsN+
lG9Pio9wTvCya+L6Nubok7r+nqn8idfnT4lwLvHrce3MjndSFnp52OWKvUzx
e+h046VNzM/sMKNCZgdT/Brt3+HKvxn7vcVqv8fwb9MUn39r+aDXprFFEc4e
Xg77/hCZ+12gsvjiqvv+tSy2Yxphv9lB7TfRT1NV/JFjqNXqnO7hA68l1YmZ
eZMQvzEqfgn+6FL+SMK/SPgXCX8h4S8k7E/C/iTsScKeWt6jSl4G/+6KP/IL
v6b4M/S/Rumfof9xFX361/adquxLsO9JZV+Cv9iVv5CIPxLnYyTiicR5GYn4
IHF+RsLfSZynkdhvE/w7RPk3TZj6M5kH3+IXJ413xy311701VD3DJ0sL5jjG
3KKEhBoxtlX+uvETVd/wzds159n7e6jRwMJI97WbvGjPl/FhA/z3+frk9F5u
e9HPG98Xss/llMTF7tc4TmHCePDA/PXU/IT5IQe+19ZZO3KDJdij7zn0SnBb
nSaPvnfROMZdGHerWJ/zzqnbvqMpt5gT95f0Mpwo1uOwfxyl9o+8qfirKtH3
S/V9DOxHz6j9qI773ckv2pwWJ/dtdOLGsyyt49kc8XtxSrPb3PqL8GZW82Zd
X05V5320eth1u33iA70O4H3ggfOBEHU+QPY58Zkp35VyvW4TThvfyCTID144
n6imzidoVETDWtFvFXNJuWovxR/N1/eDzKPqdDW8478PVIl+nGvf7b//Y4w+
fTvltP++T4/0qGW2+V6a/FJGUPyITG6RMbZczL5SrpXR/WN3Wj5H0+DPHR2L
Gftdk9rv8oJ395TEHS3kOT27JIXtLWDsB1DH4/x43I4a39vfeMiQN+g5n7xc
ecrgrZbEYn0voNKhfseNIcW0bXin/ZbEfG7x3vlm5u9L2OSzbzZDP42Ufnj5
kWE7w34r1X6SMXlTW9O8UnKFDPnUGZTJ8+tcftN81X//O/PVxb8aF1zgCb7z
ost85eiLdWM+SONvVJ7h6+nG5LBRNzlk5O+9DY1T9Ln7VsNzUQ77eX0+h3wM
++9Q9uex9wcXpNhOans/qNfuufjYE0QzR3/htOxk4PIK6/O9Xup8T8sr7ztv
Uv5HkH+Ekp8gP/Ikzh+d6vyRSr/v0d5cdJyX1du23B7qJOgL/gd9XVf6ItgD
/gZ7bFH20HZ6XcUbwT8mK//Qz81Q8UfDbac7ma/m0/ET6eGG7v77F6+oeNb+
1lz5m5brHyq+6VzQmMNhkzLp+vBtw5xHSqntgtl9DZv99ylwfpKqzk843cf/
jt734rvcD/djDdGfehjnJ2PU+Qlj/nQ1P5d0/vRnS7r/vgXOn4PV+TM3WR41
yRnk1t9tcL7TRp3vMPgmK776nHy6Op/mFh8OGGyo5db3N0LHDx5oOFFAnSae
XmK/WMhN8jpe95L/vsb8uZYDYccLac7s9BmOBP85+UR1ns5D6u96KeaFIv3d
G+dZiD98fxufEf++ofFD/ujrJQ2tG/3/P497MlXKf7fNdiWfG40f0t70bQnV
O/Nizeiz2fxV2MBq0Rn++x43k/aGmNv777Xgnkv19U1PG8MzuUfvNIcxysPZ
pvG/GSvd4kZj/jnPHurR32HHfHgkKKa2/x7F/nZfHjKG+O+L4P6GZ4upgzna
f39kt/qewfDn9cqf/ffD1fcNrlz9TzmjObdh28+cab/y5tXzI5x2/3eqhb5z
mYN0IaTtMWNqKjvGtyhJsR3VeTJx4/L3Df9z3wTfxdb7/Pmgng/rNMbL+yij
1HgCP3kPMk/xI8h7Q8mrv7tPotbVYj64RNDnbaVPgj7h19AnMOyDfRrs85Ky
D8H+8EvYv5KyP8EfOyh/JJz3we/wnbS2Lz8WEfwVfoZ6o6KqN8i429zSWv4O
y/szd9sdd8eN8BDqj72q/iDEr7x/s1rFr54P8Y35ctR8vOGzx9kpzXII553z
myfstSQW8JKWptyU04W8es2pvLjZubxoZp2B7gVPebWvPs+lJSF5C+3LnnLP
JjunOto84dXTblSNmfeIN3T+rELM+Kd07rXovu7wXB4e076Vue413prxeFFs
xK9cMefWOe/5HOoQfPufptwjGtdTmLCeVFbrCeH51ep5gj/uUf5IWO8aqPWO
EI81VTwS5Dmp5CGsvzPU+kuQf6WSn5A/Zqj8QXmv7hruXvCIV5+anWLs8ISg
n0VKP/RZSId25qWPqP7lSrG2zk8I+sT5GZ5fq57ntT9VrhhTO4ezhkbsDttb
wnktE4a6n83bY27Gw5SFj/j9r2r+aJnylJtv5GW2QbkaN1KYML6rGk+Yz6Xm
I9hnkbIPPfjmc6tzwgPacPTP7/zjGfI2VPJq+85X9qX/B9KMIhY=
                   "], {{
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[0.3], EdgeForm[None], 
                    GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxNmgn8llMWx59770uUhrJMKikSlURlTYsllUSWsS8tlERlSSShEIZhbINs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                    "]], PolygonBox[CompressedData["
1:eJwtl3cYl1Mcxd9774v2nqKIUJIWGUnKaJeMingopUgee4SsQqVCtKWUpoqS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                    "]]}]}, {}, {}, {}, {}}, 
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwl1Xe0yHUYx/EfV2YyQ0koZY+GrEMIZVRGqJNK105dOUJlZJM9G0aOncjO
aloZhUgoMjIqM6uiVK/n9Mfb+/M8z/fe8/3+ft/fVTS1S9O0dEmSDPFP5wxJ
ckNKklTDyvRJkludIv+CbepdnEevKZphk/pL9MdX5v14IAZguHowD8EgDMNQ
jNAfHsabGIWRgf4YHovRGI9xMdefyJMwAV+r3+It2Iyb7SMvtuvvVueT8yOj
XIBr80PIhCfUo62rE7+bW6qzyLvkPVxQfRtuRyHU1cuKwnI2LsK7rb1J7iZn
53rIgRfVOXmveTH5LhTFnbgDD5vdzcXxm/y9def5B87DT+lPlBvIDeNcKBFn
45LciEtxaVyWD1l7iQ9zOb0C8tZ4T3gHP+l3jn3hpXg/mIrj+mncBZ/LkzFD
nhlnwitYrzcdc+V56I4e6IkdmI9z5q/ya3gd32BnnDGed5zRPCNf4EzxLFEH
rczf13tevsQ11Bt5PlL1Sqkvy5nlK5wlnh3qobXZh3rt5D/4QXW5OIu6LKdi
iX5H9VWuGc9Svocf4Qaoj7bq5ebZ5et8I//NlfS7yg/wJvUydFJXVndCR3yk
l0svvZyT03FjboLHUTXOgw14A8uwNJ5pvB8/+zOvQ9/YKxbji7jPZifjnaAP
FsVZ8Vncc7MT/Cl6YyEW4JP4/syO88fohQQfoAoa2c9jeBT/xr3lfzgHr+D2
1nRARbysdz+3w71xD9T38V/WZZWvcTZeym1i39xBXUH+Uy7P7dWL4t3GHrmt
uoz8u1ya26gXyM/FHvlY3FMcxUV1SU6zpgQ/g2dRHK315pk/Lc/lI3Hv4xvA
eXXt+N7kWlws7hdO6yfqU7xWXUOujtnyHMzCGqxGVf33eDqmYRVWxnPRn8xT
8G68e6xA+Tg33o69+/1X+Agv53woE3+DuCzv53340fwiT4r94AAuqA9y/bif
yBXfqp/JzXvxHfabn+MJvAb7cFp9FmdiTdxfftLPjZdX41u8oN7DO+NbMm+u
HiOvwi3yrfg1vudYz6fiG5Zb6I/lWuoMKf//n/AfFtnJGg==
                    "]], 
                    LineBox[{985, 1015, 1014, 1073, 699, 662, 1114, 793, 739, 
                    1017, 742, 1016, 741, 701, 663, 1018, 1019, 986, 987, 704,
                     667, 852, 672, 1117, 800, 748, 801, 1118, 673, 857, 676, 
                    1026, 1027, 1025, 1029, 1028, 677, 858, 1088, 802, 1087, 
                    803, 829, 707, 828, 749, 1119, 674, 853, 1083, 1084, 1022,
                     744, 1020, 743, 1021, 1081, 1080, 849, 1079, 796, 1078, 
                    797, 847, 846, 848, 795, 1076, 794, 845, 1075, 700, 1074, 
                    985}], LineBox[{798, 851, 850, 874, 702, 664, 972, 928, 
                    745, 880, 881, 882, 973, 668, 854, 675, 855, 856, 799, 
                    1116, 670, 705, 988, 989, 1138, 669, 1023, 665, 1115, 
                    798}]}}], {}}, {
                  InsetBox["\<\"\[Mu] = \"\>", {-1.8, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["0.2`", {-1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {InsetBox[
                   SubscriptBox["C", "J"], {1.4, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["\<\"=\"\>", {1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["4.94`", {1.7, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {
                  {PointSize[0.05], PointBox[{-0.2, 0}]}, 
                  {PointSize[0.0125], PointBox[{0.8, 0}]}}, 
                 {PointSize[0.007], PointBox[{0.4463998339305619, 0}], 
                  PointBox[{1.2771956561278897`, 0}], 
                  PointBox[{-1.0806611991222994`, 0}], 
                  PointBox[
                   NCache[{0.3, Rational[1, 2] 3^Rational[1, 2]}, {0.3, 
                    0.8660254037844386}]], 
                  PointBox[
                   NCache[{0.3, Rational[-1, 2] 3^Rational[1, 2]}, {
                    0.3, -0.8660254037844386}]]}},
                AspectRatio->1,
                Axes->{False, False},
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                Frame->{{True, True}, {True, True}},
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLines->{None, None},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None, "TransparentPolygonMesh" -> 
                  True, "AxesInFront" -> True},
                PlotRange->{{-2, 2}, {-2, 2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.02], 
                   Scaled[0.02]}, {
                   Scaled[0.02], 
                   Scaled[0.02]}},
                Ticks->{Automatic, Automatic}], 8->
               GraphicsBox[{{GraphicsComplexBox[CompressedData["
1:eJx1Wnl8zNf6DsV1MaRq61BES6NX1cWkqrleBLe15qa2WpJaLwZVS4naS0os
tUxrqSKKliuJ2sPwWkNC1ZpRW4NJRCxJRhYime9P5+Q58/m9PpN/zufJOXPO
+7zbec/5noDBn4cNK+3n5/d5GT+/v9o5Q0YetNju8fzh1/PiYor47O5GtWyO
VI3/Uen0faflssZPD1RYHOU6oLFdYQKuo8ZrfELNp/FUtZ7Gkz8rmGWPcvG7
VVq/FR7yjFtV3R7uCH2sMeQDhnzAkA8Y8gFDPmDIBwz5gCEfcDMlj8YTlLwa
X9y3KsyUlqdb8AEGH2DwAQYfYPABBh9g8AEGH2DwAQYfYPABBh/gc6rVGDwl
L2DZgi8w+AKDLzD4AoMvMPgCgy8w+AKDLzD4AoMvMPgCN1Z8yZdfSrtK3rIF
f2DwBwZ/YPAHBn9g8AcGf2DwBwZ/YPAHBn9g8AdGnMo4lH4s7Sx5A8sW+gCG
PoChD2DoAxj6AIY+gKEPYOgDGPoAhj6AoQ/guUof5Ctvyjwl41zGgfQLqRfZ
Qj/A0A8w9AMM/QBDP8DQDzD0Awz9AEM/wNAPMPTjax+ReVvmPZkXZJxIP5F6
AX9g8AcGf2DwBwZ/YPAHBn9g8AcGf1/7ptynZJ6XeVDmBRkX4AcMfsDgAww+
wOADDD7A4ONr35f7rNynZB6XeU3GNfgAgw8w+ACDDzD4AIMPMPj4qltknSD3
WbkPybws85KMQ8lTtuALDP8EBn9g8AcGf2DwBwZ/X3WarItkXSH3XbkPyTws
846MQ+m30u5SL7KFfoChH2DoBxj6AYZ+gKEfX3WrrBNlnSXrELkvy31J5mGZ
l6AfYOhH+oXUA7BsoR9g6AcY+gGGfoChH191sqwzZR0m6xK5L8t9SOZlmddk
XpBxIv1C6kG20Acw9AEMffg6F8i6Wtadsg6TdYjcd+U+JPO4zIMyL8g4kHaX
vGUL/sDg7+vcIOtqWWfKOkvWFXKflfuUzPMy78k4l34t7Sp5ylaeC2SdLOtE
WRfJOkHus3Kfknlb5ikZl9IvpZ1k3SrrNFm3yH1f7ptyH5F5U+aJm57fZ/I1
T1vIdzztNQ7yyO3m+x6crLGf5++wHfiM6ifgi+r3Gl9R8xPmf8sjXy7P8shR
oOsn9NdX/YR+tPjdNIUJGL8DjxSFNS/IAV4tFSZfPPF/tPL/4C/n86Wntz1y
OvU8sC8w+jEe+kQ/MPrrqfG6H/oFRj/GQz5fdsP6wLLFfMBYDxjz+/ID6AkY
/ip5oR/+KedHP3gC6zq9BMMfICf8ARj+BD+DPwFLP5PjpJ/JdXz5hbSD1Jvk
CYz15DkWekZ+AIY+gKFvYOQHYOQHGa9YD/kLekWLuAVvYMzjS060Ms7wf8gv
4w390Isv3vBnYPCX8STrNhk/6Md6vvSK9aRfA2M+YMznyy7QG+aBHtAPfQBj
Pl921ed4ER+wK+wn6z+ZR7FfyN/BX+T+Je0k9Sj1IHkAgwdwlMdeDkY71bOf
3uHmnt+d4LOeuiCNgGP9Jxw1Jz+nOR75HuoW/49WmH9VmNEPjBbj5O/+5ZHr
Fp/3yHmeaxz8i882LV81JYeWJ9Cz79/XGPJjnGzBBxi/B8b6R9X6Wj+TVUuQ
B1jylLwQD1q+Eoz1Ko2otsIaaOh+4HUeO27T65f8X+sFWPxO6wsY8wCLdTVP
YPAC9rWOmJfkumJezVfIL3/3kl6EPORLD3J9zCP0p+PHl94RT9IOwIgvYMkT
8eZjPRbzs5iPxe91/Em59D1oSb+US+ZT5Clg7EfIp+gHRn+yh1+2rhuBcQ5M
VFjXAcDo9/U74DLDNvZ1mQs5/dC0U4aR5VNO4Ah7yDshkcU6ztHCTlgfed0X
L2DMBz364gEMeddW+LZrYHwOXVa/03KNV/LoeTeocS/xBL6lsJ4X6+Mc1jvh
QlaS9Sl33xuxJzT8if4d5kUdBX3iHATsp8YTxgNLfePchHzWTOVFjbFvgRd4
Y9+CfbBvAQ9Q47WegGE3+DnqBcS1zHuwJ34n4x37u7QD5kMeQbwDQ374A+QH
hryYDxj+Iu0Ie8BfYA/tlyX6x3hg+BPs5suuvuwIjHV8yeFrXWDYzZddfdkR
GHrzpVdfepTzSTvqOrhkvM4DJfspMPjALrgfQFx1VnFEiCvoCfEWpv5PiDfw
QHxgX0d86DquBKMf8YL8D3+G/wEjj0t/97VPgA/kBh/IDf2hvoP+gNEPfYI3
9APe0A/Ob2hx/wW81VTqmxh7Pj8f1KxupClP50nEM+pbYNRJ0APGI34xHhjj
sZ8jX8HuyE+o42Av9MMe6AdP6BE8oUfwwjkVfIHBt0Dx1XbAfLCDnA/3a9DT
ZjWP9jvMA/1jHqwrW8wHOTAf/B+80CJvQF+IY2lXyAee8hwv9QI50A85MI88
xyNegBH3qLsxHucrjAfG+HfVeK0HyIX1oRfIIXnBPvAT+BXyC/QE/0Q8In9i
/8F8sJuMI6wj18U4yCn9CvLCD2A/+DPsB/mQHyAf4gV61vxKzpM6jkrygdzn
5X0iMPYb+BXmkedhnDMxL/IQ5pH3R4h7zAse8h4V9Rsw8j78B+ORbzAeGONR
F2A86guMB8Z42BvjkZ8wXtYf0D/6oR/0o/6AfZEH9Pm6ZL+BnsAXWL8PKMmP
4AN/wHhgjIdeMR5xi3HAyGfwQ+m38BPUx8DYd7EfSrvBTtLfMA/Oz/ADzIf/
Sz/GPNL+4It+aW/EM/qlfRFP6Ic9ZVxATsiHdTN6rrqb1Me7j+//KHakfa93
H6/86+3iFfu85713bgzo4epn8MRLCTNiRj/QfjPx/ejxDv8nL73LqvTWzIVR
F5/ruKk2tWlB3O3nnJxVEGq6kK/zeXm/zqnO77zv2R4GfPGRafNzfS9V/XrI
vaSQYl3/Z7dvmWC5fFXzKDex8xx74m3N40zUa2Mcgek6Hx47suVeUsVHGk9b
nRBr6ek9n+L3+j6v5PfyO2ZBr1GFSdaNej70Yz75zmfko0+fJFkTCfLK9wb+
O6aXszmSdX6PyLy3PzT8qI6DvgOjGoeHpHjfeUx/95DFlkLQh3y32f6fvxw3
R3vv5UbsvDgrJjiToE/wgL7lu8nBQa9cMBe6CPbBvqW/s5W+Xy7+mff74oAt
n9iiLuYT7I9x+N3Q48NCAv/01g/2VWsfJf3vGcF/ICfkMNe92ywkwft9rPfV
c+8Hfl6s9VN+8fYw19Riivpvmwq2fRkcndHxjfAWxbyl44cNIo+7eEDu9JPm
Wc943Mpt38QMyNfthp2v77dMfMaZrziq2fa5eErwvY6m6sU8uMrs/q6pGTwi
6sn7IQlXdLsjLX9RzIDj3OG8n8n2toPv1F58yRx9my8/q9syPOQIj13YIzD8
STr956s/Gr5QGyc7ry+3fmRQSKNFD5yW4xwd/aBZ+Gt3+PdKzkRLtV8p8au4
M8b6RzTqb3Xzkqx7qJf/5NfD+xt093b8dusvO2hzM3Mvl3k7zfkpcFlM0Xmq
vzusl6vwOY2IXfNG+CuPqNyC+veS+jyixzHVWwc2LKJjpd9NMo9y8L9m/dTD
1dygjruy2prSmMPHthng2GHQ76Un+sXH7KWhYbu6uw4YVHfFqIkOv4u0KaLh
KPt4gzol3fS3FTh5S4uAM0ZWMWce2/1OyAc3uZWtRlTUHTdnFl2dHxV2kw5u
XD/QkeHmNfYFM+zpd2liZqXGIY3dPONu76/tTXO40aJrAeE/FPLQ4SuuG+tz
+cihlrGh7gLe3vZWf9PmbO8+NLBVLdtv2fTnkDqLozIK2X9r0HT7llwa63e1
u6nsU50HPlP+xKU6bfa31czT+7n/V8sq2goKeO+b2R+ErM7loXWGDHAVFlCl
k0ejY9bm6rwzXPkvdzOV/dPZrZD7DG6SaJmWwzXsV4c52hZS9K6+FLIgh6v2
O7fGerqQyvXMbBgZm63zfmcVPzylyb6V1vlFOu9PPfyfMfYtxbxu17Sz5ug0
3vt7j9y42S/OkctmHbZcTuP87OmNQ+4X07Yk60z78Lt8evAXVvteNzcprnfE
HH2DbalcKfKRm0fOPnjZmHmVBx+pFRmz1k2rJhzKjwu4wT8eidhhuXyT3xty
baSr33ku06W0M6m2QTs9ejyv95FvVD7h8O2PK8YHeL8nhnryRCIFfvnqkhj7
Ro13TPJgqnO333WDndQktV/z8JBlWp5+Sh6CvHWUvAR5ApQ81Glz9swYu/c7
x9TQh+1NJ9104Ojfi+IC/qA/5nbrYCou5qE5FfaELrlL0MdGpQ+CvmoqfVHT
9OrP4n4rZHPqP+fad2bTygoN8uMii/R3BdintLIPwX5Ryn4Ef9ip/IHamibU
iuzmPYfAH+3KH6nfmQefmBp6z0Hw3wbKf6lary9OWU5kc/3+vYID/ywk+Ot1
5a/Uqt7ILGfZHBoaenqP5UShjp9NKn5ox6x7BUmOuzzl7MG0pAA3IZ6CVDwR
4me8ih+6/FVshvOKk/r2+yDC4eem6wvm/Rwa9ED7IfxuuT16kGOH951TBZX/
dH31uN2FTaGHi3R9lH80tEXIp0/5s6rnGkYeytZ16TRjQh9Twycv3Xduab66
U2AV7/lohMrXDH1hXKX7+ZaQP/J13ocee08KznBWz+ONKd2HOHY8f+m7vnPM
f7Odk7L1eSkqo36sdUS2Pl+NU/sTw/7g/aDVCVfcoJe/JyYvTPh7/KDb3LTp
+6PtndwvfXfq7GjQKHJxKpebu35DaF3jpe+OpXdYHjqvXGT/NqlTYuxLdD/q
6JQVQ362/nJJ1wFN1f7M8H/EW5O1P+wKDT+h92XYI8lTHxzT/ZgH/f9T/QT5
UA8gnuX3v9x4j7wEeeX3wEQlL0Ff8rvuMaUvgr7kd7X2Sl+EfAc5YU/5HThV
2VPfX8xR9qRVwRWyk7o8fekdx0blXwT/gZ/Bf8KU/xDyvXzn4VL+rOvA8qqe
JOwvkAPxI9+3LFHxo+sef1V/EuJDfs/MVPGk/Sqi+y1jxUqv3iovmx0Tus5N
QwtrdTbtyeSTnXqutB4p4hMz6r0ZfjeBEvv6HTNPPUMX0yd3MKX9SD8vnlXd
1uci1frJmZHUp4hi2z3dEhr1gLB/lVf7F2E/HKX2Q1o1eXlHU8dHHLS6+/2k
2kX8zaFHk+yJGbR0xRufuFoXcxse09k0L5N6OhuvtF4tYtQHLlUf8Nohi4a5
kl3Uu+rv5W3fPOO5b7rSnIPyab5quVPntDfDJzwj2w8bZ9n3uvjyeyt2WcoU
8flNta85qz/i0UN/22mZWMSvcaPXIrs9YNQj41Q9wuCzR/Hhh3OiWgX+rZjC
1nLbwIgM/iGl3MeB8bu4fdmkqfZyKYz6Zpmqb7S+nEpfDH3tU/piv3mlLppH
HaO6quUN3Y5SYFYGVS2X1seUdozDuow+aY6+T/NrG0Nd5uO6Ptur6jPC79Gi
Xquu6jXCfLllPfMR5hul5iPUgf1US+DTUvEh1I/9VP1I4N9Z8Sfo87TSJ0Gf
FZU+CfVouqpHCfZYquxBqFtHq5ZgP7Sod/uqepdg7zBlb+0/zZX/6Ho5StXL
2n+PKv8l+Nci5V8E/wpV/qXr7+nqfMLWGqedSf/zvqdCPZCs6gFeVNTZHH7X
TQv3hFw1ZqZw1a4L5kW9qFORP+tcvxJr6WDQ/k2X2FLtJNcw0jKce7zvl1Cv
BP/pqVdofH9+I7JbGr3dNvSR07KTrqYNbhkYYejxKdtPTo4ZYFB4wJ38JOsm
wnrIp6inflL1FG3f2myFtZZBwXF7atpqXiDwwf0H6rP5qj7TPLtEVjWHv+Ll
sSHnywGOpV45Ls88W7ziuHfdTUN+veL8ztDzFh7cc9BcwZDz8fbDE1qGv5bK
nRbPC3XtfJG3/399zw/bRIxy7HBw+q0L7hXveb9DlazPZwZ3fZ704AIvunSz
YuQYg4PLJg90nD/Hqy4PjbXMNVicD3iwO6mizXGKw7b0nByz1vvdqkR+jvOc
M/dy5cwZB8wHDC7y3O9/y9W+650dd9Rgcb7gjIXDaoeHLKFkV8eKkce937lK
+LPtxystAuOZ9lbxj7XsNthdvs/yKNcp2vbvRqeN9QaL8wnv3rfaEhh/jjrd
GrXcOt9goT/OnzcsydzZQaMjvuvham1wm6DURuHHHXS4jivW0vLFvu+J8z/p
rOnjmNDDbq5Xqf8Kq5/B5598bbfkprB77ObTRh+vHu9MjB/gGGfw7M1Za6Nc
R/nG0taj7MNfyBH2bKM1MJHhL12Vv3DI6Gavh3/t1VvpNGusZZbBa5sUP3Dm
7aTHwavbmeYZ/EvwX/v2Ou2/Q5T/Ms5/9e54zn8M/01R/qvlgx7Bs/3ydyrE
B1ygOhtb5cS1M3je2e/WR40/Tzh/NlTnT0J8rVHxRUVb2eG0urnVPKNhZEwq
IT6nqfgk+F9H5X8k/ImEP5HwDxL+QcLeJOxNwn4k7KflbavkZfAPU/wZ/Fco
/gz9X1X6Z+h/1b88+tf2HaLsS7Dv98q+BP84pvyDRLyRuC8jET8k7s9IxAOJ
+zQS/k3ifo3E+ZuEP9PQHcf7mTre5tJLC40V33jr5M9UvcLDyk1ItPS8TeU+
vGgJ/NZbF1ZR9QtnDysX6ir0vtPC94RNf0z5Osa+X+MRChPGQ058bz1Q640I
h79bv1OoMSwxLam2W7+bqNMmZHHUxUJ9b9vQ5noad7uQK52ZPd6+t1CPw3mw
rjoPsqvjlidxt4v1ewqcL0er86WO27GXvstJsjq4V/nWF82d7+h4dK2bsTaq
+R2uv3FGx8D4zbr+m6nu7yjHL87hnPRY522sBx4473+vzvt05OGgn0KXFPPS
Wlc6BFZJJ8gPXrhv+ETdN1D9IW81C2lYyPvLv/pWZEKOft8z/Kv6Ax3NvO95
YhM+a2fa7H2/M+LEo1MGe9/r2BovnhwzzaAaXUqViv9POhtlp5Syxb+oO27M
qGE7lcOHg5Y3CG9RyDi/vqXOrxy14Xqi+cBTnvbjyEUx258w6nPU1bgP3t91
4EeBVXIZ8tqVvNx3/q3zRnyh/q5fxn/qkqgGhbRpz/A59r057J5w8x8hy4o4
+UrlZ3EXMhn6WaX0w0Efvj7Gnlis/aRC4sdVIqcXU9Mzm+pEPkrjJnmr4y0d
3HTjcecvHdmpnDLkaaXI37zvtecP3HrJPPUCnzuQbsTlpLDl3z0GmIad5wd5
y4y4AAe3TFhwxTwqlRef/X5OTHCSvlc/6sk7v+v7t4omz/0bwx9WKX/gSZ68
l6jtv+3tk/Nj7Cdpj23mXHvUDgaOVFjf321R93daXvk+OUL5I0H+I0p+gvw3
lfyE+8Ugdb9I7b9N2Bl66wRnx2SnGOQg6A/+CH1dVvoi6LOR0ifBXvr9T4m9
Nih7aTvWUvFI8J8Dyn/07wJUfNKraR3/6zqfQ5Po0wn2YO/7iv0q3rU/Fit/
1HJWU/FPY/6e5hc/KJ2apI0sZdtXrO9zP1X3uXxwqauHadg9/Z0L9ydT1f0J
lx9gO27J9b6nwHc5nHNxf9JP3Z8w1muq1uO5CbXeDv/J+94C989H1P0zm8/M
+jbmofe9E+53Rqj7HQb/SMVf35PXVffT3MBTr7j0+42mJ2bXjzz0hFqfetLP
lew9B4f9e+WX9uFPuc6axeMczXL1d8Or5f37uw48pYtl19WPjPXemwer+3UO
XTr0tjPP+74D91uIX3yPG/JG4jiHfy6XUff5+p4d72T2RRhvRh7P4boL0zqZ
5hWRf5l674UkZHLDHVV+Mxze9yBp1sR3Qt7z2gnfr9t4zjvp3HZE/2Qjws23
PpuX5cxL5cTUch1MDd0s30d1mPZhH1PHS/peZbj6fsHwb7fyb/2dZqX6nsE7
E/7abyZx163Td4feusTLs7MOmKd6v0uV8tzDHKBFlhMfm9KS+YpRKtFiO6rz
KL57jV/YZEaM/aD+PfZd9Aepfv1uMUjJS1g/WK2vv5vP8sT7FQL/FMWfwB9+
Cf3hnAT9BSn9EewDP4J9din7EPwnSPkP4b4OfoHvmpVNTW47qz/T95zdlX8R
/At+gfrAT9UH1K7F2IfOPd73NrBb5QUjk40+bkK9UEbVC4T4k+9z7qv40/Mh
PjGfv5qPv99aqZyt5gPKGDhgp2V3Ebdvse93894n3DWocQXb8af8waZOLQM/
z+Ibr1wtiJv9nJf/cCo7bnYWLZpZq7cr+jmv2va5OfLdAs50r/s1dEYe13nW
+Qv78Od0YkmTt0M+yOJXP67ZxdTwGvdbc/ln64hLvDP33i7L5QeU1aHwtmEc
0fiCwoT94nO1XxB+30X9nuBfY5V/Efa3Y2p/I8RPeRU/BHnsSh7CfjtF7bcE
+dOV/IR4P6findpuGFc6fnYeZ3ZpZ3U0KyDo5yOlH3p457VN1vl5tGaJs5Lt
/QKCPp1Kn/r3j9Xv2fbJwDXW8g/YuXPutJjtRbw9aN8Ue/MCKr0wvYrt6zw+
/+HjqpFjnnNAtQmj7J2y+Jp7vc36kZtqLqk8156YqnEVhQnjX1fjCfO5oz3z
EdZLVesR7Ddf2U/XV70H/+UX4xl81ik+2v5Xlf3p/wBbHRpz
                   "], {{
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[0.3], EdgeForm[None], 
                    GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxVmgcUVcXxxu/uPmzYBSsIqNhAUWmKgCAgdrBjF1AEQREUsYAitlhijcag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                    "]], PolygonBox[CompressedData["
1:eJw1lwfYllMcxt9z/o8mKg1SIiR8REUZfaVFy0qZZVe2y96yV0NImsqslJGs
KJSiEEJGZCbZKwkpv9v9uq7v/t77fs54nnPOf52mJ57d+6xcKpU2gAKcEaXS
maB3KpUagI/hH4H58AVgFzrVRx8InwBeZfDr6JnwV8A36KboE+DXqj+8H2O2
5Xkb9EP8Hotuzu8K3leX9kHofdAD0QehDwGH0vcs9O7w42jfifa9eHYO+lzQ
H7492AC/l7bW8M+T2xaBR5L7XAu/EQyHV9c30vc19Az4y2Aw/BowFF4N9Iaf
Bm6CXwlWwBczphZ8EbhCc4Nx8A7g4PA361v7agz8MTAevh+4HD4djIW3BxfC
LwInwSvAMPht4HZ4TXCTvgWMgNcAe8AHaA3wU8Fu+j72owPf1Ba9I/oodBP0
HugP0R+AufB54HD4JNpuhl8NzkOfD4bAm4F74E+DifBPwLP0HQn6qC/4AZ6Y
/0vtBbiMvg+BMfBKvY/27uhL4O+CB9BH038bfuezJ8/S9hJ8kt4FGqMPC+/t
duoPvyC8F6PBLfS9A30HfJpsgLmqobdlrh60fQR+QL9P2wcC+jv0O/DO9FkN
/5JnTfSt4Gb4cO2xbA/cJVsN2+4y8DZ8CZgNnwPegf8qm4c3BKPgnzBH/WSb
XwS/k2cHwDcGk8J7qr0cBfbke8ej71Q7ff8BU9BnoNtpfeEz1tneqvPW2YT5
VHAj+jr0MPgUfS96Ynjuh8F49P3hvXoUjIM/Ce6Wr4KWvH80eqTsib5/wr+S
T6L76Z1hm5OtaU9+pq29zkDfDrYJ+7B89/hk2zlCPpJsQ++jN0X3hC/RmaO/
Qr+u82T/R8t20IPRx4DNFSvA5ck+/Rb8TTBLtgbeoP8bskHFEs0HXwqeh28N
fqG9YE2rFFvAa+jFWjN8IXhG9gIOlu+DBrR9ln32evYW/CTGt9YZ8n238duD
Ppcmr6F62MZkW7XRtdE7oDdCVwVjsn1IvqOYciS8Cdg5eU/upv0o9HXJMe89
9Ddao96dHJuORl+fHKOODfusfPUGMJH2vuir4C1k7/CzwS3wRmAnxbpw34Fg
pGJF2PbkI8sZPwPdK9lGrw/HPMU62dBG4T3W3nYHbVjbVmFb0Dvfky+BF+BD
2Z9Nwmeks+mRvNeKgYp92nP1PZM5umaPUSytjf47OaYeBB9KW3XFdtkKulbh
WMtf6VD4reWzaMBvncI5RLljHZidbfOyde3B88y/QDavWCEfCD8TVwx+Idsn
5AuKaXPCMVexVmNehL9M+4PwyfJJ3rdefgFfq/HhmK5Yrj5/Kq4qxsr2QF/6
j8vem8bZa+0J6mSvWXsxFj645D1RrpvC79KSc55idQvFlJJjtmKjfO4/X+O3
P3rXcG5slp3rpsmnSs55st0l2sdkG+5TOIYqdjZED0DXRG+Gbos+Bb0D+nHG
V2avtTvPapfX3AneUXtA+6bZubdeONcrB/dCv4TulLzGHuhu4JzkOZRr7ud3
Zsk5pzO6S+G59qbPhHBMUixSDJwNn0/bvfD7wHPhHKLcoWfy7V9p/zbZx2ui
Z2TXI78n1x4/oVcm1yD7074OvQZei98asr3svqtBtcJnqLP7GYwI5xTlEuXY
DrS3L1x76J3raV8HWsE/S86d39P/0+Qc+jV6JaiTHOOuDsdoxWbVDEPCOUa5
RTlbufJHnV9yzrxHOSA89wBQEY5pimWDQCX92xXOlRpTBf6Hchz8e1AV/Qj6
t5KftWb8WvSP8FPAT+EaSrXTh+hp4T3XXqvmUK78OLtNOVO5/XeeLU/O8WPC
OVG5UDljTTgGK/aqzwr6r0UfnpxDHg37lHxJNc4q+Ijs2L84ObYvzeaK8c8p
X4Lp8PNlA+GaQ7XGXVqj4ll27l6KXqhcBo5MHqPcrhpDtYVyvGrH1eXap3k5
1ionKRcp5iqXL8ueSzn9QfQq9C7wk8EJjF9TttUW/E4N1yiqTVTTPKbYJZtM
9pF5tM0N13Lyga60HVDY9pTTH86eU3PJx5UbFDMUK5QjxqI/z47lqqm1tpXZ
tavW+Dh8E/r/pbMHNcI+LV9WzdMFPTw7dl8Mvsiu0VSbqcZRrao91t6qZq2C
bsz4xLN6jL8hXGOotlANXKnzQ4+m7cTkXD0hO9crZ+9aOKcql1bL7tsunJs0
ZjL8O561TK5h90XPzI7tHfn3V7YPyve0h6PKMathOUbKdmXjsm3ZcBHOGXX/
j3HqG66lr9AZh2NaZfmdCxTrCucK1WAd0aXwuy8Cc7JrENUeqiE2ZMd8xXrt
sXxdFx3dFeTz+8KbhW1DPq9Ys3M41yrmVA3nrP9yFfoq9MLsu4Ji5LpyDFLs
UUzqptwczp2qiffW3Se816oBOsE7g27aXz5lSPYZ62z1rH7hPmpbj26E3rLw
WW7QmSt/F65VdMYN4JsXroWUc7dmbNvCvnUceCpck6oWVY2vWmuLwnOp5toM
XVG49lUNobtcXfQ/yXe6HXX3Klxr92H+pqrtQSttu2wUvl1hrhxUD57D3645
VEvVQlfJrql6hmss1VaqwZrT3is8t/psr/MoXDvpHY1UKxW2BcWg3eCz5KPa
d8X5sM3KVlWzz1MtAE6HX5icC3Phu4tyomo1xWTFYtVs98GXhe9KymltwnNo
rGqAYdk2JtvSHfBU2WPYV/WOuaotsmO5aujJ8OXhu7JqgKnlHN+snNNbFL5j
6G6hNag21pq0FtXIT4RreNXuqulnoS8N3x10h/qa58+Ez1Yx7Xj6tgzfjSuy
74qtwrlBd8bp2X0qyjlkIG2DwndJ5dh/AfjDACE=
                    "]]}]}, {}, {}, {}, {}}, 
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwl1We8j2Ucx/H7nGOPMhIl2ZQZEpEZMiPPKvMkEh0PolQaZO9NxcuWIrJD
2ZXIViEjWjKiVFbG+/fy4OPz/f6u+3/OfV/39T+Kp/dqm5GSJMlA/3TJlCQp
aUlSG8tTk+QO/U6c1L/Wd3AevQVaYou+Fe9gm/W3eQD6Y4g+kAfh3egYjKHm
w3h4ZIzECAwzH81jMArjMDauM5/AEzEe3+iT+Ct8iXzuIy+2m3+r55fvQqpc
gBvy40hDK32E6xrJo7mNnlneJe/iQvo9KIx70dgsC+6T70cR7HZtdrMMORs3
QQ48r+fk/dZLyCVRFMVRDE9YK8WlcVr+3nV/8A+xz9zWfJzcXG4R+4wysf9c
NvabH+AH8af8o2vP8RE+H8+NbvHsfNysB/fES/Hu8D5OmGdwL3wuT8EMeSZe
Rm9sMJuGufI89MEreBXb8SHOWO/Lr8W94QW/twyn8jlrKXGPnMZ18Bjaxc8z
e0a+wHX1TTwfz5qV1/+SM8l/c2auh7roZO1jsw7yP1xPr4wX9Uqcjk/MO+v/
cf1453Ij1I8zgAboYv5pvD/5KmfjK1wj9kp+hDfrS5Cu19S7x/NhmVlus5uc
i29wM26OpqgVn41nwlvxe7AEG+OsuvZE7C3exOK4X6yPM2ztJ/4C/bAIC+P9
xHfL2nFehzdiD/AR1mKLtWO8Bq/jur6AH0XjOG9ogv/Nc/A1zslLuWucFVRH
D7OH4/yiapwNvRpfdl0W+RJn5cX8XNwfd9KryP/KD3FHfWHsf9wft9cryhfl
CtxOXyB3jPPDR+PcxhnGeb1c7HOcbW6PDnHW8bTZ3Dgf8hw+zIdwEGf12vF9
kmtxKZ6PU+bX+Hf+jIuihvXZ8TMwC6uxKp7ffBpPxwdYiRWoYj6V38MULI/3
jwrmBXgyjvn5F/goL+W8KGc9H5fnfbwXh62f5fG8GgdxJp4jzg83RS509Znc
vAe78Z31UzyWV+EAfo3nwm/YF++Fn/K5MfJK7Il3pO+Nv4XxXbL+pD5SXoG7
5YL42XyHvpN/wU65tfkobqAnabf/L7gFtFHF3g==
                    "]], 
                    LineBox[{979, 1010, 1009, 1069, 696, 659, 1107, 790, 736, 
                    1012, 739, 1011, 738, 698, 660, 1013, 1014, 980, 981, 701,
                     664, 852, 669, 1110, 800, 745, 801, 1111, 670, 857, 673, 
                    1021, 1022, 1020, 1024, 1023, 674, 858, 1081, 802, 1080, 
                    803, 829, 704, 828, 746, 1112, 671, 853, 1078, 797, 1017, 
                    741, 1015, 740, 1016, 795, 1076, 849, 1075, 793, 1074, 
                    794, 847, 846, 848, 792, 1072, 791, 845, 1071, 697, 1070, 
                    979}], LineBox[{796, 851, 850, 874, 699, 661, 968, 926, 
                    742, 880, 881, 882, 969, 665, 854, 672, 855, 856, 798, 
                    1109, 667, 702, 982, 983, 1133, 666, 1018, 662, 1108, 
                    796}]}}], {}}, {
                  InsetBox["\<\"\[Mu] = \"\>", {-1.8, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["0.2`", {-1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {InsetBox[
                   SubscriptBox["C", "J"], {1.4, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["\<\"=\"\>", {1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["4.93`", {1.7, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {
                  {PointSize[0.05], PointBox[{-0.2, 0}]}, 
                  {PointSize[0.0125], PointBox[{0.8, 0}]}}, 
                 {PointSize[0.007], PointBox[{0.4463998339305619, 0}], 
                  PointBox[{1.2771956561278897`, 0}], 
                  PointBox[{-1.0806611991222994`, 0}], 
                  PointBox[
                   NCache[{0.3, Rational[1, 2] 3^Rational[1, 2]}, {0.3, 
                    0.8660254037844386}]], 
                  PointBox[
                   NCache[{0.3, Rational[-1, 2] 3^Rational[1, 2]}, {
                    0.3, -0.8660254037844386}]]}},
                AspectRatio->1,
                Axes->{False, False},
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                Frame->{{True, True}, {True, True}},
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLines->{None, None},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None, "TransparentPolygonMesh" -> 
                  True, "AxesInFront" -> True},
                PlotRange->{{-2, 2}, {-2, 2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.02], 
                   Scaled[0.02]}, {
                   Scaled[0.02], 
                   Scaled[0.02]}},
                Ticks->{Automatic, Automatic}], 9->
               GraphicsBox[{{GraphicsComplexBox[CompressedData["
1:eJx1W3l8zNf6zkVvVQ25rUukre1axtI2TcVWvGrU1WoZahdDlV4VW9EyLi3F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                   "], {{
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[0.3], EdgeForm[None], 
                    GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxNmwf0VsXRxu/uvgEsSCwoiA0FVBRBIChdEFSwgZWIiIqIQRE7itiwgCXF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                    "]], PolygonBox[CompressedData["
1:eJwtl3f8T1Ucxr/3fm78ZJUklPEzGjTsEklllNGipUkaGrR3tKctW0RllYSM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                    "]]}]}, {}, {}, {}, {}}, 
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwl1He8j2UYx/HnOGSPiCjKqOxNSVQcexb/qcyQTX8gkRQlyjr26lVahGzJ
KGVkRmbZZO/ZHu/r1R+f87m+130/z++5n/t+TrGOfVr1TkmSZJg/nTMmScbU
JHkSqzIkSQH5XpyRt8u7uKDcHJnUm/E93sQO42/wTh7OW/Ce+i1+GyPwDkZi
jP5ofhejIsdcjNUfx+OjRjomYJz+JJ6MifhBnsLbsBX3eZ5C2KW/W75fXRgP
oAjq6dXHXWghjzevQdyLn5WzqPeq93AxuTgeQgk01MuKh9Ul8Qj2mZtDr486
OzdCTnSRc/FPxsuqy6EUyqA0Ghsrz1f4Ki7jsLl3c2v9Kepm6ubIhwp6ebki
t+BKfJNv4QaOm3+bC+Cl2Cs+pdc7ng19Y98wE6f1+/HL+FY9Gx+oP0R/DMBG
vTn4RP0pBuIVDIp3jrm4ZvxVHozS6BZr5Cx8w1hmzoasqIN2xj7Xf059i5+O
c8Pz8bxeefm2Ors6J3KgLjrpL9Jvp/6V68iV0UOuxJ2xVL+j/DvXlRvEfiEN
9WPf0VV/Rbxj9d+ch//ix/V7qWvEGZaXo5NcU+4Zv4Mv9fLrZVDfwynclJuh
CWrLm+K9YRiWYDE2xNl07Wn+Dq/HWvBFvPs4s8Z+4fUYioVYgG/iuzF2ir/G
a5gf7w9rsQ5rsBpDkGAenogz6HlqcWP+1z3y8j+cj1dyN2Pd8VisT+/RODOo
FudErs5/mpdL/Qfn5mXcJdbFHeSq6t/UVbi9vFj9YqyL28oV1XfUFfgFeWHs
T6yNT/KJOLO4KZeL5zGnbNwLHVAGbfTmxf3ivPExPoojuB7nJ75D9VPxLfJn
uKSfIl/kr+IbRi35I/4Yc7Aq9hM19Wfz+5iFlXE+UEN/Os/ANCzHMlTVL8hT
cdL978Q6eGmciTiTxvNzFT7A+3HM+PW4htfiCK7FOrgpN0FudHVNHt6HvThk
/BJP5jX4Gefli7iAg3I2buW6SerV2B97EL/NP8b3Z7ylPCHeBR5UF8VZ/d0x
h89hj/oZ/XROk1NT/////x8nLMXm
                    "]], 
                    LineBox[{984, 1016, 1015, 1076, 702, 665, 1108, 793, 740, 
                    1018, 743, 1017, 742, 704, 666, 1019, 1020, 985, 986, 707,
                     671, 854, 676, 1112, 802, 749, 803, 1113, 677, 860, 679, 
                    1027, 1028, 1026, 1030, 1029, 680, 861, 1086, 804, 1085, 
                    805, 831, 710, 750, 751, 856, 855, 1083, 799, 1023, 745, 
                    1021, 744, 1022, 797, 1081, 850, 851, 796, 1109, 667, 848,
                     849, 795, 1079, 794, 847, 1078, 703, 1077, 984}], 
                    LineBox[{798, 853, 852, 877, 705, 668, 973, 928, 746, 883,
                     884, 885, 974, 672, 857, 678, 858, 859, 800, 1111, 674, 
                    708, 987, 988, 1134, 673, 1024, 669, 1110, 
                    798}]}}], {}}, {
                  InsetBox["\<\"\[Mu] = \"\>", {-1.8, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["0.2`", {-1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {InsetBox[
                   SubscriptBox["C", "J"], {1.4, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["\<\"=\"\>", {1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["4.92`", {1.7, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {
                  {PointSize[0.05], PointBox[{-0.2, 0}]}, 
                  {PointSize[0.0125], PointBox[{0.8, 0}]}}, 
                 {PointSize[0.007], PointBox[{0.4463998339305619, 0}], 
                  PointBox[{1.2771956561278897`, 0}], 
                  PointBox[{-1.0806611991222994`, 0}], 
                  PointBox[
                   NCache[{0.3, Rational[1, 2] 3^Rational[1, 2]}, {0.3, 
                    0.8660254037844386}]], 
                  PointBox[
                   NCache[{0.3, Rational[-1, 2] 3^Rational[1, 2]}, {
                    0.3, -0.8660254037844386}]]}},
                AspectRatio->1,
                Axes->{False, False},
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                Frame->{{True, True}, {True, True}},
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLines->{None, None},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None, "TransparentPolygonMesh" -> 
                  True, "AxesInFront" -> True},
                PlotRange->{{-2, 2}, {-2, 2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.02], 
                   Scaled[0.02]}, {
                   Scaled[0.02], 
                   Scaled[0.02]}},
                Ticks->{Automatic, Automatic}], 10->
               GraphicsBox[{{GraphicsComplexBox[CompressedData["
1:eJx1W3l8zNfaj+W6Xoy2ijK21tZYmqqK7baeMq2rqVuhSrjuULVVaql9cGlT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                   "], {{
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[0.3], EdgeForm[None], 
                    GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxNmwn4llMaxt9zzldaVEIkoUIJZYtslUKYkhRlV5HKWsiaZMkyxpZtZEu2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                    "]], PolygonBox[CompressedData["
1:eJwtlwm0TlUcxb9zz81Mjx4ZKkOSotIzV6YSahWlQYOhiFoRjTRrLlFkzJCp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                    "]]}]}, {}, {}, {}, {}}, 
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwl1WmYTnUcxvEzMyqyZRtZKgotNENFKhEz2ZcuL5QKGUNkCfVCu5Qy9r2y
K/tSlhBGaUOLNWmjrKmEFmQrPr+rF9/53r/7f87znP95zrmmcs7jbfukJEky
yJ/NqUmyJS1JyhdIkqYoKH+CTzEYW6y/zFv5Fd6AofIQzsOrGBZdWD+CR2I4
RmNUZP1YHocxmIDxGKHfyK9hmzyRt/Pr/Bk2oRAquK4d+q1yRfkqXIOr0VjX
BJejmXmk45rG93BLcxF5l7ydrzVfh6qogma6oqgm34Dr8Y1jr9D1kotzc5RA
F3NJ/sF6Dflm3IjquAktrGXwUT6G37HHsWW4tX683Fpug7LI1KVzTb6Pa/Ff
/Df+xD7Hn+By6GqtPB/U9eV+6I/PMRWH9U/wk/hInoI35bcwAE/F76mbiTny
XDyNZ/AsNmNefLf15/h5VEe32FvcWz5prVDcTxRGPXS2tkD/gPwPNzRv5IVo
r8s0n5aLxr1EMdyNrvp39A/LZ7mR+VZ0N9/Cj2KZvpP5PGeZG8qNUB/3oAF6
6FdaLyUnckm+YL5T7iHfEc+ReQU6m+8y90FvvKcrq7tUTudLuHF8Lt8b38Mf
x/3ESyiAJfgQ6/Gl8w/wBxgU+8HbeB9fWNvP6/AiFmMR8uM3s7aP12IgFsY9
xGqsievCKryANMxHPWTFveNsTuXSnMJleJXP7CW/y4+Y68o98RjqxH51t/N/
8WzL/3IJXs7d9Uu5o7m2fE6+jTuYl8jdYl/8kLmWfEauyQ+aF8u5sTfehL3y
TzglZ8TvGO8J58T7gxq4Xzc/rjOeOf4x3hPsxglzmvXZ3C7eL91xOVU+xj15
pa4KZuOoLkU3S14R+0dd83SegWlYHs9S3Af9ZJ6CSXGNOOT8pVwBb+CA+STv
5yu5jXMmyrvkr7ETe81/8AReF9eP47FvbsUtUQq5zi3NX2EHjuA3jHNcPnbj
sPlX/ILvzcW4lfPGymvxLXLM3/FOFLbe3DxKXoNKcmUciu8xb+Of41rlFvrR
nB3PMy5DE12ebnXsTy6Hg2n//w+4CDWzxww=
                    "]], 
                    LineBox[{983, 1016, 1015, 1074, 702, 663, 1104, 796, 742, 
                    1018, 745, 1017, 744, 704, 664, 1019, 1020, 984, 985, 707,
                     669, 856, 674, 1108, 805, 752, 806, 1109, 675, 862, 678, 
                    1029, 1030, 1028, 1032, 1031, 679, 863, 1083, 807, 1082, 
                    808, 832, 710, 753, 754, 858, 857, 1081, 802, 1023, 747, 
                    1021, 746, 1022, 800, 1079, 852, 853, 799, 1105, 665, 850,
                     851, 798, 1077, 797, 849, 1076, 703, 1075, 983}], 
                    LineBox[{801, 855, 854, 879, 705, 666, 971, 929, 748, 885,
                     886, 887, 972, 670, 859, 676, 860, 861, 803, 1107, 672, 
                    708, 986, 987, 1130, 671, 1024, 667, 1106, 
                    801}]}}], {}}, {
                  InsetBox["\<\"\[Mu] = \"\>", {-1.8, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["0.2`", {-1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {InsetBox[
                   SubscriptBox["C", "J"], {1.4, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["\<\"=\"\>", {1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["4.91`", {1.7, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {
                  {PointSize[0.05], PointBox[{-0.2, 0}]}, 
                  {PointSize[0.0125], PointBox[{0.8, 0}]}}, 
                 {PointSize[0.007], PointBox[{0.4463998339305619, 0}], 
                  PointBox[{1.2771956561278897`, 0}], 
                  PointBox[{-1.0806611991222994`, 0}], 
                  PointBox[
                   NCache[{0.3, Rational[1, 2] 3^Rational[1, 2]}, {0.3, 
                    0.8660254037844386}]], 
                  PointBox[
                   NCache[{0.3, Rational[-1, 2] 3^Rational[1, 2]}, {
                    0.3, -0.8660254037844386}]]}},
                AspectRatio->1,
                Axes->{False, False},
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                Frame->{{True, True}, {True, True}},
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLines->{None, None},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None, "TransparentPolygonMesh" -> 
                  True, "AxesInFront" -> True},
                PlotRange->{{-2, 2}, {-2, 2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.02], 
                   Scaled[0.02]}, {
                   Scaled[0.02], 
                   Scaled[0.02]}},
                Ticks->{Automatic, Automatic}], 11->
               GraphicsBox[{{GraphicsComplexBox[CompressedData["
1:eJx1XHt4zNfWjjZVB3Oq4SBDEUcjrsct9JzSVaZyUGWo9lOtcWnrS017qPs4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                   "], {{
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[0.3], EdgeForm[None], 
                    GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxNmgkYllMWx9977ydLyUgMspQtiVIIhZI1ZakhTIg2WVNZGkuyRsNYx76k
sU3Zx74N04TIOhKGYWQPo7FkHXN+/f/f8/Y833nOvfe9773n3Peec/733K/D
sDGDjs5VVbVaqqpK8DNTVfUNWjZovXgwP/i0oLODdghaLuicoB2DWgb9GPRD
0NJBe0T/3YOmRnlA1njLB7WuVG4ErWAe01W/Mm8RtE1Q56CNg1Z029JBa7ve
JujnGPenoNZBA2P8vYJujPKewVvG81WDjon6zkHLB62OXpah3RKyrGGOLGua
I8ta5sy3WqUxef+cGH9y0LFBW0R9vaD1g7r4HWT8X8y3its3qFT+dVBHc2Tb
0JyxO5kj40bm7bwG7SzjxubIWMXcv8QcKwZt4jbmXj/aP4q2m4M2jXr7oA5B
O0V716BNgm5NknnzoK6Wl349lpB3S3Pk3cocebc2R96e5sg7IMZcLejAKPdy
G7LvFm2rBh0Q5X4el/F6e72Yv4858m5v3i1o55D1kXj34aATo3xk0EpRPiJL
9p3oYz34DruYo8d2ldaFOXZ1G3PPYK8GHxzU3/qgxwBzZN/dnD24m+Wl355B
23rsvczRY6A5egwyR4/fmPf1extbpn0ryYD8KUuW0UHDPS7j/db6IPsQc9av
uY7IdaA5ehxkjh5DzdHjYPM9gg4xR4/9vXbMMcxtzL3fEus60vqgxy4h55Ox
dk8ElSjnoJWjPMLy0u8wryv6HW7OeEeYM+eR5uh3lPkQy7WN12n1JH2ODroz
6Jqga4N+53VinmOsJ/qNNUe/g7P0Gcd6Zq3p+KBjvb7Ie5w5+nWPPt2CRiEv
3yLo1zH/Ge53fNA+WfNOCDrdY/HsJOuJfiebo99a8f6aSfqdaHnpNzFojGUf
FM/XSZJ9WIy/TNC6+M0seScFnbaE7O2T3j2FNYs++wetEW2XRf2coHNNJ1mW
sy0vazbZ/ET3PdH9OiSNNyXoAs+Hfudmyfp71j9JlvOD/rCEXPtljX9W0IV+
jzUbktV2cdAlfo4sl5ojyx/NkeXA6H9A0AYxzwlBQ4I6Bp0WbWOCNowyAQlZ
rkKPqHcN6hTUCj8ftFGUG1n7gTVaLkte9sz1lhv9ukS/K4JPD9oo+rQO2pjY
kCXvtKA/LSH7jebIfpM5st9sztrfYn456x5jDcUfB031nKzNs1HvHtQt6H7P
wdhjs3S6Leh263d10B3m7Pvx0WdcUOegu6zTdUF3m6PfFvjDrDnvStLj3qD7
ltDpuiW+4QOeH52eqSQTbTMrzcHYD1u3W4MeMf9z0KPmrOFj5jOCHjdHl78u
odMT5uj0pDk2/ZDXkTn+5jbmftBy8WyzJD1mBQ3K0uepoKetG3LPiT7PBd0T
5dnWgzGeNWee58zRaY45Oj1vjk4vmKPTi+bo9JI5Or1ifdDjH+bI/qo56/dP
z82cb5kz5+uWm/W+J0mP14LetNy8Mzqrz7ygN9yXZ297DOTtiX8Cd8QY71hu
5H3XHHn/bf5y0Ecej/n/5TF456V4/8Uk2d9zX/RbJav/h0Hz3Yau60T71tH/
G2QL/m3wKvin1gG9F5ij92fmyP65OfOvGeNsmTT+K0nyfR30pXVA9i/cF/22
jP5rZ8nyH7fR72PrxDp9Yz1p+9n9GG9R0CeVZPzOHBm/N//Mz9+wDt96DNp+
shyM9YP7osfXIfPcoIVR/tFt9Fto2VnL5PVh/iamBLeVJDmYv5HEGXupJM54
o6O8XdLzw4J6Jz0fGdQreeygt5NkPDT4tkljDw/qmbQGo4JvE5SD+gQtkxZD
xsW4G6wL9u1r/A7+3sH4HfwNlm+VhLmbuBw9tk86BzAGuB5MDx5ewXh/uarG
9MzBOQDs39JrAPYBAyHTIn+T+cbm4Hmw/I3GzWB5cDxYmffBxmBlsDh4FawL
/qbcpqpxPFgZmVb3O00cv2ZV436etfBYPAfLg5fbVzXmBr+Cr/9nrIxM4GHw
cRPHU+csxDicTXaIcfoafzdxfKeqxvodqxrHd65q3M8z7A8f84Tl7eL1Qibw
cFePBy4Fp4LjaQfbg+vbJGHmPyfh+80qyQ0e3txy93C9ie97VDW+37Kq8T11
8CA46pCqxvpb+x2w6C7WA7y2jWXdznVk7+16Zz/vVdX4vk8lTE8ZmcH1YPod
LSvYc6eqxvQ7V/U5obdl7Wc5mvgYHHlbEr7fp6oxff+qxvQDLMserm9rPfeo
aky/Z1Vj+r2qGtMPrGpMP8hrwdjg77ZJ7X29drtZPnQA9+5rHfZ3fRfLS31H
Px9c1fh+SFXj+wOqGt8fWNX4/qCqxvdDqxrfH2y5h/v7re2162K5wbxgX3D8
SOsDlucccmils9pRluHvSec3znVNHH+4ZQXTjq5qHH9kVeP+w6oa6/POsUnn
Q3A9WPs4y4HcYOExVY3jqYPhx1of8Dj4+4RKGO9o697E8YtxfRbeR1/w/CpJ
uH24n4/39xvhNuQGD0+wvGBhMHE74/7jqxrT8wwsf7L1QVawMbgZ/D7RMh+f
hOnB8GB5cPypnhu8PMmynO46sp/hOlgePH2m1+5Ey9fE7mdXNXafbJnOdX2C
n4Oz105qR9b1kjDzRM8N7jvfc1/gOjh/inVBjgv9bP2kMvKBzcH0F3kO8PDF
VY3pL6lqTH+pZbrMdeYDd17r+a53HewO1kW+jj7DIDdYHuwO7gX7g/uvrIT3
wfhXW76pHgucDX4Ee4PlwfE3WD4w77SqxvHUweCcAcCvnY3RL6xqHH9zVWN9
3hlqzH5rVeN+noFVwXvgPzDrTNfRCawL9m3ieOrX+J07vBZ3uY5MYNj7PN8D
rvfIwvSbphrr32V96AsmBu/f7XXgbAAOv8LyPeixmvj7r9YP3AsObmJ66k1M
T51zBmeSGdb1IY/VxPTg4Cbuf7SqMT1zNM8APLs76Rzyl0rYfKZ1ALeCLz+w
HmDdp6zzM64j92zXm1j8harG4i9WNY5/rqqx/uyqxvHPVzXuf7aqsf4c6/Gy
x2IOsN/rVY3pX6lqTE99c2PkmR4LfPumdX7FYz3tMcDNf0nC93Mt05ueA2z/
mvUFA4N9v6p0rpnlb4qM4N63rcc7rjfx/TtVje/f9Zzg1Y88xyeug+vnW37k
e8/vzHPfDy37fD9rnlWaun3qscDdC92niekXVDWm/8zyfeH6HD9rjrXAYzE3
43xpHf7jd7bKwvc9kvT50s+QEUz/tfX51nVkWuQ65xHOIb9UNb5fVNX4/jvL
94PryPej68z9k+vM97Prc42dkeObJKy/FbEkCz+De08NPizpLDQhC/e29NzZ
+Jy5i7F3E+sXnwl4Xhm/g+uRYZExPdj9PGN9sPv5STgefP+HJKzP2aB5ZmhY
pmWN4Q8P3j8phm+YlRcHt4LhWxrPQ2B78OrpxOIs/H1/Eo4Hw48NvktSrnXH
eN4l6FdR7hO8d9CDUf406JMk3MncnCOY56h4/pjf/SxoQRI+6peULwRj7JmU
YyOmg2+Qd3GO033BUWAdcAfPifdgB9p2N44AB+yRFLOJ1xckjUtObB9z4inY
hPi9GIsE3yupDl/bcf2O4INdbxHyL5WVb/tNUhwlhu6dFBeJiWATYj9xf2BS
X2LoIc7h8XzfpPwa8fVIj8U7pwft77GIF50c136blAMjziILcZGYSGyiTIzj
PeIWMetC68k7+yWNQzydkDT3hh6XuEn8OYZcl/Np45NylKzNAUlxlPFPYY2T
YuRRQYck+T9iBG3TLW9Xj31a8BNdPygpXk2tFF+6+T14d5dXZB9l5XUOTuL4
vjZZ8+BjV45yW+c3iFnIxnhrRFs75w7aZ9nlQvsFbBFfsZp9yXzbNPb0k+0S
e8L2iu0p2362cxvPOF9jm9hWbz9v6z0MTsYHcAbG5q5gL6T6TNzXdnBl8LNS
fbbewXbxaNL+Zm+TZ+5nW8AWd0qyx6uCT/Y73Hdgg5vZdjmTt7DNcp+1Er4r
yeZ3W2JPn2x76u/vuzD4l6nG33DsaFLSvgSzruYxsDVyy9gRtgmOxsawL/by
QO/z/7I3k/pdEnRxqv3UKK8tdonNYC/Xsjdd/ypoivcuuV84dko+Fhu4yPt9
iPfket7f7G3sE9vALrAf7AFbIFfMnsfW1rVO2OBJSfubcfi2I/x9O3u/TvX+
Guo99oL35SzbNzY70XsfuwBfzUvKs7C/2LPYCPiA/TXS+4j9OMx78rqknDU6
/DHo0iQ//nSSDWO/lwddlpT76W3O3nsnKQfEfvwg6S4TX/3XJB+9knXlO67j
b8h+4Pvjy8ckxSds/QjvEWQ/Osk22I/jkvY460T+mvXAxx7r/cI3Py7Jx7H2
5Og7ep0mJtkwe2289xvf7SSv+X7WHZ+BD8C/sJb4C/wGvuneoBvS4s+y2BZZ
G+wRu8K+mraFTTXtCRvBJth/7ENiCfuOfdiMm5e4bVZSbGjGhSkuE2cv8jdj
X7I/2VOc4yZ5XQ/199rWMk61nKP9vZCX+/ErLSN34ldZRvQ+zbr+wd+e8fD/
1yftXe7Nr06+O680fivHi2uS9h936MxN7u5PSfkmfAU5J8rkvjZwTCbvc19S
P/pwX095mSjflJRbW7YSJqBMHot7c54R929JyoPhW9pXKncI/kDSM9rx32B7
8Cp3zbS35dtFeVs/m56Uh9rMslFet5I/m+72M7LkJd+za1behrzC7Ul5HHI4
HbPKO2BfUe6VdR+1m/n57gPe4H1k4OxxQ7Q/nmQn2Aj63W8diS3gc7D43ll4
HXvfyWvHuuFfH7C+YBxyVeSpHkpaZ3S51WVybOAinnEXz5i/8RzbV3oXn889
9qMuI9tj1muGy+SB4I9bZt57xP2JP+RriEHkTSiPMn/SZfjfXMYmZibZBft9
lvc88eGpJD/KOj3jteLuhHPa3Y7FlP/utjkuv5x0Z4Cvw+e97DLEeYOzxvPu
f4/b6P9+pTV+wetMjH7R7eB8zkGcR17nmwT9z23/SDofveoyvhSf+qrLYGnw
P/Gf56+4fa7HwT8vdB08T9s8t1Oe67nw/bOTcMqbSWNi5G+5Thk7I0+NrdH2
z6Rzxwj3ow84A0wPnv9XUrmFOXV8+LsutzB/x+3Y979TbePvJdns+553Gev6
puelnXhALMD+PkyyQeyV3HOHSu+97z4fu50+4PVPvJ8PyvqPBXXKYPrulfLY
vAPmH5p197/AMvaxnF8k4Xtix8MBiB4p8qfbZ8Vy7lW5I8B/0b+124nvJ2Q9
ox1/xz0CuXnWgf74wal+n+ecZTr5PNMvK1+Jf4AXl8nVM+DKwbbOqlPu7TJ2
Cq4nh0gOj3HwO+Q98YPcNZCnP8lt5Ag5rzAHOO13Wec9+lHmfmI5+9G9PEbT
N51nv8HaYsf4H/wsffENnPnJA5D3A2+Btch78S4+DVvlGbhoYlaZPuRLkf8g
+8x+1j1ZF/wnsgy0bKwzZ9cBHru/ZcPn7Op3+a583yesaz/r39L9ketJ99k7
+p+alas8y7KwppzF+nsO+oMvvk/CGHxH7oH4PNS/ta0s7XbiHvxH92GNuAci
TrV2mXjFe4tsO9+73NP8O7eTr+BsgN3Dqf/X5Q4+M3RwH9q522FvrWLb/dbj
gEvQn3MTvJXXjffJCTA+uXHwN5gLDPWFbWFk9B2Rlf9lbVp4fcBPS3nvLZuV
IyY/DKcObu3l9yZVmpu1JF840v3HeW8jc/NeCr6+17+l5cQuP0/6XshLLgNf
B/bnLADeBxOB48FQYD3OCQO83j97/cGn4HVw01zrzjicr1jb9yq9zx5mz07K
2h9DbHNb53qNt7ZtkgPkDpv429Zlznp3Wn90B0OAJaZVWo9eXivaiPE3VIpf
lOnLXNj5iuZ9XH7QddYJ/8fdHL4Rjo/Dv5Hb6Osy+eNtPT7+jz4fuQ95kHUq
ybKN5fmBcYrOnN8H/3eWz1g+DoK/aigWtgnet6F4t2LwlRqKi22Dr9JQ7God
/Jus+LlClLdvKOa2CP5Fli9tFeWWDf2XBKyBjovzMNhrQ+ezuSHDF0V466fg
Pxbt0w/4DkUY/eMo/1x0JpgX/OsijLUg+Jtet8+j/McsnPNVlC/PwiqfRvmz
ovlH+TuTa8ev4/c5v7EW5PTYIydn+VPubyhzl4MvPcVt3F2AUQbbv7HO/E+R
u82uLrPmj9iXdjeWAGOBrzhDc5ZmDHwqvhWMwT7k3gL/yfmKMnGHnDP97rVf
PcW+jPn3tWybZd0hgaPusb/GV8P39vjd3Idz8XGuUx7lMhhtU+uA/PyHh9wL
dxncgaJfN+u7Sa7/n9nF/elLTv8K2xnr+V/v2y7uT9tWbicvQ/8ZVb12jI+M
6MM5HmzHnQHYbKrL3B2Qs+Guodm2hfuQJ9rYMjAe+rRx3x7uAyYhDwsGWysr
rw1mA4tRBteRGx/tNYQfZtuHUycnzf0dPrN5h8f93yGVYg74Az823P14zt47
1N+0tcvLm0Z5T34c+/QfRbGXvA1xMH6L8RA5T7DcEPe/yH4YP4u/wX8yL7Fx
acvGPd4I9xnn8nC3k/c7uCl/Vn2cv+N4f8txLrMHuJPlvwvtK8lyrOVhTQ73
+pztd+hP7m6My3DqfJ+zsvpd6bmOcZl9wD3Obc21zL5PzZKveUc5zHLyf2bk
4Lyzir/RPMvAHGOX0GGGfThy0pd8L/f3nF/GWZ6xJt4lxwmewA9gX8R9cBT4
hLaT3Q7WA6+AVfZxfzAYeIv+4ITj3Sd7Hcj7kPMh5mDz2PsBLvNtsW/sHN+y
n+v4nH1cpn2wZaBtf/enLzgKnLen66d6/CEug38muA+6cLYlZ8fZjfWgzDmX
/5ac47XlO0/2d+f8e6b78N8H6pyFOVee4XbOoeT7lveY9KcvOH+yxzza68x3
nxL8914T2hfXK60pa0fekjzZad4/fPPTPc657j/F45zrd8d4zKO9R87xfp3o
d8gH7mgd+L/DmdblCL83xmNy7ls9Kz7gV4n93JFxFuQZ8WKlrPMnsW+FLNsm
FhOTse1plWyddmyW8XiX2Mp+ZF++5v25ahauaOYZm3HgQH/Hdt6/H/rdw1xH
rpUtG7IgE3m+VT0+d5c93e81+x9kJUaTCyM/Qny5y2XuQInH5EH4tpxjwENg
IeIu+QvwOHntdpYHn7puVh7xMfch/uJT8bP05Tn9Ft9/JZ3fPjHmYS5iN2dJ
ckCcXznLow85duRa0bKxnqO8vujfzjrC13B5vsfhHAoeIu/DWfIWl9mPbWJz
/TMrRgwOPLJGUV7wiuCvZOW5O0T7Og2db2dH+zJFeZeB0XZxVs7yjeCvZmH/
sfF8XFH8GhR9WhXZxKnBJxXFrneDv1OEB38bfdYv/g9xlDds6Gy8MNr+U4Qj
2J9H2r5YW/wX+5e2o2y/Z3m/L/6Pgu2C+qIY45ui81D3GLtLQ2sPNmH9wSdL
RdvNRfnd98CERZjl5OCnFOWe342+3xXla3ojZ1F++ezgL2XFq6+DL91QjmZo
8K5FeZdO6OL9tnqU52etzz5guqLc7TXBfyjKAXUL/r1t4bQo56JcOBjwoywc
eGyUjyvK2YMlP8nCkydE24SiHPxh0d62yM+dFbwU5aq3AGd6T+4SfXZo6LzR
CH5tFk7uEX3GNpS/6RnlrYvy0Kzfpl7DrsF3L1rDdRi/IV81JMrbNXSvdSm4
tCj/ezH5hqKc6xrxfKmi/MqFMeczRXnVy4NfVpRn7Vi01qzzelG+pQivsvbb
e/3b8V4RriT+gwPAHg8WrR3rtmvwZYtsoUeM921Rn82i/KXlPyR4n4by3XyT
ng19l90YuyiP/3KWbWAX72WdHzg79I++qSivhK2sZ3uZH22PFuW4zw9+XlHu
eUrw3xflyq8Nfl1R/u/DrO/KN70xyzawiy7RdmRD+fs7onx7Ub78ruB3FuWq
b8/ac+w3+m5S1P/94I8X5cQ50xxa5Hs706ehMxP7caxtduNom5d1tuoU5f5F
fmPdhtaRNbwg+IVF+X3OPcOL/P+LWfaALWwQ7R8VnUk/CP5EUf79tuAzinL5
I4KPLLqTuCPenW0fvhY+oOie4Z6ib8z33Zm9XHRHMiv4U0W5rfPivYezchHw
NRsqDwjeu+g+5kH8QZHvnR5826Jc4FXBn7VPuyj6PJIlM4F39YbyhuOj/FzR
vdpu0bad3700+j7quICtbFlsL1Fe03Z9dTzfuyif8BN+qygnMTj4vkX3NDn6
ty+6t2G81z0m57nHHBeeJVYX5Wl6sR4N5VAeKLIN7OKg4EOL7mmGxPObsu6I
Vom2LRrKL+zFPEX5j+nx/GnHlDuJKUXrf0+URxfFke6sX9GZZe8Y47KsO6gZ
wYcVvctZ83HHu2lggaycBrru3JC+6PGWdWGN2R+sc9/o80zW3TXn8s2K8MZT
0bYw6yxzX/DDi84pKwQfUHTmYs5/ed6J0fZS0R3hSkW+D79HPNnIMWWDonVh
TdjXy3tvE7taFsWvQUU+Av/A2bp10fmaONmtoVj5t2h7sugOcE/2RdHdHnKt
aNnIK6xq//BC8KlZ94oHFPlHfCN7/IWsff58lp1gI8/jE7LuYPGv+Cl81HNZ
PgV/ckOWv8ZXz8myc2yctX+7aP33D75f0f0YdvB32wL7fbb3/JjgD2Xl0Pj+
d9gGV25o3VlzvvN075P25D+y7l3wJXdn+RP2y13GHuyXe7P2zLLRf7mG8vXE
tE2L4tovwbl8524D/3Fblg95Gt+WdVd/FH6v6P872O79xk7Y4vW2R+LY5kWx
bGZRnCPG3Rj8pqI7QvzEZPsK9tFfrNcRUX4gKz/G3vmz989i/1fkA7dpyFax
0x0beof+9zJOUU7u8yysAE7Ar+Aj8A8LsuIxsbhPkT9i/VcusiXs6JroM6fo
7nBuFq4CU12ShZ/ATqsG/yXrvmXtKO/ZUF7/T9H2YtHd5BNR3qqhXCHxfCfH
9Dfi+etFd3RfZeEwMNhJwWdl3W2+FeWZWf+puT/K9xXlEZcu8rOs25VZGBF8
CJYhzwWeAdN19pg3BJ9WdH/VwP81dF/yf0t50F4=
                    "]], PolygonBox[CompressedData["
1:eJwtl3f8llMYxt9z7kdbQwNJys+skHZmWRkfmZFRKrKVvfcMpSEjFaIkJCol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                    "]]}]}, {}, {}, {}, {}}, 
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwl1WfcT3UcxvHDbUX2KkSyGmZW9h5l3+qZhi3rTsmDIiKryMgqtEMhRUbc
lLL3yCokpIWMzIze31cPPj7X9/qd43/O75xDyS5pqf0zJEkywh87MibJ7pQk
KZEpSdohq7weGzAaO62P4l08hjdivPw6v4GxMWMc3tRP4ImRMRmTMEE/hafi
LUzHtDhOv4nfxm55Bu/hd3gLNiMb7nVde/V75JLyfSiNUmipuwNl5Oz8GB6N
33F8qu5Oeb/8A5cz348H8QBa6XLiIbkCyuOAY/PonpNzc2vkRS9zPv7JehX5
YVREZVRCG2tV+Ryfx9844tiC/Lh+mtxe7oDCqKYrxNU5lWvwZb6CSzjm+Kt8
N3pbK8IndAP4ebyArXgPp/QD+UUMwna8q/uYP8FLeDmeq+4j7JTn4Yw8mIfg
lXjG+BQX9UN5WOwN+sSecS6+ZC0n54n9QSN0tbZA/5R8hRubN/FCPB37Y74q
55Xzxz6iMXrqv9R3ka9zk9hD9Iv95Wfxlb67+QY3NTeXW6AJmqEp+uiXW79L
vs2F+RbX1teKd0luxnXR0lqdeEc4jb+2VkzOLBflTNyGG8az5wa8Dt9jJFLi
mvEd1sZeO/9X/hav4QsswjfYZu0kr8EIfI6FWB3PztoJTsfw2D/Mx0qsiuvC
CryKjPgM9eL9dk31uRVniPeDEy7CK/yd/eVl3MP8SOwl+sb7hQG6mnzTeoF4
/1AQS8299Uu4m7m6/K9cjbuaF8u94t64s7mKfE2uzM+YF8Xvxf3xZhyXf8Fl
uWL8fnxf3A3dUR5P6ubHs4974404Jv+Mf+Ss1udyp/hW43uSs8hnOY2X60pj
Lk7rMuvmxL1jaeyV+QP+EO/HexT3hzr62fF9YBau46TzF8fzx0wcN1+Le4h3
ip9wzgz5kHwQB+Ia4zvBdP0aHMWFuH5ux22RP95h5xbg/diHs/HdYarjVuMw
/ox7wF/40ZyLOzpvipyOg+hpPhT/jiGH9fbmSfIqlJV/0/2OvfgjfkvfQT+Z
m5tbIEtcl26cbiXukYvjVMr//w/8B7p/ylQ=
                    "]], 
                    LineBox[{986, 1020, 1019, 1079, 703, 665, 1110, 796, 741, 
                    1022, 744, 1021, 743, 705, 666, 1023, 1024, 987, 988, 707,
                     671, 858, 676, 1114, 805, 752, 806, 1115, 677, 864, 680, 
                    1033, 1034, 1032, 1036, 1035, 681, 865, 1088, 807, 1087, 
                    808, 833, 710, 753, 754, 860, 859, 1086, 802, 1027, 746, 
                    1025, 745, 1026, 800, 1084, 854, 855, 799, 1111, 667, 852,
                     853, 798, 1082, 797, 851, 1081, 704, 1080, 986}], 
                    LineBox[{801, 857, 856, 880, 706, 668, 972, 931, 747, 887,
                     888, 889, 974, 672, 861, 678, 862, 863, 803, 1113, 674, 
                    708, 989, 990, 1134, 673, 1028, 669, 1112, 
                    801}]}}], {}}, {
                  InsetBox["\<\"\[Mu] = \"\>", {-1.8, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["0.2`", {-1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {InsetBox[
                   SubscriptBox["C", "J"], {1.4, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["\<\"=\"\>", {1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["4.9`", {1.7, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {
                  {PointSize[0.05], PointBox[{-0.2, 0}]}, 
                  {PointSize[0.0125], PointBox[{0.8, 0}]}}, 
                 {PointSize[0.007], PointBox[{0.4463998339305619, 0}], 
                  PointBox[{1.2771956561278897`, 0}], 
                  PointBox[{-1.0806611991222994`, 0}], 
                  PointBox[
                   NCache[{0.3, Rational[1, 2] 3^Rational[1, 2]}, {0.3, 
                    0.8660254037844386}]], 
                  PointBox[
                   NCache[{0.3, Rational[-1, 2] 3^Rational[1, 2]}, {
                    0.3, -0.8660254037844386}]]}},
                AspectRatio->1,
                Axes->{False, False},
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                Frame->{{True, True}, {True, True}},
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLines->{None, None},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None, "TransparentPolygonMesh" -> 
                  True, "AxesInFront" -> True},
                PlotRange->{{-2, 2}, {-2, 2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.02], 
                   Scaled[0.02]}, {
                   Scaled[0.02], 
                   Scaled[0.02]}},
                Ticks->{Automatic, Automatic}], 12->
               GraphicsBox[{{GraphicsComplexBox[CompressedData["
1:eJx1XHt4jNf2Tv0UxZCjKRqelFPNGUUbIaqKpdI6qEukLqFplLrFtJy6R1VR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                   "], {{
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[0.3], EdgeForm[None], 
                    GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxNmgn41lP6xr/nnFeirCEqlLQhMiWhRWWJEBFJQ0WT7CL8lUR2w9hGGDOF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                    "]], PolygonBox[CompressedData["
1:eJwtl3ncV0MYxe/M3Opt0aaiQiui1EtRPpW1jawtSNbspOw7IakoLVreNoRK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                    "]]}]}, {}, {}, {}, {}}, 
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwl1Xe4j3UYx/GHQyGzZBWnY29CLjsyo78kIyNEqC5SGRVClD2KXCpCRtmb
hjTM7IasyMheDVIZve7LH+/z/tz3/f39zvf5Ps9zTlrnXs17pkuSZKgfG9In
yeaUJMmXIUka4bp6rfpTDMRG9QDexIP4M3yOwRiC1/EGhmK4NcP5TQzDCLwV
tf4oHo2RGIsxMdP/gsdjszyOt/AE/hLrcEOd37628hZ1Afk+FMT9qKN306yQ
fIvrqh/GKPlRvXTydvk7fkC9TE7jeur0KCwXRRHsMMuo103OwI/gDjylvpP3
mJeUS6EYSqA46puV5pN8Cr/hB2uzcDP9sXIjuTGyoozeXVyWm3A5Ps8XcA57
rb/I2dHJLAfv1+vG3dED6zEJh/Sf5efwPL7GN5iK9/ACesc9s24jb8AHOK5+
kV/Cy3F/MQ1n9Ptw3zgvdPb7U+Mc+FycD2eK80A1tDGbqf+EfIGrxb3jWWgZ
Z6u+KGeOa0YWVEd7/bn6beTLXF1dEl3iXOPM8Yl+O/UfXENdO+43aqAWaqKT
/kLznHKuOCv8pa6gXx5fyTX5wXguzCpyXe7Ki83ulf/l3PwPN+CqZvX5IV6D
1XgN18zn8CqsxLfqg7wCr2I2PsLyuAdmB3gZXsGsOCcsjXtktp+XoD9m4MPY
D6pgUVwT+uFva6dzJdSzp8rxXPJV/bv5Ct/Di7iL2QJury4nPx33L563eG70
yvKf5lnl7MiG+eqO+h9zW3Vp+Xe5FD+pnid3kOdw63je5UtyMW6lnh33KK6b
12Of/DPOy0ViD9YUju9CW6Shhd6M+L64bl6HvfJPOCvfimeUH7euULxP8k0+
wc/oLZDz430c07vONzA/npk4Q2ve5SmYHNeGeXGG+m/zO3GNuIwDPj+Xc2Ii
9qkvxTVwNn7MZ8bLu+Sd2BF7jPcE4/RX4kecjv1zQ26ATOjos5l5O7bF/uO9
wxjrVuB7/BrXgKPYrU7hpj43Wl6OnXH+6l3xNwyJeWP1CHkpUuVf9A5jK47E
79Jvoj+Sa8V7g/9ib3rDeAnyyHlxKOX2/4D/Ad45yXY=
                    "]], 
                    LineBox[{976, 1011, 1010, 1070, 693, 656, 1101, 785, 731, 
                    1013, 734, 1012, 733, 695, 657, 1014, 1015, 977, 978, 697,
                     661, 848, 665, 1105, 794, 742, 795, 1106, 666, 854, 669, 
                    1025, 1026, 1024, 1028, 1027, 670, 855, 1079, 796, 1078, 
                    797, 823, 700, 743, 744, 850, 849, 1077, 791, 1018, 736, 
                    1016, 735, 1017, 789, 1075, 844, 845, 788, 1102, 658, 842,
                     843, 787, 1073, 786, 841, 1072, 694, 1071, 976}], 
                    LineBox[{790, 847, 846, 870, 696, 659, 960, 920, 737, 877,
                     878, 879, 963, 662, 851, 667, 852, 853, 792, 1104, 664, 
                    698, 979, 980, 1125, 663, 1019, 660, 1103, 
                    790}]}}], {}}, {
                  InsetBox["\<\"\[Mu] = \"\>", {-1.8, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["0.2`", {-1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {InsetBox[
                   SubscriptBox["C", "J"], {1.4, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["\<\"=\"\>", {1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["4.89`", {1.7, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {
                  {PointSize[0.05], PointBox[{-0.2, 0}]}, 
                  {PointSize[0.0125], PointBox[{0.8, 0}]}}, 
                 {PointSize[0.007], PointBox[{0.4463998339305619, 0}], 
                  PointBox[{1.2771956561278897`, 0}], 
                  PointBox[{-1.0806611991222994`, 0}], 
                  PointBox[
                   NCache[{0.3, Rational[1, 2] 3^Rational[1, 2]}, {0.3, 
                    0.8660254037844386}]], 
                  PointBox[
                   NCache[{0.3, Rational[-1, 2] 3^Rational[1, 2]}, {
                    0.3, -0.8660254037844386}]]}},
                AspectRatio->1,
                Axes->{False, False},
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                Frame->{{True, True}, {True, True}},
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLines->{None, None},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None, "TransparentPolygonMesh" -> 
                  True, "AxesInFront" -> True},
                PlotRange->{{-2, 2}, {-2, 2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.02], 
                   Scaled[0.02]}, {
                   Scaled[0.02], 
                   Scaled[0.02]}},
                Ticks->{Automatic, Automatic}], 13->
               GraphicsBox[{{GraphicsComplexBox[CompressedData["
1:eJx1XHt4jNf2Dq1oMQ6aQzuclHOUqeqRqqgSXSqaainpRanLoKXFuBXF+KWt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                   "], {{
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[0.3], EdgeForm[None], 
                    GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxNm3n81sMWx78z84hkCdmTspQlUlKUZItUShJSSikhQm5RSLj2fd9C5Vru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                    "]], PolygonBox[CompressedData["
1:eJwtl3f8jlUYxt9zzpP1y4xfKdmzkAbS7iOhEKItIn0a0t7ZacguI2RmlIqW
SkRSCa1PoSHJSiWEhhJ9L9f7x/V5r+u5z3Oe5znnPtd9v9W639axd8zlcjtA
Bh5OudyDoHjI5QaC7QQDgQ/hH4HuxHqAdvBC8BPxU9C3wk8D/8LH6xp8KdgK
/49ry+Dvgxz8CuarwfXqyGPRbdEZ+lTi8/gdAi6G3wyOIr4R/RD8alCAbg7u
hrcF53Lvn8TPg68FX8KnEm8NPxp0Tn6G5u4LNhDvyj2n8VsffQKx09G/wHeA
3Vwvgf4M/gWoTbwL6AdvBu6CTwBD4GeBVxj/JGgPvwXcTWwSeBJ+NrgHPhkM
hZ8DjoN3Sn6XbmAi97bjeUX4Xc567OP3SPSXxNaATeg2jL8fXheUhLckvh9e
VXOio67B7wA/Rt+jseOZ72NiK8EsdBUwnFgr7j8A70d8JLHpYBh6ETiR2DD0
49o70BBdBn158Du8xv0jwGXBc+6BTyF+o/YieO87oPsE58DP8O3Je6E5n9Za
oR+GXwNawbuB/vB7Qcvkb9S33QMehT8CCsTBjfCblEPwmqA3/DZwrd4dfAj/
ADwHnwn687z+mkPPBgPQg5PnGgMugZcFJ8AfVI4Tv5xvrsRvBa0Pv22JP0Bs
HPgEvRG9AN6c+FD4FxobnHMl0F+h7wrO4eXo98E0+PTgtbsIfV/wGn6KPjd5
794Eq9Bfo1+B12D+1egM3Qr9OjgCXoP326i9Bj3RNyinlFvgPeUjugX8SDAE
vjSaX6BvVr4lf+sAXdPY5LPUm+f9Bl/HmMrB39CAZ43i2hPwbeB3YuPR18PP
VM7De4Er4bWC10rP0NxasyXwB7h2PrwYGIRuoj2DlwbL0EvRE+EvgQ/Qy9BT
5AXKOfi70ffqjDdF/4EuGjzHAJ1NUCJ4j58g9lHy3nfme4rCr+IbanP9BvRi
fpdw7RniL4LH5B3oO4PXeB18efS7vQwOwbtxf1N+y6D36flguLxB+Q//hli1
4DNyHmMHoovzrN3KEfTgfC7tRbfI/I56tz+Dz/LQ6LXXmdbZLK09Dj6j8qJd
xD8P9qRi6OJgNfygvg++k/gnwdc2ce+PybmpM7AGvhY8G/xOq+CrwWz00Jy9
rx7612APVOxarp0UPWY9+rvkXFQOH0NsLrHyOe9RSs5x5bY8aAGxT9HPyysY
UxnennuKcb2x/AreTzWF2M7gZ42K9iI987LMniuvLUR3Uq1AN0WXzXulao5q
jTxTtWNC9LOyvLfP1J4He3wXdFX0HuInoq9GH4N+FV0vf9ZX8Fsq+Mw3Q3cl
XiR4TRon1wjVht6giXIBbIefDuoTOzNzrdCZUK4VS66NyjnVuoAuF1zzWqNH
R6/9Ia69pb0lPld7xbVa8N+4thLdXWciuYaodjyl9eb+CLbkXJOPT67Rqs3X
gYHJHidvGwy+hv/OtQ7BOdon2RPlhYOUU+htqj3B7/Be8hlQ7itn/o0+kzqL
F2rNefYRYK9qC/ovxo4lPg39rvwRvSWaH84B9OvJvYQ8QE3GoeRap55gHGP3
o5fAu4JvdZ7kycEe+A/8b3By8Jjvkz1RXvhasBfLQ+Wd8uQN6B+SY6fkfHYP
5nsNneGJxF4AI4NrdHX4pTpz0Tn2fHKNV20foTWAvwhGB9fwhlqb5L1QzZub
XPNV60eBNsx1dHJvEaPvfSc6pjlehQ8DY+G9gnuHnYxZHNxDbIFvBW/DO/HO
o5NrtGqzPHgz/DPuWRg8ZqHeRd8QPOeu5JqvWq85tyV7oLxP96i365u89+rx
OvO+O6JzuXz0WZ0cnYs6syMYuya6tqjnk/fqDOvsyoP3o89gzO3aO+1XtAfK
+3Sm5E11ifcI9qj/oj1RXqg9LpLsifJC1dCz4Y24dhP8KzAj+h31bjrDqv2L
kmuxeoAF8DeSa9tjwWvxbXRvoDX5G17I/d/IO7l/Drpk5t5KZ3w+4+cl9y56
ZjP4I9G5rm+ag24Aegb3fOpFHk9+lnoSnZ1Kyb2cztAB9LHMvz7YI8cQWx9d
K+RJ1ZI9SV7UBL1C3qscgVcM9v7Wyb2QaoB63/LJvZJ64IrJHibvaoSuo1yJ
9iatsWrhoOSzr5o4Dr45P1Y90tPy8+harZ5BXpNlPsvyHPVC8ih5k3oinb0D
yb28zuBs+Kzk2q81GQv/Prr3Ug+gXk45rtxWT1cnc0+vXn4TWBvdM6tXVo+h
Wlwmc++umlxKZzFzbZZdVNDeZ967dfIb7i2buVdQjzMjuUdRb6KaXACfzZhD
OddM9dJ7o3NJPbV6jXKZ51LPUQVeObNXbAj2gmmM35qzJ3TUf4P8XpVUndDZ
ztybylPlJQujvUKeolzTmdBZUM5VQh+XuXdQTjTWf4/MtVs1ZFpyz61eWz14
VXi1zO+imlE3c44oNzZrD5Tv0b19F3Qj4hWSuXru6fmaqVopj1avLY+Vtx7u
udE1k2uL/tPMzNfcwvyaycvlYTHv6R3gVZJrd0G+d30q+r+Yetgp0WMK8mtW
C14zs3epR9V/tXqqV8H/2VR7Dyb/F1QNPj+5p1Uvqx7sl+ScUa7oTLzJvJOi
a5v+Y2qu+dFroTmn5vdIe6Oa+D9cys9b
                    "]]}]}, {}, {}, {}, {}}, 
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwl1He4j2Ucx/HnnGOWBiWjYxyEdjgc2ZT/yt6KKP5oUJRR5GSPpkvIJtKx
Q1KRrcyMaFvJpkIUGa/v1R/v3/vz/d73c93Pcz/388vo3L1Zt5QkSbL9rExN
klVpSXJrriSpiwvqT9SL0QdfqXvzKu7LS7AUr6EfXsXr6I9sc7L5DQzAIAyM
Wn8ID8VgDMcwLMOnGInV5ozgNTyKl+MzXFQXdF9rebW6kHwbCuN2VNf7x9gd
8r9cQ/1wrCM30LvMG7BWr6h6rlyMa6r/k4vL6bgTG9XX8JR8lWuZk6CNOoU3
65WWM1ACpVAStY2V4X28H79iq7m5+FH9YXI9uT5yo6zeXSiHBuryfJh/x2/4
1vwjnBftjOXjXXqduDOexud4B3v0n+Eu6IovMQY/6z/Lz+F5rMTYuDf9F7gb
usf7xbhYV/9FfgnF0N66Rflq3JexK7EXete4EjfnifqN5KNcOd4XT0Lj2B/1
MTlFTkMqKqO1/jT9ZvIJrqLOwJPq0twWH+q3VJ/iTHU1OQtVUBWZaK//kfF8
cn7kxRl1Rf0KsT9yVb4H1Y3dHeeCO/LHxm6Sz3MBPse1+SFjtfhBXoSF6IWz
xqfyA1iAFerdPB+vYAomY17sv7FdPBcvY1LsE+bgC2M7OQc9MQEfxP3gfsyO
Z0IP/GXueL4XNdzTfVyT/9S/gf/gG3k2dzA2i1upy8de4gmUQ6c4a3w6zqOc
B7kxU91Ofwa3UJeVT8pluLl6utxGnspN46zLx+WS3EQ9JdaL5+bl2BHnFkfk
9Fg/vilugZYojsf1JsS7j+fmZdgub8Nh+WKcUX7MvCLxLckXeB931JsV3z/e
xy965/lvzIwzE3tozns8Gu/Gs2F67KH+W/x2PEOcS+x2/TTOjzexU32Ud3Ae
buiaEfLX8kZswCEcxHD9BdiGA+rtXJfrIDXOcJx5Xo91ca/xPWKoefOxBT+o
f8KP2BTfFx5x3RCeF+uitfobXodL8R+iHshzUETe49q9WIPvYz39+vqDuJo6
K/ZHrqM3gHNws3wLvkv7/7//OoGDxsQ=
                    "]], 
                    LineBox[{968, 1003, 1002, 1063, 687, 650, 1094, 778, 724, 
                    1005, 727, 1004, 726, 689, 651, 1006, 1007, 969, 970, 691,
                     655, 842, 659, 1098, 787, 736, 788, 1099, 660, 848, 663, 
                    1017, 1018, 1016, 1020, 1019, 664, 849, 1072, 789, 1071, 
                    790, 817, 693, 737, 738, 844, 843, 1070, 784, 1010, 729, 
                    1008, 728, 1009, 782, 1068, 838, 839, 781, 1095, 652, 836,
                     837, 780, 1066, 779, 835, 1065, 688, 1064, 968}], 
                    LineBox[{783, 841, 840, 864, 690, 653, 954, 915, 730, 871,
                     872, 873, 956, 656, 845, 661, 846, 847, 785, 1097, 658, 
                    692, 971, 972, 1118, 657, 1011, 654, 1096, 
                    783}]}}], {}}, {
                  InsetBox["\<\"\[Mu] = \"\>", {-1.8, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["0.2`", {-1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {InsetBox[
                   SubscriptBox["C", "J"], {1.4, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["\<\"=\"\>", {1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["4.88`", {1.7, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {
                  {PointSize[0.05], PointBox[{-0.2, 0}]}, 
                  {PointSize[0.0125], PointBox[{0.8, 0}]}}, 
                 {PointSize[0.007], PointBox[{0.4463998339305619, 0}], 
                  PointBox[{1.2771956561278897`, 0}], 
                  PointBox[{-1.0806611991222994`, 0}], 
                  PointBox[
                   NCache[{0.3, Rational[1, 2] 3^Rational[1, 2]}, {0.3, 
                    0.8660254037844386}]], 
                  PointBox[
                   NCache[{0.3, Rational[-1, 2] 3^Rational[1, 2]}, {
                    0.3, -0.8660254037844386}]]}},
                AspectRatio->1,
                Axes->{False, False},
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                Frame->{{True, True}, {True, True}},
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLines->{None, None},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None, "TransparentPolygonMesh" -> 
                  True, "AxesInFront" -> True},
                PlotRange->{{-2, 2}, {-2, 2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.02], 
                   Scaled[0.02]}, {
                   Scaled[0.02], 
                   Scaled[0.02]}},
                Ticks->{Automatic, Automatic}], 14->
               GraphicsBox[{{GraphicsComplexBox[CompressedData["
1:eJyFXHt4jNf2TpVUMapFSjhxrTN6qJxIXFq1nEadFtU5Wq3iRCkaGUpdymhO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                   "], {{
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[0.3], EdgeForm[None], 
                    GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxVm3fclcXRhp/dPRoVMfaO1CiIVBEUFAXFghEsBAvSbShNEUXQRI0ascUW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                    "]], PolygonBox[CompressedData["
1:eJwtlwnUT1UUxd+995lLWaaShEhokCiKUpQmFWVR0iDNonkyRmXKXKaIElKZ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                    "]]}]}, {}, {}, {}, {}}, 
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwl1GfYjnUYx/Hr8ZCVEtlFDyorI0RkvQoN9ZSZDvNFRVZGxZOZWY7sjFCR
kYzDJqtkZJURWS+QXbJlf86jF9/7+zvP83/d9/W/7v99p7XtnN4pJUmSDC87
UpNkObJlTpLsuJIpSa5iFXror+ae/D3m4UN8hF7ojY+RYU0Gf4I+6Ie+UesP
4IHoj08xCPPxA4bgR2sG8xoeyguxANfUOdzPWl6hzik/iIeQC9X0rps9LN/g
59XV43Pkmno3eUPsQ+8R9Rw5D9dQ35LzyvnwKH5S30UL+U5cb809Tlcn8iZ5
ddxrPAd5IGrFfri2NanyFjkz11EPluvKW7mwOotcgAuhIOqpi/AB/hP7sd3a
g5wVb5pl4116rbg12mARRmCPfltuh/ZYjC/ivfTf4XfxHpZiNA7rd+COeB/L
MAbH9DtxZxRC47g//hcnzC7wJVxEKbN0nqTfQD7JldTPYrLcUO9x+ZR8nW/E
d4gz6qWYgv/UN7E5nheeQFPXFQtjujWvqs9x5XhvuTIqoBIqorn+t+b3OFHf
5b/VT/NTsTe5CpdGFfNSXJXf5u/MHpAvcRa+yNW4vNlz/AzPxRx0j+dgPonL
YTZWqrfxLHyAifgy3hcrzH7lmeiGCRiPGfH7Mtsa942uGIex+AZl8XXsHV1w
wdoy/Jr7mRlniv/hlDhnyIQZ6pZxPTdSPym/hRYoEVmvJJ83v8V3cDs+R92M
p/Er1hSXz8pp/LJ6qtxE/opfUheVT8uX+SquoLx+Yy7DZVE6nhvK4S9rHzNr
IhfhN+IsozDq6000fz2eGS/BJvkXHJfPxHPhF60rIB+VT/MRbq43Tc6DUTik
d4oP8lQuaV4Cn8sj8VnsAVPijOmnYbj8u/WH+TeezNkxDDvVh3hHnA+ua/1Q
eZ28FmvwB/ZhiP68+K6xV72N63BtpMSe4zviCnHO439CPYhfUOeXd/OeuJfY
u/7tmOkP4Ln4OZ6RemN8fvxm4r9N3ZdnI7e807W74jzGXrBev4Z+P64aZxmX
5ep6fXgWssrbU///v78P/SjHvA==
                    "]], 
                    LineBox[{960, 990, 989, 1052, 685, 649, 1089, 778, 722, 
                    992, 725, 991, 724, 687, 650, 993, 994, 961, 962, 689, 
                    654, 841, 658, 1093, 787, 735, 788, 1094, 659, 847, 662, 
                    1003, 1004, 1002, 1006, 1005, 663, 848, 1063, 789, 1062, 
                    790, 816, 691, 736, 737, 843, 842, 1061, 784, 997, 727, 
                    995, 726, 996, 782, 1058, 837, 838, 781, 1090, 651, 835, 
                    836, 780, 1055, 779, 834, 1054, 686, 1053, 960}], 
                    LineBox[{783, 840, 839, 862, 688, 652, 946, 911, 728, 869,
                     870, 871, 948, 655, 844, 660, 845, 846, 785, 1092, 657, 
                    690, 963, 964, 1112, 656, 998, 653, 1091, 783}]}}], {}}, {
                  InsetBox["\<\"\[Mu] = \"\>", {-1.8, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["0.2`", {-1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {InsetBox[
                   SubscriptBox["C", "J"], {1.4, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["\<\"=\"\>", {1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["4.87`", {1.7, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {
                  {PointSize[0.05], PointBox[{-0.2, 0}]}, 
                  {PointSize[0.0125], PointBox[{0.8, 0}]}}, 
                 {PointSize[0.007], PointBox[{0.4463998339305619, 0}], 
                  PointBox[{1.2771956561278897`, 0}], 
                  PointBox[{-1.0806611991222994`, 0}], 
                  PointBox[
                   NCache[{0.3, Rational[1, 2] 3^Rational[1, 2]}, {0.3, 
                    0.8660254037844386}]], 
                  PointBox[
                   NCache[{0.3, Rational[-1, 2] 3^Rational[1, 2]}, {
                    0.3, -0.8660254037844386}]]}},
                AspectRatio->1,
                Axes->{False, False},
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                Frame->{{True, True}, {True, True}},
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLines->{None, None},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None, "TransparentPolygonMesh" -> 
                  True, "AxesInFront" -> True},
                PlotRange->{{-2, 2}, {-2, 2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.02], 
                   Scaled[0.02]}, {
                   Scaled[0.02], 
                   Scaled[0.02]}},
                Ticks->{Automatic, Automatic}], 15->
               GraphicsBox[{{GraphicsComplexBox[CompressedData["
1:eJyFW3tY1NXWxmveMPNSOl4SSxxvx+vQ0c9c5qAlegg5mGad8XLEPAzeLR0z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                   "], {{
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[0.3], EdgeForm[None], 
                    GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxNmwn41sMWx38z89qyhSSRSkmoJClLXFtFSUSSSgqhJFvJnp17LdfataXb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                    "]], PolygonBox[CompressedData["
1:eJwtl3f4llMcxt9zztMQv6i0UNJEpPx0VUKD0kDLjiK6EJURRbQ3bUmFlNll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                    "]]}]}, {}, {}, {}, {}}, 
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwl1He0z3Ucx/HvdS8yInH8Q+VyyV4ZEdmz5JipcAr9kYoK2VvZxyaissfp
RCgqe69oyKw/siJ7j1Qe7+OP532+Xu/v5/v9fedN79S9ZbeUJEn6+bMjNUlW
IC0tSTLjZqYkuYU1+NB8LffmxeiL7/Q+3B/9YqYP5EEYgCEYHNvMh/FwDMVH
GIGlWIKR+N6aj/kHvoOWfv827zRbx19zFrOFclaurt+VH5HvcQ39OQyUK5rd
541YZZZdXyzn4Jr6v3JOORcexSY9MW8l/y8/L6egqZ6Jt5mt5m/inOXBqB3X
wpXjXsk75SxcRR8m15V3cV49q/wYP448qKfn41/5IH7BXmt/42x40bbsvN/s
dX4DnbAMY2K9eWfugjfxJSbgiPlb3BVv4ytMwnHzd/hddMNyTMaf5t35PTyB
Zn63IP+NU7ad4ws4j3TbWvP0uHb5L66kV8YMuY5ZunxWvsrXcCWOpa/EJ7iu
38AmbEYGmtuvCLfDbGsa6Be4il5KLo3iKIkSeNX8c9vv8j3cwSW9FJfEKrkq
lwlify7LHXm+bSnxTOM569f1NnKCeXJjrmC+CL3iGuK8uTwW4lt9Gy9Az7ju
uB9x3Hg3bNvK89AD0zAVc7Hati38BT7AVX0Kl4trwWd4P+6XeVlu5Dzmyv/J
l/mfeGdxP46hd4h9uGHcE7k9XsPTaB33iy/afpNv4xbm6K/wp1zfmmLxXOWi
XE+fJb8sz4x3Vy8sn5MvxjnEPY7jm7flIpwRa+I4KIoz1hay7SX5KW6D02ZP
ci2zaXKruCfxLce3KW/ACflUvKfx3VlXQP5DPsm/cwuzOXJ+TMQxsxN8lGdz
3nh3rRnH4zE2rhGzUMA8N4/GT9Yf5gM8k3NgFH7UD/G++F/CVe0zQl4rr4ln
jp9jfww3X4bd2K/v4QO8I95/TsUL9k/jitge34g+hGvpueV98ZvYi63xjPGM
+SBegs1oom/h9fHsUV7vz4uQTd5l391YGecQ99G8gvkAflavFt+ZXM6sDy9A
qrw99eH/+Acvzcjp
                    "]], 
                    LineBox[{953, 985, 984, 1045, 683, 645, 1080, 780, 721, 
                    987, 724, 986, 723, 684, 646, 988, 989, 954, 955, 686, 
                    650, 843, 654, 1084, 791, 734, 792, 1085, 655, 849, 658, 
                    998, 999, 997, 739, 1000, 659, 850, 1056, 793, 1055, 794, 
                    819, 688, 735, 736, 845, 844, 1054, 788, 992, 726, 990, 
                    725, 991, 785, 1052, 839, 840, 784, 1081, 647, 837, 838, 
                    782, 1050, 781, 836, 1048, 1049, 1047, 1046, 953}], 
                    LineBox[{786, 842, 841, 863, 685, 648, 939, 910, 727, 870,
                     871, 872, 941, 651, 846, 656, 847, 848, 789, 1083, 653, 
                    687, 956, 957, 1104, 652, 993, 649, 1082, 786}]}}], {}}, {
                  InsetBox["\<\"\[Mu] = \"\>", {-1.8, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["0.2`", {-1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {InsetBox[
                   SubscriptBox["C", "J"], {1.4, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["\<\"=\"\>", {1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["4.86`", {1.7, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {
                  {PointSize[0.05], PointBox[{-0.2, 0}]}, 
                  {PointSize[0.0125], PointBox[{0.8, 0}]}}, 
                 {PointSize[0.007], PointBox[{0.4463998339305619, 0}], 
                  PointBox[{1.2771956561278897`, 0}], 
                  PointBox[{-1.0806611991222994`, 0}], 
                  PointBox[
                   NCache[{0.3, Rational[1, 2] 3^Rational[1, 2]}, {0.3, 
                    0.8660254037844386}]], 
                  PointBox[
                   NCache[{0.3, Rational[-1, 2] 3^Rational[1, 2]}, {
                    0.3, -0.8660254037844386}]]}},
                AspectRatio->1,
                Axes->{False, False},
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                Frame->{{True, True}, {True, True}},
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLines->{None, None},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None, "TransparentPolygonMesh" -> 
                  True, "AxesInFront" -> True},
                PlotRange->{{-2, 2}, {-2, 2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.02], 
                   Scaled[0.02]}, {
                   Scaled[0.02], 
                   Scaled[0.02]}},
                Ticks->{Automatic, Automatic}], 16->
               GraphicsBox[{{GraphicsComplexBox[CompressedData["
1:eJyFXHl4zNf6V1QjFdtPlam1RadpkbqGVsmrYrspOjRaXB3XWkRRe1pV6wQX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                   "], {{
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[0.3], EdgeForm[None], 
                    GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxVmwn418P2xz8z800ishRZUgmVFlFIEaVsIYREkkJalOw72WXfZb243Jul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                    "]], PolygonBox[CompressedData["
1:eJwtl3nUVlMYxd9zztUs1acIqe+LrxINMiappUgokilKMi0yDxFp0KR5kCZk
ajVQ5jQJKVKKqKhFmstQilQS8ttrv3/sdfc+595z7zn3PPt5TmGX+9rdG3O5
3B6QgVUpl/uahhNCLvckaIXuBIbDe4PN9G1BL4IvBperj7YR8L6gGH0DGAZv
DE5i0KvRg+HbwD3wIWAMvCk4Eb6d5wfBbwX10XPRpeD3g4Hw8xjjH3gPvu8w
+kr0WVzL0FYJXhEcA28LPqd9OWPMhs8Bp8Dr078T/hsogm/lnqfhW8Et9N+q
b1YfOB7ejHsy7mmAvhN9F7gZXgdcAO9FX2v4E6A8ujH3H9RcwBT6+oI28AfB
D/D1oBj+LN8/Gf4kaIWeDN7k+bfANHg1MErzQw/UWgQ/exn6qeAx9K2vgBeC
v7km/Dqtqb4VlIKvSJ77ejBdcwXXB7/jR/gP9C+Afwiq8+01M6/FbWAHfT+D
T+GNQGfNHVwLrwqe4vmZ6KnwdsxnDLo5z5fguhC9W/+S/rvpPz94rlozrZXm
3Bv+Pm0l4C1AH/QS9NHwy8DFyWuqteyle+AtwRXwroz/GLwbyLRWwXNrje4T
PMey8AtBz+BnysCXR+9l/ZN34Q/Q1hwewaDoPay9qzV9FP1o8tgT9f36dnAE
/BlwO/wOcKPWXv9Uc02e61jwLc+P0j/R3gfr0G1Zn4ZcT0F/yXUk/e3gx4Gh
8PFggsYCe+gfjr4P3iy4723axgffM1b7Jfpd48Dg5DZxxdS45BhTbOmZZYrN
5LWtDB5D90iey3OKGXgBqA3vB96ArwTzgmNqP/dfwfc3yv8zmUQGvoW31B7i
3h70HalnwUPo99ApeI3nwKfS9jJ8RrBXtEl+lzxjmMZHD4DfFDzWeejuwWNW
hn9PW394J7AIvkhrovXhc+ahp6FfRc8EGXyh5hgcozPQr4MpwXv2Y/qaoS+R
d4Ce6Kbox+EVtb/hX0Svlf6RxjqCtkuDxzwZ/gttQ+F3gQoaK9kbC8Es+nom
723tmenw15JjvTwoAS/L+n0vbwCfcH/5zLwANKD/o+hveQDs1PvAmfDPQEq+
R32aw1Tu7Qeu0toHe1H/6FiRJ52Krgv+Qv8S7IV1eH5XsCeehq6Xue/cYK/V
nDQXeW4ddK3M3vITaAIfohiXFwevRe3MfVqTM5M9V17bDcyDzwcvwrV9Dkb/
M/2ri8AZPPuE4p++vehzMnuMvGU/uiG6W/Sze7Q+6I6MpwbNoTU6JK9tMfdd
olzBtSy6SLGNrqH58kjtvFdt49ow2LMuRFdP9rrS6JboX6PXojzXFujxXDfy
fFmuDyd7hLxhJLiY/hfQf9NfIK9DV02O9RidS57h+lbOOeWizDlSubFC3htG
ozsGe0Qb9ODoXFeP6xT6DiknB6+hct9/tBfmnAPl/cW07QjOAa30P5O9o0o+
dvdxLZlzDH9O31LFqMaibYm8nvZZwW2Lk2NEsfFOcC5dip4bnFO/gX9HW3t4
de1JPZ8ci4qxNck5TblsfvDeXJ3MtUfHonfJ8+F3yF/gv9O2Ev4VOICehD6c
c9tf6IPJffrnv8FngbOCx9gN38n9y+BLwXb0tuRcpBplj8ZP7lMMqNb4NTmW
VHP8A99Lm2ogrfGf0nonerninfWbjT5bYyum0a9wc0HOnvOvvE31Ss4eNw0+
ADwPf1j+A39PHhS8B+Rdi6PXVh5WhvEWas3g6+QHWn9QLrjtJXh/cE3wmG/D
3wHTg2Owe7Kny8tHB+f2DeiPgnP8SO1drQe8C9iE3pxcW9QLHkt7TntNY56Q
uUZQbbAJ/Ej/CPQk3vUx+l30xmiuOW3S+5LH0jvuhQ9LzmUXyDOSa0DVfqop
5LWas+Yqz10gv0vOHYrZQ/kYLsp7wh/RHqDYD/qH6MaaM3w16AtfEV2bXAkm
5GNYsauY38X1j+R/uUL/K9pz5DVa4+bJHizvlccrVj5IzlWKmQPai+hVwf/4
b8USz68N3gPnKndEe5m+SXuxNm1dg/dkyWRPk5epxlHtWY22W4Jr0LrJHiLv
aIKerNjJvPaqOZX7qiTnRuXAfoqF6NpBNcZafVt0LHYAA9HfRdce8pTCZA+U
9ylmcsmeWZz3kPboLdG1rr7pQfQjyd6mHK5a6/HkvaWaa4xqh+RvVY2nvbk6
unbWHlUs/RldWymmBtC/JrpWUg35NHptdC2tGmoiekLyXlHNo1pEOUa5RTVJ
VXil5LmpBu6ueciDg88IKfOZQWcF1STywjeiY1WeeAx6UvLe2BhcGxbQtiG4
RpS3VcncJ487iv5jM9ee8jidXWqgtwSfYQoz18yqldW2nv7jwObgmDs685lE
ZxG9Y1lyTa5aXB5bmr5Smc8u2kMzoz1RXviI1ixzjaXaag34imcrKCaDazLV
RiFzn2ok7U3FhGJBe/RI+spl9nbVGOPyOa50Poep1pInyAtUc/0U/Q16t2qM
s5NjTrGmNa4lb4rO5drTynX7kmNJOU9erZxTJe/ZpyuXJp/llGP17ToT6Syk
OayMrllUq+iMqbOlPFNeqTOmavmh0bWeavoO8o/kWktnSq311uSzp9b8eJ39
0J2Dz0wj8jk45j1rYj7nKtfK0xvKi6PPYnqmKDnHK7fL4/8HYhXYnQ==
                    "]]}]}, {}, {}, {}, {}}, 
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwl1HmwTnUcx/Fz77UL00yjseaSJYTslbJmSyMXLcokM6EFkexbGGvZ91DZ
t6IoW9bsoumPyp6xVpJ933p9xx/v+/58vr/fOed5zj3PSW/bOaNTSpIkvf1Z
l5Yk83Ebd3A5NUmu4Dt8qK/gLjwDH2Gl3pU/Rjf00HtwT3RHb/SKbt6X+6EP
vtf780wMxA/6AF7F1/BypiS5yj+areYFfBdfyfe4Oq7L9/kGP8NPx/XkSo69
yWux0CyzPlvOwjX0W3JWOTuyYV2cB83ke/ycPQka6ym8wWwRL8ZcuR9qygO4
qj2Z5M1yZq6mD5Rry1s4t55Fzsm58BDq6Hl4J+/CDmyzdzdnw17s1H+Odc5r
76OYpX+BwbHH/C1ug7fjvmAofjN/h9uhPeZgOPabd+B38R7mxXdBIectiKPW
D+t/8hHOj5M4rp/g0ziFwvY254nxHeVTXFGvhElyHbPCsV8+y//iH/ylf43J
OKf/F89A/N+RjpccV4RfxTR7XtDPcmX9SbkcSqMsyuB188+tX+CLOB/X0ktx
SSyTq3BplLf/Ca7AreMeWrvBN3EtjtebW7suz5IbxvXi/OiMC2aj43Ngenw+
dMJn+BRT8a09a3gKOmIURmIylltbHfcHH8Rn1Udw2biPmID3456Yl+EGrj9T
viqf40t8BZcxQ38zPgfXt6+E/AZa4XFkmBWPex73Ir43SqKY2WsoIX9jrTiv
0v+Wi3I9far8SnwHrqs/Jp+Rz8S++B/GNcxbchFOjz1xbhTFSXsLWWsSzxS3
wAmzAlzLbIKcIY/npVgpr8Ax+SiPid+Vffnkg/IhPsBNzcbLj2AY/jA7yL/z
OH4YQ/CL/ivv47GcC4OwR9/Hu3kMZ8cn2KHv4e3xPuDqrjMonlN5KZbEGrbF
fvN5+CnQt/JW3sS1OBUvOj4tnjNsjOdP78/P6znkzbwljsF687vxfJv34Tm4
jUb6nXjvYX2cBxvQV3+WU6ynIon3TlwP5c3XxO9Q7hXvJL0aLslPmXXnL3HL
bG3ag3f8/z7rypo=
                    "]], 
                    LineBox[{942, 976, 975, 1040, 678, 643, 1081, 778, 716, 
                    979, 721, 978, 720, 679, 644, 980, 981, 943, 944, 681, 
                    648, 842, 652, 1085, 789, 731, 790, 1086, 653, 848, 656, 
                    992, 993, 991, 737, 994, 657, 849, 1051, 791, 1050, 792, 
                    817, 683, 732, 733, 844, 843, 1049, 786, 984, 723, 982, 
                    722, 983, 783, 1048, 838, 839, 782, 1082, 645, 836, 837, 
                    780, 1045, 779, 835, 1043, 1044, 1042, 1041, 942}], 
                    LineBox[{784, 841, 840, 862, 680, 646, 928, 901, 724, 866,
                     867, 868, 930, 649, 845, 654, 846, 847, 787, 1084, 651, 
                    682, 945, 946, 1102, 650, 985, 647, 1083, 784}]}}], {}}, {
                  InsetBox["\<\"\[Mu] = \"\>", {-1.8, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["0.2`", {-1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {InsetBox[
                   SubscriptBox["C", "J"], {1.4, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["\<\"=\"\>", {1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["4.85`", {1.7, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {
                  {PointSize[0.05], PointBox[{-0.2, 0}]}, 
                  {PointSize[0.0125], PointBox[{0.8, 0}]}}, 
                 {PointSize[0.007], PointBox[{0.4463998339305619, 0}], 
                  PointBox[{1.2771956561278897`, 0}], 
                  PointBox[{-1.0806611991222994`, 0}], 
                  PointBox[
                   NCache[{0.3, Rational[1, 2] 3^Rational[1, 2]}, {0.3, 
                    0.8660254037844386}]], 
                  PointBox[
                   NCache[{0.3, Rational[-1, 2] 3^Rational[1, 2]}, {
                    0.3, -0.8660254037844386}]]}},
                AspectRatio->1,
                Axes->{False, False},
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                Frame->{{True, True}, {True, True}},
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLines->{None, None},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None, "TransparentPolygonMesh" -> 
                  True, "AxesInFront" -> True},
                PlotRange->{{-2, 2}, {-2, 2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.02], 
                   Scaled[0.02]}, {
                   Scaled[0.02], 
                   Scaled[0.02]}},
                Ticks->{Automatic, Automatic}], 17->
               GraphicsBox[{{GraphicsComplexBox[CompressedData["
1:eJx1W3t8jNfWDnVQNU2OovmmjuK4zKHUpxm3YrXG0QqpqbY4LqOuTQ11106O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                   "], {{
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[0.3], EdgeForm[None], 
                    GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxNmwX0VcUWxu/MXEBFRUXAQEpCUHxioGIhoAK2YoC0GIiE3d2t2I0FFnaA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                    "]], PolygonBox[CompressedData["
1:eJwtl3f8zlUcxZ977zeRZMZPsitpkVCUjFeUJtpDg/YQEaIoeyYlGiShhaSt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                    "]]}]}, {}, {}, {}, {}}, 
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwl1FWwVWUYxvF1QkJngBEJSekSUEJAakQYiRtFQXDAC1JBSuLQwpAG0h0i
JSGhCCJdIgIyXtDlqCBdItLxe4eL//k/z/t9e5+91/7WKtKmW9OuKUmSZPiz
Li1J5uMO7uJmapL8j1Xoon/HXXk6uuN7vRt/jB6B3ot7oycy0CfWzftxf/TF
an0Az8Ag/KAP5DV8Gw3Tk+QW/2S2lhfwPXwl3+eq8RnlB/E5uRq/gl5ySa+9
x+tiL0rpvblG/G/extuxFRv0FG5kT8KvIhX19DTeaH0hL8LX8R1QSx7AZe3J
JG+RM3M5faBcJ947ZnoWOT324SnU1bPwbv4Vv2CHvXv4afyGXfq+WOPs9ubA
TH0WhmCfeStujfcxB8NwwLwNt0U7zMUIHDZvzx3QEfPiu+A575sTJ60f10/x
Cc6HvwL9Tz6Nv5HL3rd4Qlxv+Qy/pL+MiXJ1s0LyP/J5voBzgb4Uk3BRvxTn
KM4OiqCB173AzTAtrq9+ia/GucAVXI695t+aT0VNubjZRfkKLmM5KpmVQVHr
pbkYv8ez4xzzLfyHG3oTazfjusp15fLx//ER/jX7nF/EVExBZ3yGTzEZK+1Z
y5PQCaMxKq4FVlhbE9cKH+K6PjLOCMZjHD7AtThHXCd+Y/mGfJWvxWeI18U9
orfk6VzbvlJyC7yLEmhsVjKut/XCcS3jd0Axs+YoKC+zVoBX6+flonHW9Sny
O/F94v7QC8tn5TPh+C2R3/xtzsN5kRv58DxO21vQWn25ADeNs2KWP+5Hs/Hy
m/F9eUk8R+K64Q/5JI/hqvFe8lH5GB/hN8zGxpnDcBwyO8oH+Ut+FkOxX/89
7hsew9nwSdxb+n7ezV/wMxiMn/W9vJOzxu/r/wyOzyYvxjfYFfswyHxePC+w
Q9/OO3lz/A6cjtfjvuaK2GReRu8f51NPkzfzlljDevNHKG3eh+fG8wuv6Q/j
WYf19m3EBmTEPcWPkMQeTuUUVJB/tF5C7smV9SpxtuXiZt15TjxLY1/ak+f6
Y+zUymQ=
                    "]], 
                    LineBox[{938, 714, 975, 1034, 1033, 675, 639, 1069, 780, 
                    715, 978, 720, 977, 719, 676, 641, 979, 980, 939, 940, 
                    678, 645, 839, 649, 1074, 790, 730, 791, 1075, 650, 845, 
                    654, 991, 736, 990, 737, 992, 655, 846, 847, 792, 1076, 
                    651, 680, 731, 1088, 732, 841, 840, 1042, 787, 983, 722, 
                    981, 721, 982, 784, 1041, 835, 836, 783, 1071, 642, 834, 
                    640, 1070, 781, 833, 832, 1037, 1038, 1036, 1035, 938}], 
                    LineBox[{785, 838, 837, 859, 677, 643, 925, 898, 723, 863,
                     864, 865, 927, 646, 842, 652, 843, 844, 788, 1073, 648, 
                    679, 941, 942, 1094, 647, 984, 644, 1072, 785}]}}], {}}, {
                  InsetBox["\<\"\[Mu] = \"\>", {-1.8, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["0.2`", {-1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {InsetBox[
                   SubscriptBox["C", "J"], {1.4, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["\<\"=\"\>", {1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["4.84`", {1.7, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {
                  {PointSize[0.05], PointBox[{-0.2, 0}]}, 
                  {PointSize[0.0125], PointBox[{0.8, 0}]}}, 
                 {PointSize[0.007], PointBox[{0.4463998339305619, 0}], 
                  PointBox[{1.2771956561278897`, 0}], 
                  PointBox[{-1.0806611991222994`, 0}], 
                  PointBox[
                   NCache[{0.3, Rational[1, 2] 3^Rational[1, 2]}, {0.3, 
                    0.8660254037844386}]], 
                  PointBox[
                   NCache[{0.3, Rational[-1, 2] 3^Rational[1, 2]}, {
                    0.3, -0.8660254037844386}]]}},
                AspectRatio->1,
                Axes->{False, False},
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                Frame->{{True, True}, {True, True}},
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLines->{None, None},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None, "TransparentPolygonMesh" -> 
                  True, "AxesInFront" -> True},
                PlotRange->{{-2, 2}, {-2, 2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.02], 
                   Scaled[0.02]}, {
                   Scaled[0.02], 
                   Scaled[0.02]}},
                Ticks->{Automatic, Automatic}], 18->
               GraphicsBox[{{GraphicsComplexBox[CompressedData["
1:eJx1WnuczFX/3zbhkVkeicyqPG5NCGEo4aNmqyfEWJVCs491zZTLSqw8pWLS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                   "], {{
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[0.3], EdgeForm[None], 
                    GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxNmwf819P3xz/33i8pKyGioVQSySyjSEhGIZWSNGRL9sjeyt4yQzLLzorI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                    "]], PolygonBox[CompressedData["
1:eJwtl3cYj1UcxX/33temyCoU0lRGKURDT4qGCj0VDUWUVGRkk6IUkREamkao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                    "]]}]}, {}, {}, {}, {}}, 
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwl1GWQllUYh/GXkBkMQCSlUwUVxIChhlBqlA8goDQo0iwGSEuXRZmgEkup
dCOxK8MYzAjMEBISrnTssrA0wu8ePlzvdf/vc57nvE+cp0zXpBb9siUSiSF+
luZIJKbjHM7jbHY15qGDnMwdeQI6Y77cibuiC96R3+ZueAvdoxfW78m90AML
5N48EX2xUO7Di/gC6uW0Pi/TW8wz+AKmqS9yRVxUp3M6P8lPoKe6jGMz+Cdc
Qlm5F1eKtXgtr8MaLJOvor45WVxZ7xrXkq/zcnyh9yW+Qj/5Ge7PFcy5xatw
GxXld7mK8dV8k+/wNb6B66iKW9iMLdgU/8Wcrfw//8obOJU38gPOmQuT5MlI
wlb9V/k1NMeneA+/6bfglngdU/AB/tRvxa3RJu4hpuIR530YO43vlHfxruhj
H/bIe/lv7EcecxvwOP2q6v1xb+VyGK9+Tu/RmK8+zP/gUCDPwgQckQ/zwnjW
KIC6jnuMG+FjYy/Kx/i4/COO4SiK6X+vPxkvqAtHX52Gf/EDysc8FDdeEiXQ
LO6FsdN8BidxWm5o7JT6c3UNdam4DrTHKb0hXDKuF2PRDoMxCGMwx5yfeTTa
4kMMxCjMjvePR+LNWFMewCXwEUbgDZzQL87Vrf+Z+oT6v7ieMNLi+cpN+RN+
ybzH1cfVTbgIGugV5SN6RWMcRVBIrzEKq78zVogXx3NRF+Tn471SvxL7kKvJ
+dUH1Qf4AB/kgvoF8LI6Xzxj5I1nFvOxz7x8xupEnxtir14erqI3NvZX3DOe
iQXq+dit3h33iJN5HuZih/yg4x5C7kDvffyh/xf/zsM5V+xDpMrbOYWHcfbY
p7G35G38Cw/lu7FPY5/hDmZhJtbrp8Qa/C1/g6/juNiDsbfi+4M1WC+v5Q28
kp/lG1zb/7wZ3x55RbyHchI/LWfhKlZjaXwveAlfQTnzevN0ZKKmfDneq/j2
xBpxPvSRn+JLyEQGruAySsc+MV7asT3iuxT3kc+glF43noqzsW6O+9/4e2Ka
0GU=
                    "]], 
                    LineBox[{925, 701, 964, 1024, 1023, 661, 628, 1063, 768, 
                    702, 967, 707, 966, 706, 662, 630, 968, 969, 926, 927, 
                    664, 633, 824, 636, 1068, 778, 716, 779, 1069, 637, 830, 
                    641, 979, 722, 978, 723, 980, 642, 831, 832, 780, 1070, 
                    638, 666, 717, 1081, 718, 826, 825, 1032, 775, 972, 709, 
                    970, 708, 971, 772, 1031, 820, 821, 771, 1065, 631, 819, 
                    629, 1064, 769, 818, 817, 1027, 1028, 1026, 1025, 925}], 
                    LineBox[{773, 823, 822, 843, 663, 908, 907, 881, 710, 847,
                     848, 849, 910, 911, 827, 639, 828, 829, 776, 1067, 635, 
                    665, 928, 929, 1087, 634, 973, 632, 1066, 773}]}}], {}}, {
                  InsetBox["\<\"\[Mu] = \"\>", {-1.8, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["0.2`", {-1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {InsetBox[
                   SubscriptBox["C", "J"], {1.4, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["\<\"=\"\>", {1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["4.83`", {1.7, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {
                  {PointSize[0.05], PointBox[{-0.2, 0}]}, 
                  {PointSize[0.0125], PointBox[{0.8, 0}]}}, 
                 {PointSize[0.007], PointBox[{0.4463998339305619, 0}], 
                  PointBox[{1.2771956561278897`, 0}], 
                  PointBox[{-1.0806611991222994`, 0}], 
                  PointBox[
                   NCache[{0.3, Rational[1, 2] 3^Rational[1, 2]}, {0.3, 
                    0.8660254037844386}]], 
                  PointBox[
                   NCache[{0.3, Rational[-1, 2] 3^Rational[1, 2]}, {
                    0.3, -0.8660254037844386}]]}},
                AspectRatio->1,
                Axes->{False, False},
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                Frame->{{True, True}, {True, True}},
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLines->{None, None},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None, "TransparentPolygonMesh" -> 
                  True, "AxesInFront" -> True},
                PlotRange->{{-2, 2}, {-2, 2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.02], 
                   Scaled[0.02]}, {
                   Scaled[0.02], 
                   Scaled[0.02]}},
                Ticks->{Automatic, Automatic}], 19->
               GraphicsBox[{{GraphicsComplexBox[CompressedData["
1:eJx1W3l4zFf3T0NRFVRtHV77ErFUI6Pqpaft1FtLtSOqljLUVpW2WrVNXrWb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                   "], {{
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[0.3], EdgeForm[None], 
                    GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxNmwnYl0MXxp+ZeUlCok3ZStGqUgnZI1mSkLJElkIk+77vO6Gy78sn+xKy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                    "]], PolygonBox[CompressedData["
1:eJwtl3nATVUUxd855yVUkqF58CmSKUppVCklRdJA5pRMlYTIGE2mChnLTCRJ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                    "]]}]}, {}, {}, {}, {}}, 
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwl1FesFVUUh/GBiyKC9CJFEUGUogElgEERhIgPSu+di4ABpDcp0kET6b1X
6dJ75wFMKCogvXdQqjQTSfS3wsN3v/Vfs+bO3vvMOYVSO9fulCZJkoH+rExJ
kjG4jhu4kjZJrmISGsiTuSEPRmNMkRvxVG7CQ9BA3YyboylaogUa6g/lVExT
t+Lp3JqHoQ1myF/xTL6OsumS5Bqv0pvFY/kmhqtvcaFYp/rP6PNfPJvfjPVx
Hvff4rkxg1flJlwk1scbeCPW4yf5HsqZuctv6d3n0vIDXoRxeuMxIfYkv82t
OL+ZR7wUj1FATuVNri/jiTwJ38f+UEzdll8z94RXorjeU97Jq3gHr+Zn/C8P
5xFohw3yZ1wNn+MHtMcO/S/4S1THj+iI3fo1uCZqYTRGIT3SWsNe1w+o9/FB
fgkVsF8+wgf5MB+IzwC9cVT+I84Ni7AY38aZ+H+Z1L+pT/JRPsFH4vzQF6fi
Xl7CS5EVZdyXhSvhO9dKyCf5rLwcZ3A6ZvXH6w+IM1Pn0DuhPoPTKCi/jpyu
5eFsMYPsqCoPNXOFr+JSIH/o2uV4f9XvqfOrB6E+Lup15XwYGGtDPVzQ78ID
0D/eCXkF90NddEanOBP0RR/0Rh2cN/sN50Uv9ERtnIt3lN+1hsHqi+qzfC6e
F/fFuuQqsRYuaS63+pT609gzyuvl4uN6meNM8UrsX68yMsbng5eRAcv0jpnN
xsXk/upPYh/8jpxZfVh9jH/n4/F+6KdHRXU6fgEp8Rz5Rf7VXEb1B/Ec/hiH
9DJwUb0+6o9i7zwGC9UL8Iv6EHfn+TwPc7FHTtyXBv/JKeiAXfr7eSf34ARf
Y5O8hzdyd37GbXkt7+I13I3/4Yf8GI8wHdPws/52bsNTeQomYxu2orX+SCzH
ZnkFb+ElcWb8N79vrQ/jOx7fDc4nt+Si8oOYwTos1Fsb++c7yGuuKY+I3zOU
km/zPKw2N5/XcDMuzHdwF7dxH/dQAHNcz+3eRvyGPJEvI5defR6Ga7HXlOe/
+/8DNP3Kkg==
                    "]], 
                    LineBox[{923, 691, 960, 1015, 1014, 649, 615, 1054, 761, 
                    692, 963, 697, 962, 696, 650, 617, 964, 965, 924, 925, 
                    652, 620, 818, 623, 1059, 772, 706, 773, 1060, 624, 824, 
                    628, 975, 712, 974, 713, 976, 629, 825, 826, 774, 1061, 
                    625, 654, 707, 1071, 708, 820, 819, 1022, 769, 968, 699, 
                    966, 698, 967, 766, 1021, 814, 815, 765, 1056, 618, 813, 
                    616, 1055, 762, 812, 811, 1018, 1019, 1017, 1016, 923}], 
                    LineBox[{767, 817, 816, 837, 651, 904, 903, 873, 700, 841,
                     842, 843, 906, 907, 821, 626, 822, 823, 770, 1058, 622, 
                    653, 926, 927, 1077, 621, 969, 619, 1057, 767}]}}], {}}, {
                  InsetBox["\<\"\[Mu] = \"\>", {-1.8, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["0.2`", {-1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {InsetBox[
                   SubscriptBox["C", "J"], {1.4, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["\<\"=\"\>", {1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["4.82`", {1.7, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {
                  {PointSize[0.05], PointBox[{-0.2, 0}]}, 
                  {PointSize[0.0125], PointBox[{0.8, 0}]}}, 
                 {PointSize[0.007], PointBox[{0.4463998339305619, 0}], 
                  PointBox[{1.2771956561278897`, 0}], 
                  PointBox[{-1.0806611991222994`, 0}], 
                  PointBox[
                   NCache[{0.3, Rational[1, 2] 3^Rational[1, 2]}, {0.3, 
                    0.8660254037844386}]], 
                  PointBox[
                   NCache[{0.3, Rational[-1, 2] 3^Rational[1, 2]}, {
                    0.3, -0.8660254037844386}]]}},
                AspectRatio->1,
                Axes->{False, False},
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                Frame->{{True, True}, {True, True}},
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLines->{None, None},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None, "TransparentPolygonMesh" -> 
                  True, "AxesInFront" -> True},
                PlotRange->{{-2, 2}, {-2, 2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.02], 
                   Scaled[0.02]}, {
                   Scaled[0.02], 
                   Scaled[0.02]}},
                Ticks->{Automatic, Automatic}], 20->
               GraphicsBox[{{GraphicsComplexBox[CompressedData["
1:eJx1Wnl8zNfaT1EtNa3rapumSvVapnqLt6/YiofE0mudi6KW0dqKsRXVTqrU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                   "], {{
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[0.3], EdgeForm[None], 
                    GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxNmwf811MXx7/33n+DQpQRERVNqYySEGlaj5BNZc9kRdk8j53CY2Rll6Ls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                    "]], PolygonBox[CompressedData["
1:eJwtl3egl1Mcxt9zzo9ukZC4VouMVEb2yIgSRRJpqG6lQUslRJQWGkqREaWp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                    "]]}]}, {}, {}, {}, {}}, 
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwl1GfUj3Ucx/HrHnZmSrJCp5RT8kRF0cEDlWzZkjqUcRuZmTm2G2WljMoo
svfWtLeksvcoxDke2Ly+x4P3/f5+vr/fdd3f6/r//v+SrTvVy0hJkqS/P4vS
kmQUTuAkDqQmyZ8Yifqxxg24L95FptyQR3Mj7of+aIKmaIzmaIZ37BnALTFG
3YLH8ns8EO/jc7kVf8F/4YX0JDnIi/XGcSafwqfq0/wY/laf4X/4LI/nx7k2
53X9IZ6Iw8gn1+EnrNfnFfwVL+ev+RhetOcoF9Y7zs/IJ3gKxsaMMR8ayEXi
PXABe87ydJzDo3IjXmn9Gx4Xc8X7UTdBsXgnXNC+81xCLo4ruCBv4Jm8nmfx
Db7En/EgfIA5clWuhuoYgjZYrF+D38RbGI6PsEz/ba4ZnwVGYgRu6N/jVbyN
V/N2vsn3uQJexgZ5D6/nIeiAvfK+mDXmxGxk6Bf3XHf5Z/yh9xvv5195KDrh
gPw7z+UfkYayrkvl1/CJtZLyNj4oz8eWOI+cXT8bhsld8ZQ6q/5W9U7siM9A
LoBHrOXkHJwrarwh97LnKB/DYeyXy1s7ou6pflqdV90H9eI59Tpynjh/6I26
2BvvIu4X18X7lhdwD9RBe7RDd+RGt3i2OJ/YY+/HMSO6ogtqYbd+Li5thh7q
Q+pd8Z2Icx5nPu4nV4n7cSn7cqi3qytzNrykl50362WJ94N0ZNF7HanqNKQg
wTy9Tfamcwm5i7qSujPP4R/wPX6RU/j5uI4r4p5eOfk+/4Q7eE6+za9a38i3
4tzrdeRX4r3wYMxQf4c18bnFWeVv43uD6Vge9+O7uI3rclteylt5CXfma/xh
nKU4dzw3zhlf5tYxO2+MM8oZfJH/j+twFZPxJWbor+OmPIknYgLWxoxorN83
ZsSqmJ1X8zQuyqe5jOc8w/nlqWG5IT8pn+Rn5VM8Rh4d/1u9LM4T98ER/Bez
4xImyUtiPl4a55EL8XlcwDn8G8+EfDGv9Tz+R634jZFHxPcQufVqcm8c11+Y
9vA3/wFct8tn
                    "]], LineBox[CompressedData["
1:eJwl0EEuQ1EYQOGf2oJKykBbNFEDimWYGKumTTVhoDsgYhVYgAE60wGDRqkR
FqIJiaqGUb8Xg5Nzz/9y733vZWvN7cOJiNjCWSricjKiwwN84UjvYHoq4p2z
ZvPI4Vo/8BUfYxdd/YhzXODErIpl6zpnnDPkNb2KEn70rPker+t9fuU7fuF7
fuMD3uBNjKzn7GnwKW6xqNu84nkRf8k36Gdu8RPfcI8/+ZeXUMCHnrG/kpyj
y5zWfV7Q+eQ9k3sxxHfq/3+NAWGnK70=
                    "]], 
                    LineBox[{752, 809, 808, 833, 640, 900, 899, 869, 687, 837,
                     838, 839, 902, 903, 813, 615, 814, 815, 755, 1049, 611, 
                    642, 924, 925, 1068, 610, 967, 608, 1048, 752}]}}], {}}, {
                  InsetBox["\<\"\[Mu] = \"\>", {-1.8, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["0.2`", {-1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {InsetBox[
                   SubscriptBox["C", "J"], {1.4, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["\<\"=\"\>", {1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["4.81`", {1.7, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {
                  {PointSize[0.05], PointBox[{-0.2, 0}]}, 
                  {PointSize[0.0125], PointBox[{0.8, 0}]}}, 
                 {PointSize[0.007], PointBox[{0.4463998339305619, 0}], 
                  PointBox[{1.2771956561278897`, 0}], 
                  PointBox[{-1.0806611991222994`, 0}], 
                  PointBox[
                   NCache[{0.3, Rational[1, 2] 3^Rational[1, 2]}, {0.3, 
                    0.8660254037844386}]], 
                  PointBox[
                   NCache[{0.3, Rational[-1, 2] 3^Rational[1, 2]}, {
                    0.3, -0.8660254037844386}]]}},
                AspectRatio->1,
                Axes->{False, False},
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                Frame->{{True, True}, {True, True}},
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLines->{None, None},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None, "TransparentPolygonMesh" -> 
                  True, "AxesInFront" -> True},
                PlotRange->{{-2, 2}, {-2, 2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.02], 
                   Scaled[0.02]}, {
                   Scaled[0.02], 
                   Scaled[0.02]}},
                Ticks->{Automatic, Automatic}], 21->
               GraphicsBox[{{GraphicsComplexBox[CompressedData["
1:eJx1Wnt4jNf2TnG0R42qaqtp6/ZrmariOCaux1JDTqvK0LqUNlRDW6MucR1N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                   "], {{
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[0.3], EdgeForm[None], 
                    GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxNm3f811P7x9/nnLgjiZKWJpXkDolES7bsbBmFny1bwu22V2RmZxPZe2bk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                    "]], PolygonBox[CompressedData["
1:eJwtl3fcj1UYxn/nnBeRysoolSYNpU9aSqlQMrJCkb2SkpFRCk2KkJJ6G0RD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                    "]]}]}, {}, {}, {}, {}}, 
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwl1GmUjmUcx/F7ZmwhIdmOUu+VSDrxgiEqg2poE2FsRZYhZV+mBdmVndQU
zqGYrJFltNj3bWy9cI5zkn3JOsLnf7z4Pt/r97+v576u577+9/NUVu/MXilJ
kgz0MTUtSYZgO3bgr9Qk2Yz+aCZ/whncCy3wqdycB3BL7o3XMVB+jQfxG9wH
rTBYzow1uDVn4y0Mld/kYbwV1YokyRaepjach/JOfGi8i0tim/Hu2Cvv4RFc
ihtxIe/inJiDO3Jjfpib8mz+kmfxKD7Eh7EfB3EAZVCAI5iL0ebN4TG8D3eN
X+ay/Con9nyQx6Gc2iGuqHaYx2OkWg56xLPEo/EMOdWcAn5MroBjsab8I0/i
H3gyn+IT3Jf74R1MlV/keqgf54P38K16A26I9DgPtMP36o3iWeClOI84I5xW
P8PzeSkv4Dz+l8/y03gGP8m/8mLORjuskddiAibiglplv+k8Pysv4V9QXi0v
9o/346zkq7wMv5m3nNfxFVzGc8iKMzNvDefLX2O18Ub+D1fjWcgdUdq8m7G/
uE/cEyVcL46buCNf4xu4jhfQTW0Lb41exx/yk+6z2bhrnK1xqnHPOGP8Hmtx
Cj6Ks8Qr2KTegRN0jz6N3kC+enu+xx/EetF/2BjPgO9yV+6CJtgg/49HrNuF
/1Rbz5tib7E+Ost1uROXMa+Q1+J5tVtcXe02r8INVJWvc514ZvyEfI1XYr3a
Ct7AHbg2t+cp0XPRf1gqX0EV37vMtdQu8uPyJf4Z51BJPsurXV/EK3gVVuIS
auJ89AfO4Yw5F3kh1+A28Z7wOIxFrnw6ehD/4JTclr/jJTyPO/NJfpen80Ke
xp34b347eobn8xTO4qN8PK7H+4TP8Vn0rnouN+diXDR62jjF78qI/o3vxvrx
HsU7FvtUn8f74/017wAXkb/ie9EbcZa8hyu4vpdHyMNjXeMZ8R5yd+w13he/
I/YjD+OZ+CJ6Ivojepx3xH+He+3kNHkk3+Z0fog/jr7BLeOG0XfYZvxN2oP/
9/sb1tJA
                    "]], LineBox[CompressedData["
1:eJwl0DtOAmEYhtEPBxKls/GKiWPhBdeC1wRNtKL2tgnABVgo0mEMqI2wG0kU
JOg2PBOLJ2femcyfzKS166OrXERUVE8i7mYinvmlT13Ye0ryER9cdG9BS3qw
u7znpQ7Us1tssKlbHdvrrHLWOVNu2Zva1o895/4Jd+wz9tnlO3sc8Jxl7urX
ddE7p7xRR/P2Ezc8T7Nz9W2/sc0XPvI1+z5OWdJa9q12wfuHXLX3mbeHXLGX
s7M00Vij5P9//QFGoiav
                    "]], 
                    LineBox[{736, 799, 798, 824, 622, 885, 884, 858, 669, 828,
                     829, 830, 887, 888, 803, 601, 804, 805, 739, 1031, 597, 
                    623, 905, 906, 1051, 596, 941, 594, 1030, 736}]}}], {}}, {
                  InsetBox["\<\"\[Mu] = \"\>", {-1.8, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["0.2`", {-1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {InsetBox[
                   SubscriptBox["C", "J"], {1.4, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["\<\"=\"\>", {1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["4.8`", {1.7, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {
                  {PointSize[0.05], PointBox[{-0.2, 0}]}, 
                  {PointSize[0.0125], PointBox[{0.8, 0}]}}, 
                 {PointSize[0.007], PointBox[{0.4463998339305619, 0}], 
                  PointBox[{1.2771956561278897`, 0}], 
                  PointBox[{-1.0806611991222994`, 0}], 
                  PointBox[
                   NCache[{0.3, Rational[1, 2] 3^Rational[1, 2]}, {0.3, 
                    0.8660254037844386}]], 
                  PointBox[
                   NCache[{0.3, Rational[-1, 2] 3^Rational[1, 2]}, {
                    0.3, -0.8660254037844386}]]}},
                AspectRatio->1,
                Axes->{False, False},
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                Frame->{{True, True}, {True, True}},
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLines->{None, None},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None, "TransparentPolygonMesh" -> 
                  True, "AxesInFront" -> True},
                PlotRange->{{-2, 2}, {-2, 2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.02], 
                   Scaled[0.02]}, {
                   Scaled[0.02], 
                   Scaled[0.02]}},
                Ticks->{Automatic, Automatic}], 22->
               GraphicsBox[{{GraphicsComplexBox[CompressedData["
1:eJx1Wnt4jNf2Dm3DSQVVRYdS2uqgwVHRNsVSo2h6mzquKQmKqkFbtEyoqqPj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                   "], {{
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[0.3], EdgeForm[None], 
                    GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxNmwf4l1Mbx59zngYKqURFoqGiFNGwN8koErKSSCgjM943WyQjkU1SZI9E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                    "]], PolygonBox[CompressedData["
1:eJwtl3f411McxT/33lAyi6TypB4ikZUk2mWkNJWWpooWadASaYl2WigSDUW0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                    "]]}]}, {}, {}, {}, {}}, 
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwl1OWXFmUYwOFZFkTAQKnP/AMoioIrnZIKUlJSEsKyhHS3tMQSBzxHwgAR
l10QEJSUrnNo6Q5RQGmp6z58+HE998y78847QfG2GQ26pSRJku6fSalJMkC/
6XetyZUkvypDdc3dWS/UR+ph/pA9WT9mfaxe5gb8gg1jvxqrt7kR+7BJfE6f
qK+5KftxnfLlTpK1nGxbfw7kerWz3sACcY7WG+M8uSnOmy+xLM9xIwfFPp03
l+MrrMCL/IND4jPWm7VFW2O7CmqbvtJUTdFQn92uy9aV+Dqr8hp3cqQKWe9i
4vx3c5QG2zZE7a2rqYj1B7zOPSzGotqhveZZHMuZ/JKzeYApjnmQE1XOtvLx
W+JaqqUyba8S56Rqcd30qWbbXp01dM46l+Oc5SLzPC7k1/yW53mYb6qkFpiX
cj67xD3ST+ZlGq8JumxbqmNeYinzIn6vR9bfsaua6a75On/Qz9bLlaXjKq0W
tudwKbP5Y/yN8jr2Haarue7Zdy/OQ1lxrHhebHtRp/W/+QRP6aTeV5t4jrlW
q7UqngXHXWPd2vohU5ShOvrFtnZM1E3pqq2Vtrfl0/hd7KJaWmFuwyf8nJ1V
Uznm1nzMTuwY917ZcX30IO4RV8X14Ir47vgetTKnxb3lfT7kMr1nfZ8vO/8H
XKLbesH8H8vYfyveBfO/XKybymO+wXft/5sFzP/Efddfym2+xnfsv8L85qvx
fOjteE95hxf5TRw37pGW6E+9paM6piO64DNvsIQaWY+L5zmebc0xH4r7w4M8
wVacxQWcyQ5xrLjnnMy5nMTPeCieqXgGOYfj2J77uJP7uYvD4r3VGHNmvAPx
9/FMWY+O383qLMztmq4ZmqYRtu/QVesqcX2ZR8Otr7AyX+NWPuW2uIbxnbzE
inyVm/mEW+I94WBeiPc37iHX8zE3xLvJgTwbz23cg3j+uFpnrNPi+dM664mp
z/+/fgaJJcuP
                    "]], LineBox[CompressedData["
1:eJwl0DtOQlEYhdEjdxIoilEpBHUgopiAifYUklDIGHx0Fj7oFLlW4GAEFRJN
KNQJIInY0bAIxZf17+7krJVrpdOFEEJBZ1EIV4kQ7tnRi07sXQ3d71xkUku6
sRu8ZkV7erRvec4LXerAXmeRf/xilpvK6dses8QtHrHNJluM+cxjbnNHP+5/
HrI6e7Mm9gMz3FBfA/uJdTZ5x5if7DGtVX3YI+5zhXn+ssdlpvQ2+wO9qhvN
/2sK0KsrQg==
                    "]], 
                    LineBox[{728, 801, 800, 828, 616, 885, 884, 860, 660, 832,
                     833, 834, 887, 888, 805, 596, 806, 807, 731, 1009, 592, 
                    617, 901, 902, 1032, 591, 929, 589, 1008, 728}]}}], {}}, {
                  InsetBox["\<\"\[Mu] = \"\>", {-1.8, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["0.2`", {-1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {InsetBox[
                   SubscriptBox["C", "J"], {1.4, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["\<\"=\"\>", {1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["4.79`", {1.7, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {
                  {PointSize[0.05], PointBox[{-0.2, 0}]}, 
                  {PointSize[0.0125], PointBox[{0.8, 0}]}}, 
                 {PointSize[0.007], PointBox[{0.4463998339305619, 0}], 
                  PointBox[{1.2771956561278897`, 0}], 
                  PointBox[{-1.0806611991222994`, 0}], 
                  PointBox[
                   NCache[{0.3, Rational[1, 2] 3^Rational[1, 2]}, {0.3, 
                    0.8660254037844386}]], 
                  PointBox[
                   NCache[{0.3, Rational[-1, 2] 3^Rational[1, 2]}, {
                    0.3, -0.8660254037844386}]]}},
                AspectRatio->1,
                Axes->{False, False},
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                Frame->{{True, True}, {True, True}},
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLines->{None, None},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None, "TransparentPolygonMesh" -> 
                  True, "AxesInFront" -> True},
                PlotRange->{{-2, 2}, {-2, 2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.02], 
                   Scaled[0.02]}, {
                   Scaled[0.02], 
                   Scaled[0.02]}},
                Ticks->{Automatic, Automatic}], 23->
               GraphicsBox[{{GraphicsComplexBox[CompressedData["
1:eJx1WntY1FX6J221Bx0zV03RxbuNmmkGaqW8ybjqYubEL11vO14KU8e08Irp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                   "], {{
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[0.3], EdgeForm[None], 
                    GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxNmgkYVsMXxu/MLRGJJKFSWhQppVL2iLSIItllyRIh+07IkuxLlDVEZE+2
LBFJFLIlhLJkiYg/Ev/z877f8/U833nOzNw7M2dmzvLOuV+zw04YcHwuiuKi
GkVRBv8wFcUHQf+L8lrxIJqLOkFrFirXDKoX7WsH3Rnv1XXbKkG/RP31oPFB
G8XzJkG/RfncoJ2D/uW9aKsZdHvU/4n6akH1g9Z1uXbQ+ivNuV7Q6kFrBG3g
NuZshHxBawd1i/G6BrUPSjHuOtHWNKiBx6P/hu5Hn2aF3mHejVeav33QRu7b
wv2Zv6V5w6BW5si4iTlybRbUOKhJUHOPR//Wfs78bcwbeYw1vM5N3Ub/rTwu
/bawLMjbwRx5O5ozz5bmyFsjSf52QRdEedegHNTJz1lHZ3PWcURQ/6ABQV3c
xtyHB+3pZxdF/92CagbND/o4qFbQNl5z26B5SXNuH7Sj9xHZd7As1PsEbV2o
39ZeM/27+13Wt5M569vVsiJXD6+TdfR0G/vUK6gr5x/U25yx/0B/g7aN8s4e
j/67uR99Vovn2wXvF7RHoTLyH+Bxe3v9O3hNA8yRdy9z5N3bnHn2tdw9vX/b
u/9AP2cdTUNHdwm+j+Vobb1ontV3kNfRxnt0oGVh/w4y7xt0ScjfJ6h20L1J
6xgctL/XyRr2syzUD11prYeZI+Mu3lf2eojXyfpuCxoddGXQxiHbp9h60CdJ
Mh7FGFFeM2l9R1t29mCY5UbeNll7emzQMX6OXMd5r3nvsRjj0aCDo3yax2a8
4V4Tsp9kjuwnm6Onp5ijyw1jrvWC1oixWmXtxdCgdaJeL2l96yaNf6rHZo4T
WXO0r5ck4xdJ8p4RdKZlR96zzFnf8njnr6Djo7xhzLUBPjHq62eNd27QBZYb
ec/3XNRHuA3ZG2TJQZ8GSXJdiMxZY4wKuj9JlpGc+0pyXWqOXJeZnx3UOPo2
Ctow+rUO/mXwhkFXWK7zgi7yHrDfu8ezOkm6PNrPkfcqrwF5R8fz5kFNgr4O
+gpfE3Sd5WW8RUky3hg0xrIi400ryX5P0LWF+jVO6kv9nyivSFrHxKR1jw26
3TqILLcWWgMy3uG2q4MWx/vfBm0c9E3SeHcH3et5rg8a572k/1XoWlCzoAl+
fkPQfebI/0TQXUHjkcdrYE1Tos+TQTdHuVWSjA8Gtc2aY1LQo5YbGe/3ePR/
yHKwjofNb/P6zvdeP+I2+o+K8Q8MahQ02bKwrifN2csp5qz1KXPW9HjQnV7D
Y5aF+tN+zlqfMUfGZ81Zaxv0JuiBKNeIdX0f5U2CXvAakP1Fc+R93uvm2Utu
Yw9mF+rDu69YJvZ1mp8j13S3sb5XzVnfa+as73WvDdlnmiP7DD/nWQLEZK3j
zaCplutlz8PcmyW1zwp6y8+Rb45lRPa3zZHxHXPGeNecdcw1R/b3zJH9fXNk
/8AcGTePedsGvRHlj7we1tEuSdZ5QQvdn34few3I+IXnY55PvKfI+6k58n5m
jrwLzJH3c3P6L/LYHwZ96fGYb77nme1nMyzfFiFb+yR5tw++vBDG+8Z9kOVb
c2T52nLzbLHbkOvd6Pty0I9R/sEysabv/Bx5f3Qbci0xZz+2jH4dk2R/Lmnu
nzmzpLmX0hd8kzT/L5aJ+Zd5ju9NCzz3r37Os5+SZPotqEuUOyfN/37waUHH
BQ0L2ipp7OODd00a44Tg3ZLm2Sb4H4Xw87ZR/rMQVt6OGFEIH4Opwbzg0RWF
8DV4t6ZxNBgVAmeCG8HX4O81/B54sr7HAseCg8HWdX0uYG1wN/gWDP53IWxc
JOFs8G6HpDP6qpAcDTxuDY8HFv0uyZaxE+ZuaJl4Do4F74KzG3l8cDe4HuzK
3LSDccskLL5RUcXZzSwHvClyJ2HWzb2mDT0HMjV3H2Rs4TrPwEubFFUs3rKo
YuvWlgNcCXYC+1IGkyMHOLRdUcX0LSzvpu6PTFv4PWTs4DqYd57xYgVzd3T/
Tq5XsHUny9XFdcYGk3Yrqti9g9ewld9D7q6uV+4VrSxTNz9jLPDhLl4DuHJ7
y7qj68ja3fUKnqYOdgd3t/XeVDA4suzs91hDD9c7eZ4elq+n565j+RoWVczd
y2P1cR3c3cdzgMNXTcKrYFDw2H5eTy+3rZ6ExXcvtL/g0n5+foD7sM49/Yy1
gVH7F1X8vZflHuh6d7fxHnh7oNfCGsCfg7xf/T0u2Hsfr7mnZeQ9cBC4bLjX
dqBl4hk4EYw6wfj7EMsNRh1cVHH2oZ7jcNcvTcLNYGmwOxi5r2U5wu8h9xDX
K7ifuesYw+5lXdnN8oJ1j7Hc4O2h3jdkBa8e6/7DXB9k2cHB4How/ZGFMPgw
zweOBpueUFTx9/Ciir9PKqr4+2SPBZYEU4KjT/Mc4O5TvJbLk3B2Q+NZ8ODI
ooqtwbJgVfD36YXw9VlFFW+vlYRvwdrg7HMs0/k+K2S6wPUT3Xau5RvhZ8gH
Vr3Q+8KcyFI/6R1kXT/pndOKKs6+pKjibOobGKsiD1gbvH655wNjjvL8o11H
pitdR46rXG9iDF2RiTL4tbnx9fV+DzwILgR3g7Nv8LhgyHGWD3wKzgRHj7Gc
/yZh66bguSRsfYvlo99Yy3KH5xjteW712TAe+BUMepX3EdzM+2BvsCEx47lC
GBz8Pd5rAJeCU1smYfO7vL57/Yw62O9xzwH+BI+y5gl+j/kn+hm4e6LXeQ02
l4TBWQfYc1JRxdbUweQPeo2s6RE/Q3YwIRi0gvsneP2P+r07LRfvsZ7JlrWC
vycXVfz9ZFHF31M81tOuV3D200UVZ1MHXz/rtSErOLSCo+FTiyrOfqGoYt/X
Ld9LfsZ8YLbXLCsYdZplf8V15J7uegVnTy+qOJs696EWSet+yvPM8H5M83zg
65mWP2dh7k3R0aDDkvA1soMn37Tcs12f6rZZlnuOn1Uw9NyiirPfKapYfE5R
xdzvFlWc/V5RxcGfWF6wKhi2rXErst6Ez0xVrA3+mVdUMfr7RRXrv21Z5/u9
2R6b+oCk3MGpRRVzf1pUcfYCy/iF68j3pevMsdB15lzkentj2w89B/i2gqPh
XxVVnP2Nz+NDj8Hci/0MDAw+/slygHe/sxw/uI4cFQxewdnUOxrzLiyq9wfW
Bsb+2fN+5vEq84GFl7r+q+s8X+b63CTcD54Gu4J1wZsdsnByDRM4GTwLJgGr
gU+4K/xmOXkGfgbfrh59f0+6h5yUhC/BdFtF+xZZePfsaNvBeLd7Ei6tVwgT
UgYHgj95DiYdHu+Aj2ljLPBq0+AnJmF0ZD8vyjsZy/ZIkpNxPg++wDoxImgX
Y9lTgvolxWowENiLPOTJSXgXrNsrKYcK3rkneG/jJOIumIA8WM+kvuzJyKQ+
4KRaWRyssUbWnODB3sYTYAnuNct87mAfcnTgomZZuIO2fZLyVcRQMAVxmhjN
e8gOxtgzKZcGBjg1eP+k9+D1HdfBP48k4bd9k3JYxDHubmcl6dcmWTEfjLJ3
Unwltp6WVAcvDEyKqcTT24JfmRQDiTnEHmLNAUk5LeLsFUnzkUP61ZyYs19S
TCWeEkeIofj4/ZNiIDGbGMQ7PD8oKZ4xPvGIOIW/H5Q074hC8aKZfWMTy0Vf
6vjMu8xbuky8IS4RZwcnlYlDzyTVyaWQWyEG4P9PD35oUh2OTyU2kC/Al+HH
Dk/yr/jPMzirpGfs8VDv83VJuQb6HZN038OHHJnk//B7+EX8Dn7kzOBHJdVv
TLrz8xz/08Hv35x0lvipRfYX+Ap8aTvLg29HNjAAfquT561jWxhiH8E9eql9
BPdo2sYl3b2X2H9wp+b5hUk2gP7jM7hX4zN+Dr619Rv/wR274ifIU6xi+8YP
YL/nJPmCerZvbHkd+40d3Y5v4PsUdo09Ycv4gxlJd3vu9ecn2X8T+6pdLRs2
yvcRbHxW8IdT1Vbh2Di2jX32tX2Tt8fGyVf3Tbo7vJXkO8jFrmmOLZJbxg6x
QWyXu8PAomqH2CB2s791G/sjVhGnGttGsEfsD+yNDWJv2B02CKbG9ip5Y/wC
PgH7HmT952zw5cQLbBcbw75uTbJhxp2cZJ+X217JW15tuznYtvNOEm7DBsgr
DrZdYB+H2F4qNoD+j0nS3Xm2gyOsn+jaYdY3dHCI9bC99XmRz/9E60BH28gS
6+ax1k/08TjrJPo4zDqJ7h/teW9Isr1Z1s3jrZ/o4AnWw8qect9Bv4Zbx3b3
mWIHfIPAh9bzfrFv9CHXiv2zbmwX22at2CL2yZrQ03Osq8Qr4lwlxvFtFf0d
m2TzrIvYSNxC37lfj7Q+or98F0R/iUXErRrWZewNfcbm+OZX0euLk3QbmyDu
YhfoMt+f0GXsBtvALtC7y5JiIrpD/rqR9YXvB/hOfOTVSX52sPWhlc/zWp8p
+w2m5Jz5XnxH+g96/ueryd0385nf4HNBL260btyVlE/L9nvgv3bWi5utG5z/
WO8VejHOusH+3ZJ0/txVb/VZMT+5u/j9pxdjrBusiVhFPADf8A45PGybuzTx
nDrykEtbM+tbDvequ5PydbUK5c0ok097KOkZ7b+4vCo+JCvWEmf5/s46S7eD
CchBbGk+ONonJb3DPtyX1Bc/g6zEVuLiuvGwfq7eCeH/fc9IuivSxjuUseva
YA+vAb91n8d8LWk+5sLn4QNreS+P9n4O857wveypePHxEP6lpFzlL15jR/+v
gHXB67nM/q3tXChrquecKbFgaZItLnX9N78zw/sz3nOwt68k4cvfC/FX/H59
399H+Z3pbn81aW2sizFmJuFM9OFVt8/0+Mi/jveTvUJW8rd1PP66bn/A+85e
d8o6swb+VtfI76zj73f4Ye766M1I60/doIt9VvVz9fvgmm5nDzs4d0yugPcZ
41yPe45jHNgRLAqv4zJ5TsrkOuf5nXZe4xteO1j+A+s7MQGcT1x4PvjUpDvD
i0n3B/wq/EW3f+s6d4r/fHwS1qHO/eVrc8bhLgN/zn3fS7pXMCf4jDwDd/F2
yJ6Vg+Db3NNJ2KrMykdcUwgPoxvLbKMf2JbxQd96vKfcn+96jyd9k8aO30yq
U2bsOR4fv/V2Utwipzc7KTaD8Yhz+Db8Lpigl/dp7kq6967LnHNjn8uPfvaD
9/Alrx1ZnrDtoD+TbY/ErmneZ+QmPzLGfIrlnOg65Wk+i6XeH3Az+0jMb2wd
BGuAObgbkDf613tCPEbhufvPdPkN8+QyZ0mZd9lX5vgmVeM9uHeFx2VM/Bb+
C5/GdxB8fbZ9UeasvndfcELl/rO7z5E++Fd826r2fff6nX72GzU95q+WB334
h341FAfGh5O4Pev87wx+Tyks/2jwKVl6/VSUR5fSmYeDD87SzxujfHmWflwS
/NxSWG9M8Cuy7k63RPlq7+f1wS8sha12j/K4UhiOPcvew+uCjy2FF+4MfrPP
5cbgt5bCd3cE3yMrR9rU+wn24+xXeG+fjOeTs7B1l6ycKRgSPSN3ij+gvXNW
Hb9e22PiT6iTF8XPN/RayAlTxufju9ZzufKM8fkOxX+/atn3NnH5C4/J+Nzj
V3c7+7KB9b+zfSG5W9o29Jh/Jn1LAIfAqa9qeyBHPMz+gDO+1me9LAn/LnP7
NZ6Xb2bcEZa7TplvT7QTh5mDbxjbuA35aScOE6dYUx+/A54/yzKcbb7cZfaA
8Wv53T/8/t9+B9kv83mRp6WNZ+DxfdHlUrgZH87/LfDtG7nOfZY8+WZZ+7qW
fT73I3jHlWJoR8eCCj7gvDbN6jvU50KdXDjfQVpkfQvhmwBlvhXw/59mbud7
wcYuN3D8GlzoOe113a+5+/I9YlPPtavn4DsL77T0OH9YbmRmvE6WE9tvZ9/e
1DJw98EObsiyhR5R3qXUvaRn8N1K3YfICfGdkrhP3NrCZWJFO/sTxqU+yTbR
2brH/wl5H7y9nuVhrXwrZMzGHqet+8I395jjXB/rvWKN7CXfY/hOwzca8iH8
L4c72YiQ98qsO9+VUT6rlP9j/m5ew6igm0rFgL7Bn8m6u3T1O5U7bFeX6dPV
cjLOVm5fEX1nZt1R/onyW1m4fvcoP5t1BxqJXKVw/9/BX826S3EHYRz2clq0
f5jlG/pF+bmsu9EeUZ6ahcf2jPIpWWfLulkz96TWLg+1/nS2jdPWyu0HWG/2
t662sX6i8639Tu8Yv08p/8cYXTzOHcHvLhWr9wl+RlZuYK8on5aVM9iPfc7y
ARu4L+f/Q9D4rDjVPt75OuvOgWI+kXV3BE99ZXvEl19kf949+E6l7PezpLPn
mxo5Qs6f72Ng0o+ScgrgLPBV5bsynO+c6At9sYvNbDvY6MKk9eM/V3Mb/hlb
wjZ62J/hd/Bb4O+PPTbzL7A8n1q+um773O3run6UbbmpbRM5GWdzy9bC+gye
AldVcrWUyTeCrfgPMdv2nG2M/BB4YLH98A9Jts1zctdLkvYWrEcdHLjEZeIs
88+3DF96Lxra/1FHHzgXMPAi+wzGf9A+hPk2sd/kOd+ansaOSuH4KZxvKez/
SfBtsvK/f0b5/qx7+YQo75d1f+0S5Xuy7u4PRPlul1cLB/xb1t10ebQ/mpU7
A2v8m4U3/or2SVn3+9rR/lfWHWmNaL80677+LX7M5VXjnZ+z7seLo/29rPzR
RqWwAjhhdpS/z8KiP0X5q6z8yyhwSClc9kq0vVAKx38T/J2s+/2CKG8fZQ7s
c55n3el/i/KKrPvxl1HunpVXWBjl2Vk5g2vwE1m69mmUX8vyE+CXay3b/OBX
ZdnFZcGvL5Uv/ip4j6w8xL34nlL3/++Cf5SVNwSL3ZWFx36N8q9Zd/25WXgL
DLAs2v/Iut9P5LxKYfDnsa8austxVpwTZ7R98EOy9OrcrPPmrLfNWgPyf4R/
K/U/oB2CH56F1W/JwmTgsXFRfrMUFv8gyyfiD1+iX9a9YTo6VSq3d37WXrPP
+K3FWb7rfXBlqfvNu/BS9wT2rLv9yYwof1Yq3zM6C1+CueYEf7vUPYTz71RK
B3LwD0rdD+aWWgPyn5zll/HJQ0rJjczn4MNLYZzpWX4fn/96VswgXoAl1yyF
J9/Mih/EjseydB09n5hlM9jLQ1m6jp5jT3W9z8PRw6x75Igs3UKvZuHTSuWo
dsjSRfTwiyjfXiqPuSjKs0rlGWcEf73Uvas1elvqm8CrpWIq8fRz7KDU/aZN
qfd45wxsolT+5pN454BS9x7yE9y1wGY7Zek6ej4mC1uAK34Ovrfjwtql9Aad
GRjlk0rlowcEH14qZ31C8BNL+XzOcLusc2we5Ral8mX7Bj+5VP66Rujs71m5
K+y4XSlbrhnty7NyVN2ibUJWvh8dn1xKz48stR7Wsoj9y8rn9Qu+cSk/v0rw
40vF6F7YTdZ9ir3fMWv/j8i68+DD0f0nrT9bZz2jvYx5l2bl6oiZ95XysYcH
r1EqT3p6Vgwm/nJuC7POrleUzyyVs945+GmlctBnZsVm4nKH4B1L5QqJ1dMc
rwcGPy4rjpyaFdeJ6UeVOm/O+mLOMysHuWuUTy+VgzwMXSuV592u1D0Qn3xE
lGuWyuceWsp+sB3uefgLfMWWwQdl5cS+C/5WqVzAZsHblsqpDWC8LGxwTdbd
j/vNsqzYQFyYik2Xyhf9krWP7CFrutXrQhf2tz4w3shSY6Jfg6xjN2VhX3Av
+tXfOobe7W3dG5uFk/Azl6NrpXJ7xIQlWXHhlCgfVOp7wNBoO7VUbvrB4JNK
5WheDn5BqXzfVeh5Vr6vf9ZdFExybfDrSuX+OM+Dfaac+SG2WXSwb5YeDi2F
O8GcrYK3LJVzxfc3KeX/rw5+dlZOlLjXqFTseyj4I6XyQ8Sftx2DmrHWUvkY
dPBY6+HMUvaGrR1dCkODn//MisHEX/TiGOsGujDM+oCt7GF7Oa4U3gXrfhx8
fik8hy4Ptj7fFvyzrFz4edhc1jfe1aNcu9R34N5ZsZy1HJQVw4hffbLiH2tH
R17O0pODs+IxsXhOlm1j17tmxXLiONgB3ABmODArXhIrwbD4LPzVRVlxl5i7
VxZWwLf8lIUzwBh/Z/ka/MyQLH1Fhv9l+Sb80v8BrSlH0w==
                    "]], PolygonBox[CompressedData["
1:eJwtl3f0z1Ucxj/33g6i0qBooUMOpUUZ0aAoMiMjfkIiiojsKCOjyEy0JHvT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                    "]]}]}, {}, {}, {}, {}}, 
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwl1Pe/T3UcwPFzh65ERIj84m/IKCtkZKQQChlXVriXIlv2quxc4/Gg3DLK
ntkjUjaVEcosorJnxvP96IfXfX7e5/u9557v53zPLZ2Z3SgrJUmSLn58mpYk
/fSt1mpzapKM4/vsz3X6VceVre5qqA+8/gZ7shF76E31Mjfmh2wS51Ez9TY3
ZR++Fb+v5uprfjuugVuVkZ4kWzjesf4cwPVqb72BhbTNeiO/4yYO4DOsxJP8
noO0U7+ZK7MIX+Yp7uJg7dZpc1UWZXWe5T4O1X6dM7/C4qzFP3mQI/Sc9SE+
4k8cqYHWg9TBurZKWtflRf7MUnxeW/SL+TOO4RSO5dTYbyb24XjcC1WLa4vr
iH1VK+XE+fmq6sQ+qo1mOF6X9XTROsV5LnCOeRa/4Gzm8i/uZVmV05fmr5nL
bmqub8wL49r0sf5xLNU5/+ZL5rlcoLvW85mllrpuvh7n0yLdi/MwW+/ohvkO
F2uZ7puXsrta6ab5AZdrlVbqaccKxL4pJfY+9jT2Pu6t2sV7uVortNGc37Wu
tM60vs0nlKXXtcGxd5lH3dRVDeL75ng7pquL3tNr8Sw4nsk0dVYn1Y/nxvG2
TNVhHdWReKbis3FNfA625dK4vtgTLtHiuG/mKmzNW0zi+q0r8yGf8hkecYn+
Ux7zfVby+l3mM9+LexWfUenmW6zo9Rt80nyT83RNaearrOD1f5nXfIVf6UXH
WsT7eDm+N/F71gvi/sZ3X+W1XwfiWdEl7ynDF+JZtx7D0RqlmeY9PBfPG8+y
Nafzc05jR56K7w0ncDrHswNPsAU/YU58B9k+9jn+X8Q+cxsH66P4u+bJ8UzE
eeP+x3XwQjwrLMHNmqhJ8fc03PED+sO6Zuw382mY9XnWYDHu4UPujT3lEJ5h
NT7LH/iAP8aexvXwd1ZhYW6P+8cdzOBAnmBFFmQPbtIx6wrx3dSa+Oxp//+f
fgySNcri
                    "]], LineBox[CompressedData["
1:eJwl0LtKAmAcxuEvvY5MK6gG7XAbZogHyNVJQeoarNaGsiBKIyG9kc5egQ0J
DRpoYG6NPeHw4/m/8E1fonyYO1gIIWRUj4ZwGgnhio96UMVOa+zuM8ZFLenc
vuYZq8roxm7wiMc6UdZeY55TDpliUpsa2T8scIv77PCO92yzyxK3uaMv94xF
1tTUr93iBtfV06d9y8v/N7xgiwO+cUWr+rC/ucdl7nLCdyYY14te9ayn6Py/
/gAKViuO
                    "]], 
                    LineBox[{735, 806, 805, 832, 618, 885, 884, 861, 662, 836,
                     837, 838, 887, 888, 810, 598, 811, 812, 738, 1006, 594, 
                    619, 901, 902, 1030, 593, 927, 591, 1005, 735}]}}], {}}, {
                  InsetBox["\<\"\[Mu] = \"\>", {-1.8, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["0.2`", {-1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {InsetBox[
                   SubscriptBox["C", "J"], {1.4, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["\<\"=\"\>", {1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["4.78`", {1.7, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {
                  {PointSize[0.05], PointBox[{-0.2, 0}]}, 
                  {PointSize[0.0125], PointBox[{0.8, 0}]}}, 
                 {PointSize[0.007], PointBox[{0.4463998339305619, 0}], 
                  PointBox[{1.2771956561278897`, 0}], 
                  PointBox[{-1.0806611991222994`, 0}], 
                  PointBox[
                   NCache[{0.3, Rational[1, 2] 3^Rational[1, 2]}, {0.3, 
                    0.8660254037844386}]], 
                  PointBox[
                   NCache[{0.3, Rational[-1, 2] 3^Rational[1, 2]}, {
                    0.3, -0.8660254037844386}]]}},
                AspectRatio->1,
                Axes->{False, False},
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                Frame->{{True, True}, {True, True}},
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLines->{None, None},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None, "TransparentPolygonMesh" -> 
                  True, "AxesInFront" -> True},
                PlotRange->{{-2, 2}, {-2, 2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.02], 
                   Scaled[0.02]}, {
                   Scaled[0.02], 
                   Scaled[0.02]}},
                Ticks->{Automatic, Automatic}], 24->
               GraphicsBox[{{GraphicsComplexBox[CompressedData["
1:eJyFWnt4zFf6j8v2gtFQtIZ1LcY9axvU7aVT6hLMWrd2dbRui6E0ZZm6lNZO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                   "], {{
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[0.3], EdgeForm[None], 
                    GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxNmwf8l9MXx597ry2jUNIepEFJkZktUdmbkk1kZO+ZkC1S2WVvIjskQsjK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                    "]], PolygonBox[CompressedData["
1:eJw1l3f8z1UYxb/3XrM0qERFRXsPESEiZJOSMjKSTWWEQhFCJOFny8yoFCKz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                    "]]}]}, {}, {}, {}, {}}, 
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwl1Pe/T3UcwPFzR1mRLX7zF5DKnmWnhOhhr8rMRWaUZEYoFI9HSGTvHWVv
oeyVvfeKZPZ8P/zw8jzvz+c693zP95xbuFVG3U4pSZJk+GdJWpKsTk2S5UxT
un43D2EnduMKndU5tVU7vasM+++wM2uzveqoi/k9dmVddtD7+tRcj91Yn5+o
o1bqV3W33p2r9JvWmIeyB3vEdaml49XMobWO13Ad17InX2YZXuAm9tZmXTSX
ZS6W52VuYx9t1xVzBeZhJV7jTn6uXbpufpP5WIW3+Ce/VH7Hf/HF9CTZw/7q
aa2XWjmuqlcc1+Ad7mUhFtR6bdBoDbT+HQdxDA8xk3Me5teqYK1iXF/cczXU
GOtVWFXV4h6rscZZrx6/UxccZ3ae8/zJ/CMncQInx7XHZ9GrKqafrc/gZLZT
Q800z4prjOvTFWtZnPMy3zBP5XQl1qaxvRrrsb2bcT7NVor9WeygJnpi/x/O
0Xyl2p/Hjmqqp/b/4wIt0WK9ZC2b/tZT8xEe09H47tXC2iIu1oJ4lswL2Tx+
RzxfnBfPHU/zjE4pVW30sWrFM2m/GVP0kT7U2/E+xLUxUev4jlVTy+Mz8RmP
86ROaFl8Pi7lXDZjaS7iYT7hIT5mKR6Md8PxAQ7Wwrh3fBjPr/vzKM6jB3Ev
zP+ypP17zGm+H9+X7iqb+Q5L2L8V74f5Nn/RDWU1X2dx+1eZw3yNU/S6tUZ8
xEvx7MT/czxd07Rfr8XzrH3ao4t+piiLqIHjAfxK/TXevJun452Ke85G/J4T
OZYteZwfcDh/4DC24BE24BCOjXvD5vG7uTGuh5v4mXprgPlbVmfr+KxxLbwd
7woLcJ1GapRGqF9co246rhzPODPri7hffIt5uYMvuFd/xDtq7sur8X4yN7cw
3f7W+LsQ18RLLBffUbzzTLO/Mc5jXs/zLMVh7BXvPL+J+6DS5uzxDMXzlPb8
7/b/IILK/A==
                    "]], LineBox[CompressedData["
1:eJwl0LFKglEch+GTXkZlfVFCpV1IJYIFOotBk11A5uyg1hKVkWBdi5rVaoNB
g3UHGZRLPuHw8vx/cKYTFU9y5YUQQkan8RBqsRAu2VNXJXtXX+4hl7ioZTXs
K9Z5pH1d201WeKaqsvY6c/zhmFvc1LY+7F8eMMU873nHDtt8YIFp7ujTPeUh
j3WjP7vFJDf0onf7lhf/b3jOFt/4zEhrGtnfzHCVe5zwlStMaKAnPaofn//X
DLDvKxk=
                    "]], 
                    LineBox[{732, 657, 803, 829, 828, 614, 879, 878, 856, 658,
                     834, 835, 836, 881, 882, 807, 597, 830, 808, 662, 735, 
                    1015, 593, 615, 895, 896, 1037, 592, 924, 590, 1014, 
                    732}]}}], {}}, {
                  InsetBox["\<\"\[Mu] = \"\>", {-1.8, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["0.2`", {-1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {InsetBox[
                   SubscriptBox["C", "J"], {1.4, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["\<\"=\"\>", {1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["4.77`", {1.7, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {
                  {PointSize[0.05], PointBox[{-0.2, 0}]}, 
                  {PointSize[0.0125], PointBox[{0.8, 0}]}}, 
                 {PointSize[0.007], PointBox[{0.4463998339305619, 0}], 
                  PointBox[{1.2771956561278897`, 0}], 
                  PointBox[{-1.0806611991222994`, 0}], 
                  PointBox[
                   NCache[{0.3, Rational[1, 2] 3^Rational[1, 2]}, {0.3, 
                    0.8660254037844386}]], 
                  PointBox[
                   NCache[{0.3, Rational[-1, 2] 3^Rational[1, 2]}, {
                    0.3, -0.8660254037844386}]]}},
                AspectRatio->1,
                Axes->{False, False},
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                Frame->{{True, True}, {True, True}},
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLines->{None, None},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None, "TransparentPolygonMesh" -> 
                  True, "AxesInFront" -> True},
                PlotRange->{{-2, 2}, {-2, 2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.02], 
                   Scaled[0.02]}, {
                   Scaled[0.02], 
                   Scaled[0.02]}},
                Ticks->{Automatic, Automatic}], 25->
               GraphicsBox[{{GraphicsComplexBox[CompressedData["
1:eJx1W3t4zFf6T3dVVTOqFtUpoRp+s9qSIqtavK1ZqV+KTq26lI6i1HYsXbV0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                   "], {{
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[0.3], EdgeForm[None], 
                    GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxNmwf4l1Mbx59zTmkYJSsyGmZoIcmISjZRtqIyQvYema+VPTJDQsl4Zb5G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                    "]], PolygonBox[CompressedData["
1:eJwtl3f8V1Mcxu85JyUVlayswite9ohoaWiRop2U9iZKpWGVSnvRkNKUprZR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                    "]]}]}, {}, {}, {}, {}}, 
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwl1PmXiGUYh/F3FsZQIktJdU5/Q0SYLIkkKTs5tmwzYhAhWyQUqWwxHM6h
jBY7YexbKfuaLUvJvpQlkvC5Tz9cc93f55n3mWedZzrkNuqRkiRJjh8r05Jk
c2qSrOYiyMQmeQz35X68Br/iOLrhbTTGu/obcT9uwt3RDP3lpjyAm3MPtMR7
cgseyK24J3KxDmsxSHt/Xo8N2CI/yoP5B5xQV+NS/AJ/xp/jUwyVx3N1Psnb
+H1sxym5BpfhWvw77+Lh2I3T8ov8GL/EZ3gfj8B+nJXrcDmuxxf4II/CE+pf
OD09SQ7xaAyItaKr+hU8qW7Al/gwP81PxT7H3mMKxmj/gsfy1NhrLmTME7FO
1I65xTzwDtogL8bn+ng1zgNtMUN7A34Nl9SFjXOR58iz+Cuezfm8A9tREc9h
rvb5nM+5aIsF8kKMwmj8qS3DmFf5efkbnod76u+4J9rjtnwzxsMi3I9xuBc6
4B/5Di/GMiTGXMq98Rbu6L/P32MVCrBU2xJ8jMVYFGeBPvo64a46DSvVNbgL
r+CNvDzuFR/lYziCDOQgG2/E3Yu5ceE4v/ger8cdjTVxIXRGJzSMe6u9HafH
PYjzxaF4M7EmXh3zj2+4Oq/gA5yK/UiJuxz3Lc5V317+CMtjP/hfdFRnxbpj
j1HUPv3H1aKfH5HvxjnFniJTvs1V9f/NxeVb/C1uoIh8navo/4sflq/x16is
rR3f4itxZ+I79bw4W+xBpXg/2I2duOx3KvCzaK0eyR9iBGbKX3Jzvs5neTpm
q6fxQ/52R/VpdWseH/3xruMO8El+k8dxHn/CR3A57jcP5kEYGHdCnhxvgbNR
IvaSL8Yb4fJxDzARkzABI+M8cF79cuwlF4/5q89xXX481s1p5ro39kv+gP/g
2lw23hGn6t8Za5KH8W9ck0vzT5yi/+c4P7kYflRvxRCMjTXG+pAll+QCrEr7
/3/0A8IayGM=
                    "]], LineBox[CompressedData["
1:eJwl0L1KwlEcx+FTXoipKRaY2X1E9achgxwcDfQOTK+gobchSoWC9D569RLS
oSBQh2zQtqAnGj48vy+c6STKtai6EELYVD0WwvFiCJd80L0q9pY+3a9cYlwJ
ndpXPOGhdnRtn/GIDTW1a2e5xxlHXGNOeY3tOYtc5wG7vOEdb9ljiQVuaOL+
5j6rauvH7nCVK+rrw+7wgi2e/73lO1+YVkZv9hcjLnObUw6ZYlLPGthPfIz9
/9cvd1MsWg==
                    "]], 
                    LineBox[{739, 664, 807, 834, 833, 620, 882, 881, 861, 665,
                     839, 840, 841, 884, 885, 811, 603, 835, 812, 669, 742, 
                    1010, 598, 621, 898, 899, 1035, 597, 930, 595, 1009, 
                    739}]}}], {}}, {
                  InsetBox["\<\"\[Mu] = \"\>", {-1.8, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["0.2`", {-1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {InsetBox[
                   SubscriptBox["C", "J"], {1.4, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["\<\"=\"\>", {1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["4.76`", {1.7, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {
                  {PointSize[0.05], PointBox[{-0.2, 0}]}, 
                  {PointSize[0.0125], PointBox[{0.8, 0}]}}, 
                 {PointSize[0.007], PointBox[{0.4463998339305619, 0}], 
                  PointBox[{1.2771956561278897`, 0}], 
                  PointBox[{-1.0806611991222994`, 0}], 
                  PointBox[
                   NCache[{0.3, Rational[1, 2] 3^Rational[1, 2]}, {0.3, 
                    0.8660254037844386}]], 
                  PointBox[
                   NCache[{0.3, Rational[-1, 2] 3^Rational[1, 2]}, {
                    0.3, -0.8660254037844386}]]}},
                AspectRatio->1,
                Axes->{False, False},
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                Frame->{{True, True}, {True, True}},
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLines->{None, None},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None, "TransparentPolygonMesh" -> 
                  True, "AxesInFront" -> True},
                PlotRange->{{-2, 2}, {-2, 2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.02], 
                   Scaled[0.02]}, {
                   Scaled[0.02], 
                   Scaled[0.02]}},
                Ticks->{Automatic, Automatic}], 26->
               GraphicsBox[{{GraphicsComplexBox[CompressedData["
1:eJx1Wnl4zNcajqWuqlE01Rqu4qKppdaxtNHP09FeTelNLVXb2F3tlLaxhiCI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                   "], {{
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[0.3], EdgeForm[None], 
                    GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxNmwn4lkMXxp+ZSRFFpNVS+rQrSZESEspWlCX7li37votsn33LvmQXIkIh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                    "]], PolygonBox[CompressedData["
1:eJwtl3n0zkUYxb8zQ3JaSCgpRZuOc9RpUShKdrKlLMlOtmRJCmUrOylbWaOF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                    "]]}]}, {}, {}, {}, {}}, 
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwl1Pe3yHUcx/Gvey+yZSQjs/wTQpJNZikyU9Y1c44VMstMxrU5Ckc2GUlc
V7JKtsxsZZXsEXm8jx+e9/l+vT/f+/3ez7rl2vdo0j1bkiTpfmxLTZK9KUlS
kHtyFv/KX/FgHsQ/4y9cQY94Du9hiPHm/Bm/z73QEkPlFjyMP+DeaI3hcise
wW24Dz7BTuzASP3BvAu78ZtcnEfxPlxVv8UluCZn8DRMxRfyEbyUliSHuZTe
aD6Ka+pa/ArX4Rt8nMfiBP6W63IZrs83+TSPxx/4V27A5bgR3+GzPBHl1ee4
gO+ej3XDkFiTWA91Y7yqbsb3+AJX5NfwS6w15mCK/uyYC8+N9eaveQbP55l8
iA+jL/rhQyyIb3ATNMWnGIjfcRSLjS/lb3kZ3+GVvJxX8ApeFeuBY6iMKvhO
fwOv4X74GN/LGzEeE/Agzo153+dq8rp4Brn0NnB/dEKK/IQ34kfkljfxAHRG
qpzi9zertyKPnMkD0QVpck7jWeqa3I1z6m2P98kTsQk/xF5gkH46cngmj/yT
um6c3Xh/rDtn8h6+zH/iEgqge7wf78YZjHlzfqSjK96J86n/EedDF3SO/Y1z
rN+B8+I8LsZ+x9nW3xz3iLfEN7h2nEXkjrOEXHFGcSb2MM4df4lt6hc4u7l0
VddQb4m5cWG97HEnkIriclqsg/FsXEhOuDqe6r0s/8/r8R9elB/zm8YfcjH5
Ea/FG3od4z1693h19PXWxz7H/UBVnMQpnMBdz7zOleJsqsfxWIzBEnk5t+Yn
fJMXYYl6IRf1nU7qG+p2PJu/4Vncka9wW57G8ziDL+J+7AkP52EYisnyrLgP
3DvmpZ7Ed+OecIXY+7hbca8wPdZa/wxuqxvG/xEuGudcfYvf5rIxX87vbz3F
ReRx/A/X49Jx7zif8WNcOObO17k2l+SDnNf4oVj/2CPsVx/A55gkT4k5oEbs
WZxfbE99/r/6GfLgxeU=
                    "]], LineBox[CompressedData["
1:eJwl0Esug2EYhuFXf4Nuw8ipBEkpezAxcEgHDmGqA5JuoIctmOCXKBISyjqc
mliCNiGRYIJB9Uo6uHO9T77ZN7RVWtodiIhFVZKIg0xEygfda89e1o/7lSMc
1qiO7FMecl+ratjHrLKmuor2FNfZ5Sdnmdecvux/brDAbd7ymk3e8I47nOeC
vt0xGLHJsi6Vta84431aL/qwL3jCM6Y85ztbnNCk3uw/rjHHFf6yw3GO6Vlt
+4mPSf+/egTMLOI=
                    "]], 
                    LineBox[{748, 674, 815, 844, 843, 629, 886, 885, 866, 675,
                     846, 847, 848, 889, 890, 819, 610, 845, 820, 679, 751, 
                    1020, 605, 630, 904, 905, 1044, 604, 937, 602, 1019, 
                    748}]}}], {}}, {
                  InsetBox["\<\"\[Mu] = \"\>", {-1.8, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["0.2`", {-1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {InsetBox[
                   SubscriptBox["C", "J"], {1.4, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["\<\"=\"\>", {1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["4.75`", {1.7, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {
                  {PointSize[0.05], PointBox[{-0.2, 0}]}, 
                  {PointSize[0.0125], PointBox[{0.8, 0}]}}, 
                 {PointSize[0.007], PointBox[{0.4463998339305619, 0}], 
                  PointBox[{1.2771956561278897`, 0}], 
                  PointBox[{-1.0806611991222994`, 0}], 
                  PointBox[
                   NCache[{0.3, Rational[1, 2] 3^Rational[1, 2]}, {0.3, 
                    0.8660254037844386}]], 
                  PointBox[
                   NCache[{0.3, Rational[-1, 2] 3^Rational[1, 2]}, {
                    0.3, -0.8660254037844386}]]}},
                AspectRatio->1,
                Axes->{False, False},
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                Frame->{{True, True}, {True, True}},
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLines->{None, None},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None, "TransparentPolygonMesh" -> 
                  True, "AxesInFront" -> True},
                PlotRange->{{-2, 2}, {-2, 2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.02], 
                   Scaled[0.02]}, {
                   Scaled[0.02], 
                   Scaled[0.02]}},
                Ticks->{Automatic, Automatic}], 27->
               GraphicsBox[{{GraphicsComplexBox[CompressedData["
1:eJx1Wnt8zFfaT1FsX1OqcZvaULWMW7XWqHq1Dx0fa7OlIy1S7Ii6pcat7oO2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                   "], {{
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[0.3], EdgeForm[None], 
                    GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxNmwfYl9Mbx59zTkmLsrJnlCii0iChkBWZoZCVTfbOzp5FdkbZhIyQlpKV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                    "]], PolygonBox[CompressedData["
1:eJwtlwfUz1Ucxn/3XqNSSUlpamjppEGFyMp6SYTI3lulrBBRRqhQRslBKlmV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                    "]]}]}, {}, {}, {}, {}}, 
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwl1Pe3z3UcwPHPvZfsZKSjIlT4G0RGdjZZ2YSyV5QdZe9d4Rjn6JS996bs
vYlCiIzIXo/X6Yenx/v1fp/r+/l+Pp97C7boVKtjSpIkHfyzNS1JdqYmyWv8
nFu4g+PYk31j1kX9au7EzqqvXuZ6/IoN2EWf6mtzQ/ZmI3ZVE/UxN2ZfNmV3
ddNv5p3sx37xObGnXeZdfFNvabf5EkvybZbmZE7RJA0wH4zvki5JDjC/vYE8
pMvWZfgOy/IKj3KQjumquRwLsgL/5kl+q1O6bq7Id/kxb/IMh+o967PM4HPP
cZj6x/XoC+sqKmxdnbf5O4uyiPZor6ZrpP0fOYozeImzOY6zOJ6HeSSeTdx/
tYyftV+TtVQ77nPcex2L76jZzn/hHM7nHS7iPC7kT1zMEzqu4iqhBfZXcT67
xDPTavOauEaN1n17mX3v/1jKvIhLlWJvCbuquR47e8JlWqlU5yvYTS30xHmi
VdZrleZ8DburpZ46S6911uXYmi+4ges5Ns60Nu6vvrT/mZ5bZ1JlVVJbe5u5
nZu4jX8yu/7Qq+qoDqqrrc5bM5vaq50+0Zb4/5k1nnH87qiONttvxcw6ryy6
oE32N3AjN7INK8Q7pYw6pwwqH++Sejg/wzFab/0Kn6mVdVmuZrq4LvcpjR8p
RbnMqVwe90dZzc9Zxt5T5jQ/i+cdz0RZzI9Y2vkD5jA/jPdCJe014yPei3dI
y61XaoVO60Od0r/OTvIuP2AxNbIeyREarrnmBazP+7zBmfrZegaz++y21tfi
neFEzuEEtuFlNot7Ej8X7x/P6451jfhd5jcaGJ9p/oHV2E5vxDXwFqvyfe7W
NH2vqRpi/7T+ifeFefi6vrO+Ee8PC8XvSDwP13qCuc2DeS2eHQvwMNM7P8Jc
cU38K54R83FfPDvn++N+m3Nqj/Xe+Luh8fHd43urlDlvvKfxzqb9//f6Jdah
yHc=
                    "]], 
                    LineBox[{737, 1032, 736, 809, 810, 662, 932, 661, 621, 
                    594, 933, 663, 901, 902, 903, 597, 816, 601, 1015, 749, 
                    821, 820, 750, 1033, 751, 823, 822, 605, 946, 681, 945, 
                    682, 947, 606, 824, 825, 752, 1016, 602, 624, 677, 1024, 
                    678, 672, 817, 746, 936, 666, 934, 665, 935, 743, 814, 
                    664, 742, 1011, 595, 813, 593, 1010, 739, 812, 811, 977, 
                    738, 976, 975, 900, 656, 928, 974, 973, 620, 792, 737}], 
                    LineBox[{744, 667, 815, 844, 843, 622, 886, 885, 866, 668,
                     846, 847, 848, 889, 890, 818, 603, 845, 819, 673, 747, 
                    1013, 599, 623, 904, 905, 1038, 598, 937, 596, 1012, 
                    744}]}}], {}}, {
                  InsetBox["\<\"\[Mu] = \"\>", {-1.8, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["0.2`", {-1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {InsetBox[
                   SubscriptBox["C", "J"], {1.4, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["\<\"=\"\>", {1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["4.74`", {1.7, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {
                  {PointSize[0.05], PointBox[{-0.2, 0}]}, 
                  {PointSize[0.0125], PointBox[{0.8, 0}]}}, 
                 {PointSize[0.007], PointBox[{0.4463998339305619, 0}], 
                  PointBox[{1.2771956561278897`, 0}], 
                  PointBox[{-1.0806611991222994`, 0}], 
                  PointBox[
                   NCache[{0.3, Rational[1, 2] 3^Rational[1, 2]}, {0.3, 
                    0.8660254037844386}]], 
                  PointBox[
                   NCache[{0.3, Rational[-1, 2] 3^Rational[1, 2]}, {
                    0.3, -0.8660254037844386}]]}},
                AspectRatio->1,
                Axes->{False, False},
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                Frame->{{True, True}, {True, True}},
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLines->{None, None},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None, "TransparentPolygonMesh" -> 
                  True, "AxesInFront" -> True},
                PlotRange->{{-2, 2}, {-2, 2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.02], 
                   Scaled[0.02]}, {
                   Scaled[0.02], 
                   Scaled[0.02]}},
                Ticks->{Automatic, Automatic}], 28->
               GraphicsBox[{{GraphicsComplexBox[CompressedData["
1:eJx1W3lY1NUaxjQyaswMsyaXMBc0t7xi2lU/bTRLvTpSV02745pZtKjlMmZu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                   "], {{
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[0.3], EdgeForm[None], 
                    GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxNm3kcVkMXx+/MJQktIlSkIm3aVLJLkl0SJYQs8WaXZA9vEiLZypp9j7IT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                    "]], PolygonBox[CompressedData["
1:eJwtlwfYllMcxt9zTioqK5GGuLK7ZJRKQztNKU0N7ai0hxapiIZEJC2FpgZK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                    "]]}]}, {}, {}, {}, {}}, 
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwl1PmXT3UYwPE7M5aIc6QFLZY/IYTsW0UKTWTJNrZkrNkSihTKVkI4dCjb
kLLv+5JlUApZx5IllciSJeH1HD+85/V57j3zvXc+936nVNvu6d1SkiTJ9GNt
WpKsTk2SvGzLNVzFkezBvtygw1pj7sS39Zp6mhvyHaazsxqpl/l19mZjZqqJ
+pjfYF82ZVd10VrzRvZjP27SZq0zb+EjKqz15iOswEdZkZ/xc41Vf/NW5cnl
9/i4Y+9xm45aV+ITrMLj3MGB2qkcc1UWZXWe5G6+rz06Za7BJ1mbZ/gjn+ZT
+sn6f+7jEL0b9xPX1wvm4qzDc/yZJVlC2/SlJmmiPnJuMg9xGkdwKj9hNo+z
R+y9WugL88usp1dij2Pfdcrx3fG5nMXJnM3fmcVpnMv5mqc9KqOy+tq5xZzB
zvGstMT8DYfHPemidWKf/2IF8/OabX2Ds5ip5rpsvsI5mqeb5ix20Zv6x3yD
8/WdbpkXsKta6Ir5Dr9XVevWvM5FXM5PtUxLtV/dHW+la9aJaqmmMhxbzZVc
xRU8xDz6Vbn1ljqqgZY735q51EHtVT+uFZ/PNLWL74xejes73pIpOqBUHdQS
x1dwMVeyDavHu6R71r/wLqvFe6Fu1vvieWthvFO6at2SVfgt/1Oavb/Nyo7d
ZH7zrXim+lep5uus5PxV5jNf48zYc6WYL7Oi83/zIfMlljeXUzPrS/yT02P/
Y8/jnuJd13Px/uuCc3v5B0vzWTW2HsaP433WlHj+TOdFnuaEuBfr8czt2hnW
OfHOcCS/imfLNjzMZhzGKfG5sW86b12XgzhQAzQ0Ppsvsb0KWn/Is3yRz3Br
fG/i2hqnwfE36Ld4X9hOBaw/4Ol4f1iMu3iH2XyYg3iC1ViEP8Sz4fZ4HnE/
PMbKfIybeJubY7+ZTxusN8b/C40yj9Ho+D6ZC3Gd1qc9+D99H48uyjI=
                    "]], 
                    LineBox[{725, 1022, 724, 801, 587, 1001, 652, 783, 614, 
                    588, 927, 653, 895, 896, 897, 591, 807, 808, 740, 1031, 
                    739, 812, 741, 1023, 742, 814, 813, 598, 941, 670, 940, 
                    671, 942, 599, 815, 816, 743, 1006, 595, 617, 667, 1014, 
                    668, 662, 809, 735, 930, 656, 928, 655, 929, 731, 805, 
                    654, 730, 1002, 589, 804, 586, 1000, 727, 803, 802, 970, 
                    726, 969, 968, 894, 647, 923, 967, 966, 613, 782, 725}], 
                    LineBox[{732, 657, 806, 837, 836, 615, 879, 878, 859, 658,
                     839, 840, 841, 882, 883, 810, 596, 838, 811, 663, 736, 
                    1004, 593, 616, 898, 899, 1028, 592, 931, 590, 1003, 
                    732}]}}], {}}, {
                  InsetBox["\<\"\[Mu] = \"\>", {-1.8, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["0.2`", {-1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {InsetBox[
                   SubscriptBox["C", "J"], {1.4, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["\<\"=\"\>", {1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["4.73`", {1.7, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {
                  {PointSize[0.05], PointBox[{-0.2, 0}]}, 
                  {PointSize[0.0125], PointBox[{0.8, 0}]}}, 
                 {PointSize[0.007], PointBox[{0.4463998339305619, 0}], 
                  PointBox[{1.2771956561278897`, 0}], 
                  PointBox[{-1.0806611991222994`, 0}], 
                  PointBox[
                   NCache[{0.3, Rational[1, 2] 3^Rational[1, 2]}, {0.3, 
                    0.8660254037844386}]], 
                  PointBox[
                   NCache[{0.3, Rational[-1, 2] 3^Rational[1, 2]}, {
                    0.3, -0.8660254037844386}]]}},
                AspectRatio->1,
                Axes->{False, False},
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                Frame->{{True, True}, {True, True}},
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLines->{None, None},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None, "TransparentPolygonMesh" -> 
                  True, "AxesInFront" -> True},
                PlotRange->{{-2, 2}, {-2, 2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.02], 
                   Scaled[0.02]}, {
                   Scaled[0.02], 
                   Scaled[0.02]}},
                Ticks->{Automatic, Automatic}], 29->
               GraphicsBox[{{GraphicsComplexBox[CompressedData["
1:eJx1W3t8zMfXjiIUIVValmpdu6VV9WtCKQdboaq60lQQVuJWLG9bt9o0JUW3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                   "], {{
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[0.3], EdgeForm[None], 
                    GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxNm3f8l9Mbxp9zniRZZURRUUqFdsmeIRQiDTsjhMyUlZUiM8pKMrP3HkUh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                    "]], PolygonBox[CompressedData["
1:eJwtl3n0T1UUxd89lwYiGqSBxrVazauSSoaiCI0yEyHRKCLKkEyFIlQiiYpk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                    "]]}]}, {}, {}, {}, {}}, 
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwl1OWzFgUUwOHlXlokZkjp+BdApEupGVCkpLm0wr1ISaggISWCIDHEMENI
t7Q0iEqXdEl8IaWR8jnDhx/PObszd993d19Kp2U0Sc+UJEkP//yWqpQkeYed
uZVbOZZ92I87dFrb7J/zCzVVX/un7Mdm7KkW6m9vzgFsyV5qpa/sn3EgWzND
6dpu38lB7M9d2h3Xte9hARXUTvsZVmIhVuGPnKgJGmL/XVkzJ8k+FnHsa+7X
WXNVvsfqPM+/+K0O6IK9BouxFi/xMIfpiC7ba7MEP+I/PMZSLKnj5hc8wREa
EN83vqvq2suwAa/zJMuxrPZpqqbpZ33v3HSe4yyO40yO52xe5ite4VQ1MjfW
DfNrXudCzuQCzuIvvM0lnMvFXKalOqD3VVELnFvL+eypVlpnX8hR8dn0rzlx
f++zStxTLTY/5iL2UhvdtT+Ja2q5nsQ1ma62umd/wRVaraf2VcxQO923J1pj
rsWOfMh13MAxWq9f497rS8c76IE5c9zzeE7q5NgWbuFmbubfzKlTyqEe6q4m
2uR8R2ZXN3XVJ9oYf5/Z1CV+K/pYGxxvzyzx7JU1nm98Nsc3xufjJqaxDj9U
arw7Sol3SkfVO94zjtZac6a412pvrsmVfKNU9/41azj2kjntr7hU/ynF/pzV
nX/KHPZn8Q7EM4q/a3/Eas4/YHb7Q1aO35Vam+/wHudpVTwDrY7fgz7QId1x
7iDvsgLLq4V5JEdouGbbF7Epb/FmvNuaH+87s7h2J/PVeCfiN8w5/IFpPB/v
Ujxrzoh7w1O6YW7IIRysQRpln8L67Kp85pG8xnoszb36SZM1KT6j40d1NZ4L
uyiv+TteYR0W58G4t/G9mYdDeZE1WZR/8Dn/ZG5+w3OsxsLcw2dxfebiu9pl
3q3BGhffWeNV2Z6f27Q99e3/z/8DUpjJEQ==
                    "]], 
                    LineBox[{727, 1020, 726, 805, 589, 999, 654, 787, 616, 
                    590, 926, 655, 893, 894, 895, 593, 811, 812, 744, 1031, 
                    743, 816, 745, 1023, 746, 818, 817, 600, 941, 672, 940, 
                    673, 942, 601, 819, 820, 747, 1004, 597, 619, 669, 1012, 
                    670, 664, 813, 738, 929, 658, 927, 657, 928, 733, 809, 
                    656, 732, 1000, 591, 808, 588, 998, 729, 807, 806, 970, 
                    728, 969, 968, 892, 649, 921, 967, 966, 615, 786, 727}], 
                    LineBox[{734, 659, 810, 841, 840, 617, 881, 880, 862, 660,
                     843, 844, 845, 882, 883, 814, 598, 842, 815, 665, 739, 
                    1002, 595, 618, 896, 897, 1028, 594, 930, 592, 1001, 
                    734}]}}], {}}, {
                  InsetBox["\<\"\[Mu] = \"\>", {-1.8, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["0.2`", {-1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {InsetBox[
                   SubscriptBox["C", "J"], {1.4, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["\<\"=\"\>", {1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["4.72`", {1.7, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {
                  {PointSize[0.05], PointBox[{-0.2, 0}]}, 
                  {PointSize[0.0125], PointBox[{0.8, 0}]}}, 
                 {PointSize[0.007], PointBox[{0.4463998339305619, 0}], 
                  PointBox[{1.2771956561278897`, 0}], 
                  PointBox[{-1.0806611991222994`, 0}], 
                  PointBox[
                   NCache[{0.3, Rational[1, 2] 3^Rational[1, 2]}, {0.3, 
                    0.8660254037844386}]], 
                  PointBox[
                   NCache[{0.3, Rational[-1, 2] 3^Rational[1, 2]}, {
                    0.3, -0.8660254037844386}]]}},
                AspectRatio->1,
                Axes->{False, False},
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                Frame->{{True, True}, {True, True}},
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLines->{None, None},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None, "TransparentPolygonMesh" -> 
                  True, "AxesInFront" -> True},
                PlotRange->{{-2, 2}, {-2, 2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.02], 
                   Scaled[0.02]}, {
                   Scaled[0.02], 
                   Scaled[0.02]}},
                Ticks->{Automatic, Automatic}], 30->
               GraphicsBox[{{GraphicsComplexBox[CompressedData["
1:eJx1Wnt8zfX/HyPClJlLJ7nlcghbcpKFlzr4FVpLilwOVpYcWiF1fCWRE0LS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                   "], {{
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[0.3], EdgeForm[None], 
                    GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxNmnXclsUShp/d/QQECwMRURSlFFGkBBsssEAsDETE7u4jKmCgx0TBBLs7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                    "]], PolygonBox[CompressedData["
1:eJwtl3f811MYxT/3PiVkZCRlZrx4iVCSUUZpW5WmaIqmJJEkMtMwomS2hUii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                    "]]}]}, {}, {}, {}, {}}, 
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwl1OezTVcYwOHtXgRBMBMpShD+BSWI3plEDUa9JPigRu+9dzEuMyTRo/cu
0XtvET36J7335x0ffp717n3uPvesu47CaZ3rdcqQJEk7/2xNTZIdKUmSne24
hf9wFHuwI/+Oa9pp3qWeqmfuxfr8WQ3V29yAfdiIv6ix+pp/Yj82Yft4L+02
72B/dorna5f2mHczr77QXvMlluGX/J7jOUHjNNB8WJkzJskhfu3aIB7RZety
zMcKvMrjHKITumauyAKszOs8zWE6oxvmKvyG1Xmb51iYhfSv9Tuejz1TZ+su
6qoa5m9Zm3f5H4uxqPZpqqZpisa69xuvMj0+G2dwImfyJv9kOv/gTM7lXc7n
bM7jHC7gPS7mXC7iEv2lkyqpUlrs3iouit9bzbQ6Xhefn8P12DqDfX3EsrH3
Wmb9gkvZRS30wPyCy+OZemleya5qqYfmt/F8rdMr81p2Uys9MqdovXUltuFT
bozXc2S8XmtiH9Xd9TQ9sc4cfxtVizPn2uY4s9zE7bzIT3VB2dQ2nq+62uZ+
c2ZVmlrrR22N/WAWtVJL/aAtrn/CZ3HurTdyM9dzEzfE81mFVZUpzoYyxvmK
86Jf3T/HEdpgnRr7HO9tXTE+Y+x5/Ix9T+Lc6p1r2czvuUJv4ufMr1ne/ZfM
an7FJXquFPMzlnP/CbOYn7KMubSaW9/nQy6M51ov4Eqe1Rl9F98H3Xf9FB+w
BIurifVQDtFg/R7PYSMOiu+lBmiW+ThP6JhumZtyMmdxUpwhXovvMY/qiHqp
p8a5Pp112D32T900xjyZtdhBeaxH8w5rsgj3aG+8R5wh1ybGvvOsbsWZYXvl
jvPOm/F3Y8H4rvAtTzEXh/J/VmL++D3j7xCfiZ/FHvAKy/MrHuBrHmQO5tQ+
6/0aoNHmsfE5VNb8eZzHOLOpH/9f/gA0A8ke
                    "]], 
                    LineBox[{732, 1023, 731, 806, 591, 1002, 657, 788, 619, 
                    592, 923, 658, 888, 889, 890, 595, 812, 813, 746, 1031, 
                    745, 817, 747, 1024, 748, 819, 818, 602, 940, 675, 939, 
                    676, 941, 603, 820, 821, 749, 1006, 599, 622, 672, 1015, 
                    673, 667, 814, 742, 926, 661, 924, 660, 925, 738, 810, 
                    659, 737, 1003, 593, 809, 590, 1001, 734, 808, 807, 970, 
                    733, 969, 968, 885, 652, 918, 730, 967, 618, 787, 732}], 
                    LineBox[{739, 662, 811, 842, 841, 620, 874, 873, 859, 663,
                     844, 845, 846, 875, 876, 815, 600, 843, 816, 668, 743, 
                    1005, 597, 621, 891, 892, 1029, 596, 927, 594, 1004, 
                    739}]}}], {}}, {
                  InsetBox["\<\"\[Mu] = \"\>", {-1.8, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["0.2`", {-1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {InsetBox[
                   SubscriptBox["C", "J"], {1.4, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["\<\"=\"\>", {1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["4.71`", {1.7, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {
                  {PointSize[0.05], PointBox[{-0.2, 0}]}, 
                  {PointSize[0.0125], PointBox[{0.8, 0}]}}, 
                 {PointSize[0.007], PointBox[{0.4463998339305619, 0}], 
                  PointBox[{1.2771956561278897`, 0}], 
                  PointBox[{-1.0806611991222994`, 0}], 
                  PointBox[
                   NCache[{0.3, Rational[1, 2] 3^Rational[1, 2]}, {0.3, 
                    0.8660254037844386}]], 
                  PointBox[
                   NCache[{0.3, Rational[-1, 2] 3^Rational[1, 2]}, {
                    0.3, -0.8660254037844386}]]}},
                AspectRatio->1,
                Axes->{False, False},
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                Frame->{{True, True}, {True, True}},
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLines->{None, None},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None, "TransparentPolygonMesh" -> 
                  True, "AxesInFront" -> True},
                PlotRange->{{-2, 2}, {-2, 2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.02], 
                   Scaled[0.02]}, {
                   Scaled[0.02], 
                   Scaled[0.02]}},
                Ticks->{Automatic, Automatic}], 31->
               GraphicsBox[{{GraphicsComplexBox[CompressedData["
1:eJx1Wnl4zNf+jqXaq0bDVXREar9TpFw1KZr2U0Y1Ty2dotWqDrWkGL0q1gn3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                   "], {{
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[0.3], EdgeForm[None], 
                    GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxNm3f8l1Mbx+9zTqIyIqMhKaMohWQ9DSRkRLKSmREykj2ySaKs7FEhe2Sl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                    "]], PolygonBox[CompressedData["
1:eJwtl3f4llMcxt9zzi9NcjWkYWaVEaUiinbSHiTR0pJKRYlKKQotaU+lnRJC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                    "]]}]}, {}, {}, {}, {}}, 
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwl1OWTVmUYwOHDLhIiiIQwIwpL179Ai4TU8IEGCQnpTlFaEOkeQmboEKSk
S7q7u5kBR1okve7xw4/rfs4u74n3OZvWskvdzumSJGnrnx2pSbI7JUlysiO3
cbtG6XvrrvxTu7THeq8GqqH1D2zE9mqiH60bcxCbsoO+0WDrZhzC/cqUPkn2
8WfHhrJbXEN8vg7EOfi5vtBB6yssz/ysyHEcr7Eabn1cmX3mMaY5NoIndNVc
iQVZmdd5miN1Rjesv2JhVuUtno/r0gXdtq7GoqzBe7zE4iymy+bEea9wrLo7
1kM9VdO6JEvpmvkAr/IgS+uQpmqapsT9+Nl03uEsTuJMTuZsPuACzuF8/sqF
fMTFnMdFnM8lfMHlXMxlXKHf4v5VLr4Xx/+OY/yMvdlca+N3OTyeo16bU93j
K1ay/lKrzK/4O/uopR5bJ1ptXqfX5rXsq1Z6Yv2B/jBv0BvzevbTt3pq/aE2
mquzLV9wM9dzZPxfrYvnrgGOt9FzczbVVq3Yc45tjT3LzdzJbK5/S+xT80vm
0HdqoB1xffxE7eK8qh/vQNwXs6uNWquetjn+Mf+JzzBv4ta4J27hxvgc1og9
oKyxZ/SRvtZF9Y/9xZ+0yZyFz+Ic5qqx55RZGVx3JlaJOT7LOiPX+L308Tyt
U2MPK12cwzqFK/38ffyO9TtWduxNnMf6LStaV1AL8yP+G3tFq83LuCbeA52L
905n437jneFLlmUZNTH30jDzUC0wL2VDDuFgDdJc61P8iyf5MPZa7H/Oif0f
e4B3413mvXh/4zmpnyZYz2Cd2G+xV9Ur3o14T+K7d7yL8prH8X7sBZbgPu3X
RI1xbAJ/4UXdje+EnZXHPJp3WJ1F4r7jOcZz4KccxZvxfbAQT/IdTzF3fJ+8
Fu8IC/AI3/Ioc7ETD+lwPDONjmuK64nvwzpf7FftSvn/7/J/Ot7HWA==
                    "]], 
                    LineBox[{738, 1025, 737, 813, 594, 1002, 663, 794, 625, 
                    595, 927, 664, 891, 892, 893, 598, 819, 820, 754, 1034, 
                    753, 824, 755, 1026, 756, 826, 825, 605, 944, 681, 943, 
                    682, 945, 606, 827, 828, 757, 1006, 602, 628, 678, 1017, 
                    679, 673, 821, 750, 930, 667, 928, 666, 929, 745, 817, 
                    665, 744, 1003, 596, 816, 593, 1001, 740, 815, 814, 975, 
                    739, 974, 973, 888, 658, 922, 736, 972, 624, 793, 738}], 
                    LineBox[{746, 668, 818, 849, 848, 626, 877, 876, 865, 669,
                     851, 852, 853, 878, 879, 822, 603, 850, 823, 674, 751, 
                    1005, 600, 627, 894, 895, 1031, 599, 931, 597, 1004, 
                    746}]}}], {}}, {
                  InsetBox["\<\"\[Mu] = \"\>", {-1.8, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["0.2`", {-1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {InsetBox[
                   SubscriptBox["C", "J"], {1.4, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["\<\"=\"\>", {1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["4.7`", {1.7, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {
                  {PointSize[0.05], PointBox[{-0.2, 0}]}, 
                  {PointSize[0.0125], PointBox[{0.8, 0}]}}, 
                 {PointSize[0.007], PointBox[{0.4463998339305619, 0}], 
                  PointBox[{1.2771956561278897`, 0}], 
                  PointBox[{-1.0806611991222994`, 0}], 
                  PointBox[
                   NCache[{0.3, Rational[1, 2] 3^Rational[1, 2]}, {0.3, 
                    0.8660254037844386}]], 
                  PointBox[
                   NCache[{0.3, Rational[-1, 2] 3^Rational[1, 2]}, {
                    0.3, -0.8660254037844386}]]}},
                AspectRatio->1,
                Axes->{False, False},
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                Frame->{{True, True}, {True, True}},
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLines->{None, None},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None, "TransparentPolygonMesh" -> 
                  True, "AxesInFront" -> True},
                PlotRange->{{-2, 2}, {-2, 2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.02], 
                   Scaled[0.02]}, {
                   Scaled[0.02], 
                   Scaled[0.02]}},
                Ticks->{Automatic, Automatic}], 32->
               GraphicsBox[{{GraphicsComplexBox[CompressedData["
1:eJx1WnlY1NX+5qotoiC/ch3RrFzG1CR11Cz9WENec6HRvF0172iWWJFpSunw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                   "], {{
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[0.3], EdgeForm[None], 
                    GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxNmwn4l0P3xp+Z+VUqS4WIpBTizZbsImVLtrIVZcm+ZcmSbG9S9n0pa2Xf
smVfkp2EJGSPUMnyitc/vPifT/f9vb6uq9OZZ2aemTMzZ865z3m+vw6Dj+s3
JFdVdVFDVZXgV6eq+j34oqDm0dAs6Jyo2yL45kG/RPnnaAtWNQ3aLOri1WrJ
oK2i3D1oUTQeHrRR0P9F/RpRt3rQr/H8Wzw3CWoVtGXWGMsF/RXUMqhd0ArM
7TFXNF8qqI350kErmS8TtLxlaUZ7jLlk0LkxV+fgawb9HuUjgzYN+l/0+Tv4
jKC+UV7V8yJPh6BlLc9q5ozd0bx1UCdzZFzdHBnXMEfGtYJWDmob1Nmy8nwM
+xj0t8do5nWmqFsleJegDT0f86zr/UDG9czbB61vjrwbmCNvV/OObm/l9XTz
eMi7TqW5GHcj1yH7xuZrBm1ijuzHhWzdg3LQG0FTgxqCXk+Sd8ug7padsf9k
j4M2Rze8F2ujG25nTVubs6bG7EnwnYN6uI719fTaWNO23hfWsZ05svdyO23b
u4517Og1bBq0jcdjrB3cTltvt2/mtbbxOe1SSR7Wta/Hou/uXgOy9zVH3n7m
zLOHObLvY1mRazfvEe+vnSX3nuxH1tr2Ctr1H3u5t9e8nWXs7H3cz7LsFDQ6
ac/2DzrA+4fsB5oz3gCvmTX0tyw8H+R25BpszvomB00Muj/oOfMHONuQ882Y
r3nQYZYXGQ83Z63TkuoPZb+z5jsi6IIkGYcEHe09ZR0bZsl3ZFDbKI+JftcG
HfePNZ3q9qOCTrTcyLtM0jxDg07ynMi1bdS3TJLreI9xoN8f4Lm7xlyzok+r
oA+Sxj+Fc4tys6QzHOZ3kPedqJsetGTQ20nrOD3oDK8Jec80Z86zzE8IOtsc
2S9Ommdk0Lgo35wk+7me/1T3PdDrHOU6ZFku+v47+GVBlyTNfz57+w9ZLjRH
lovMkeVic2S5Id69PuiYKF9eacwRQbdG3S1Bp7GfwdsELR/0adAnQa2DPk6S
/aqgu6J8Z9BoxkmSZWzQdf+Q63pz5JoYfe7jfKN8jdfM+m5wO/LeaI68bZPG
uzuoXZxXCUpBs6P+86AVkdf7wTpuNb8i6LOk+glBt7nuyqA7LPvVQSdHn95B
KwTd7nba7nQ7MvaItqZJ93vjrLXdE/R4pXcYb6LXgOz3m99U6c7Abw560Hxc
0COV5Ebe+7xHvP+Q28cHPWyO/Pd6T+k3yXW3WMaR3scnLAuyNw05v8KXBM1J
kvepoKctO+M95n1hDY9aFp6fcTtyPWvO+lok3TN0ZYrXxppqthg79aLlRsaX
zFnrC14bbS+7jjmn/kOuxiFzo6x1vOJ2ZGyf1Of1oDfcFxlneg7Ge6uSzcJW
vW2OjNPNnw96xxxZpnkM1veq5+E8Z7iddbxrzhw1f48/fc9zIuNqIVuHoNdo
S1rPB0GzvDbk/dCcOT8yfzPoY3Nk/8yyIuOnXgPPn7tuhvs+63XOdh0yfuNx
Ge9L7wsyrh7ydAp6P8prJMk0h/5JMn0V9LXl4/33vSb2Y67H+yToC8/DuPNc
h4zzzZH9W3Pk7Rzjr5kky97B10qaa+2k+b4PejBJ7h8qYUmwI/hnftJ830FJ
cvwY9B/LxPxgR3AgWPPHJDl+Cuof5X8FLYjyfsHXTXpvg+D/rYRp943yOklj
dg3+q8cB14IbwbKPJK1nYSX8C8ZdohL+BfM28x685XNa3RgTPArGBFeC8f6s
hHHBlOBgMBh4F1wM3gWPMSd4EnxZw7VgR/DyH5UwbTPrH/3YoxX8DLYFU4N9
a/iYtgU+B3SEBYGnV7Ec4EbwHrK09zNydPAz+Hglz1vD1m2qOg7uUNVxMM81
34Zf4W5hDx7yO2CpNbwXYBawy98ut/XYnd2vJGHff1V1LLt+Vce763oN4MYu
VR37rlfV8S7vTDUeBbeBZ8GB3ao6rt2oquPajT3/pn5mTRt6rHaecx3Lu5n7
gX0pr13Vsf7qlgm8tmVVx7VbWb4efkbebfyMrD39zHy9/Mz82/oZ+cBoNTwL
386y7ui2Tl7fhpavt9uYGxwHngOHN0rCiksk4ew+lfYIfLiz5d7Vz9393q5e
/1auq+FdxgXX9/a+sJ5+bqthX57Bt3t4XcgNNtzb6+jvZ9YwwM/Iva+fa5jy
MO8Hz3t5ffu5X5OkMusCZx7uMc9LwsSDqjoOPqCqY1wwFTHfYK9lV9fRr8qK
CfH34Fyw7CHeI8YAj56YhBGbG+ciI7izFgdyJmDaI7wucCX4DWwHrj3aa7gw
CRMf63HBjUM8z/F+Zlyw4VCvmXePsqwnuB+yn+jnAW5nzqWS6lkn8QVxRi+3
D7NMYMBhHne6ce1wywGGBFPOMj4+uRKmPslrruHdM6o63uV56SSbwNw3G68O
9frBKeCVS5Pw63meA3wIXgR7jrJ8NSx7QVXHrzU8e5HbGBu8d5nXM8pzLJvU
HznAr/QZ4TYwHbgJ3HqN37kiCb+OqYR5wblXVHX8Cvaq+e8PPfcNbjvf7WOr
On6lDawKrgT/gRvvdp+VjVvBeWBYcOp4rwFMN6GqY9kaxgPTge3Aqisl4Ujk
u839wK23+3mk37nKdIfbwM03eh+RF4x3j9dwn5+Re6Kfa1iW51OxH0l4HPx+
p/exhnHpV8O4PBMrECcgF+t8yG2s82E/IxOY6zHL+ISf2yWVmQMMCCZ52bKC
/Z7yOh+r6hjxVff7ynj3yUpY8lWPeav7PlLVce0zlgm/NaWqx7qTLd8Lbqth
2Rf9/st+vtdjPO09muxxH3Zf3q/hPPSmSRbGXTVpDDDaTL8PPpzq8ab5+Vm/
P62q49fpVR3jvuW94L3XrTeTPP9kt79pWZkHDDcs5t4lCVMj3wyPy969b5k6
GDOyd6dHefckbFvDxDOqOq6dVdVxNjLd4j2aZLlo/8A6McWyI9cn3hf8A7F2
P8sBbvnMc8z283TXfer5v3Ab84MnwZZnxRh7JOFc1vql+4F151gOzuAbvwP+
/N7lGpadV9Wx7HzPvaD2bFw523LP9VidjHPZNzDvd5737CTsC+YFt4DBwBRg
2h/87o/Gp8wL5vzJ84JhF3reB5JwbZegw4LWT8Kj22Rx8GMbcKCx7NZZWBdM
u2ESPmzs/Z5nucF11IPxwGbgVfDYEdG/W6pjVjg4caUsHAwGXjnKfxibbpz0
bguPy1rA1QOTsG9Lv/tbUg75qOCbGI9uloQFmXetrLzP0/jCoM2NBVfN4otz
i0nYC9wF5qBMXnHrJBwABhgUvPJ+b5WUmwTjHJ/0DO4ByzEv4yydVYdv3yEp
vv03+5/l29HNd5P8KD70gOA9/Qxf2v4V3QUvgH+eSVoHMr0f9F5SjqqX+VDf
k099JmAWfCr+FLu+sv3C9kk+DP+1SsiTs54XJuWA8BU7Jvk2/BrvrGg/MgUe
tJ393vL2ZVBr2+QNsvJezI8NX8E+5UC/h0z4qrb2iX1s+/FhXyTZaOzzQeyf
n2/2GsZ5zjael/ZVbdOxV+1tn3e1HcJ2ET9jd7A5g4Pvlup2iDvG/ToYO5H0
3Nc2CdsyPCnWpe+ZSfEnd/JL30nuI/d/Dfc/JPheSW3zguYmxajcJ+5X8r3n
HnIHDw0+IPnZd5H2H4J/nxRPYke469iiPZPmmuM7QRy6OIYNvl5SHWd3ks9v
xawYtfjOcQeb+I4SBy5j+8Hdaen7yvcL7s7RSXeJcvLdWcX3o7vvyJCk+4PO
N/Zd4F7skyQzdpD4YGvfo5bWAXAe92Ab34Wa3qPzLazTi/NBSXpDzrWVOXqF
HSLGxhZxV7a3PmPvyalxb9Bl7h73bkLSvoywPva2TpHL6mPda2d9e8J6tIt1
6bQkfUKX2OP9vM8vJ2GXPtan3awn6M7u7s++DvTenmHd+sD6sofLrwZ/JdVt
+t4+6zWtS9j915J0pZaHQGcWWn/7WSe7uH2B9WJf6wY2aQufEWc4yOfI2fKt
iHZyTYO9DvSd+9DJ+n6I9bm/ZWB+7DPfutCXbX1GnC22/DDrOz6C73PoGmey
f5Itw37jD36zDQD7YQeI07HR6BryDrHM6Bffh9A7YkxsLrqGnh5t/eRi4QP+
st0+IclOohdDk+zbVJ8N54ItPCXJrnG2YJf2PsPhPkfOCozS0Wd1hs+L/T7T
ez4yKb8T/xaf+Wken3sKbuCcuQtn+2z7WGdYN3d0RJItOz8ptiSuHJWU82lU
KW9DGb96VVLb4vqsMv73yiQ5kAGfjTzkdZbJ8kPEqy3MiQX53kr/7D7M28f2
4Jok/9syK4ZEnmWx51nfFjqaEwcsH+XlsmKtFYK3zopzLkp6l9iztduJYy5L
is2IyzpkxadDPA71wz1vC7fh64hpiWeJISkfYz7GZfhYl5HhCo+PPiELfgZZ
rvNa6EdcynhNPAfjD3M93yZuTPqGQV/sFHFmLTdNeYT5OJfHu0zfu5O+W/DN
gjFu8pjYvPHuQ98JfvfFpHfoTz9i1GHmt7r++eC3eRzqbnf9be5DPft3h/eQ
2In4k+8gozwW/Ue7fpT5Xe5zvdfLONTd4/pHk7Ajdga/TGx2VyU+0eX7Xab/
S0nPlCcFfygJj17rd5ALbAo+xqfR/qD7cG73+uwe9Lv4jueSzoOzQBZkAss+
7vJCy/mY69HrJ6zb3/qd+Z7rYY/JvXnSdwdb8lSS38JX/jf4L1E/OQlvoSMv
g48aNAdYo7G/I6SoeybLRjYJB9uqQXaCduIxcAcx+BJZcXgjx2jUg0UaubzQ
fS5lvcGfLLLlDf4mdUml+ehPvEldg+N/YtKvk77FbOrvMvgy8tjkjrEfL8V4
Lxftyz5RN67I1/4efJkiX3J/8IlZ5zcu+PgiP8x4TZ1fuDH46UX+9jbey8rb
3BPlu7L0+OYoX5f1HZP5+U0G9uqOqL81S2enBj8na5/bGX+yRvwEeefG5ku5
TK6A/AJYkvwZh3twJfxBrhDMvobjFObCfhFHgG0WxwdJmId5GIccBX6Isfp6
DPKY4JPefqb8l+uZZ4b7My91tIFrJsa6Hiy6A8QzzEXOeyvHJrXcPjYXnVyc
43cZXaUee93H+8w5Yu9ZPzZ/kdfQpGbXs2w7/ix7LZ0dN7XwPhXvFTlwcu7E
YUtaJ5by3vzu/eEusM/M+UCs44Oie70751zku64K3i/LR1we/NOs+OecqB9R
ZNdPCn51kS+5MtpPKNqfqcHfKLpjV2Cfi949PPjAImx6YdS/m3Vuq0Tdi0UY
4pqou67Idg+L8llRPif6zM6ag/FHR93/nPc4O/gnRViK+J34HGx+adEcjH8E
elLkw4/OugPo/5FRXlSEt44IfkARvnwNH1eE3S8JfnHRb5cuYO1Zvhd9n2+d
vzDqz8/y1ZdF+fIin3pB1F1UHKsGP7LIJxwWvH8RrmwV/NAifDk4+j9chFPv
j/JDRfHP18F3Qnmwc1F+vCiOfyjqHinSn0Oj/FgRlp2MXEUxyI3Bx2TZ0+fY
pyw7ir053zbnleCvFtnHPsGbFWGZV6PvC96HZ4I/n2XjJ4FDivZ/DvqThctO
DX50ES58L/j7QS+wruB7F8U1h6BfRVi1ZfCDizDr21n7xV4NiLqRthUDs+wO
NufL4DtkYUnOs7HP9BTai/AU59ncZzo8+GlF2GR/9DQrpwGOXNq6zX1qZxuB
jvK9h1imfVaZ70fwN1ymje9BfN8g7iUnSU6UOJgcJXWdssroLfkZYjr83XpR
v27WNwBiN/I1+K913Afcvriv+yMDOQvmeyvp+wHfDsgBMAa5fDAmsQTxA/iC
/SbmwZ/jm/HDW9jHEQ+CI8Afoz3Xd54XzALmAA+Ao/GF+EFkZl5y/WAufDN+
Gf0jPiE+wGc+GzSwkhzcRXRvrteP/yfOXZAc6yY9E+OAxfGX4ysRPnNCJd9I
Pf6ReJq4eo5962zXf5mEUe5yf3wq7+MTN8nK22IP5vpd+vJOu5p8STEX8R59
n/Jc37j+Te87Met9nutOr2W+5W9m+853VPSVfeaqcv6fWgfAIpz1PHPOnljy
i0rjzA7+k+t/Mjb4OSmWne+9WuCxf/H4i/sm2RDWzDvkcH52mf0ZbT0nHwVm
51sM30bA9Xx/OcV+hpwaPot2MDr4HL5aFp4nvlvJdxN/28b+nTFaGQ9c7DJj
guPB88QdfANazXNTB9Yf5LWAvdBJsDr1vFeLN87x3aI80mN2sDzc2VWMH8Dy
5PqID4rvMvW1fB93Ft7e5VpchAxj/O5A32n6dfHZcYeZH79JjhI/iyydLBs2
ob3vJnu8jO0JvpDyaO/Hst4f1s8ZgNXJAc5Myn+Qw3vPd/mjpP0a7n3j92Gs
l/2b7nJf45LdXd/Be4tcHS3zh0nf2E72OIyLn9ooq/4I2xDyidiTWX6nlft0
s34gJ3OBf2b6mTK4nbiLWAsi3iPW28Bnyj24xOtF32inPzh/mtd7iHVyee8J
sQzlSzwncw32OK39Lnhldever9bFBvNfXb492u8qiosOx94Xxfd8zyVHSR6J
3xySk8WmfYW/zcqL8G2VfnzzpX1t9wE38TuMWm57TevDDO5IUfn64HOych7Y
+PX87tCo3z0rP3Fy8JWKciJf0adoP7Ez69kv7Bp8qHV1Lv48KxeydZQPyopx
GZ/vr3wr5ls25V6Vfveyhe8U8rPO5pa9s2XuBc7Ksnnr2B8h52dRv5Sx319R
t21RLgzZurjPNlF3SJa9neZ1IsMX+IgiH9AFP1/kQ8CPJ/leDCrCWOCrfYuw
IPrSI+sbA7/XIe7Y1HZ7drT3ysonYcupJx7BztIXbMu7m3u9s6y76O3Gtv/0
h/N8j+00/Rnjj+DbFcVi2CL2jfY5no/+6Av6wH1Ztgi3YW+JCycXxYZHRftO
xf4l+PZZeTLsBnuO7nS17jHO80U4Egy5tvWQXCiY6MUsXIQ/5RtGzbatZRvF
GfNOz+BTaC+Kb7cMvkXRbw97Zn3L4fdAVweNLfLbJ0R5SlG+6MQov5UVX3QF
62XdR/KrW3s/O8Z/M70WfASxDXEO7T3c56Ai/Ap2fYe7XJRr3sxnyn08Nvhu
RTH4gUWYD7xXovH9rFxpQ5Q/yspTfsa9K8o187sm5sU3rRp1b1ofcoPmYy7W
2tN9urvM2sGt4Hiw61pR/jwrptvS+9PU96WHdY/3unuc2vcwyossB/HdujHO
W0Vnwd3dO+v+zvIZc76nBb83y//eFvzO4txNFgbFbp0b5f2K9vu7KI/Psr3g
02lZfa7Piqux2z9kPVMmhgYfY2MP5P4V5ROHBN+0KL94avBrs/Lidwb/TxY+
3Zz3svzj2OA3FeG+tsFPz/r2sqz3iN9ngdlfyMKnbxfZL2zXBsQERb9b+T0r
DiEGuZu1F2HPlYOfkvWNq2+Uj8/K29wU/Nssv3deUawCFgOz72Lcjr5zB9jn
naPumCysRd6iX1HstmfwPYq+FXC3unoPyYtgR7Bv+DF+N8NvVzi3a3125GyW
KMrboKRPZuW/fwx+S9H3g5nB3y369kX8SgxMfMC6Z3jtxF4Peu0LmKvoGwax
ETEq8dE3Uf9O0TcPYqzXi+IsfleDbPici7JiG+KaHbNiKuKpWVn+Cd/EXcS+
cB+5B9hH7sJ9Ub4jCyu25O9sinLS22OfsnL8LRpk07Hnr0V9u6IcS5+o+6Yo
7z69SG/Qmcuifl5Rbp4x/i4ah7iweYNiQ9p3yeqzYtE7lBnv46wx7wl+X1GO
76ooLyjK5eOTk/0yMe4DWXHuJPxhVp7+kyz/h+9rhFwNys3/mbUe1vJelh3B
hnyYZUewIedG/5FFOGV6lr3AVjyblb8jd/dU1tlz7ruhk7Y5GLamDfo+MCvK
v2V9q8hF+8veXpIVk2NM2ZtHvc/kTj6zD+V+j8q648dE+diiuIx5sHHMRQ7g
pSyfMigr33FOpbU2FK2XnMqJRXkP7mKLovsI5iH/Be5ZmHW3udebFOkxOjyh
SC/Ryf5Zth473z34VkXfQsjtnVGU3yP/d3NWDnAjdK3oO8qZ2Pis7ypgkOFZ
OARf2833C71oWqQbB2TZQWwg+9ejaA/Z17+z9nZM1F1ThME/Dv5R0bc1clHg
DDDGoqwz4F3uSjfbWH5rhE8f6zu+kevRr75ZOtYzyh8WfXdpU6R/1P8/OKNb
rg==
                    "]], PolygonBox[CompressedData["
1:eJwtl3nYjkUYxd9nbmtRrkihlEql0KKkvRCKkCWRpQjZlaUSIsRlbVEU2uxk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                    "]]}]}, {}, {}, {}, {}}, 
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwl1Pe3z3UcwPHPHWa5iMI5yYiI+BeUvTIPMrJykXXtY0R22VzKvdYvZa+y
slfDVpklm4ocznEO2ePxOn54erze7w/f8fm+P8p1zWrRLyVJkkx/7EtLkgOp
SVKcA7iHezVZY62z+JN+1kHrQxqnttbj2Y491EETrNtzIj9mT3XSJOuO/IJH
VCg9SQ5zir0v2Z+/aH+8R3wevaUyOur6JdZiWdbhTM7SDE2xPqEMr3mc5e29
rZPmy6zLCqzPqzzDafpD16wb8B024j/8izN0Tv9aN2ZlNuV/vMAqfFcXzXm8
7yVma4C9gRqkZtbvsZquxPfmZR5ldR3T15qnrzTXtRxe58LY5wLmcBFvcSm/
4RJ+y2W8w5VczhVcwVW8z7VcwzX8Tuvi++sDdbN/l+v5JkcyU5vNGzgxfjc9
Mef3HR+zTtxPbTY/5yZ+ph763zpFP5i3KfFvtnKUeuq+a3m13bxTKa7v4Gh9
qgeuvaIP456rj73H3M2tcU60JV4/7rvG2O+tR+bCaqHm6m9vd5yneJ84tyzm
vXaZs8xPWUzd9VGcbXtd+Joy476ojX6035lF9Ym6qrX22S8S90X9zDvieYnv
zD3czr5sGmdAGXFmVEhNdF6fx/mK50G7zK/yoXqZG8ZZVMG4Hz53gTijyhef
0Tp/3Ic4d/F3rNPjbCs1Pqt1GjfG/WcB6+fmeuan8bmtn7F2PE9xD8z3+Ijf
a2OcE26K50BnVVN/6kE8M/E5+T5rqIt5hCaYx2uleTU7xv8RHBu/k5ZYL2c7
3uFtztdicy5v6Ja5Vbweh2tYPBfWuWzJoRyiwfGsaE785vYHq1SseTPOAKvy
kA4rW7PtzeYsno/3i9+Cg1TSPJPX4+yxUnxfprtXZ1nCejr/ZkNW5CmmuX6a
b1hP5RXWYzn+xlTXf+fr1gN5TL9qsqbGa2qaaluXjvOm/akv/z9+AUOVwcw=

                    "]], 
                    LineBox[{741, 1030, 740, 815, 598, 1006, 667, 795, 630, 
                    599, 927, 668, 891, 892, 893, 603, 821, 822, 755, 1039, 
                    754, 826, 756, 1031, 757, 828, 827, 610, 946, 686, 945, 
                    687, 947, 611, 829, 830, 758, 1011, 607, 633, 683, 1022, 
                    684, 678, 823, 751, 930, 671, 928, 670, 929, 747, 819, 
                    669, 746, 1007, 600, 818, 596, 1004, 743, 817, 816, 978, 
                    742, 977, 976, 887, 662, 922, 739, 975, 629, 794, 741}], 
                    LineBox[{748, 672, 820, 852, 851, 631, 875, 874, 873, 980,
                     979, 673, 931, 674, 981, 982, 876, 877, 878, 824, 608, 
                    853, 825, 679, 752, 1010, 605, 632, 894, 895, 1036, 604, 
                    932, 601, 1008, 748}]}}], {}}, {
                  InsetBox["\<\"\[Mu] = \"\>", {-1.8, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["0.2`", {-1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {InsetBox[
                   SubscriptBox["C", "J"], {1.4, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["\<\"=\"\>", {1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["4.69`", {1.7, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {
                  {PointSize[0.05], PointBox[{-0.2, 0}]}, 
                  {PointSize[0.0125], PointBox[{0.8, 0}]}}, 
                 {PointSize[0.007], PointBox[{0.4463998339305619, 0}], 
                  PointBox[{1.2771956561278897`, 0}], 
                  PointBox[{-1.0806611991222994`, 0}], 
                  PointBox[
                   NCache[{0.3, Rational[1, 2] 3^Rational[1, 2]}, {0.3, 
                    0.8660254037844386}]], 
                  PointBox[
                   NCache[{0.3, Rational[-1, 2] 3^Rational[1, 2]}, {
                    0.3, -0.8660254037844386}]]}},
                AspectRatio->1,
                Axes->{False, False},
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                Frame->{{True, True}, {True, True}},
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLines->{None, None},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None, "TransparentPolygonMesh" -> 
                  True, "AxesInFront" -> True},
                PlotRange->{{-2, 2}, {-2, 2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.02], 
                   Scaled[0.02]}, {
                   Scaled[0.02], 
                   Scaled[0.02]}},
                Ticks->{Automatic, Automatic}], 33->
               GraphicsBox[{{GraphicsComplexBox[CompressedData["
1:eJx1W3l4zNf6T4s2F+OmbWoZEbdqSdHWjSYlxYupKD90bqy1TLTFdU1LpVUd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                   "], {{
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[0.3], EdgeForm[None], 
                    GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxNm3f819MXx9/33kopSkXDKlLJLIlEUqlsIVuUvVfIzMrIjuwRv8jeW0aK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                    "]], PolygonBox[CompressedData["
1:eJwtl3fYl1Mcxp9zzpt6U12KiKyQ0bBCREZCmloaMnq1tYyGUKShZERJUqIl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                    "]]}]}, {}, {}, {}, {}}, 
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwl1PmXz1UYwPHPzGiGZN/DOSFRyVb/AsoShpRD2ZWYIVkSouzL2MYuMrZf
LNnGkiVLsmQnyS5L1tI5nSPZej2nH97zfp7n3rmfz733+XyrdO6dmZ2SJEkX
fw6kJcmR1CSpwIN4H+/HVIyV9+ODOISj8mMYhw/k47kD90InTJB35IncmbPQ
FTnyLjyJT6BkgSQ5ztPUJnN/PhzvgWPxHFTDizhp/AY34ercjGfyLMzANPkZ
lLLmr1xDrSbOim/y2/wyt+DbfIGn4yLuyFvyq9yK/+DfYn1cwZ/y1vwa18Z1
cWnPucZ15L/zs/IbPBcD1AbiM7wrr8+v45b4JN/kn/kNnMICfIP5gbGFfI+X
8EJezHm8lP/mVbycV/IK/pbv81pezWt4Da/jx7yB8zmfN2EjLqIheqo/4O/4
BR7BvbBdvIVz4r6QgiL2mMQdINvYQ97GVXgk98YjcTq2i3fiGf+zg0ehDx4b
K4xd4h+Qbnw3j8YneGKsODLjTtBPLcWcH2M9+RTswPdx7hij/ikSc0rHeaNN
nL3a3uhX3hO9G70d68TdiNPE5WP/eB8/qXXncvgYPdAeB9S7cVl8hA/RLr4N
9TKcap0BsRfxPt7Fe3k39+fW/A5KRd+gZPQYruIarkSvRf9jj/kl+Cn6iptH
v6JYnInnFI0+xnMoLy8S5xC9F3PkheK7QEbsQ16Qt8YdcFF5AW4a7xz7kadx
Y7yFLPP+jWfzZmyNXuFtfBmX0Ahv4on6P3FO3CDOhL/CRPEErBWv5648nsdh
LFbKV3PHmM9fYjgWyZfFufIw/gJD47uQ53FbHsyfYxC+xjy8pz4E8+K7izrX
47o4jhOYE6jP5tl8FX9Fj8SaqCyexffinrhW7JULOZ/LXEk+g+9GT/IrfI4L
Gj/PFeW5fIub80v8C2cYP83Px3vH945TmIJctanx+xP3wVWj/3A49f/f4f8A
alW+Ug==
                    "]], 
                    LineBox[{749, 1035, 748, 821, 604, 1011, 675, 799, 638, 
                    605, 935, 676, 899, 900, 901, 609, 827, 828, 761, 1045, 
                    760, 832, 762, 1036, 763, 834, 833, 616, 954, 694, 953, 
                    695, 955, 617, 835, 836, 764, 1015, 613, 641, 691, 1028, 
                    692, 686, 829, 757, 938, 679, 936, 678, 937, 754, 825, 
                    677, 753, 1012, 606, 824, 602, 1010, 751, 823, 822, 986, 
                    750, 985, 984, 892, 671, 930, 747, 983, 637, 798, 749}], 
                    LineBox[{755, 680, 826, 857, 856, 639, 880, 879, 878, 988,
                     987, 681, 939, 682, 989, 990, 881, 882, 883, 830, 614, 
                    858, 831, 687, 758, 1014, 611, 640, 902, 903, 1041, 610, 
                    940, 607, 1013, 755}]}}], {}}, {
                  InsetBox["\<\"\[Mu] = \"\>", {-1.8, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["0.2`", {-1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {InsetBox[
                   SubscriptBox["C", "J"], {1.4, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["\<\"=\"\>", {1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["4.68`", {1.7, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {
                  {PointSize[0.05], PointBox[{-0.2, 0}]}, 
                  {PointSize[0.0125], PointBox[{0.8, 0}]}}, 
                 {PointSize[0.007], PointBox[{0.4463998339305619, 0}], 
                  PointBox[{1.2771956561278897`, 0}], 
                  PointBox[{-1.0806611991222994`, 0}], 
                  PointBox[
                   NCache[{0.3, Rational[1, 2] 3^Rational[1, 2]}, {0.3, 
                    0.8660254037844386}]], 
                  PointBox[
                   NCache[{0.3, Rational[-1, 2] 3^Rational[1, 2]}, {
                    0.3, -0.8660254037844386}]]}},
                AspectRatio->1,
                Axes->{False, False},
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                Frame->{{True, True}, {True, True}},
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLines->{None, None},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None, "TransparentPolygonMesh" -> 
                  True, "AxesInFront" -> True},
                PlotRange->{{-2, 2}, {-2, 2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.02], 
                   Scaled[0.02]}, {
                   Scaled[0.02], 
                   Scaled[0.02]}},
                Ticks->{Automatic, Automatic}], 34->
               GraphicsBox[{{GraphicsComplexBox[CompressedData["
1:eJx1W3t4jGf6jjrUaQh1aEMRVKfo0vwkQrN9VERTVUYcq3ZKN1I6SDdWGZs6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                   "], {{
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[0.3], EdgeForm[None], 
                    GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxVm3XclcXTxu/dFUkFARUwCFExEUVRUZASAwMVAzsxUbGwfoiI3R0YWFgY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                    "]], PolygonBox[CompressedData["
1:eJwtlwf4V1Mcxu8531LIJjJCZsgsqzKyNTQk7RRpSJGRrIYGkZkiQkYl0qZo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                    "]]}]}, {}, {}, {}, {}}, 
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwl1Pe3z3UcwPHPHTIzQmbnRGQnqn+BkhVu5RzCtddFVuiY2XvckpmMn+zL
Jevae4cKZWUTpx+ERI/X8cPT4/16f76+9/v9jG+lzD4tslKSJOnkn0NpSXIq
NUnK8yse4EHN0njzQB7RUZ02/6wJameeyPbsrUxNMnfgZHZkljprirkTp/Ks
SqYnyRnOtjeNg3hMx3VSJ/SWquic47fYiFXZmN9xJr+Nz8mLKuU9L7Caver6
3fo2m7AGm/EuL3OOruieuTlrsQX/4p/xvrquB+aWfId1dcu6tL9zk++ab7Ow
+Q7na3CcQw1Rhvk9vq97cd54l2f4gc5qkRZrYawd+4F/cxmXcCl/5HI+4mqu
5Cqu4ho+4Xqu4zquZw5fMJe53MjN2qQ/1FDd7T/mVr7J0eyhHdbbOI3Tlaai
vmMqP45r7di/3MFKHMMsPbPOrzzr3XrF/9nFb9RH/zlWRHus9ym/43s5Vn31
3LEScb7jWqi/vRSvOcidcb11wDqPN3VD48xfKvG60ubP9ZkG29sf9xH3xn3F
cl6zz3qQdZp1Oete+iLuPXtdWVY91UNt456334Vl4nypm9rE82D/daZ6n4HW
e6wPcxcPxffnAGbwU5XSdZVUK12L+0xXdUUztN/rX4vrpn7WzfmJisd58XeK
xT2sV+NzmotyZ9x/8RpzITZVgfi85oLcHteBxcz54tmJ50Hpehrf3/FG8Z35
hCnaYr2NP3F7PC+6pA/1kRL9E+fC8QbszFGaaj1FOdYbmMnJnKSJWm1eG+eb
Y+J+0ygtNa9ga47kCA2P58K8JK4nv+YwDdUCzY/zan+YFmhePEOsz3o6pdP6
XvPsz401b+hhXAMOjd8RpTs3c1nHfu24JtaF7F3jG+Zs3o9rwZrx/LCg45dY
0Tybd+Lc823+xgKOn2cF8xD+ol81PX574nozO54nVo57RydTX/4W/w/sS754

                    "]], 
                    LineBox[{751, 1036, 750, 822, 602, 1010, 676, 799, 637, 
                    603, 935, 677, 900, 901, 902, 607, 828, 829, 763, 1046, 
                    762, 833, 764, 1037, 765, 835, 834, 614, 954, 695, 953, 
                    696, 955, 615, 836, 837, 766, 1014, 611, 640, 692, 1029, 
                    693, 687, 830, 759, 938, 680, 936, 679, 937, 756, 826, 
                    678, 755, 1011, 604, 825, 600, 1009, 753, 824, 823, 985, 
                    752, 984, 983, 893, 672, 930, 749, 982, 636, 798, 751}], 
                    LineBox[{757, 681, 827, 858, 857, 638, 881, 880, 879, 987,
                     986, 682, 939, 683, 988, 989, 882, 883, 884, 831, 612, 
                    859, 832, 688, 760, 1013, 609, 639, 903, 904, 1042, 608, 
                    940, 605, 1012, 757}]}}], {}}, {
                  InsetBox["\<\"\[Mu] = \"\>", {-1.8, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["0.2`", {-1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {InsetBox[
                   SubscriptBox["C", "J"], {1.4, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["\<\"=\"\>", {1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["4.67`", {1.7, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {
                  {PointSize[0.05], PointBox[{-0.2, 0}]}, 
                  {PointSize[0.0125], PointBox[{0.8, 0}]}}, 
                 {PointSize[0.007], PointBox[{0.4463998339305619, 0}], 
                  PointBox[{1.2771956561278897`, 0}], 
                  PointBox[{-1.0806611991222994`, 0}], 
                  PointBox[
                   NCache[{0.3, Rational[1, 2] 3^Rational[1, 2]}, {0.3, 
                    0.8660254037844386}]], 
                  PointBox[
                   NCache[{0.3, Rational[-1, 2] 3^Rational[1, 2]}, {
                    0.3, -0.8660254037844386}]]}},
                AspectRatio->1,
                Axes->{False, False},
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                Frame->{{True, True}, {True, True}},
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLines->{None, None},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None, "TransparentPolygonMesh" -> 
                  True, "AxesInFront" -> True},
                PlotRange->{{-2, 2}, {-2, 2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.02], 
                   Scaled[0.02]}, {
                   Scaled[0.02], 
                   Scaled[0.02]}},
                Ticks->{Automatic, Automatic}], 35->
               GraphicsBox[{{GraphicsComplexBox[CompressedData["
1:eJx1W3l4zNf6jy3VMKSaqjsit7XkDnpRDNqqtzWakqJjz1Ud4jbozbVXdRRV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                   "], {{
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[0.3], EdgeForm[None], 
                    GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxNmnUYVsUSxs/uoiAiBmAgChIWBhIWiCACAmKiiN2t2GIHYrdiB8a1W0TF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                    "]], PolygonBox[CompressedData["
1:eJwtlwfYj1UYxt9zHnxUX0qLhtIktPdOeykrlB2pyMioNKk00FKUpIFC0lCy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                    "]]}]}, {}, {}, {}, {}}, 
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwl1PmzT3Ucx/HjWi7CvfbsZN9C/gUhskvKfhkz1iu7REOy7/ulMGkmlN2M
fd9b7aVsZSsqOyHp8R4/PO/z/Xp/PnO/55zP+5wKGZmt+2dLkqS3P0eyJ8nJ
lCR5mT/gQ3wYkzFF7sNf4xuckqfwVO7L3+I+HqAbMtAR06x34OnciXugO77H
d5ih349/wDGclqfyTO7Px3Eifi+uDRXwCs5Yf8jNuSK35Jk8h2fwXD6HcjmS
5BeurFcF59WPuBVX5Tb8mC/xfPyKJ3Jbrs7t+F++wgtxFc/kt7kW18bv6vJ+
5zq/Kv/BxeUb/Cky9QbgPbwj1+PX8Kf6R77JP3F9nMUCLMR8LEIWLuCufUv4
s/i/vJyX8kNewav5C17DK/kxf8Ub+EveyKv5OV/mdViPtbEW++I+8Tr62ZPL
PWznsvL4OA9sVe/g8TwB2VHSvhR+I+7RWh55Vzz72MMDkVcvVd6t3odC8l6e
iEF4Sc5nfb/6IArLB3gSBiOfXDDOLc4aw/TS9I7wdnlSzKp6G/8VzzbmVh6K
AvYVjbPEWxgZvxGzxftj7vgAvx/XFrPIe2NG+S7fwx0UR1d0wbsxv9Y7czH8
jdu4Fe+C/u54T3gPj+Bd8e7wDj7KO3k4t4lZQ5GYAxRG65gh3IjZwnVMxKF4
bpzf/QxRN1e3QDrK6KVxs1hHRbkA74lny6XlvPwmcsc7JOfhnXHOXErOyU3Q
FDlin94A643VmZwqZ1NvU2/mrbyFr+EqGqIREuS0t6/1Bupe/HGgHodN6jXc
kz/isRgTcyiv4gweGecRzw6fy8u4Ew+Ps8dQLJMXc4eYER6EgZiHuXFG+h/G
O4M58lKuy3VwGmcwG5/oz+LFfA3/qdvzaGQh3b0s4pr6NfCbupjeZS4lL+Cn
MVtcjS9wUesXuWRcD/8T58qV+CwXsf4zl5BHxXcgvgFxHZgW18XT43zj2xIz
gxMpL77R/wNI0sNm
                    "]], 
                    LineBox[{751, 1048, 750, 820, 606, 1024, 677, 797, 641, 
                    607, 929, 678, 892, 893, 894, 611, 826, 827, 763, 1057, 
                    762, 831, 764, 1049, 765, 833, 832, 618, 949, 695, 948, 
                    696, 950, 619, 834, 835, 766, 1028, 615, 644, 693, 1041, 
                    694, 688, 828, 759, 932, 681, 930, 680, 931, 756, 824, 
                    679, 755, 1025, 608, 823, 604, 1023, 753, 822, 821, 989, 
                    752, 988, 987, 885, 673, 924, 749, 986, 640, 796, 751}], 
                    LineBox[{757, 682, 825, 856, 855, 642, 871, 870, 869, 992,
                     991, 683, 933, 684, 993, 994, 872, 873, 874, 829, 616, 
                    857, 830, 689, 760, 1027, 613, 643, 895, 896, 1054, 612, 
                    934, 609, 1026, 757}]}}], {}}, {
                  InsetBox["\<\"\[Mu] = \"\>", {-1.8, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["0.2`", {-1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {InsetBox[
                   SubscriptBox["C", "J"], {1.4, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["\<\"=\"\>", {1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["4.66`", {1.7, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {
                  {PointSize[0.05], PointBox[{-0.2, 0}]}, 
                  {PointSize[0.0125], PointBox[{0.8, 0}]}}, 
                 {PointSize[0.007], PointBox[{0.4463998339305619, 0}], 
                  PointBox[{1.2771956561278897`, 0}], 
                  PointBox[{-1.0806611991222994`, 0}], 
                  PointBox[
                   NCache[{0.3, Rational[1, 2] 3^Rational[1, 2]}, {0.3, 
                    0.8660254037844386}]], 
                  PointBox[
                   NCache[{0.3, Rational[-1, 2] 3^Rational[1, 2]}, {
                    0.3, -0.8660254037844386}]]}},
                AspectRatio->1,
                Axes->{False, False},
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                Frame->{{True, True}, {True, True}},
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLines->{None, None},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None, "TransparentPolygonMesh" -> 
                  True, "AxesInFront" -> True},
                PlotRange->{{-2, 2}, {-2, 2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.02], 
                   Scaled[0.02]}, {
                   Scaled[0.02], 
                   Scaled[0.02]}},
                Ticks->{Automatic, Automatic}], 36->
               GraphicsBox[{{GraphicsComplexBox[CompressedData["
1:eJx1W3lclFXbxq1PyTHtdWsk27Bv8g33cUu9zTFLe9OJ1yLJb9zSfMXS1JYh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                   "], {{
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[0.3], EdgeForm[None], 
                    GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxNm3nclsMXxu+ZIUmplLSTEiKSRNZIJZF93+NnJ2uSNYlsyZI9su9EJPsu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                    "]], PolygonBox[CompressedData["
1:eJwtl3f8l1McxZ97P2kgmQlRRkSyZe/MItoq0RYpRUl2VkNmpGFHKEQhSiVF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                    "]]}]}, {}, {}, {}, {}}, 
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwl1PmXzmUYx/GvGdn3rCdrJJHiX7CUVPbdSJx+iNFYshUiWQYxY8bOjHSi
0H5KZTfWVEr2tSJrlhbKPr2u44f3vK/Pdd/Pme/93Nf3qdd/cKeMIkmSDPRn
Z2qS7E9Jkqo8nndwJqZhAL7FbhywNp1n8UD+DtdwHX3xInohy3pPzube3B/9
8AO+x2z9dN6DH3FQnsE5PIh/wl7sw8+ojTo4ZP1fbs91uRNn8VyexfP4eKwV
TZJjXF+vAU6ob3BnfoS78i3+lRfgN9yWu/Gj3IPv8u+8CGdwT+7JjbkJzqvr
+T/n+HH5AteQL/JSvKKXgcHoLT/JzfCH+iAfjvOgOY7Es2N+nAULsQAn8Zf9
efweL+HlnB/fOb/Pn/AK/pQ/4Bu8mr/gVfwlf8j3+HTsj734GJ/jszgnWsaz
2lPcGTbwQ3H/PARfqzfyJJ6MFNS0rwg/jVetlZI3c015Og9Hab1i8hb1NlSW
t8ZdYwTKyKWtb1fvRBV5B7+NUSgnl4/7Rju8rldRbzevlafGbKq/4cu4hJny
a6hg34Nyl7h3vKG3PeaJt8Z8xTPxOC6ImeMtMY/8N/8T3z2q4AX0ibmImbWe
xpVxBX/iasy2/qaYb97MY3ljvCO8jjdgPcbIHWN2USnmARXRIWYIF2O2cA5T
sCvOwuWdZ7T6efVILiuXUz+HZ1EmZl2vLBfEfcR7I5fktiiO+nIJ3mT9Aa4l
F+U2eAapKKk3zPpT6qFcQk7i2dVreB1/xWdxBq3QGoX6xezN4BZyOmfiLfVE
rFF/xC/zmzwB42P+5JX8Utwbj8YorIj3iPvySB6B4Xg33sm4Dx4Wz4ghmINc
pOlPxDvIkZfxE9wU+3EAs5Gvn815fBaF6l7xbFiMSs6yhB/Tb4RT6up6p8Py
Qr7D3bkhn+Rq1n8Jy/P5Zsxf/E7wwziq/i/umifgcPzm+swRzo25j3PwTO7I
teL+sS/l/m/0/xehxEY=
                    "]], 
                    LineBox[{750, 1050, 749, 818, 608, 1025, 679, 794, 644, 
                    609, 928, 680, 890, 891, 892, 613, 824, 825, 762, 1058, 
                    761, 829, 763, 1051, 764, 831, 830, 620, 948, 697, 947, 
                    698, 949, 621, 832, 833, 765, 1029, 617, 647, 695, 1043, 
                    696, 690, 826, 758, 931, 683, 929, 682, 930, 755, 822, 
                    681, 754, 1026, 610, 821, 606, 1024, 752, 820, 819, 989, 
                    751, 988, 987, 883, 675, 923, 748, 986, 643, 793, 750}], 
                    LineBox[{756, 684, 823, 854, 853, 645, 869, 868, 867, 992,
                     991, 685, 932, 686, 993, 994, 870, 871, 872, 827, 618, 
                    855, 828, 691, 759, 1028, 615, 646, 893, 894, 1055, 614, 
                    933, 611, 1027, 756}]}}], {}}, {
                  InsetBox["\<\"\[Mu] = \"\>", {-1.8, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["0.2`", {-1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {InsetBox[
                   SubscriptBox["C", "J"], {1.4, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["\<\"=\"\>", {1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["4.65`", {1.7, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {
                  {PointSize[0.05], PointBox[{-0.2, 0}]}, 
                  {PointSize[0.0125], PointBox[{0.8, 0}]}}, 
                 {PointSize[0.007], PointBox[{0.4463998339305619, 0}], 
                  PointBox[{1.2771956561278897`, 0}], 
                  PointBox[{-1.0806611991222994`, 0}], 
                  PointBox[
                   NCache[{0.3, Rational[1, 2] 3^Rational[1, 2]}, {0.3, 
                    0.8660254037844386}]], 
                  PointBox[
                   NCache[{0.3, Rational[-1, 2] 3^Rational[1, 2]}, {
                    0.3, -0.8660254037844386}]]}},
                AspectRatio->1,
                Axes->{False, False},
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                Frame->{{True, True}, {True, True}},
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLines->{None, None},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None, "TransparentPolygonMesh" -> 
                  True, "AxesInFront" -> True},
                PlotRange->{{-2, 2}, {-2, 2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.02], 
                   Scaled[0.02]}, {
                   Scaled[0.02], 
                   Scaled[0.02]}},
                Ticks->{Automatic, Automatic}], 37->
               GraphicsBox[{{GraphicsComplexBox[CompressedData["
1:eJx1W3l4jNcajy0UU0ujmJagROzhGkuqfTFtHlSJ1LUbSyt1O3opqg1pa0mH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                   "], {{
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[0.3], EdgeForm[None], 
                    GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxNm3f819MXx9/33owUSdIUJTurlJDVQMrKyiYjFCJ7h2Rki1D23mRLGZGR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                    "]], PolygonBox[CompressedData["
1:eJwtlwnUT1UUxd+958tQUmjSoKTSoFnzPI+ECJGEoiIypUlFRZKS0qCoKEWE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                    "]]}]}, {}, {}, {}, {}}, 
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwl1PmXzmUYx/EvY5lsw1ijZCpRlkL5F7K0jhBRUZzDwYgsUULZsi9jzZJj
b7EWZSYz9l32KFvWotWW9Xhdxw/v5319rvv+znme+7q/k9E+K7NbgSRJOvsY
npIkXbEdO3CgYJKM4NHcjXfiCg7K7/C7eBNj5LY8lt/ijuiAQ/IuHsdZvBt7
cFj+jMdzd/4JA9R7+TE8jp/lq/wSV+dXeQxP4tGczcfwSKEk+ZVr6h3nCvIJ
fkp+Es3U//NvPAWncUN+jWtzC77F53gazuO23JKf5mfwh3of/877uV6cTZwD
JmCW/niezZdwV92Kn+Xn8Kf6MB+J34WGOIopmIrJmI5pOIHL9s/ieTyT5/Ns
vs6LeCkv5GW8mG/yV7yKv+Rv+WtOcCb2YXk8h5VYgbNoFPO2t4gzy+Wq8vCY
NYrqpcg/qr/ndfwDX8B5vID39IrZlx9zkEdwDxTXS5XXqzehnLwxZo6eKCGX
tL5ZvRVbMBLV9NLxsPUyMTv01S8j7+AceWjcT/Va/ivOFqPkPihtX3n59Zgf
Poy/zVuxCfvkzdyfN/Je3hD3j//jB/EvKqE92qFN3Fnrb3MF/I2K+Cfus34+
7+L13I/z4j3h3DizOD98ILfg3pzmO5ZTN487iIu4FHcs7heGYJt9ZbmUvb3U
mer3uaRcOt4FvBLreFQvjTfEufJDcnF+GQ8gQy7GeTFTriIX4Rfj3ULh2KfX
3XpTdRanyoXUOerVvJbXcMF4T9AYTVAgnre3i/Xn1Z14GD5Vf4Lv1N9wRx7M
gzAw7qK8JM6Y+8X5xJyxQJ7DbWOecV7ohbnyDH4j7g/3iLuHbExCa/1B8Swm
yl9wA66PQ3HG8jieyWP5c76AO3FXeCCmI91vmcF19evEu6OupHeWq8hT+WbM
jmvxSa5o/RRXlifzdc7kJ7gGflFfi3nwxziC8p45yhPi3lubyKNippwRM8V+
9eWYE3+EbephKff/R98Dk1/C0A==
                    "]], 
                    LineBox[{752, 1049, 751, 823, 606, 1024, 679, 797, 643, 
                    607, 929, 680, 891, 892, 893, 611, 829, 830, 764, 1056, 
                    763, 834, 765, 1050, 766, 836, 835, 618, 949, 697, 948, 
                    698, 950, 619, 837, 838, 767, 1028, 615, 646, 695, 1043, 
                    696, 690, 831, 760, 932, 683, 930, 682, 931, 757, 827, 
                    681, 756, 1025, 608, 826, 604, 1023, 754, 825, 824, 990, 
                    753, 989, 988, 884, 675, 924, 750, 987, 642, 796, 752}], 
                    LineBox[{758, 684, 828, 858, 857, 644, 873, 872, 871, 993,
                     992, 685, 933, 686, 994, 995, 874, 875, 876, 832, 616, 
                    859, 833, 691, 761, 1027, 613, 645, 894, 895, 1054, 612, 
                    934, 609, 1026, 758}]}}], {}}, {
                  InsetBox["\<\"\[Mu] = \"\>", {-1.8, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["0.2`", {-1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {InsetBox[
                   SubscriptBox["C", "J"], {1.4, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["\<\"=\"\>", {1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["4.64`", {1.7, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {
                  {PointSize[0.05], PointBox[{-0.2, 0}]}, 
                  {PointSize[0.0125], PointBox[{0.8, 0}]}}, 
                 {PointSize[0.007], PointBox[{0.4463998339305619, 0}], 
                  PointBox[{1.2771956561278897`, 0}], 
                  PointBox[{-1.0806611991222994`, 0}], 
                  PointBox[
                   NCache[{0.3, Rational[1, 2] 3^Rational[1, 2]}, {0.3, 
                    0.8660254037844386}]], 
                  PointBox[
                   NCache[{0.3, Rational[-1, 2] 3^Rational[1, 2]}, {
                    0.3, -0.8660254037844386}]]}},
                AspectRatio->1,
                Axes->{False, False},
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                Frame->{{True, True}, {True, True}},
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLines->{None, None},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None, "TransparentPolygonMesh" -> 
                  True, "AxesInFront" -> True},
                PlotRange->{{-2, 2}, {-2, 2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.02], 
                   Scaled[0.02]}, {
                   Scaled[0.02], 
                   Scaled[0.02]}},
                Ticks->{Automatic, Automatic}], 38->
               GraphicsBox[{{GraphicsComplexBox[CompressedData["
1:eJx1m3l4k0UexysgYiVsRS4jyykQEAErWbkHtrgoKsQKiliDoqJQBKkollWs
LhtWXO5AFRUpoMshLaAWqJEBKsWWw8rRYJU7raVcJZSWHmkWMnwmzzM85Z/3
+Xbmfef3/d0zE9qOnRz7Sp2IiIgu9SIirj/3ftexhdt7Qv5n3O9XUlOq5X0N
fz7jsx/S+GpG5ByXP0Njj8IC3FLN1/gn9T2NezX+xul1XJD3/6XPvc6YCvnh
S+N/sLv/1Jj1wawPZn0w64NZH8z64OlqPY17KHk0nvZCeZLH5ZcHNn8Saym4
ouUFIy8YecHIC0ZeMPKCkReMvGDkBSMv+E0lr8Y84WE+4QOGDxg+YPiA4QOG
Dxg+YPiA4QOGDxg+4P2Kj8bYybSLyQtsPuELhi8YvmD4guELhi8YvmD4guEL
hi8YvuDOiq+oLW5MvzTtavI2n/AHwx8MfzD8wfAHwx8MfzD8wfAHwx8MfzB5
xMwTZhyafmza2eQNNp/oA4w+wOgDjD7A6AOMPsDoA4w+wOgDjD7AM5U+RG15
28yjZp4y49yMA9MvTL3AHwx/MPzB8AfDHwx/MPzB8AfDv7Y6ZdYNMy+bec2M
ezMO4AeGHxg+YPiA4QOGDxg+tdVZs+6ZdcXMy2beMuMYPmD4gOEDhg8YPmD4
gOFTW59g1m2zLpp1xcy7Zh4y49DkaT7hC8Y/wfAHwx8MfzD8wfCvrS8y+xSz
DzDrqFlnzLxr5h0zDk2/Ne1u6sV8oh8w+gGjHzD6AaMfMPqprU8z+yCzjzDr
rFl3zLxr5iH0AUYfph+YvMHmE32A0QcYfYDRR219qdn3mX2T2VeYddasM2be
NfOWGfdmHJh2N3mbT/iD4Q+Gf219rdkXmn2T2UeYddSsK2ZeNvOaGeemX5t2
NXmaT/jW1teafZ/ZB5l9gFkXzbpi5mUzT5lxafqlaSeTh9mXmn2a2aeYddus
e2bdMPOomTfMuDH9yOyLzD7BrLNmnTLztpmnOoXGfTI/9F6ljAj92+b5W0iO
GtlajQvGj4aexXp+Tuh7JTIpxKNc9xeMH1bz9ftZar5gPv4Dvje0Xql+tlFP
ASaewLyHHO8qLMCsC888hTXvUyGcr59nQs8cjdEHmPeYB2beHvV3wTiYcfTJ
OPoxv8d75pP3wbwPRs4D6qnXBeNvppyM677yBkZ/rIv+wOgfu6J/sGlH80kc
gk07mt8lfsH4o2lXU04w+gKjn57K37V+4G36HevDG7kZN/0afnwHuRlnHeIG
ucx9CnbFPqY/8nfsavYB2Bl9MM775A3eBzPf3BeZ/sE6yA9GH6bdzHMeM85N
vzDPTfiOqTdTjmHpY753OC/LNZZbZqV4yvSTv7tC8736OT30/VMyOrTuT3Jv
aN0CAV4f9eYOa06V4O/lL/ZolWi5op+fR8573JZ2ScRu/fVidvxVPY/3Diks
Nyqsvw9ert6XT6v3Jd8DV6l19HOo4iHghRyMf6X+rvXAOshhytXsh+t6W3uT
Ppoo/poPmHnT1FPwPtjkiZzIjXxg5IYHcpvzwOgLfZu88AfsB0Z+4gg/BrOv
IW4YBzNOvDAOZtyMEzDjxAd5jH4ZXO+VFaP81krZI/T3M7XKCR7jiekSkxjQ
9qtNbjDz0Y/ZBzAfzPxloXlrdX5mvDY9gHl/R+i93Fr1AkY/5G30A0Y/H4be
Oydy1Xc1L+wMxi/BfJ8+kDgr/PHd3cHgRY2pS6w3W60nzTpE3waOUPMF88Gm
PenziBfiDmzWNexNH2faHz0wH3szHxyn5mu9gfEHvkdcm30F/SQ4Qcmt8wAY
fzHrLvKAWZ/3wbxv2pXv4V98D8z7zAfjf6Zf8D148j0w9rcp++l6hj9ifzD2
Zj4Yf8VutdmVOEZu7FabXWuzIxi91Ka32vQERg+16Qk9Mh/50TP9g5l3zLwA
Zv8Cxt+IG/yLOKFfAWMf4ps6QXxjLzDjxDs8iU9dV27EJ5j4ZH3Tf+m3GMef
GTfPM836BYY/csGfcTD2YD3dt9zgofs2I8+Qt8y8CDbzornvgAcYnviBue8C
63OsG/Lgx3yfcfyTceoPccD+GUyc4WfM57vMBzOfdfg7fq7PqW9g+OH36BU7
oVfsgt0YN+2GnpELPR9Tetf5hnH8lXHsZ/o92PRzs26ZdQp/0f214ffkudry
IPrke+T52upAbXkffH+IzzGtV/SD3Py9v5qn/Yc8gl3JM2bfYvY9Zt0x+zTW
pS7Av7a+Bbsxjt3ggb6JD3iY8YP/gc37AsZ5H/9kfezF+vgDfJAHffE+cYi+
kAu9k+cYJ+4YR07GsQPj/J11+DvxzjjrMI7fEN+Mw49x3ieOeR+ejCMn4/DH
n82+E32ZeiROsAPxA28w30d+5EN+5MNvzPMX6gRy0G/wHXjhz/BCXvKEWSeI
B/Oci3G+Z8abeY7FfHgwn/jA38H6vtbo69EP88HMR1/Mp46b50ucJ5AP2U8S
38wHMx+7Mp/zCr7LeQaY/S7rYC/0Q14A41f4hWlnMO/xffbBvM8+mH03f0de
zlHYb/O+eY6LP/E981yH7zNvzrKS+52Zp/U+c9gPyS3cySU3/c6jyfRu5akn
q/T3EoJT+9guVmm51n75WZw/P3xuFJnc8u7E8+Wyy7rB2+2HSm/6fVC706N/
D8rwudGh5F5l2XtK5VLvxmmerPB52/KqwnbOupW6r5n70pxHLIurdN/19F93
P+XPD/8eo826h1c6loX71uoTi36x5qwM3zt1bL04PqLmpt9R2HbnbrC798nq
/lUJ3txTelzfY2/96LB1Qq683Pmewuyz58P3Vje+xzzeN++xHFcLEz2udP0+
48hL/kJe897v4reRfWMqMgV8zfvVpDqFC1zRR7Rc3wxo8WBM4hG9P9845cpt
aS+G+8x3n19z0Dr9pECfrIO+zd+l5TXfMtMzrkT3CR1eyh/vH10isBd2x97Y
FX8yf0f0/ccZ57LvqxT4H3Kx7nbrbU0T+4f7mYqhb/zVeU9A8102/JsjvoJw
n76hbvtZrqE14fvD5VMKsh+r0Xp8fOHw6SnnArqPO1SZ87ClQ0AscPZ4yzv/
pJzQ94VVjppq+djchv7U7GNi1BfxD1ueC8ivx3SY4Em4KH3fl61xHKqQKZf3
P2b5sUK2+f3wevvgi3LVa2d62X6plnW3/n2ZK/qk/HvySw5LB69+frPmjvaJ
T5ySNT3uTvA6MmUX1zcRaR8UiowD7zzgzNwhxz63PcLd/IJ4qt76L+JtW0XS
m5673M98Kx6fPvUx2/AD4uVnzm60l1bLOw7WX+6KPiFeXrNrf/B4leh3pv/r
3qhC8e7GSR+lxF3RzxErTz5r2XVJRMbeG0j94Nq+aX7vWSmfF4pe72X+7utw
Tb8fF/zD8u+9stuWN2a5WtXIB1pcrx/PycpJcQXZz9TIBmOu2yFORH00Pid4
DbfNGdTA7c0WbUobN0q8v0ZuqV+nReKcI6Jbwfhb3JsD0uEsbuNsf1a6/1v5
tD+ySn7ofGCUf3SxbDB+2v8cA67VK3fvHjF3F4uWw97saxtTJYNl/brF9D4r
So6sPOprWiXruNceCx4P3yclbC391LXisjgQtSTeG3Etn9xeEJH2YpnOg02i
LTNTXrsqnf/KORFcd0m+8fFwm/NymbD2TH3asviyHDYk+W3PuKvi809GHLSu
vaTzWL7yX1ln6YQsa2X4fKhPavCo72SlvOdQm7PZd52VDd9+drVjW6V4Y/Dr
T/tHn5VvZ36UGzxeKVrubdAkcV+xzpNbVTzJOs2/mO2Krdb1oM/6pwqz9wTk
tlP7hvutv8icpbNcrhX75aWhj893WX+TO5N7/+ZbHBD2IcPjLK/kym6tbttm
zQhc8/fTs1L6Zcn0r08VZN9RI7ueGB3tjFkgX21Xc9A69KQ+/5u3+/l+Mb1P
y8mLHllvd38pOw3dscSVsEs8rJ5y7Ov5L3tzc8Qjnuv8HGG8PoTFhtxNDdzJ
Z0Rs43X/9Lh2yQ357X6xRvrEpq3X4/Utjf3fh7BouuSxPUFvQPhva33EZ18m
wXUUFmWbT0z0FAbk/qK0mtSU3QJ5eLJeT7WegO8KxVegj05KH2JqnuMvidf6
9r17vhhuWezV8dxF5V/xt4GO8z77Tr3PQ78nlX7F2wcXX8qO3y1bDHEIW/ff
RNKJz95POXetjta/P8FTWCwGLj082xUd3mdj3ybKvgL7v6bsL/C30crfRMvi
97zBi2Vy28I/bk1bcFmsklVb7KVXdR+IPzZT/iiy+n/XN+bTy7LV4pEWd3mZ
zou5qt6J5W2n/mifWKbvTfD//cr/dV6tr+qpSO8aOOu7Er6XIf7mq/gTxFsL
FW8isO+X1s7Ms3of27B66gJXwhE5Y0XWGO+GgM4HXVU+EDN+F/Ncm7LlkHS/
02urEeSHqyo/CPJBK5UPxFd7pn/lcO4VLaKW3eNsXyPID11VftB95cItNVdS
54R/F7hc5W9dZzep/C3Llj+8Ot72reQ+G/tHq3wuJ+/s8Fsw+L1gnPw+TOV3
mb4teYe9iU/XPexcb1RsK+dn4d9/b1X1R0Y/OPmX4Ptnb7of33bUfbu7eXj/
95OqRxJ9Mv/WrHu/dG0q0XUSP8j5asaF7PsqZMeRi0dYdt18D75/5NxZKRPL
JPY07ye7NUmYlfJumVym6utN9+7+Z11Jnqxr/dEN/zHvK8v2bK/I3uPXdbez
qtcSf4Xnly83Kc5eV3XT7wDId/hNzBMP/hp8v1gSP+Y50HzVf1yrwwu2W4f+
cdM9aKMu1rppbQ9re2eo/kTvT7Lu6PNPT9ZhSXyT76b99s6/Ujw/6zrPfmPY
MyuTXf6fpO89T6PEfeE+gPn4DfN7qPmC+ebvZiNV/yfIt+QX+OBn8Al2DvHR
5xFblPyCeoDfoV/znpp8g377Kv0K6hN+hP3Ne+wLyv46D/iVvXWf3Ur114L6
iV/hj+Y9d47yR52Huij/033416q/F9Rr83cbGSpeBPGA38EjS8WDIN7M+/+5
Kj8I4tc8D41Q8SvID9z/kw/A5Nt2Kt9K8vVOla9lv5YtOzgzj8jctelPWl7J
kxOHD3zAefqkHOdYZXNmZsmcx1rtsFZWiYWD/v6U5d8Fgn7iE9VPiMFbhg6z
jLwq1t7R7ILvWp9VOnZRtLP9JVH9wr7b3eVXRV78e31iHvWJNelJ+4LJ1eLF
rrcMts0qlGVDO/Wx3VMtV9z6zBnfWz6Zc+austQPquXijtbRlq9OijdaH14S
3yAg6df6qX5N8r316nsyVk581Z9xSTaYlBbpnnZVJsS1i3a+dEnOfHVApHvz
VTnw2ISF8f+5KHq+dfcA2/EKST/YSPWDEnkjXgzJK3Mn7fnTN/KKftJHJqmn
LNvheDDm2asyok7U7Wk7Lkn4pyr+skXBw1M96RWixbbMmkUPXZRTp6R9ay+t
knGJdz4U07tQPhrz52yXrVquit0g7bYCSf86WPWvWt9Llb7l3CudWjm/rRan
DsjX/JUnZObazT1t3Y/Lp5+IvuD7/lc5tuOc/cHgOtmyWe9FrgSv9KYOHu91
rJY1KSV5QeGV9M9xqn+WjY+1e8fj2i169nn9OUvBdhlb58vR/soiMVv0jHI/
s0v35ydUfy7wh0eUPwjeb6beF/Tvn6v+XfC9iep7AnmHKHkF+4Ce6inwvx3K
/wR8Gik+Aj4lio9gf1G1JbS/EOgnX+lHoO8RSt8CfX+u9C3Yr7RQ+xWBvaKU
vQT2rb4lZF+BH+xVT4G/1VP+JvC3JOVvgv3RCbU/EvhfD+V/2v/9yv8F/p+l
/F/vv8ap/ZcgHiaqeND7Ust3of2vLHY3ygvK8O8DwJxTkY8bqf2Lxuxn2N8w
bgvtV31incoj0ppxfq91aIGuJ5yXPPztxYGWAimZT95hvq4nN+bfrubrerFk
y5DffHMCuo+3qn5J15mpxQ07x3Su0efAU15bcYs7OSAP5S1eGl8U/h0f/WxX
1c/KwRn2P7MfC+g6S//8h+qfNe5R1bOTc5FXr5/30eUTPvtvcnDdurH+/LBc
9PPnVD8v6yTlPOmvDMgWFxesj7dtl3fkJf5ojazRdZv9Sr/jof2K2FQVucFe
r0bOiq1YEW9LF8X54+unDTqt57N/eX9haP8ipj00O8EbdVr2a9ryoDVno97/
N1HnJWJUhymXUtte1HZEXvTGfmu52m/pfWmdUXKqN/dXgX707zom3iqtXQLS
emjTRnuTowL90iewH7xL7QfFoTk/d495tlK239JplaPVeX2+mLymYX138/B9
yopez3aL6Vwl1lp9Ezz1j2u71IT0eVT+UpD7uscZkCu2fNfdmXlAjujfaYO9
NCDP529s44z5Qfe3xS/P2GO15ok67w4ozPaG7y8+U+vJZeV3HgoeL5JF9cZ8
Gv9JlZb7a7W+HDb/5ZO+K0Vi8JMN2jhXVsnGlq4nfU0rZOqmFoeta0v0+eDS
UJxdkvC7T/GTPXJmn832VmqeOWue6m8bXilalfSX1sjzstFx12TPuGr5t0Cr
o0F5WnI+cZc6n5Dot4vSr1z4Zv18X9uAjoNz0ye96N1eLao/jhgU8+kJGXPv
qI9ckQFxbGMg37f4D/n16J9XOkYExPo//pkSH+GVffK2l6YOCuh9C/aNUvaV
XUfv2+yo+VWeahD1nD/jiNw/pv0269rwvXuTkUsess0LiA3Npzxh6/6rnD1h
w2DLroDIWjq2mdu7Q+KvmcpfJf74jvJHGbXhvfpub/j3oJP3LvkwpV/2tTx3
vS5sluB6CotRvZ+c4anv0/M535mnznfkwJxXFscfCejxootls1wHAqLvki1t
Ey3fSnBwcQgL4q/yQij+BPzwf/isVnwEfJcrvno/3U7Fv8AexAP6/lLpW6Dv
QFVI3wJ7lSp7Cey1X9lL6zlL5ROBPQ4oewjHvx+5PS1lhyzquGad49gRgX/h
t/hXM+VfAv8dqPxXcF50Tp0XaT9apPKpjreBKt4E8bZXxZvI+O9fb0kblCf/
sinviG9f2C/YrxKPsSoeRa+meTNS4n6Q8+PmpdmH1mg9J6j8LIhXzheHZQ5K
dxw7ICKUnbReJ6n8LYjnCBXPgvPFkep8UXzTc/VET/1jovqnna97xgX0fiSg
zjslfp+k9usSPncqPpL9+qNqvy6Rf6GSX7I/p94gL37F+jVqfX2ufESdj8q7
bU+VZ993rR8vXf5uyufVMj1+9HxX4wox6s4hMz1fl8ihVzzP+qff/HsM8ot4
e/lx35XwuS/3ygNbzx3jzT0vV7+1p7dteLWY1GX1FO/88DnwTHU+LZMj25Wl
Jlbre7d+wfvrujeH/79hyZCJLRMtefpek/Mfmzr/kfhfufI/+fX50Xk+e5qe
v3PR+tc9CeFzZe6tJ/7jwfc9roPh39P/cSY/GFwlXX/++IkrNvx7EcbHqnHB
OPdsfJ/9I99/Xn1fwAe9oy/qIPrqpfQlOF+tp85XBfXAp+qBvheJUvc1Iqv7
5I7OukU3/T5lkrq/EUXxKbutQ4v07xqwd5Kyt/6dw0tzd/ayFVSLpi+Mb+xu
7pMzorrOdi2slhnT62Q4tpXIVoebZlm7VEhf67HtEtf75bl2h+L8GeWysK63
iXuzX/jrPzrcsqtcOi7/ut0+s1TU+XJFZ+eDZbLyg/nTPR3L5OPXXNo9rVQO
iwvOSulaJlZt6NY68b1SeWrAmAneDeXiWN/z3Z0r/fLzuOrGia9UiYb/e3y3
dXqRvC3UR8wTmY7oZFf0YVleMmqro9VJuWjdwTsTLXvlmgfsw23dt4ue8zIW
x6/eJ69G2z6Jf+ScqD/g+j3NTo2LQvc2OwXf+059T1Dvuql6J/DXccpfBfLU
U/II6u1aVW8F8TJCxYuAT77iI9BHzbKQPgT6tCp9iuX7Bm20jzgvZ38yMt0+
tVLrf7rSv+gU33yjfeJ5EfvqwHR7UqX44UBik8Q54fuQj5e+VJGaEr4PQR/N
lD4E+l6u9K3n04+w/ly1vvQ4p30T/3OJuHfr7C32nhVy1bQFY/3TS2Vs+7F7
rF3KZKHiJ7HXjBkLvrNPrZI/F78d6U4ukr1C+//fZdLMrl2dmYc0TlBYMH+7
mi/4HvpivWFqPYE8bZQ8YlXNqOe9URfFqblfHA4GkyX6eVrpR/vHW8o/BP73
iPI/gf8WKf/V+4pD1vtWOAbUiP8DrL7htA==
                   "], {{
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[0.3], EdgeForm[None], 
                    GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxNmwf819P3x9/33viRERktSTIyQpISlZKRlQbZIyNJ2cqWTfbK3iR79yMZ
Cb/s2aCQqGzJ/hv/8+z1+jw+PR7f8zh333Pv+9xzX+fcz7f1oKP6Dc9VVY1p
UFUl+Pupqt4LWhjpZlHRNOjQyG8avH1QCWoR1DxocJT/E/Rc0JCglaPPUkFL
BzWJ+lWDDo7ynYLWCvolyqcG/zDot0ivEdQ4aKWgD5L6km4VtKLrmgYtG7Qc
8pgvHzQwxt4jaJegdYMaBi3FnFHXMGiZoFUsC/ldYvx1gv6M9F8ef3XkdFvm
aO35Wccmlo+ytSqNS9s2Hpf8YUG7B+0RtI5lRca2Qc2DWgSt7X7U7Rbzrxf0
d6TXdVvarek5GbdPrGGHoH8jvZFlZD/aWxbabmqOLB3MkXEzc+bc2P1Yw/ZZ
47QL6uh65N3cHFnWs7yrBXVyGevYwnXrB3XzGMjV3Zx5tjZnz3qYI++2lok5
uwZt6P49Xc86tjFnHUOT2mwV1Mtl9N/NczNn76DOlqttrOuC6HN+0G6R3iko
RXrHrDF2Ye1eJ2vazrKQ39XzIFcf824eu63X3Ndzsr6D3Ie2nbPkq337Xl7r
QHPm2dOc+YeHTDsH35/5s9Y8IGgv1+8QtLc56+vvfWSf9nHZjkH9LAt1gywL
e7NsjPlRkrztgpekthsFb5A03oHeD9ZwQCV5yHeKvtOjzRJB05LWdGjQBUHX
B10XNNjrZH3dsuQewvey3Mi4XpRfFv0vDTomaa3Dg47yuplzqaSxjws6wuun
/9GuR8ZjzNnv011H2bEuY92neVzqPk2S5cSgEZaLsUeaI+OV0eaKoCMj3T54
w6Q1He+1co6PT5L3lKBTF5O9a6zrs6hbJuiMxWTZI/KNg5YPGpE0/9lBYyJ9
bdLYW2bpweFB51o+5BqZNA97fM5isl/kuVnfjdHmhqCTIr100p6dGTTa9ezN
cklllwV9Eek5QY2CPk+S5aqgqy0X81xjjiyXe7xRQRd7PNZ3W/S9Neg89iJJ
xuusC6QvDLrBHHlvNEeuDWK9KwQtHzQw+m4etELQvKC5QSsGfZkk7+1Bd1h2
ZLmb72SZ7wq6wvl7FlvHnW5L3ViXsaaHgm4KujlolSR5xwVtlCX3fUH3ew3I
/oA5sj9oTv9Hgm4JujXoYY9H/u4Y8y6+q9uN9p496ra3BT2+2JqetKys4ylz
1jfenDX915x1TLRMyPKEx6D/aUmyPxM0YbF1PGtOn+fcjz14zLIgxyTLR9mL
Xhv5F7w28tgb7CI27yW3ZR3PezzaTXYZcr1szvpeMWd9r5qzvntD5rFJ62uS
JPuUoDcsN2t90xzZ3zJnzrfNkfF9y8T8r3v99H/H9azpXXPW+ljM9VXwBUHv
uYz+szwu/ZpFm9eCTwvqkTXu9KBeWfLNCPrIsiLjh14za/3AspD/2PXIPtOc
Oaa6LfvxiedExm+CPg36LOhzj8XYLUKe5kn9tgkZFkR6taAfk2T5Imi+52Ad
s70v9P9yMXnnmn/sOd5zu3kum+n533Vd45jrt6TxVg/eMkmu7sFbJc37S/A1
kub52uthjK8sC/n7k+b+Hn1Jmu+HoD+T5P6RvYn0U0ljgDu4f7nTf6+EMcF8
4E1wIlhtVeNNMFtT403wWXvjTXAaWPKP4I0qYU9wJZjw/yrhSrAd+BRMCl4E
b4IvwZPgxWZuz3xgLrAX863qPPM1cZ75mjpfw6DkwZtgSTDTHsaezb0exgNH
bh1ztk76/v9Uwp0tK8mxRiV8RluwXGvP3cZ55l7L+Sbeu7U8H9ikredo7bGQ
aR23Q8Z1nW/utuT/dt/VvEfMv7r7g9lqmBFew57wdlUdL3b0nO3dB6wKvtyw
qmPT9lUdm25a1bEpee6N2h2LTJ08bkPfmdzFRyZhwS0rjQs228pydHOeOcBH
Pao6BgWrVUnYcP2qju12reqYtZtpN9exH7TvXNXxaE/LBDbbzjLu4DztejvP
enq5D9gT3LlzVcfBW1tu5gdrgVN7e76OHntby9XXMtHuwEp4iP79XIfdqt0D
4M8BnreGO2s4FL675+/v/jU8OtBr2Mv5nT1PDZf299qREUy3t2U/yDKxX4Oc
B28OssxHJWHc/SI9IAl3gidruJb5ctKY4NjlsjArOHUzrwHZpxuDHuI1oAuH
uj9YbojHG+o8WHOoZT3WuHOY5QOjgdXAq4d7vawTTDfc6z7aeXDaYO/Pge5X
qwNroatgQLDmCZYDvHZiVcea5MGYIy0fcqPP4LYlk+Rhv05IwponWw7GPsXz
ne75/mOsSR/wJZhnlOcAu4HhwIbneu6TkjDl+R4DbDLaY4PNLrSs9DvbOjLY
+3uK68F21xpPHmc5Rrv/skljnuH+4C4w2RxjTXBaY2NPsBn2hnPSqarjTvqc
moQpx1Sah3Vd5v0+w7KDPa/xOmtY8/qqjjVvsFw3OQ/eBGOC1cCbKyVhtpWN
N8Fnc407b6skKxgMTAZOvcn7hRzgrtst153O0x/cBF66wv2ou8VlYCRwJniz
hpPBZvdVdax5f1XHmg94L8B9NWx7j2VClofc7maPTR7sOdb7yBoes0zUv1AJ
MyETeKyGH+HgNnAR9/D8qo5BwWqrGqONreo49UnLjY15pqrj1PHel8c9dw2D
TrCs4LeJ3o8XLRPyTXKePi85zxiTnX/Isj/nfZnocWtYc3JVx5ovV3WsSR6M
+aplQ1bs4xT3B7+9XtWx5htVHWu+WdWx5luW9R3nkQncVMOP8Hctxweuq+HO
dyzTh65jXLAWOKypMR3y7cs9loQ9wZzTLCuYc7rlfMP9ZlgO8FUNV870uKx5
queb4H6vWY5P3Ad5P6uE05AJTAfGa258R98DIt3NOHOBseYcz4OOzPM6Z3ss
ZAIDflHVseaXlmme88z9lfu/6/mRaaUsrAm+/M04qCYfaTDh6Ul+ztORPjAJ
g4I7P3E944JFwZrfVcKZ33tecOYPlgN97myd3hsMkKQP4DFwJlivb8iyaxZe
XDL4r64HC4EbwWWU/e7yXWOMtZNw2xLRvkHQz5FeJ/jSWRgUPAYOBFO9Em1f
TrrreiThUcbe0GXcfT2TsCA4sHeMcXZSrG/94GAXcMuk4C86v24SbmP8flmy
gMv6RfkGSfGunaN8tNPgGdozDnc/dyz4Yf1o0yjLln+cdCdxH22edVdz97+d
hNfBrBsn3UPcQZskxW64F3q5jv7cIeA27pFPgs9yO8Yi7sT82wbfNKnd/4Ku
cz5lxS+wux2T7jnuOGzv8r5HoEa+Xzokyc49sVVWPIb5sZMrpLrfvqLtPGM0
9jjUreS7AL6y052S4gXY7q+TdAh7uJ11ifx3Qd8m+bJbmKNXW/lM185zM5dP
9XnjrH2fZAuwA9sH75pUh+6zx+h3z6yzOM3nlbPC2ds/yTej7OfgC5N8M84e
54Pz+Bc6FtQm6PegNT32Pkm+JbJ8FXy+14n+4zs1ss4SD0eviDm3TdLJRT6C
9bBvkl6SJr6KvoHJl7QOoBt9rKOMc1GSru/o79/OOoB+bWS9IJa1iXUJXeZ8
cUbQtQ7+vg2tI+AnvnN7f2v8yAW2CejOZkk44qAkPaPd9Un6NMp6sbl1456k
7z3O46DnP1X6Pl28V9yv4I9r/Q27ev/5Pt38jdj77t7/N4P3TvLzWOs2Sedt
vyT9oP2arv/Ga+3h9bLHfb237H1P7z97yTsB32Frj4+uYJN2TLJlLyS9qWDH
sDE7J9kvvvn21rH23hP28h/bsr/8zfv4e6FfOyTp3CVJNgUbwtvNIcGzzyax
zuX9fXZPOof4COf7W7Ove1nH2Mt9vJ+csz2TzmQ37wt7wn2IjZ5i29g/yT6y
3/t7z5mfmED8VYclxQSQBz+dND76mUl1lPNWRZo3LGw9fWmL7IOSbMHhSTGE
BpX8etL49KNcRzlvW6SXiPQRSTEE0mcl5Un/4/SSkf43yYbjrw7I4vh8w5L8
WM5LZfuMj8QZGuby1bLK9vc4tN8g0kcn+VT4U2tm+Qvg9JZZffBzVjfHhzgu
yf8Z5jbHum+rrHb0J32C25yYlD7ZsjHXTpX2gvUSG2kd5WtkxbbbZMmBj3Fy
kr+Br0H5SR5nbWxLFr7H3sDBw2ck3fHc72t5jAvc/lSPs0mkN87CAdha+DMu
py9ndkPLgv8x1HtObOAcp9m3iUnfaQnbZ7BXM9fTjnv2mSS9ye57rsvZ+/M8
Dncvur2F7TS24mvb+C2tt7w7XWT95xvyffGn4Rf7HF3sc0UaXIC/iq/KOwS+
In7ixe7L/pOnzZHmlznNmwJ2bVSlb3u5vy82kvsUO8kbx9VJ7wV822v8ranD
r6u9H1zrcZj/Srcf6fxJrh/jNtc5zRhXuT3y0A7/k37YSvwTbOdNSe8WtXrS
vCNcmLRfXSqV3ezy82xv8fWmJPU/yWW8QzA2+nWLdexcj0u/292GNPwOt+ce
R557LdfdTqNH91iXFvk9Sb4DOnin9fD1pHEZk7ubNv9z23udHuc0Y4ARxjlN
2X1u80ASXgWnwsmDXR90mnIwK1gWHPtwUvoHpx9xm0eT8pRz5+HLzXe/h93m
8aRy7sXxyOL0k0l1C9zmiSQ/ED3m/vvK7Un/5LLxbv900jnJtsNPO/2Yx2Sc
uV4beAS7OyHJ9j6bdA45g88nxWexk3Dyv7j8Bacx8Jw3zhq49yXryRD3xRZ1
yHrrpd3kpHb0o3yS23N/cMY4X9jvZy0Dd8urSfWbZWH0fSuVveLy862fnGXO
0BTrIe1512Rczt9rSfch+vu69QSf5Y0kTAAeAd9wzrAZb3tvO8bGfEucwnaD
tXSxnSHN/Jx15kI2fIt13B7MDna/xOXrOtbc0Gna4Mv8x/4MfFE+0rOT4lbE
rODkl/E+MRc2ZuusOmJk7bLsLDGdtnEZrlpk78DflBGrwAda5AtVir1sYNmw
99j3C9yWcc52e347UvytOuT6ujt4H17xt0GuRh6T2AzxNu6gE2wH2vj+GOm5
OLMj3Ib4Fry123Ou1/Z9xP3H/YUNgbdxmjHW9jgj3YZ7Fj8Gf4Y4JPvTfTFZ
4Mw1M8mPOrjS+wK/a2HPf3MeX5Lv/451ABz3btJ9Qr+P3Pcj5/HFusT4W2TF
QPu6jvjqN0l2rWbTSOOngAV5O1naMtPvUI9DLJUYMXxGEgaHT/e6wEf0TR7j
fadXzpKftayS5acRO+NOx5cYU9XveNKrOH2d9YeY4FmV/LY51h34Fy5H7zaz
nhOX42340koYkfxtlfaO95qVLA/6TB555ro9e8Y3wBfB55zltdMfeW+vtB+z
vF72jH3Ep2tvnUSHiaET++5Zaa3McannZ17iAOBN3qVq9hB8fLDLmrh8ruVj
7lpd7Q0LbFpsJ0kzHtgNLAf2g4PbuNM5J03dHhvIOxZ2jHu/pTHfYJeD12pY
kLt+uMfczzIzDji5eQy2XgNh8A+irFWRLzkp+MVFPspLwV8uup9eCT4t676a
HOmzsu6vKZGekXUvvRvpS4p05o3gM7PunCci/XzWPTo+0hOK7uBngv9YpMNv
YNOKfK/JkX62yC9/KPhQn99HIv1MFiY4PvjEIl8O2w5Gr+1BC+8POruy9QT8
CJ4klgkWAvse731q5b2q5cHPxF2xN8QS6AfuHOdvga7gKxDj3djl8I08/gjb
OnR7sHVrkX9hW7botxVJY57mM9HONvZ6j8vZYYx2Hgf718h2FblWsGwrOk15
7Q4g/oTPyXsKNoM7gXuCe4H6ZbJ8feJwxOO+9X3BXnHGl/E4tCcWxFnAbvzh
+6aR+VJON7JtZl3E9Bp7zOaWqYXvhUWyWi7ee2q2blmnW7rv7Eg/xV4W3Z3c
+fhXYAYwOX7RorfArLgPcQDecsgPtH3rYpu5CINn4XDiKsRbibFiU7t4XbQj
z/tSZ9vbAW7T2eXch9h9bD22nzT3I2/0PXM9bsv4xH6Qa0u36eVxsStdLfPh
HrOr0/2z3k3x9/FNiAPiyxAHJi7M2NtmpWe4bFvPS1/igNu7bDuXIxfy1eK6
27icNG2I8zIH/XhH3T3LX629WcJ5e0Qu5MEn6m056ce+7uS2PbwP0zwO5fiz
tf3ifYx3t+5eL7yby4m/9rUu/eJ87fecu7qcOft4f4iN9LE823vtxD95cx/o
9rzpk6/p4B6LjdPfe1Xzz5ETeXdzekfvw1Yu39170s99kWGAy2lPDKWfy4ml
sRbWgV/PmPh6LcMALMySffVI/5FVv1qkf8iKA7HWXbx2dATdAJvt5b3b0/Ls
7DH5fttaH0bEWXkoK8b2QvAni/yfZt6L5t7XgZ7j0qgfXnR3leDjPdeE4I8W
4dkpkX6hyId5JNJji7DwET6P3EWji+8PjH6s5YCs2NIPSf4Svg+cfFPrHfqH
Hi70GoibbWfdJT/WfYmR4vsTbyVWQJyVPHGAn6zTvFPwFvBrUhyO/gtdXosd
0JdYKLbpW9so8t/4LDAWZ2S26z6r5McwLr7MH25P35yFCcADxFl5b8D3gZPH
L/vb6R/d5i+Xk6aO2OzZtmPEFrBRAIadLCfzcf/yrgBW5t4HQzAvsXE4chDv
nO+559Xauv1RHpP7fxGuybqDlvEdxv31q9f4nb/Fz963Vt5Dvsu90fa6ojjI
g5G+syjW8Gik7y2KKTwb6ceKfHKww4dZ8v8d6X2z4pEvBZ9omc9nvCI8/nQR
JgAPjI36MUXxlxTC/pwVEz00yj7K2rd/wAxZMUvuhyez74hIn5AVXzw90mcU
xY8PC3591l5eHelbs+6xK9HxLP+IO47fvIKHG8W8KxfFLJeN9ApFPv0KkW5W
FI+kLX24Izo63d/3TieX38Z+FPlw7wR/s8iXfi/4+0X+84vR9qmiWAN45+Us
zHNVpPfOiu9+wH4W+dJTwWBFfuz8qL/J8s/mG3mNQ4KPK4rFfxzp9RvIz58V
Zb9l+coLi84t3/mX4L8W+asLgg8sOrNLgPuK/Nff6VsU2/4m+NdF7za7BG9Y
hD1mBN+k6I7OwbcriukfE3x6kc34Pvh/i2Iy2JWfbFuOCrkuz8I5jaNsz6J3
FWQ5JUse7NkPtmlDgx9Z5HefGXxYVhx6xyK5kRlc2d/YEh8Lvws/68IsWZFz
WPCdiuLBfYLvWvQb1XeiTdMGip2zr+gQe/sEZ7/It/gpy6Zjz9GvOd7/RXpa
/P6SZeux85dF+oii+PvgIp2mzfdZdwD2fwF3WlG8f78sXUfPPwv+eZFPvE3w
eUW/qfk32swtekf5sugOwP4fG+WHFMW456DzRb7VbVlnkvM4O3gPlz8X5UsW
+Wc7BO9dFNNfpcjnx99/LdqsWGSDvwp+T1H87/0ofy/r3WA636ooVjU1y5fA
DrQO/meR38u+vp21t2sV7QX7gC/Sosgf4buNyPp2/SJ9XJZfuRF6XfTm8WuU
zSyKDbFn+2ftW5eib8N36YAuFL2F7BVlF2Xh20+j7IaiGGSOeQ/KetMaFHx0
lk3uHvVbF8WKSrQ5OOtd4pDgF9tW7xn8gix/5/zgbxf59bMi/VZR3O0a+hW9
qZwR6X2LbGzL4PsV3SnHRPkVvlPaxFxNimLV9xedJc7RbsH7Fr2dHMFdWeTD
7hH8pKw7boNIn5plu07OqqOc/bvSe3gJ+1T0LnVX8L+y3qmwE68X2Yq/o6xn
ESa/LPiYrPj4mg10PjmbJ2Z9G8YcgL4Uvfe0jjbLF73/LFVkI7APjYrqKP86
K/6Ff4ENwxZjx44PfnPR3fV4lh3Hhm8avH3R+xZ7f7/3/2TWXvTWwf5N8h7e
VPSdaHMR37nozYF/asKfxJc8N/g5RW8Xt2TdDdwL2KFRRbaobfBLs9630ZEt
i/TkWvasKH6DHo3L0qVvI/1dUUwQ239Hkf3nzvnG986JzF/0noOu3WN9w3Z+
mWWX0Cl8afRqq+CfFMXE1uPMZb1F7xP8miK82S1416K3utuDzy+KyXO+5/iM
c14fzjqzp6EnRW8+VwS/MeuNZJ9I7130exDOyjyfl05RtnnR/0sdVKTr6Pkd
WZgPvDckyg8ven9Ax0/P0vOmRTqNPl/Ouct6W1upSJ/QJWIJBxbhkD+zzhtn
7cAsHAAGQB8Pz9LJL4r0GB0emXVPc0ej+9zf6P8vWWeb73Va1v3N3c25OSzr
7HD+RmWdwYOxl0Xvxr2K7Cw2FrnOzJLtAOxMUXz3/wHwN1W1
                    "]], PolygonBox[CompressedData["
1:eJwtl3nYlkMYxZ+Z+eorlSJFhaTFWkhIJDtZimxtQoWUFkulRGkjlxaFUKES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                    "]]}]}, {}, {}, {}, {}}, 
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwl1OezTlcYhvHNMWNG79E7QyJqEKL+C6J3onwxSIheo3eiReccvYySjhkt
0TvRid57iajJ7xkfrnPd99p7nXfvtdb7lujYo1H3dEmSdPVnckqSdMdxnMDf
6ZNkCs/mHnwSf+GyfgU/oIs+h6+hQIYkucpTjc3lnnwKp3Fdn8bz+Gs+g3Hy
Wa6MG/I5vslVuQpayTN5Ic/gRXwPZX3OXa5u7D4X0h9wTb0G2sjv+TEvwRP8
p7flWtye05nznJfiBdLrHfgL15fxRX7J5/kfvsB1cCnWJd4Pq4zP4dX8Gin+
x1dc31gDvJEv81VcQUNci/fA4ngvpGIJbuMOlmO9ect4A6/gDJGxWV/PW3gj
Z8RP2Kb/yNv5Z36Eh/gNv+PXmBPzY03wJfq6N7Pn3cPl9encD1mM5dD3ytt4
H2/np3iCZhhoLJv7DvLH+icYJGc3lkc+JB9Ffv1I7B0GI4dewPVj8gkcj/1F
BWNFUdr1IrF/GG48j36Kd+oT4+zJO/jf2BvM0j/lkniFEniNDhjj2hE+Gs+D
i/phHs0H+QLv5/PxDj7ngDxKzieXlruiM84ZK8V5jY+U98lneU+cYd7LI3h3
nHPexX/iD3ynt+dhnNv84nK7OId4EecKz/EME+L75b5inMu9Q+XW8hDOqReO
7wNaoiDKGyvEh2OduZT+EbeIZ0U5PR8fiM+ONdJzcXPsj//JWY0NkJvK/Xl8
fCcxFrtjP2NN3ZONG6NJzEEmY31cbyT34u8xJtYWO+RfuCeP4pGxPtiqb+Ju
cRbivMQ5wkZ9Zaw3D4jnQD+s09NiD7gPf4veWID56GR8ItZgnr6W63HdOB9y
Uc/4invp32Bl/F5xR56A5Zilr+DZnMa145xzEXOfxe+MnsqJ3o4/j+8VF9Yf
cRl9Mb/j1lyNP8Md+W3sRawpbqGgObd5fqxXvAdPj/3kilwJl+Q3sUc8Fsfk
SSkffpf/B6GAyJI=
                    "]], 
                    LineBox[{766, 1055, 765, 834, 616, 1029, 690, 808, 654, 
                    617, 937, 691, 894, 895, 896, 621, 840, 841, 777, 1063, 
                    776, 845, 778, 1056, 779, 847, 846, 628, 957, 708, 956, 
                    709, 958, 629, 848, 849, 780, 1033, 625, 657, 706, 1047, 
                    707, 701, 842, 773, 940, 694, 938, 693, 939, 770, 838, 
                    692, 769, 1030, 618, 837, 614, 1028, 768, 836, 835, 999, 
                    767, 998, 997, 887, 686, 932, 764, 996, 653, 807, 766}], 
                    LineBox[{771, 695, 839, 867, 866, 655, 874, 873, 872, 
                    1003, 1002, 696, 941, 697, 1004, 1005, 875, 876, 877, 843,
                     626, 868, 844, 702, 774, 1032, 623, 656, 897, 898, 1061, 
                    622, 942, 619, 1031, 771}]}}], {}}, {
                  InsetBox["\<\"\[Mu] = \"\>", {-1.8, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["0.2`", {-1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {InsetBox[
                   SubscriptBox["C", "J"], {1.4, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["\<\"=\"\>", {1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["4.63`", {1.7, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {
                  {PointSize[0.05], PointBox[{-0.2, 0}]}, 
                  {PointSize[0.0125], PointBox[{0.8, 0}]}}, 
                 {PointSize[0.007], PointBox[{0.4463998339305619, 0}], 
                  PointBox[{1.2771956561278897`, 0}], 
                  PointBox[{-1.0806611991222994`, 0}], 
                  PointBox[
                   NCache[{0.3, Rational[1, 2] 3^Rational[1, 2]}, {0.3, 
                    0.8660254037844386}]], 
                  PointBox[
                   NCache[{0.3, Rational[-1, 2] 3^Rational[1, 2]}, {
                    0.3, -0.8660254037844386}]]}},
                AspectRatio->1,
                Axes->{False, False},
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                Frame->{{True, True}, {True, True}},
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLines->{None, None},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None, "TransparentPolygonMesh" -> 
                  True, "AxesInFront" -> True},
                PlotRange->{{-2, 2}, {-2, 2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.02], 
                   Scaled[0.02]}, {
                   Scaled[0.02], 
                   Scaled[0.02]}},
                Ticks->{Automatic, Automatic}], 39->
               GraphicsBox[{{GraphicsComplexBox[CompressedData["
1:eJx1W3lYlNUaR9vVwSWu2mjuy2iaZI7eTH0tLE0TJ8udRjL1qpNlZumQJZqO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                   "], {{
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[0.3], EdgeForm[None], 
                    GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxNm3f81tP7x9/nHAkpRZKigUKSrDJKJBJJSkoZCVmZIXtnbyKyMr7J3tmk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                    "]], PolygonBox[CompressedData["
1:eJwtlwf4j1UcxX/3fiUyQpHSMBPSHtJUKaI9SSm0RVaFpigpiqS0SYWKiErL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                    "]]}]}, {}, {}, {}, {}}, 
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwl1OWTllUYx/GbXWLGFwKudIMuI4h0iqL8CSbSu4QyKD10CAgoJZhIr7Tk
EgrMkALS3d1t0Q2fa3jx3e/1u855nj3n3Oe5y2R2fK9DjiRJWvkzOjVJPsd+
HMDZlCT5lifyF3wQh3BOHsOTuAMfxhGcl8fyZO7IR3EMF+TveAp34uMYpT7B
VXFRfZIvcXWuhhbqn/hX/pGn8XW8ljNJrnEtvb+5uPwP15FrI0Odovc/z8AN
pMqZXM94a84l3+bZuIPcchuub3wOn+F7fIrv8ml+K84j9o4JmK8/nhfwQ+Tx
HZ/yO3rv4pH6fOwt9o+GsT9MRVacRewp9ofrsRfMwhKfm8lLY32cO/4HVsnz
eTUv5BewGOvlbP6Tl/BN3MAfWI7fsRIrcAsfoI+5ea13C1eQx3Ff5NNLk7eq
V/M2XsN3cBuNMEDvJfN2ckX5dXypTtMrpN6l3oui8h7+BQPxslzc+D71AeyP
80MlvTIob7w0N8cQ/cLyYV4nj4x7p14b54qH8QzkN/hVPMYreIJMjDC2h/fG
enBa3s3DeSef4u18knfwN7yNT/CWuJ+8lb/mzXGHeVPcZ/6Lh/HGuPO8njfE
+WOonMFfcSHrL6duGXcZ9/Eg7lXcqVhj/J7MK8sFzR2sbqYexAXkUuqmaIIS
cc56JXm38WKcLhflxiiMinIR3mG8YJyLXIA/wfY4f86v11/9sbofD4+9xz6x
OZ5rnKM5+flDfIR8eFGvt/H31T34ZwyL/WJZ3FV00xsSe8dgrJEXcSfuw73R
K+bLc7g994zvQ3dky9O5XbxD0E3dFZMxCZ/FOyfuPibKi7gBvx1nqy5ljQ+4
i9wZ8+Lucdt4h+G3WLc8l8fFb43fjN8Ll/TZW1xensk55VZcV/6XS8j/cbo8
nXPILbmGXBNX1YleMx6Ny/GM5Cs8Fd+bk8U/xP3mylwFZ9RP4znzSOxTj0p9
/h5+BhxGyQ0=
                    "]], LineBox[CompressedData["
1:eJwl0DlOQlEUgOEDjwQckNpOtFG34RQ1IrIESoPPWJBIgsMaIHEHNJQUDlES
C9GtgKxB9CMWf757zn23eeX6ZS3NRMSJfrMRa7mIGXeSiAYXzI/cMnd5ob7z
E9u80a2uzIc80rK2vVtiRUVtmFdY1amuff/GT77yi0O2eMaaSvO33jXtHvSh
VfOI7zp2n9e6XYH3utOLuxzL9gkP9GyX5aJd6rzvfM6COeO8p11NFfrWRE0N
fNfjD8fscDP5/19//UQi8g==
                    "]], 
                    LineBox[{773, 698, 840, 868, 867, 660, 872, 871, 870, 
                    1007, 1006, 699, 939, 700, 1008, 1009, 873, 874, 875, 844,
                     630, 869, 845, 705, 777, 1036, 627, 661, 897, 898, 1064, 
                    626, 940, 623, 1035, 773}]}}], {}}, {
                  InsetBox["\<\"\[Mu] = \"\>", {-1.8, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["0.2`", {-1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {InsetBox[
                   SubscriptBox["C", "J"], {1.4, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["\<\"=\"\>", {1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["4.62`", {1.7, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {
                  {PointSize[0.05], PointBox[{-0.2, 0}]}, 
                  {PointSize[0.0125], PointBox[{0.8, 0}]}}, 
                 {PointSize[0.007], PointBox[{0.4463998339305619, 0}], 
                  PointBox[{1.2771956561278897`, 0}], 
                  PointBox[{-1.0806611991222994`, 0}], 
                  PointBox[
                   NCache[{0.3, Rational[1, 2] 3^Rational[1, 2]}, {0.3, 
                    0.8660254037844386}]], 
                  PointBox[
                   NCache[{0.3, Rational[-1, 2] 3^Rational[1, 2]}, {
                    0.3, -0.8660254037844386}]]}},
                AspectRatio->1,
                Axes->{False, False},
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                Frame->{{True, True}, {True, True}},
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLines->{None, None},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None, "TransparentPolygonMesh" -> 
                  True, "AxesInFront" -> True},
                PlotRange->{{-2, 2}, {-2, 2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.02], 
                   Scaled[0.02]}, {
                   Scaled[0.02], 
                   Scaled[0.02]}},
                Ticks->{Automatic, Automatic}], 40->
               GraphicsBox[{{GraphicsComplexBox[CompressedData["
1:eJyFWnl0jNf7TzTWGo21Osda6jeWoggay9N2SlWLkYpYaiy11dRSW40qsQ21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                   "], {{
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[0.3], EdgeForm[None], 
                    GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxNmwXU1sUSxv+7i6KooICUqGCBCmIgBhaliCJloNiJDXrtgKsiJhZeAxG7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                    "]], PolygonBox[CompressedData["
1:eJwtlwf4V1Mcxu853/wllXpUVv1JZI+syIiQvZVRRFmVZETSJJVRMhsIkYYG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                    "]]}]}, {}, {}, {}, {}}, 
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwl1FeTVUUUhuGNA5IERiRKkEGtIkdFRW7kD4A46oASC6okDaHIiIBIkiBR
hgFmQKISRPSCoKDknFFyRsk5S1E8q7h4z7u+7r3P3qd79Ulr161ZZp4kSdr4
GJ+SJF9gH/bj1AtJ8h1ncUc+gIM4LU/g6dyJD+FvnJEncjZ35n9wGGflSTyD
u/ARjFQf5Vo4pz7G57kO18an6u85l6fybL6EinmT5CLXM3aZX5av8FtyfTRX
P+Dr/ANu4KHcghvw5/yYb/N83MH/ckt+lxfwSb7Hx/kun+D3Yj3it8fvwE/G
s3lxfD+eqFvzTJ6FbuiOMcbaopG6PT/lp9yYP8AFzMN8zMVycws4BUuwSl7M
q3kp549rsFb+mVfgl1gLNEFTbDS3kjfwZPTCqvgOjIi1xxRjfZDP+qXKm9Vr
eAv/zldxBR+jv7H8rtvOVeSqGKAuYKyEeod6N4rJu2K/MBAF5bLm96j3Y1/s
KaoZq4jy5ivE3mCw8SLyIV4rj41eU//Bt3AT0+Tq/HrsHyrjDlpheLxDPAs7
cULexd/wDj7O2/gYb+dhvJWP8uboSd7CX/Om6FveED3MG3kor48+53X8F/7E
ELklf8Uvef+06DF8hhuoFL2Ia9ELcYZc9xoXdu0gdXP1l1xILq/eq87gV5Fm
rFz8HmNluJxcOs4GSsZ3y6V4m/lX4h65OH+CrXE2+EVj/dTp6r78LY/GKGyK
PeOyrinKzfARiiCvsd7mP1T3iPOL4bGe+A2/ItPYsFizWB+skZdxJ+7P/eKZ
0Z/yQu4QPce90QvL5DncjseiZzwLs5GLNvG+WIIceSm/zw1xX13COz7gTLkr
flRPj37g0fFMTJMXcVacM34neinWy723+M04d/wo9ozfjt7n4uav8RvyHL7P
GVyXc/g/3IvzwaNwAanu+Tf+A+LcmZvFU2I/uAbXxEn1XU7nEdirHpfy/L/3
GRv5xzg=
                    "]], LineBox[CompressedData["
1:eJwl0EtKQgEUgOGj16AXznrMxEmtogdICpkNWoKBBUFCzXrtoMAtOHImaNZE
qNxJ6SasRD9x8PPdc+6De2++Wj+7TkVERX/piI1MxC/3kogap+xwly+8UMtx
l3e814OuzEcsakU5z1nmsVa1bV7jicq6cf0bv9jjgO+8ZYWnWlfivrpdQx/K
mj/ZV8n5jLbslvikR/WcS3HTPljQ6/xbFHaXPLQ754QTHnBfI/2bh/yZv4/a
5ibH/OYzd5LF/5oBJ68mYg==
                    "]], 
                    LineBox[{770, 694, 836, 864, 863, 655, 868, 867, 866, 999,
                     998, 695, 937, 696, 1000, 1001, 869, 870, 871, 840, 624, 
                    865, 841, 701, 774, 1026, 621, 656, 895, 896, 1053, 620, 
                    938, 617, 1025, 770}]}}], {}}, {
                  InsetBox["\<\"\[Mu] = \"\>", {-1.8, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["0.2`", {-1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {InsetBox[
                   SubscriptBox["C", "J"], {1.4, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["\<\"=\"\>", {1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["4.61`", {1.7, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {
                  {PointSize[0.05], PointBox[{-0.2, 0}]}, 
                  {PointSize[0.0125], PointBox[{0.8, 0}]}}, 
                 {PointSize[0.007], PointBox[{0.4463998339305619, 0}], 
                  PointBox[{1.2771956561278897`, 0}], 
                  PointBox[{-1.0806611991222994`, 0}], 
                  PointBox[
                   NCache[{0.3, Rational[1, 2] 3^Rational[1, 2]}, {0.3, 
                    0.8660254037844386}]], 
                  PointBox[
                   NCache[{0.3, Rational[-1, 2] 3^Rational[1, 2]}, {
                    0.3, -0.8660254037844386}]]}},
                AspectRatio->1,
                Axes->{False, False},
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                Frame->{{True, True}, {True, True}},
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLines->{None, None},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None, "TransparentPolygonMesh" -> 
                  True, "AxesInFront" -> True},
                PlotRange->{{-2, 2}, {-2, 2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.02], 
                   Scaled[0.02]}, {
                   Scaled[0.02], 
                   Scaled[0.02]}},
                Ticks->{Automatic, Automatic}], 41->
               GraphicsBox[{{GraphicsComplexBox[CompressedData["
1:eJyFW3t4jNfWj0tTt7i1Lk1TB3UZpJKmUrRqqSg+Raealqoz7ilGXSJFcnzo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                   "], {{
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[0.3], EdgeForm[None], 
                    GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxNmwfc19MXx7/3XpVUpKiEyIqMMpKEtgpZFSGUkey9i5C9iZA9MrP3VvbI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                    "]], PolygonBox[CompressedData["
1:eJwtl3f8z1UYxT/3XiNRRlKaiEqkHZHKqqRBsqnQkpWolCREktHgp6xEgwgh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                    "]]}]}, {}, {}, {}, {}}, 
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwl1OezDmcYwOHlHETvIphREyVKxAf+gIgunCDDTHSCaEH0Fr3X6KKF4IOS
EL236L0Lid5LxidRr3t8+Lmee/e8x767z57irbuldU2XJElL/4xISZJvdVCH
dD59kozkODbnYR3RBfMojmcLHtUxXTSP5gS25HGd0CXzGE5kK57UAOtT/ESX
rU/zCsuwtOpaT+BUjuc0XlPu1CS5ynKO/cNU87+crk8dq89HvMkZuqXH5q9Y
gQ35lHc5W/f0zJzGSpzDC3zAc7zP8/wsvl98l7gm/eL4FC6I36//rBtxGhey
HdtriHUTVbFuyud8zmqsqqvxf2quZmuZc/P4gou5mou4hkv4msu4jku5XL/p
hr5QdW1xbhU3x/NQB62O36GBGqTB6uT4/8yobdZruZ2/81bcQ9VWF8decReL
spi6Wr9mFu223qcUz2JvPGt10xvncmq/9UH9pRLm4soX5/x83ng26ulcOvNR
/mkeFnvNej0L6rbGmkuykO7oo3iO+lr9nNvPA9qrs3FN7Ms9PMNdPM3d7MOd
PMXtsSe5g725LfYtt8Qe5lb+yM2xz7mBm7RRvcxp7MHE9X8Ye0wNlD9yrEC8
O87/Ee8V1/EH1md3vmWeuHbreswV98fncnOPYzmYw5w93gtlVV5zNu50PjOz
mz9gHe1wLBNfqrN1LX7Pnzg09qS2mjMwm8+lsoZqKiX2njo6/yXbxbuuAdb9
tVIr1MaxfnF/415qrflXtohnH/sj9k3sTfN8NmPnuI7Yd1pinslvODT2qPV3
mqGf1dixwbH34902L+bnrKyH8f1c9yO2jWvRfOvJsRc4SHM10TyPkziLFWMf
MaPP3mER80w+iefF8rwe98X5Gywc18KHrMeynMy/dT/eDQ7UmdhvsT81ydya
4zTF+kE8E5bixzoXf3NYi/3jnbAenvL+b+87QwrBNA==
                    "]], LineBox[CompressedData["
1:eJwl0E1KglEUgOGjNvBn1tygPVQgGaROGzkKKggJpUnZzwYSXIOjRgaVNQnK
Wku1hjLRiIL0EQcvzzn3woXvW64dV48SEbGlQTIivRDxyZVUxA5HvOYSW9zV
pfmGTZ7oVPv2dRY1MS9655+b9lDOnmBZJdXd3fGZPb7wng1W2GeSPzowt/U4
O/POEx+04e6XWWd/PLefqWf+Vsb5mAVnt7Nv0di8xzVuc8ghr7Rq/uI733So
rr3DD77ygvnU/F9NAVXaKyo=
                    "]], 
                    LineBox[{760, 683, 826, 759, 852, 643, 857, 856, 855, 991,
                     990, 684, 926, 685, 992, 993, 858, 859, 860, 830, 854, 
                    853, 831, 690, 764, 1015, 610, 644, 885, 886, 1040, 609, 
                    927, 606, 1014, 760}]}}], {}}, {
                  InsetBox["\<\"\[Mu] = \"\>", {-1.8, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["0.2`", {-1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {InsetBox[
                   SubscriptBox["C", "J"], {1.4, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["\<\"=\"\>", {1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["4.6`", {1.7, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {
                  {PointSize[0.05], PointBox[{-0.2, 0}]}, 
                  {PointSize[0.0125], PointBox[{0.8, 0}]}}, 
                 {PointSize[0.007], PointBox[{0.4463998339305619, 0}], 
                  PointBox[{1.2771956561278897`, 0}], 
                  PointBox[{-1.0806611991222994`, 0}], 
                  PointBox[
                   NCache[{0.3, Rational[1, 2] 3^Rational[1, 2]}, {0.3, 
                    0.8660254037844386}]], 
                  PointBox[
                   NCache[{0.3, Rational[-1, 2] 3^Rational[1, 2]}, {
                    0.3, -0.8660254037844386}]]}},
                AspectRatio->1,
                Axes->{False, False},
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                Frame->{{True, True}, {True, True}},
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLines->{None, None},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None, "TransparentPolygonMesh" -> 
                  True, "AxesInFront" -> True},
                PlotRange->{{-2, 2}, {-2, 2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.02], 
                   Scaled[0.02]}, {
                   Scaled[0.02], 
                   Scaled[0.02]}},
                Ticks->{Automatic, Automatic}], 42->
               GraphicsBox[{{GraphicsComplexBox[CompressedData["
1:eJyFW3t4jNf2DipaTJvSgw7VUnREq5QoGhZGtVV0GtGmOEMVVdFDiTJOqkFN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                   "], {{
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[0.3], EdgeForm[None], 
                    GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxNmwn418MWxr8zUyiJLElSyE4LQlkKJVlbKUuIZN+yZL1lvXYiupZLtrLv
OzdZIvtSlL2QNUUkFO75eN/f8/M8/3nOmfnOnDmznfPOmd9/jQOP6Xd0rqrq
mgZVVYJ+lKrqw0g/Br9yfGgeac/IrxK0RaRBwa8atGWkvYOvgk4Oum+kDsE3
iqIVI60U/IqRBkR590itI82P8k+Cfhzpp+DXiLSC628cdTtG2i++rR755f2t
RaQmkZaJtIpp00gD0SvSLpFSpJej3QGRmse3xpGWRodK+pBfGKlZpNaR2pin
j5Vdlz7WrOmOPtaPsrVdD13WqtQH+WGR9kSXSOtav5aR9mKeIu0WaR2349us
0G9mpN+DX891V43U1n0i99MkHdtF6mBdmY9NrAt1NzVFl06m6LiZKX12dDvG
0P4f497c39F3C1N06Rn9rhnp1+A7u2z9SAdG2UZBt47UzbLQa1tT+tnOlDnb
3hR9e1on+uzqMdG+u78zjh6mjGObSn1RbweX0b6v+6bP9WJOzwudzo3UN/id
Ii2O8l5ZOu4WaXfri7xeHidj2tG6kO/t7+jVx5Q+lgw5S0TaIPh+7pPxDXGb
Pl7zHtZxoCljHWRKP3uZ0v9+kXa1bltntd0j0t7+vlOkfUx3jtQla44GRBqW
1HZwpP7WhTluFHVmJ83NOkH/sr7rciaT6m4VdT4PPnE2PC+MYf9/zNNnSboM
jXSw9WJ8C6P8iaBTmJessR0S6TCPDd13ijrrRfoz+EOTdDwq0tHWl3EfY0qf
m2T1cXykwy2DcR/r7+h4nCnz/S9/o6xBko7DI51huXw7ib6t1whTZF8a9S+J
dETwRyTpdSrzFzp8F/klIm0YqWHSOT7tH7qfbkof3ybJPzHSFcEfnaT/90HP
oizSOdaD/s92XfLbZ80V7Ycn9f/vSBe4P/q5OsqvinRy8Bd5bIz7fOtLveOS
ZNLfUsGPZHyRdgl+mUiNIl3p7/Q/xhS9rotv13Je0Cup/7GR5gU/N1LjSJdV
kjkq0n+sI/1fY4q+15peiExT9N0gxrhMpKUjzcdvRGoS6YckHcdFusn60s/N
ppdHusV0dKTxlcaA7rd5Xsk3CznLMUfB3+q6fFshaRwTIt0b6b+Rboh0h8eA
7neaovtdpuh+t+n1ke4xpf39kW60zvdZHvnNsmTeHmnX6LdjpKUjPfCP8T3k
sTGmR6wr43jUlPGNSJLxeKQdsnTljP3POqHLw5ZB+yc9HsbxlCnjeNqUNhPd
jjl40Lqgx3OV9KPsWY+N/CSPjTz2BrvYJdLzrss4nrE86r3gMvSabMr4xsVY
bkwa3woxll+DXzHSyx4TujNPTZPm9nWPE33fMKWfN03Ra6r1oM+3rTfjeM1j
pv0nkd7y97fcjnqfuuydSK96vmizXOi2bJbuMyK94u/vmyL7A1N0bJ5k896N
9JF1fdNyn7N+H7uM/j90O+pNrzR++pjpNozprpD5RdA5kVoEv3KkaZV8zSLP
/+duj46zrR96feEy8ovBYZHeC/5Lf6f/r0zR98/43ipJ3i1JMj+L9I31Zv7u
Terje9Y8SdbcSI8myZoXadXgWyaNo0vQ1ZJkfO1+kDU1yiYkzf30oE8mfUe/
KZ6LnythyaUq4UrwIJgM/AhmBM9NNjYE1/1SCRuCz8CJ4EFwGhgNzAVGamHs
CWYDM4I7wYrIBUeB4Zobq9KusdvVvoGjwEXgRzAjOAz8uKASHvutEl5czXqA
m8BPNQxaw6QtrBP6re56K1j26u6vrfujHthsraqO4cBA9A3WAoeBF9ezDuBH
sNj6lgW+6mA9wFDtrAvtwHMrGqczVjDmp8ZtLfx9bevXwe3RcWPL5Tu4qIYf
oTVc2cm6sqc5009VdexIG7BSZ+u5pse0see7NlbG1Nlt8Bv4PfzcQUn4cqtK
vhdfd2pVx5TbVnVMuZ1ld3eevsFXPa0jGKxHVcemYDlwVH/Xr2FN2oPBBphv
77pdrV8vywU/go/ASeDE3s7X8GJvj2knt6FP8Fdfz19P64Te/f2tm7/THtwK
Zt3VeoG5wF7gNTDZQVUdX/JtI+uxtfsDO4Et/qiEoXau6jhy76qOR2l/SBKO
3LdSf+Ax8FnjLBz5V1XHrIM8zgMqYTJ0ArMNtR7DnAcTDrN8cOgQjwsZYLBD
PXf7uz/ma4jlgosOcV/gePTuYr0Pd/s/ze9jGWC9Y6o6RiSfk3jkgi2HW88a
FjypqmNQ8FxDYzf0BwOC7U7wXPD9KOtNuxqGA0OdXdVx4WmWd4bz6PEv50sS
j05HJuHOUyrh0BEezzHGkCPdB7LBbWDAc6w3ZwDcBQ47KQm3Xe0+wFycoSWT
ePpDFpjqUssCN4GRljG+u9y60g4Md1gSXj+yEnak7SiP7QL3DTYE446u6pjy
yqqOBWvYEFrDjFAwGbaJc7JNVceLtPkbJybhLTDpGM/v8Un4+LxKOPI6j7N1
CVvTIM5lfFvWuPIGjxOcM66q40gwD7re6jzjv8159B7vfA0X3lHV8SiywJjj
PU7w3gSPhfbgnYc9Ptrd7j4oAxuBb8BL4DD0u895sOP9zqPrA87XMGgNk95l
ndDjQde72bLJ13Dq3VUdUz7i72AlMAl48nHrdnIS1nws+P5RvnuWb6vhyCct
Czz1tMdE2RPWGzw2sapjTdosb6w33uOZ5HroCi56tqpjRHQCG062nmBD7pMv
uQ9wwRSP7Xm3v98yJlmXV1yPvl91Hl1ecx7dX3e+hilfd3tw2ZuWV8OJ9PGO
8/Q51Xmw4VTrjE5gF7Bfn9C3UxIeRI/p/tYsC1OulKTTDH9DLjjok6qOKd+3
Th86j44fOY9+Hzv/ltuRX9mYq6bfTMutYdYZVR03Iw9MCM6b5W/gxc/dH7hu
dlXHiF+6v6+dp78apgM3glO/cz+zLWuCcR/6TUvCfODC/pE6G2uCJ+e4/nT3
D+ackYQLVzM2nOd+wZlzrc89Xj/Ws3cWVgTHgUu/tx798JNZGBE8Bj4Ec41M
wpdgS+j2Se1fSoo5Un/DLCwHbgKjgKmI7WyVhPPAeOsSp4t0ZpS9Hum1JFx+
cNC1k3zsGkltW0XqFXzbpLjTztHuAvP4Q3wM/mUtt8Mvb5AUv8A/gQWIz4AH
tsyKzVD2ZZI/w5dtE3R95/EZ+ELiGOgCj0/ke7H/+wbc7T6Qiz8HZ3QFAybp
xP15Odvcdkn+A9/xZtArXa9HpDZJ89UgK9ZQu7c3sh9ZP8qbZLXHLmHPsX8d
kuqMCn7brPgK84E9xG5jC6nX1Da8W9CNk3SCLm/7+3PQn5Lu95uYTnC7Zd2W
fpaxPr8EXZB09/w96VxidzjLzW1zNvM55lxP8xnjfPVOuo9RxtlexXU4c+xx
zl2/pLvQTO9r9jt7mzlirpp5fxLfXraSvV09aZ9wbtj7nK8dkvZQK68ncTPW
lBgmewkMfH7SvmHP/OH13sf7ZR2vLftlXe+Z0Ul7i32VvWeO8x4nlss+3zbo
5kljrsW8WBf2TjvvgTFJ6zfK69nRa1pbG9blBq/HBM/f5p4T9kj7JAzCGm6a
5CeY706e/75Ja/Cu53gL8w2978BkjG/rpL3LvG7pub0j6f7JXFL2i20A4+jq
vc2adPa6EC/q5n3F2m7rsSNju6T14M2AuxP3TWxAD+959MZvPeL529FzeFHS
mV/sNSHu+afP0c4+S4yvj/cZ60w8/Vefi118Npi/3bynuZdyP+UeyTzt7rna
K6mctxjsIPdl7nS8p+yR/n5uqQYm3fXg+ban5bEm/bwuzHFfz/OpSW2oz5vO
QMtHHvLjrzotqW/KhyTdi9nP6Mddm7vvPkl8QLK/cft53qu8B/GtYaV63OuZ
29OTyqlP54PZg5Xovq7Pu9JerrN/0n1/yeD/lZSH546MPtyLRyXph268+8Av
h3jbb+6TvCXRFr+An0Am9/IBWd+5Qw1Nun9u5bbwG1Y6i0NdXmzbuTvBc4/a
hTMdfKssDN3alLvD4UnY+kjXgefOdVTSfYC7wJpZ9wIwfpus8iPNt/a3TkE3
zbontM1qAz4+Nun+wFmjDjxnv72/Ub4G9icrZtzOlDvBCUk4G4y9luWB2WlD
P5x9xsRYuQ/R7/HWGXvMHQQ8vEWUb56FL7G7UHDnKUm48zHXgcdWvBD0DK/1
2ln3GXSYmLQv2ZOTkvYfe++5pH1T2w8jvY60RW/0wF+flfSOxnqy7tyPzzLP
OtLnYPdL+dmuj50e5f3Dmp/j+vh89jT30J28v9nbxLOJZeO/sOvYcWz4hUl7
g/0AJb/Y5ReZZ/0v9h7A1nMPxJ+z5pd73YdZDvfyEa5zsuml5nkj+E9SDJ+y
y1z+FmtiHjuKH8eW8k4xxmvKN+6WyD7H/Lle8ytch3002nuJ71e7zljzyLjS
9ZHPvrjGewO8B/7Ef3Kn470BrDHGeXjsxPmez3eCXm/57JEbvE+ud1vK8ePY
4Rcr+Z//JvmWcy3zHNvpca6Dz7kpyX7fmqTPZ9aL/Kzgx5v/zHVuczkybrac
mywTOfiT8a4PDgAHg4FvT+K/dRl5fNOd5ikHB4OlwQt3J/FzXEYejH2PecrB
uGBo2j0Q9L4k7HuveepA7/8Hf6/rgKHBysgAVz+WhK0pe8h1HjFPOfRhl9ew
ODJoBz/P/OOu/4RlznPbB13OWO9I9fsD+P4r06dcH//yv6QzDp2Y6v7rmaTz
Dp1k/vkke8GZRcbTloN/eDbJJkCfM49ved718SfEkZu6LXr8UMk/TEnyES8m
3Q24F1D3RfP/TtqjW1byM8SCV3V96uGzXnE5cqDkF7j8VfOLbEewIZ2z3qrJ
v5F0r1hkW7SufRV9UmdLt4PH7oCvwdkXV6rH3QT7BqUtdoy3g6X8fkAMljz9
PhkT+XIWDursb5R3DbpNVmwR+bzbEWv5IinmSLwRSh6MSX3yxEm5W9CO2Noy
botuYCbuV9yhZlpPdCP2THlrl2+UVYYvwjcR98K/EbM73rZoU/PQTo7lbWI/
ONxj/1tWJd+FL8CP4E/Wtl+gbG2X0w++kPhe7Rv+Dv+KP6354rbmsWlt7ReH
u86pto2d7Is3sg6Ml/sVcU9inrxr8LuZ+Psba/BuAW4Ba3L/5Xxwd37X9gH7
je3GrnKXpT44hbozvG/BZR9a5o/uAzzYPsuvE5sjhjknCddj799Owps9sr4R
Y0Xe+5YJ/v0gSa8P3Bc8vgW7fK5t2lTr2dI89g+Z3bNipl8l3VcP9N74xvtn
jnU6wXNDnSGV6GzXX90yTvTemOX55O76tffYl+4j+xxPt/7vJc1jS+/Hr93v
VJejM2u0Ya6/f0DbeY4/8boQ6/gr6d5wsPcZ/RLfI/Y31rYLzM06LOXzxV2A
dyUwNPYKnM5bVBPbNMrB4iTq1TB+c9fHjoF3KQNH8wYGXgZ3gRfBCWCG1Ywp
kU19bB11wdnYuhruPNJ2r6XLj3A5WHRvt6ftxdH5JUU+lDszMWFipUfF9zuL
7o0vB/00y//cG/zELP//YvAfZ/mrF4I/N8t/PR/85CIf9lrQWVl+Bt0YDxjy
7ig/xmfwlSzbhF16KOgvRdjgwqCPFp3jB4M+n4UFHgn+BJ/lEUEfL7qXPhD0
4SKs8FKUP1YUGwCTsnbEP4dZB+aTdzHWEb/DHYC3Qt4Av7UtQjfwGPi7Nn9t
PLfECIgPTvO55q0RGVDuGODSPllxK+QSM2/vs8ke3Mi2ERxLfWQgbznLpG1H
y6EN5/qsShQ5Z1Z1HA9PbIO2xDegzSyHWM3ykS6pFFvGrhObaZplr7HVTWzv
a7/ZaOJy9jdzVLtHrui54k7bxPXxs+w99hTvRbwbHegz3sj8ZM8VcVTivfwm
gHsB93nqYC/B0ugJnkYv9CPesLT1ROcFbks8B9+LMvhffC73PfwvOIozDL7i
jY84GvEQ3tF42+tuX8bvn/BfW7kOPL8bJJYI/qesS66/BcJvX8kP47/xy/ht
ePwzsrdxfX5HRJwLGwsljx3u5nJiLNSlzR7uCz2SbeR2botN5T2MdyfuALwJ
8m5GXJE3wl29V7u7DrSH29Kuu/nvbPep2zPojrn+O5Oe5u9w/nbr3M1tF7oN
sfm9LJe3uT2sA3dhKDot9voin3bcXXa2nsRUiK1wX2eO4ZtaDnfvXtZlB/dF
H+gw0HPV1XPLHbyv+wJX8X4BHuN3lfDcv/CJvX12OvgMNnK//by+vO8PNI8u
e+Z6LGFPlyOvv2Vylxzg8SKvj+X3sv5bex728Fi4D9IWHQe4nLbcMdFhvuv3
dXlHy+zgcTAe3vyvDBt2ZJHPGeRy9Fkiyp7yvprvsTGf+L5tvK92t4xVveeZ
Q763DMP/Y1YsDefzsPceb/HUX9/yBnqdKBuU6zHyQdahVcj5PWtNTgk5DwUP
KLmds1AUI3uEPVWEa9pE/UZFMYlnovy+InyBPcM+Yseg88xjD7BftTs2dFwl
zEbc4Wr7q7n2WdgQfmeGrVvBdcZ6T/6WZDewIcSFiUXs6D230LbnR7d9yft+
iuvQnjOCDHi+I/tn60AM+0frONr2mjdG7qHcV7F/Q2yj2F+Dbbvwz4tchzvm
H0lvNrMqUfLERP+yTcO33uI63KmxhQusG/PUMCvmyr2AuBWxi9/dB/7hIJez
l8ErS3hNOafEsIhXNPScX+L5hifOf4jr4D9r8R3mEL+Kf+WePsK+FhtyUZH/
xnf3L/Lx+PcJwd9WFKt4IujJWbH7yUGftf4Ak32z3m1GRZ0zi2LSC6Psjqx7
zWdR9nnR/e2uKLuuKI5zctARRfo2DjmpKJ7eMPghWTHdJYNfkBXHzcHvlxU7
LsHP99lNwX+fdV6fCxkfZd3j7w56fVFsaF7wXxXd8cAaU7LwBrEL4lzMx/tR
/kHR3fRNzm9RPHelkL9aUVyWOdvCc9gsylcsils8GGW3FMWJPkSHojvtu0Hf
K7o3P8qcFMWMXg9+YlHMYnrQGUV36OZB38ja/5OC3l8Uo5ka9K2iO/HqyMza
b49nzTtz3pb5a6CYxxpBly+KVS8MOqho3y4KumYRBh/Ammedi5+Cn1/0joRe
v1q3HkEPy8LnYL1+xnusVU+v17SgVxTdcXYI+mNRnOw75GTdm78O/ttS98NQ
/PKLwS9XdC5/Drqg6P7zTdCuRXX+wq4UvZfMK7JfdEY/493XEUF3LYrRs0/7
Fu3VPkF7F/3e84koz0V3lIuD/6QIkzQI2rqB3mB+y7KV2MlRWWvPuh8QdfYv
ei89JOiwoljdKkHXaaDY/5iof2jRe8bAoKdnnbuliuwptpRzMNtnYWjQ3Yre
wKaxng301oFem1m37fEpWdisYKeL9GSsB3u8x4Lti2zVEM5Wlv1hzUdmrfuB
nPGs+9cPWX4Fn9Iqyts20LvH7mDwIjzZK2jDoveZmVH/1aJ40xfBv10U00Hf
qVk6z8I/FMX7P2PNi2JPnwQ/pSjmNSP46VnvcOzTtYr26vtRNqkoljcs+Mts
35jXlkVzy+9H2hS9hzQI/oCs95ktWRfbgaWi/OCst7e38M9FtvT7oDcUxYc2
RV7RG/NQ7KVtL3PzTtH87B38RVn7+awoOy7rjejQoKOz7iOcm7E+O1fwvejd
64+sNWO9uhftXfbtGsH/XhQ7eC7KGhf5w+ODvyrLh7IHi9f3sKCHF787Fe0h
9s+pWeeWfvmHH84nZ3OnoDsXvWPtEXTPojeqJkXrypqeiL72F7dG2eKs97pL
gz8ty46xF1Yt2g/7Fv12hzk/I2tPs5/3QUbWHXy/KDsnO14afJcibH86Move
UsbF9zlZMRLW58aiNcKWdy6y57Sbm9X2KfZXUbz4pqI9wX64L+iJRW+qBxWd
N84ausws0od1m2Zb1D7olVnv8OzNG7P25+jgLy9668D/3Fzkg8ayT7LeHK6m
/6w3jAn4t6yY2Em0zfpNAet2btHasddaeL+NCXpd1rsI92zOJOdxPXQviuOs
UGSjsc9XBX991tvJutiTonfOa6Nsk6J4z/Csezj33JGcs6L3qLlF+4+9d1bQ
wUWYhHO2cdFZo+zMrPILgj+/6B1pUdaZYS1Yf/wZe4Czck/Wedki+M2Lfoex
d9C3s97bb8ry/fj9wVk+GP97a5afZk3xYysV+TLs2bdZNm3b4LsVvcX+lHWe
OcsHZfl7fD1nGh/PuR6fhQnAA/iEOUV+gb38gvczNuN+75ONsFtFvw15M+jn
WfHvw7NwBj6Lc3+nz/7/ASKeTTU=
                    "]], PolygonBox[CompressedData["
1:eJwtl3m4VlMYxc/eL6GSUsZCpcxD5iTzWBnz4DFzL1LiCiFSUsosQkJUKhWp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                    "]]}]}, {}, {}, {}, {}}, 
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwl1Pe7j3Ucx/H7OKQrv6BjFyk710VkFJEf9AfIjHNwzMsmWRkZZZRV2cfO
3vMHe++tjMzIJikilB7vqx+e5/l+vT/3fV/3/Tnvz7d4Ztd6XVKSJMn057vU
JOmEn3AK17Mlyfc8jTvzaZzBDXkCZ3EXPoufcVOeyNO5K5/DedySJ/EM7sYX
8I36IlfBbfUlvsPVuCrS1SnZk+Qez0EPvSu4imv4Fe/hN2vX+T7f4Ln8Pjfn
VPf/wfPwJ7LLLbim9VacU37EC/GB3l9cRO8xL8IdvSd8M94xvgO1cBf34nuw
zPp0Xs7P8LL72/BMvRX8GffCOHU71FF34Fdcl6L+CHXxAPOxAPOwLt6Lc8az
sUVexlt5BefCauyUV/FarIlvQD18jAPWNvB+noy+2Chviv3HaIzB5/p5vE+a
+pB6Mx/mLfH9eIzGGKSX5rpjXEEuiDflAvwJjuv/iEJ6J3kKvkA++fWYK/UZ
nMY7ckU8i2fgbxTHU2RgmGt2xPzw9pglLs2lMFVdicviOcrgH2RilLUTfBLH
Yk7k4zySj8b88OGYJT7CI/gQ/8IH+DIf5OG8ny/xXr7I+/gr3hMzzDt5N3bh
S7klD+UCvrekukXMId6Kd9QrEefE+tY4M7yNh3A6D+b8rnkjzp66GRdFab1i
fELvtXiWXISbolDsh1yYj1pvwgP5Vb386iOx95xXHqBupO7P42MeMRYH4/rY
e9fk5QZoiDzIrdfPev2Y4TjD+Dr2GOtjRtFTb2TsY+wZtskruRsPivfBgLg+
zhR35P4xc+gXMyzP5fbxXuij7o05mI22emPjmZglr+IPuXbMTOyJd3zKPeVP
sVSdxa15DBZjqryEp8X54od4yX2ZXF7vbcxX59BryTXk37mw/IDLyT9wNjmD
q8uz+C5exP+CR+NyzBEmY6bcnafEd6gT9zbjyvK7uKb+N85N7GmcG/W3qf//
Bv8HD4rIUQ==
                    "]], LineBox[CompressedData["
1:eJwl0D1OAlEUgNELM4UEBEsbBQpKXYSYGMX4wxLoSGSIhVE7FVcAiSugstUE
sDNRdDXqAhQ9icWXc+9785qpd/rtLBcR+1rkI9bSiB9uJREnLNon3LSP2NO9
ecorXutGp/Zd7mlZDe9KPFBZNXuFRzrUue+nfOOE75zxgsecc4UV787Md3rR
qv2Vz2q5X1LVWYG3GujJXcp15wl3NHOWZ8lZZt42d1mwh/nR3OQvv/ipSz3Y
x/zmB4fcSP7/1R/5piQB
                    "]], 
                    LineBox[{774, 699, 840, 773, 867, 660, 872, 871, 870, 
                    1011, 1010, 700, 939, 701, 1012, 1013, 873, 874, 875, 844,
                     869, 868, 845, 706, 778, 1038, 627, 661, 901, 902, 1060, 
                    626, 940, 623, 1037, 774}]}}], {}}, {
                  InsetBox["\<\"\[Mu] = \"\>", {-1.8, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["0.2`", {-1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {InsetBox[
                   SubscriptBox["C", "J"], {1.4, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["\<\"=\"\>", {1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["4.59`", {1.7, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {
                  {PointSize[0.05], PointBox[{-0.2, 0}]}, 
                  {PointSize[0.0125], PointBox[{0.8, 0}]}}, 
                 {PointSize[0.007], PointBox[{0.4463998339305619, 0}], 
                  PointBox[{1.2771956561278897`, 0}], 
                  PointBox[{-1.0806611991222994`, 0}], 
                  PointBox[
                   NCache[{0.3, Rational[1, 2] 3^Rational[1, 2]}, {0.3, 
                    0.8660254037844386}]], 
                  PointBox[
                   NCache[{0.3, Rational[-1, 2] 3^Rational[1, 2]}, {
                    0.3, -0.8660254037844386}]]}},
                AspectRatio->1,
                Axes->{False, False},
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                Frame->{{True, True}, {True, True}},
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLines->{None, None},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None, "TransparentPolygonMesh" -> 
                  True, "AxesInFront" -> True},
                PlotRange->{{-2, 2}, {-2, 2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.02], 
                   Scaled[0.02]}, {
                   Scaled[0.02], 
                   Scaled[0.02]}},
                Ticks->{Automatic, Automatic}], 43->
               GraphicsBox[{{GraphicsComplexBox[CompressedData["
1:eJyFW3t8zFfaR8vGZVAbymzdulFTrUtb87YUDyZVUmKkWtZqRC/ZMFSqbqOo
FTubpolbh03DIt1SRRPSuEcel4RMXBp5MRFEyCSNuCRG7plJljm+J+/n+Mzn
zT/n851zfuc83+d2nnN+v/T8eE7QZ82aNGny0rNNmjxuzya/1Nlqz+fI0KsV
CfEufqVNxm2H/qLE1YdbxVichyVOEZiAXxDjJU4T80n8VofdwXbjfe7bbrBf
sKGGV3wy44je+rvEWB8Y6wNjfWCsD4z1gbE+8GKxnsQDhDwSLwypWp5icXL2
gdggTWGFlBcY8gJDXmDICwx5gSEvMOQFhrzAkBcY8gJ/KeSVGC14qC34AIMP
MPgAgw8w+ACDDzD4AIMPMPgAgw8w+ACfF3wkhp1Uu6i8gNUWfIHBFxh8gcEX
GHyBwRcYfIHBFxh8gcEXGHyBXxZ8yVvcqH6p2lXlrbbgDwz+wOAPDP7A4A8M
/sDgDwz+wOAPDP7A4O8tT6hxqPqxameVt9qCPzD4A4M/MPgDgz8w+AODPzD4
A4M/MPh7y8tqnlTzkBrHqp+rdlf1AL7A4AsMvsDgCwy+wOALDL7A4Au8UvAl
b/uQui+oeVfNW2pcq34OfsDgBww+wOADDD7A4AMMPt72UXVfU/cNNe+qeUmN
U/ABBh9g8AEGH2DwAQYfYPDxVgeo+7K676n7hppX1Tyjxp3KU23BFxj+CQz+
wOAPDP7A4A8M/t7qDnVfV/dFdd9Q86iaV9S4U/1UtbOqB7WFPoChD2DoAxj6
AIY+vNVZah2j1gHqPqnuG2oeVfMM+AODv2pnlSew2oI/MPgDgz8w+HurK9W6
Ta171LpA3SfVfUPNq2peUuNa9XPVzipvtQV/YPAHBn9vdala16l1j1oHqPui
um+oeVfNW2ocq36s2lXlqbbg660uVes2tY5R93V131P3DTXvqnlIjUPVL1U7
qTzUulKts9S6Q92X1X1N3RfUPKnmCTVuVD/C+uq+r+6b6r6j5mFgrA/c29Pv
4FzPc7XcXWACzvSML+PlHjmrZH2A/lOin9Dv53m+XLY9REvAiAdgPId1lghM
wFgHcl4W+Cm5b3naXNkPjP0XWG1ve9pMiZt4/lJTgLEOxgFj3BnxO6Ef+gO+
5GlLSH0ez6ktngfG88CQK1u0BDmA4U8YD/2gX7Uz5EK/rBufYOgTGH6j9mM+
2BN+AXsCq36htohLYNUv1HkRz8Cqn0AuYOgHelD9EvOBB+RAP+TDc5gHcYF1
1DhBHKNfPVfArtA/MPSt+iPGwc7qvq/6I/rxPPIEngfGeLV+Vf1Hrb9Uf0A/
xkMu1Q7Qq5onVD9Q9xN1HuDA/dP2GYMf8s+apv+MT6mULX63eMbbZbvYY+9b
/LpnnTQ+61mnkIB/af/lcW1mHfX15OU8qpo+oJtZUyFbjMe4iwLzXoHlfMB1
4jnZBgi5CHJiXvRvE79LXphnqJBHygcMPr5CfikfMHgvFK2UC/wgB+TC+sCQ
C3JCLnUcMPQBOeHHat6Gn8Fv0Q+MfuQ79AOjX817wN78GBj910W+lfsSMOpY
5GP0A6Pf23PAz372w2SntpYHeH6/LfUCu3njDTwtxdDHYHZLf/WmB2CM3+wZ
t5PUfQP1AfBxT9xmEcYj36p6V/UKjPUwjzc9AUMfKzzz3KUs8Zzk2emIRw6J
4cfA8GPgKDHPU3oG1gks14V8qAM/PHSh1Gaq5qKjS043NJRKjH0Iz2Ed7Duw
L+o24CZiPGE8MORC/MH+4AE9IK/B/tgPgKeK8TJfqXqDHYCRl2HPuWJd2Q8M
+2N9jMf6wFgfzwPjedVumA/+gvmA8TzGQz+QC/ECrNoV9oB/wR7A0D/GA8P/
YDdvdvVmR2Cs400Ob+sCe6tjoSfkb+gJfuDNT+BHqp8Aw47e7OzNrsCwmze7
wo4YD38E/v/qTMQ3xoM//Ar1h5oXgVH3qHkQGHWOmreAkR+B1boGfgg/Rf0E
DPvKfPTkfIe8kyfyDCHPIN8Cw4+Qn4LE74T8BIz8JOuOJ/Ul9AY9AKv1HfZ/
PK/ei0AOyIt1geHfkB/9mAf29RbHsDf0h37wkHXkkzwJOaEX6FPN26gnoR/U
m8Cod7a2Wj1Wl/iA1XMW9AQM/4Efop5W63N5L/dEXsQh5kc/4gP90B/iGPoH
hj/BzzEe82I8MMZjHfyOOJP36k8w+CHuoFfMC73C7tAv5IB+gaHfTUK/0o8w
n+pHsIt6/kP9DzuhvoT9Ma8aF+q5C/ZQ63o1XsETLfI+5PHmV9Av8gb0jrzi
jRcweIEn5Id/oc5X/Q/2A1bfD6Afz8O+kAf2gjzAkAf2Ax88D/vCfvBrxCvk
hH6Rh9APP0Y//BH98Ef0gxf6oVf043fIgd8RX+iHHOjHPgfe6Acv9ON5yInn
oRf4n3r+xO9qnoKfwr/gn+AFDH3D73DvivMY/AXyQz7ID/ngH+p9nozzJ/UM
/B5+4+2eCHJBP5hHvQ/COR3zog4Cf8Qx6g/1ng1+DH+AHyPe1Hs1jAdvjEc9
hngClu9/lXMI9InxwBgP/WI87IN5gZHvYC88h/oS46AHYPgJnlP1CoxzlXrP
puZl6AnjcT6HXXBfgHoFcQ8/hryYD34L+WBnyIf5MD/u1yAf5pd+fLPnMMOg
W/Lcmzzu2FRNr7KnvvPY0PazZfGb6uR6Wz71LbHtqpPz5y6Y/4/4TY/0c3Xk
s4nm8qe+B7IOnf1s4vRyPlEUf0Q/r4rV9xijnAHdzbPLuVu3ggGGQ43f13x8
/2iJ7b06eQ8V6lw3SDfH9dT3CD9NnTHDGZfP49oXBjmn/J86NcF/ht2446l7
/HVR7eONeXmc11vzH2Oq+6nvLO68O7vhO/t5Ns3ZGhPvuiX7EecDu90apyvN
4taH7yfqfRvfg2E+jMPz6nuxQx65Dsrn0Q/5ZR38RH71u4fQMdsO6a05ct1r
wXxKm5lD0A/qQOgPdoN+1e/Ouv62ONCZW0qwD+yKOnP/w5VbjKmlBPuq30Ut
+Lo8QxtVRfAf9bshy/Vx2Q03agj+BjtADuu2Nw/oyxvfv2wfG/yK4Urj+5ez
94r9Ndsa6+qWl81Hta3qpd6+3fVZjkNT3/i+dUB0kW2XW+ohYUZ4rqPQRRMX
bHHZXrnJY08/X2w742JX7K0Rhi75NGueO8TexM2TfaaN1HQs5aFRf+xk3lbD
aS3eq0uIqeG/NT3fxlx4n6duKjjXMM1FL4zpFOaccpOLZ0eH2Ie7+eeXo62W
pMvc6fW0raYwe2Nb9fZ7ujm3+MfQ3A5W+0l+YWzkD6awIqo83HKnSXeCteUd
2pr73qcOmSN8rPZDdLzTB+F2YzJ1/U/ci+aYbOr8U/hE52IXlegnXNJG5dO3
BYvbW/tXyHai+bk3DYOKKPyLxF/15XU0pHnmR/as81yis/prLrk5eshPVx36
aE49WW41da7n1heGL0xpkUH1F51/Cn7o5sO9J43XHLVTeF9qZ45w87XMwW/r
vr7DV5Oc+/S7aznqbkWd7dsHPHzjW1tMo6v51gdJvubZJXJfnjth/CRnbgnp
WvSdm1JUy6ta+uwyxT6g0QcDAjUfVMs4Xyz8g8MNhRe0i51y32o2PumEft5D
Ctn+vtWSXcnfbY87o21VKfPxql+OntYOruac+sV+5qUPuElPzQRNeiXtsJm+
Tgl9yJHzerS2vllNl9Ov/825+IHMW72EP3N2UkipbVfjfVKPreMmOwNq2Vi2
sjJhxF1udWRCmrZPLS06vKRbcMRdnjx+hK/5l1rKL1i40RRWwh+6Q6sSjj86
Z65dnqq/WMinYvsl63fXUYuMdm8Zfi7k8O6XNph83LJeHPRG0w2m5W6eeWXA
DOfhLE4YvzvHUXiOvy4b9Df7oiucOT7yPU3hz1y25/sCxz47J/ktStUudtPN
QNO38UPS2NF6xXpThpsXZw7vZdbE88Art18Ljrgp7yObmYZmaWcWsLbXxNcM
5u85+0HKHmN9OpWJlqOWb6lKiD9DSYcex+d8nnmVVluSbtOwoTfWW5zpPCrG
ud1UXEBDDzy+N46Q+KN9HkydVr1RnrDWTXci2o/XFP7EwF8KTNnT/pyq3enm
nb3TI+NT0gnro8V6PcR6BH4nBT8Zr34if5Jmw8GeZs1JeU6CfvKFfgj6f17o
n6DPOUKflD+g8rRWm8Hn5i/fabRckefaFSK/U1DX0+87cxvfnx28+M9JzsO1
vO7+sy8GR5QQ7J0j7E3wh3DhDwT/uyj8j3Z//XaTxOOVHKiL6xf8yUPqEX50
nGZbdeO97RP//FH4J9nnHDuhn/WQ+56ebrVkVsq8OVLsdzT8r4uKHB0r5bkA
8TBVxAMh/oaI+JPv3y6L/ZbM/rO+tK9pfB+H+LWL+KUTB11jNOklnHEo4o7t
ai0hXv1EvJJrZbN9+oF36MSltjUJF2pJv73NR844O/vE7A5yPrIb8kmxyCfU
qdetLabi02xuaNHUWuom5JcUkV9o92APJmDkG5fIN7SjNNHojDtPsaY3i2xX
3YT8M1vkH1lXpnbdvM0Y0Pid4XmR/+U+3Frkf7mvxoj8L/fNpSL/c09PHr0l
711Qv0190DrWNNkl88Ka/rpS25lqnnL8qxhLUok87+T88dUuVkPZU/XeqNXX
SXejmkcub7/dFPb0e/b7TkOQpmMlwz7q+83Avb2DNL0qZR6cVzJgkyXYyfAH
zDPzQCuHY36V3Gdh51bx0TcapjkZ/ifzW03AFymhdU99N9Bu7sq/OONuy3P5
389uWBE/5LbU73xRT/AnTYeM0hRee+o9ac3EwK7mmEtS/yWi3pDnhSnrN/nr
+l9mxBueQ3wjfwX2v3lAb7WR+j516tD8RfEpCbK+/OTVOUtTLGnSXjlvP/ar
3bLOH7TCvtcYnM6hHR6uN0U21gWYX33f6hjimV/ed4WI+eR98Z/EfIT51O9s
z4l6kJCPMS/0Bb8D7xKhL3m/O1boh7BfIB/BXup78j8Ie8l7PLOwF2E/U78D
CRf+Q/AX9T19C+Evsi5fI+pxwn4Lv4Q/q+/dS4Q/yzwVIPyXsJ+r35FEi3ii
c5ZtL5kfxY96XzlSxI+s69eJ8wWhvlC/Ozks8oGsYzeK8wchXjEe8a7eb04W
8S7z8WsiH/MGzfUa2xEnh+yPGKmbVsXI70Eiv3N/aydziquST/cPOKnv9pDv
++b0MfRys7Fp50N6Rw739OS3HL5TsbYhoaed60PD/p4y6hb3dD5T7NCny/ok
W9QnhPrIX9RHtKfh8Kr4qU4anrbtF2NqFe2KHJ1k7FZIw3QbnzP3dZHRo+ci
/jxm8HFtSR2/9KpulG58IUd+uOtdTUcXTx72zc0GuklBu6JzHZdcjHpwnqgH
GfONFPNxcMuiAtsrpZTWyh5q31PDWN9frM9nLZnfxOsqZIs6c7VoecCIZIej
YxWdWLF7kqb5Q+6dlzxM988aGrgn/jtTzn127Ekdpdno4pVj7h0yZuYz6len
qF95wzud/2GZe4N1xeuGGWoucFAb29mGht2c0Hd6geOSnVH/9hX1L7846l4f
Qxc3bYlql6r3vcyvLarZq7/76Nwwb90mU8YVjoj/OMyelUGR96ZcduiZN1Q9
d7HhRjEtmBnWJ/hkuqy/LaL+JtjnGWEfwvNjxfOE+jxH1OeE+SaL+Qj1fpyo
9wn+MFz4A4GfVvAjnAN8REvwl+vCXwj8Nwv+BL5rBV8C3x6CL0G/S4R+CeeT
aeJ8QrDHq8IeBP89KfyXYL9UYT+CnTNES4iHqSIeCOehQeI8RPCfY8J/pH/O
FP5J8M+Vwj/leWu0OG8R/DVQ+CvF/GHPEf2s3+X9OuL7HZH/ZT/ulbQ7j3Yz
H3XQ82c+KnTs2y/9W57fcZ+iPXVabz3GGH810zNexpfM70/GF3XxjJf52/+w
/nfbe25Zd4c0/cfLhkK33O/C/nqsifX5erkP/BA5Zr2puDGvbz43Yq9+olve
33Q56+NrPlcr969eVmd1ws1aDqpZu8O4uVaOQ30aJ+pTPtGvTQfzvTqZB18P
2fuqoYuLIhq+nKTpVSDl2393aCdzzBX+IuyHptZ/NcqNej1D1OucY4jdo092
86ysPx8wBp/gw+2bR1oyG3nh/NFMnD8oeuYef026m3sPN95z6JNo6rIxcZa5
BXI8ziN9/DznEVp9+qMhhkEF3LD+8b7/K/3evGiwLvGM3AdxPnHu85xP5Pl/
qbgPoZkXfstooFI5HnygZ5yvpojzFX3cb9l/jMvcfG5Je7ftThZBX8j7OK/V
n/ac18gy6qvvTZF1Ms6hf9gF58PR4nxIB4O6DjC8XMvFIy78aEy9S58XdZjp
HJzPB8cVnm0odXGfi0l79b7XOXdWc9b2cfO844t3moovcCTntDUfdbPfd+9m
ajP388EbX/9gbFvP3SKPvGQwM4U0f269yaee32+9u411kp3CRN3BHXQTcx0V
dzkjPS9A804to34/K+p3bhb74xpLcTVvHrp2ZcqSMnmPGLGq3yHj/zxgyFsm
5OX0FtY8R0ytvPdM+HzHUF33WnKYf38UG3c5948+241tXfKesnbP0fCU/XU8
fOEz5bbWRbx8jG2UZr2Lr90PWGAvy+eymcN+1Q90cbXvqk+dUwoY+vQT+mTY
45qwB//FZ3C2NiCb2x1YMj+lxRV2pZ2YnRLa+B593cJ172jeeVS/nb6z07Tj
AsdZfyxPmOCmUx13jjAMypLn4wib32hd/zSGP34i/JHhb2976sxfOS7lm2Up
RQXSf3C/EijuV/hYr4Zp9jWN7+F9P9jwpm61m9pnf/SmLvEXBo694MGEeAkU
8UKQH/4I+T4T8hH43BZ8CHwOCj4Efct75Sf6vSj0S9BvmdAvwR5vCXtIvW0X
8U7QbxOhXyr1r73Z0HCMO79rJF3/K7Q13lKRcMFFo3468K0l6Srh/spX3F8R
8slXIp8Q/AXxAH+5JvxF+lFHkc8I/pom/FU+11PkN9J+vOgtXbt7dPZWWU3C
hMbvK4aL/CrjKVnEEyGeLot4ogtDJvQOjrBzq1Nj2pmXNvpNsMjHhHiziHij
rH9fekOXyNziU/LXNK+Xdg4V+ZoQj/tFPNLktLsOR8V+Ov96H3/Nc/XSrltF
PifEa7CIV5pXt9knsWk2tTw/vch2svF7io0i3xPiGecI3C+GiftFyj2R3Mcw
6DpZit/pGvyGW54vdor7Tsb5u5U4fzP4txH8Gefvr8T5m8HXR/BlnL9x3wd+
WYIf4/wdJ87fDD6tBR+GfFFCPvldQpK4P+WAuq3JxswC6pr37lWHqfH/qaPE
/S7PXtm3nTnmnvxuC/cLp8T9AsMfsoQ/yHvoWHH/y/lLU9qaz92T70Mq0/7t
tm0so+Due1ta/1DDQ9qt8DObH8j3G2WxBX7BBdW0ZlhWZ+vCxnvnVHFfzaO/
mtnS2r/mqffUE4uvzLcPeMApsZvu2XY13lPjuyDkzxUrQp+x/svV+P+bO6bb
Gxouy/esuH+6Lu6fGPGnE/HHK4Z+/rvtFbe8xw735AmHfH8HjPdsGI/z5KeT
7uzVl7vYsCxgafyQa/IeY4t430G1LY98Y8lu/J4E8sr/x3rCD3oGP+xn0O8U
oV/5/jJ2+I1hujk1BH1Db7B/F2F/+T1J7vl2UZYfXJSzMOd7S1IBh4g8w+U/
fRuoW13Gk5ttmeKsrebFGzMO6ZcXs/3DwdGWsDo+VrKglfVfxbRs2dpk/bw6
7jHT/Zkzykn9Zs/Zaoqt4rzI1bcdH5TTmoEhQZrmldwyeVPTxJoK/qvP2VhL
QDn3mFVcn/D3Ku40Y0Gafp6T8zz3kBU0cNTdd3Xjyzns/PYvUl6vo21R8Svj
fYsZ+nxf6JOP5X/3mzbzOxoWcHyDZe4lRr78UORLDhH1Kr9105qkt57leL/3
A3WJx+jVFTlWk+48t5g9tjJh+l0yvBR9x6E/KXEvgQnz9xfzE+T5t5CHsJ/H
if2cwKeD4EPw72jh3wR9RAt9UDdL5Jf25U5+8ZvaX4yrqgj6nij0Le2BvA/5
2wr5CfoaIPRFedcP/GoMLOfobyJfMLsr2BluemCLqKJ7s2v2Gxc8OicbipL1
/nW8xnOuLeZW53/rHnzyKr/fPWZJSotLnNWm8Gdjno2aTXt8P3RQ4lOe+6KD
hPH+YjxhPnFOLiasd1usJ+WJFPJQyMiIrcZ+pfR5i8d15UZpH62wD8E/Jgn/
IPjb/wp/o/8CrA7ABg==
                   "], {{
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[0.3], EdgeForm[None], 
                    GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxVm3f819MXx9/33iKJVKQhRSGjaBiZpbSQFFJIRvzsvUVk/4xskl32yM5K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                    "]], PolygonBox[CompressedData["
1:eJwtl3n8TkUYxe/MQyQJaVcoSUmbUlqVaN+0L1q0SFmSRJIQEVIfUckSKiJb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                    "]]}]}, {}, {}, {}, {}}, 
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwl1FWUllUUh/EXZpTFFSGNxIAo4Fo0gtSFXMKNKDX0AAul0UUrjUgj3TF0
Kl7QoXSHIEopKd2lCMpvLy6eefZ/n/POnPf79pm0jG4NumZJkiTDjzEpSfI5
juMXXMqaJGN5CnfkEziJy/I4nsqd+FecwhV5PE/jzvwbfsdVeQJP5y58Gt+q
z3AV/KU+y9f4A66KZuokNUlu8Gx00/sDf+IiLqAablq7xLf4Ms/h6tycs3j+
Ls/HPWSVW3AN6635DfkBL0RNvYdcSO8RL8I1vcd8Jc4Y74FauI4b8Z5YZn0q
L+dneNPzGXFmvZX8BX+J0eq2qKPuwNnte8l15Y9wF/OxAPPwg7VMTo2/gY3y
Ut7Eyzk7VmGbvJLXYDUe4GM0wB5r63g3T0RPrJc3YDi+wQj00s/hPLnV+9Qb
eT9v4md4iobop5fbvkNcTs6HNDkvN8Zh/WMooHeUJ6E/3pILx1ypT+IEKsjl
8RzF8DeK4p/47jHInm0xP7w1Zonf4ZKYrK7I7+JflMILtIp3snaEj+JQzIl8
ON6XD8b88P6YJT7Aw3gfn+c9fI738lDezWd5J5/hXTyEd8QM83b+GT9hsNyS
B3I+71tC3SLmEMXjrHppcU+sb447w1t4AKfz15zXniJx99Rvcx75K3VT9ZGY
TS6hV5CbIH+8u1yAD1pvxH05l14e9YH47Dmn3Ef9qbo3j+KRcQexN/bHGe3J
yT9ih973vDbmEE/wCR7FfYh7ghyoj3roYf+w+Mzi88FmeQV34X5xJvSJ3xd3
jT/j3jF36BlzK8/h9jwG78dsczZnase15ZuYiVmYjhX6M+JsXNi+p9xD7o6l
6incJt4Vi2MW5SU8mTP5PlI914rL6pXBAnWKXkv+UL7NBeU7/J5cGnPV8zAT
1/GfXlMeiXMxR/gOM+SuPDHOrP6f07kSV8ZF9cv4HnlE3Bv16JTX/4NfAcCN
yPU=
                    "]], LineBox[CompressedData["
1:eJwl0LFKQmEYgOHPrBBNV5cyBMe6hhIiG8qiS3AQSlCotrKuIMEbaGpWSN2C
lLqbalcL64mGl+f/vnN+OJxirXXaTETEoeZLEevLETPuJCPOmDY/cdvc4bke
nQe85o3aapr3WVFGJffSPNKaNs1ZHquqS+8P+coB3zjiFU84YY459y6cu3pR
3jzmsw48X1HBbpV3utXIs+CG/Y/znvOQC2XsGizb1Zkyf7OvXbsvfvLj71vU
Mz9wynfecyv5/69+AUrYJgM=
                    "]], 
                    LineBox[{771, 694, 837, 769, 864, 655, 869, 868, 867, 770,
                     1007, 695, 933, 696, 1008, 775, 870, 871, 872, 841, 866, 
                    865, 842, 701, 776, 1037, 624, 656, 896, 897, 1059, 623, 
                    934, 620, 1036, 771}]}}], {}}, {
                  InsetBox["\<\"\[Mu] = \"\>", {-1.8, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["0.2`", {-1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {InsetBox[
                   SubscriptBox["C", "J"], {1.4, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["\<\"=\"\>", {1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["4.58`", {1.7, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {
                  {PointSize[0.05], PointBox[{-0.2, 0}]}, 
                  {PointSize[0.0125], PointBox[{0.8, 0}]}}, 
                 {PointSize[0.007], PointBox[{0.4463998339305619, 0}], 
                  PointBox[{1.2771956561278897`, 0}], 
                  PointBox[{-1.0806611991222994`, 0}], 
                  PointBox[
                   NCache[{0.3, Rational[1, 2] 3^Rational[1, 2]}, {0.3, 
                    0.8660254037844386}]], 
                  PointBox[
                   NCache[{0.3, Rational[-1, 2] 3^Rational[1, 2]}, {
                    0.3, -0.8660254037844386}]]}},
                AspectRatio->1,
                Axes->{False, False},
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                Frame->{{True, True}, {True, True}},
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLines->{None, None},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None, "TransparentPolygonMesh" -> 
                  True, "AxesInFront" -> True},
                PlotRange->{{-2, 2}, {-2, 2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.02], 
                   Scaled[0.02]}, {
                   Scaled[0.02], 
                   Scaled[0.02]}},
                Ticks->{Automatic, Automatic}], 44->
               GraphicsBox[{{GraphicsComplexBox[CompressedData["
1:eJyFW3t4zFf6j7DaDdOqurTTbNB1Gaq0KhZVL+JWpTtSKo0aopVWI6TqlkhX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                   "], {{
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[0.3], EdgeForm[None], 
                    GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxVm3n818MWxj8zk6UVRYqs2WUpUqQiJVEiydYlu64l2bPckCxdLiKE7Ltk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                    "]], PolygonBox[CompressedData["
1:eJwtl3m8V1MUxe85570eSdKgyJOMkTFjmgxJpkrGPFMTEZqTsdIrSgqlqJCE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                    "]]}]}, {}, {}, {}, {}}, 
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwl1FW0VVUUh/ENF5BuqUFIKKgP8qgvgoCkoJSElAwJQUFCaelQkEYapRwD
lFBKukO6G+lSQGlQ6jcHD9/9/nPueffaZ521T9Hm7Wu1S5UkSQt/uqckSX1s
xdepk2Qb7+MePJwb8B/Yjv3qnjyCG/IO7MQBdS8eyR/xLuzGQfWeuC96oxH2
Rtbfx0VxSN7Ph7k4F0NN+QEf5bFoEnMxEz0cQQkcc+0YH+fjPI7/RME0SXKK
X9GbwKfxUK7FJbkuP+KzPBml5HOc0/+d5ylxH70LfIJP4SRexWkMwmAMxI9m
LuOxXI+H8Qz+mJujv1wfr8fn58Qa17m0+o1YA6MwOvYPYzEGl3DH3CSezxN5
QTwvP+QrPA0/YCqmx7PgKt5GGawwN4eX81C0wVz1z+iEzvgSbfXTea7U8ir5
l1gT83AD5dBeP4OZNbG/6nTIr07L72Kt/gZk11sf+4AvkFGdyfWNcuVYl7Po
beZC6pvIhn+QFf+iKr5y/bc4e/wrb+PcnAvfyYX5RdyKfcJt1EBP1zbxZqyP
dbEBPfTX8R5eE+eT13J3Xh1nllfGeeZV3I1XxBnn3+P883Luykt5GRZhCRaj
i3712E/O6vPllN9DNWRHEb0cvNX1BbyFF8Z3wFW4I2c2k0XeFJkzqTvIleR1
sZdcQC8DV8QLKKxOzxVQHu3MpddLI6+WU2JO/bn8jvwZd43njT3GSnUqzmcm
4dlYqjeDZ2EmrqMs/sY1/IWnZt7iN9FS/gYd5Q5YGO9QnH/+lFujFX5Sj+PG
3JJb4BMMj+8UDfUHIH+sy0+4Ab/GZ/AthmJInPdYky9yLs9+iZupm8Y7Effh
D7kfpobjfeH+PInP4H+5DvdFPnki/8e1+WU+wTnc+yTnUefF9/J4jMYR3NN7
n/vggHwQfTBK3Zj7Yox8nz/gIvwS9sp348zGbye2xJlLef57/Awf78MQ
                    "]], LineBox[CompressedData["
1:eJwl0L8uQwEUwOHTW+Yu/iTE0F2bSFnQNzBZJSUMVfR6CgaLzROgrU2q0dfB
QitYdKC0nxh++c45uXe4N797vJlmImJDvSRiaiLihYvZiAoz9gbn7afc1oW5
yQMe6kh79hKX9W1e8N4XV+1Dztp/uG5f0765wXtes8smayyzw19Neq/KM7WV
s9/xViue++SM24Cpva4b84em3d+55NbimxK3HRbdtjjiK69UMPf5xMe/b9Kl
/ZzPfOAJ57L//2oMdSYq9A==
                    "]], 
                    LineBox[{755, 683, 818, 753, 847, 647, 852, 851, 850, 754,
                     997, 684, 919, 685, 999, 759, 853, 854, 855, 822, 849, 
                    848, 823, 690, 760, 1028, 613, 648, 879, 880, 1051, 612, 
                    920, 609, 1027, 755}]}}], {}}, {
                  InsetBox["\<\"\[Mu] = \"\>", {-1.8, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["0.2`", {-1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {InsetBox[
                   SubscriptBox["C", "J"], {1.4, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["\<\"=\"\>", {1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["4.57`", {1.7, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {
                  {PointSize[0.05], PointBox[{-0.2, 0}]}, 
                  {PointSize[0.0125], PointBox[{0.8, 0}]}}, 
                 {PointSize[0.007], PointBox[{0.4463998339305619, 0}], 
                  PointBox[{1.2771956561278897`, 0}], 
                  PointBox[{-1.0806611991222994`, 0}], 
                  PointBox[
                   NCache[{0.3, Rational[1, 2] 3^Rational[1, 2]}, {0.3, 
                    0.8660254037844386}]], 
                  PointBox[
                   NCache[{0.3, Rational[-1, 2] 3^Rational[1, 2]}, {
                    0.3, -0.8660254037844386}]]}},
                AspectRatio->1,
                Axes->{False, False},
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                Frame->{{True, True}, {True, True}},
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLines->{None, None},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None, "TransparentPolygonMesh" -> 
                  True, "AxesInFront" -> True},
                PlotRange->{{-2, 2}, {-2, 2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.02], 
                   Scaled[0.02]}, {
                   Scaled[0.02], 
                   Scaled[0.02]}},
                Ticks->{Automatic, Automatic}], 45->
               GraphicsBox[{{GraphicsComplexBox[CompressedData["
1:eJyFW3t4zMfej6JatVoaabstSl2Wc5DSaBuXr4o6PQ7OSlO36nJo2pC6vNGS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                   "], {{
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[0.3], EdgeForm[None], 
                    GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxNmgf419MXxz/33lBJSGTUX5JZISmh0pC9peyV7C0lO3tFJInsiBARWSGr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                    "]], PolygonBox[CompressedData["
1:eJwtl3f0z1Ucxj/3XpQko5SGpCkpFUVFpSKRZDRwrF/IKFHkR5EidCgOGkpm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                    "]]}]}, {}, {}, {}, {}}, 
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwl1FmUzmUcwPH/zFg6J2RJogu640ZZshZdkH1pdDTJhS01hkGYoSjHHrIT
51AUQpayp1H2fZkpik72ypbs+9bnd7r4zPf3PO//3Z93nu/SOz07JUmSrv5k
pSVJc36gf2qS5OlW7amjtIVu5Ee2WffS0dpSf2IT262zdYy20s1sYYf1Vu1N
H1rHYzDA/nYtyU7zDt2lpbUUTcz/6B4dT1vz7lizj72Uibptf+zpAf1U8ylZ
KEkOall7k7SAS+am+oy20Cv6iz6r5ThkLuJ+h3UqP9v7VQ9qAfmUj/swkEHk
MsM1R7lqbqUf6Uxtp2/wgbk1z5nT9Yae0EpakSMMZwTD4jNnJL8zPt4T45jI
BP5gClOZzHSmcYyqvMByjz9Hl+kwOvG59Re8Q3fepbP9e3pNv2Wu+UvmcZrq
cb39h7pSn9RbWtzndFNfsq7FanMhe6t0BN15ZP++rqGeOVNTXLNOi1n/xWPz
GX2kf+rL9DQvjPOoC3RDPLamxecSz62F+ZtznOVV3nfbev2eNaxjLX3tr44z
qSvjvOqqOI/6XZxhXRHnOz6DOKu6PM68LtU8XabZukS/4WsWs4he9htqlqZ6
f6nmBrxCEufUXkq8Lrd/pet1vvbQ+vqeJq55qGt5wOP4frSO1uWeuYRr7mpt
69vxW7G+ozWta9At7qs34n1xnfvWXbWadtHhZMZzsiLObHwXHueKzrK3RGfE
+eUzTvFinFdOcpzLrqmileloHkq3eB7mmydphr6tHXiL2dajtZ1m6Ju0Zygf
09b+hzxhnqXXtI1W0EMMZkj8luJ1xbX6mxb12o9ouvXr5DCAlvYGMY1+8RvR
/vG7id81l83NdWA8RvyO9F9tpk/rfi3ssQ/E/wTrXJ3ARMaymwv2G2sOO827
4qzxiXWbOI+MM1/U1+L706fYYj6vjeK1sSHOQtr//4f/A8NCxR4=
                    "]], LineBox[CompressedData["
1:eJwl0MtKQlEUgOFVp0HpqHkKUk66vEmTIgPBLvQA+gI1aOYz2HUiFvY6GWRG
OUiodBIKzfo2DX6+tffh7H04pZPGbn0uIrb1Mh+xuBDR50oWsccpr5jjGStq
mq9Z44EOVbVe5Zq+zMvO+eS69Tfz1mNuWm+kd8wX7LLFB17yiFu850S/6Q6e
q6PMOXdsq+zZR/o2eyMep/d1ax5qyf47S/Zu+KaZeZ9F7vCHr+lbVDAP+MSe
Kmqlu/nMR56mc7P/f/UHITEqFA==
                    "]], 
                    LineBox[{741, 673, 802, 739, 833, 638, 838, 837, 836, 740,
                     985, 674, 905, 675, 987, 744, 839, 840, 841, 806, 835, 
                    834, 807, 678, 745, 1016, 603, 639, 865, 866, 1039, 602, 
                    906, 599, 1015, 741}]}}], {}}, {
                  InsetBox["\<\"\[Mu] = \"\>", {-1.8, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["0.2`", {-1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {InsetBox[
                   SubscriptBox["C", "J"], {1.4, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["\<\"=\"\>", {1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["4.56`", {1.7, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {
                  {PointSize[0.05], PointBox[{-0.2, 0}]}, 
                  {PointSize[0.0125], PointBox[{0.8, 0}]}}, 
                 {PointSize[0.007], PointBox[{0.4463998339305619, 0}], 
                  PointBox[{1.2771956561278897`, 0}], 
                  PointBox[{-1.0806611991222994`, 0}], 
                  PointBox[
                   NCache[{0.3, Rational[1, 2] 3^Rational[1, 2]}, {0.3, 
                    0.8660254037844386}]], 
                  PointBox[
                   NCache[{0.3, Rational[-1, 2] 3^Rational[1, 2]}, {
                    0.3, -0.8660254037844386}]]}},
                AspectRatio->1,
                Axes->{False, False},
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                Frame->{{True, True}, {True, True}},
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLines->{None, None},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None, "TransparentPolygonMesh" -> 
                  True, "AxesInFront" -> True},
                PlotRange->{{-2, 2}, {-2, 2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.02], 
                   Scaled[0.02]}, {
                   Scaled[0.02], 
                   Scaled[0.02]}},
                Ticks->{Automatic, Automatic}], 46->
               GraphicsBox[{{GraphicsComplexBox[CompressedData["
1:eJyFm3l0lEW6xgG9XFDioIOKbRRZbTZBhmYzUmBDZAJixAUQbBYhZggCYsAE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                   "], {{
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[0.3], EdgeForm[None], 
                    GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxNmwf811MXx7/33qSBJHuVPUoUGoqirMhIsh4zIVRm5kPhobJXZnjKJnuV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                    "]], PolygonBox[CompressedData["
1:eJwtlwnYjkUYhd+Z+aXVkhYKJSqltGtFaaE9S4hIIkIoSoRky3apLJEWsm9F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                    "]]}]}, {}, {}, {}, {}}, 
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwl1FWQVmUcwOGzu8CM0iogXMBwBTcgKo230jWUXDBDSNfSnTKEdDdIqeSC
9NKtdIeE0qACw9BIPv/h4rfP+77n7H7nO+85W7RFer3OKUmSNPOjTVqSVNYm
9U5Nks08wLb8kVWYqS363bwdR7Mqt2qb/jBvzzGsxu3aoYPmO9lBHVVdu9TH
+m7m1iHjPTzMvMyjqsb/8CgnqKbx/riu+Ky4Dn2iY44d5HEe4kSeUq4sSXKS
n1r7TKeN/4vPZz7m1znj3M47ywLm55nV/AJn6Ji1P3k4rkNH9Hl8lnqop7pr
tnMu675xLfbjXNZhXQ00rq1CxvX4kNdZhIV1RoM1RIP0g4bG9WlU7IFGxr2N
+64LGq8JGqdJ8b3jWlVCJbXW35/F3zhczTTbfI6aq4W+j7H1Z3zK9ZprPF/z
9Je+VCvrL7mRH/Elc7hPL/i1eVu+5mZ+HNcaz4jeGL9mWZaJ/TdO/N4WZo97
oHfGf/Oarqq80q0tiueHC+NZYhamxf2Iz2ZW3dAt3dQ3sR/xHbghvrfWxX2I
vbK+hvuYwb1cHXvHVdzDFdzNlezG5fGccil3chm78hf+qsX6WUvUxXoldmaK
75dqXFEVlCivtRRuc/wnbuUCdmK5eDf4jm+ZGfdNb83bszTb8BVfcZP+j8xb
8yu25As+54bYTz2P/WWp2GuOUKs4N+6L8ZPYA9f1mNOsZXAyp2qKrugLXdJl
XdQj5xRnMTUxHhbPlXFTLTUey8b8jo3UUAviPNZngzDeAQ1Q/3g/rA9Stnjm
+IB1WJAn1Ed91SueXeu941rifNd+Kd4r81qxZ7E/qmltgGYq3XwWu3A6z+ie
cQ3211Sl+TvTOEUn9K/j1eId1iSlOj6Z43REdxyvzL7aG89U7KPGmteIZyDe
TeO7rMKczKX9xrf5LXtpY+xf2of/ve8BmNTEvQ==
                    "]], LineBox[CompressedData["
1:eJwl0E0uA0AYBuBP2wRd2auE1kY5ik0F8ddKHKBO0NTCGbDStLppSrgK1lSD
BQlFYt9n0sWb5/1mkpnJLB0db9SnImJdBpmI6VzEM+ezEZv8ZZszPOGWnOod
7nBX9pLmIkvyrc8554sr5hHz5h+umstS0895yzPe8YKHXONNulv+9Wq6U/qS
c841e7Js74Oz1j55YN6Xrv6e3mz9jYvWrvgqf/o2F1jhiEO2pKC/8JEPaV8u
zQ0+8Z7N9EfZyV+NASgxKiI=
                    "]], 
                    LineBox[{744, 677, 801, 742, 829, 641, 834, 833, 832, 743,
                     981, 678, 901, 679, 983, 747, 835, 836, 837, 805, 831, 
                    830, 806, 682, 748, 1012, 603, 642, 861, 862, 1037, 602, 
                    902, 599, 1011, 744}]}}], {}}, {
                  InsetBox["\<\"\[Mu] = \"\>", {-1.8, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["0.2`", {-1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {InsetBox[
                   SubscriptBox["C", "J"], {1.4, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["\<\"=\"\>", {1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["4.55`", {1.7, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {
                  {PointSize[0.05], PointBox[{-0.2, 0}]}, 
                  {PointSize[0.0125], PointBox[{0.8, 0}]}}, 
                 {PointSize[0.007], PointBox[{0.4463998339305619, 0}], 
                  PointBox[{1.2771956561278897`, 0}], 
                  PointBox[{-1.0806611991222994`, 0}], 
                  PointBox[
                   NCache[{0.3, Rational[1, 2] 3^Rational[1, 2]}, {0.3, 
                    0.8660254037844386}]], 
                  PointBox[
                   NCache[{0.3, Rational[-1, 2] 3^Rational[1, 2]}, {
                    0.3, -0.8660254037844386}]]}},
                AspectRatio->1,
                Axes->{False, False},
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                Frame->{{True, True}, {True, True}},
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLines->{None, None},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None, "TransparentPolygonMesh" -> 
                  True, "AxesInFront" -> True},
                PlotRange->{{-2, 2}, {-2, 2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.02], 
                   Scaled[0.02]}, {
                   Scaled[0.02], 
                   Scaled[0.02]}},
                Ticks->{Automatic, Automatic}], 47->
               GraphicsBox[{{GraphicsComplexBox[CompressedData["
1:eJyFWwt0jEfYVvyh2MqJW61UVUWXUKHWpcWrFtVoSVMVVBcVSqOoS1lN61LW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                   "], {{
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[0.3], EdgeForm[None], 
                    GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxNmnf819MXx9/33pLKHg2zCFEZJUm2bD9SFNkjQmQWEjJDJKvISPZIZYSQ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                    "]], PolygonBox[CompressedData["
1:eJwtl3n01VMUxd89txIW+VFCmTLLkCGikNVoSIk0SxGpDJU0UimJylChgQZz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                    "]]}]}, {}, {}, {}, {}}, 
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwl1ElUV1UcwPEX0DwtaleLaB7XDYJghLHpnKAgBCxAK2OW6iQkqZWVFU3Y
qJXaIBGSKTRSQTSJDdhEo6dVSIQEBQ3Syc/vtPjyuffy5/Deu/f90yvrC+oO
SJKkzI/i1CQ5V+2qTkmSF9ihBbrZ/Dy+qE71mpdwOc/nFnXpLfNStvACvqSt
etv8ZZZpoeZom2qsb+fBese4m308lIdorvF3fJerlGn8ql7TG3pdh2nA797k
e+zlrfxQ/xl/wMP5Ef/gDt6hj5WkJclOHmH9E07zU96tPuP+uKe4trgHHRnX
oqt1jRar1Wd36UfjC1nN+5nNeVpqnKOjjS/mTxzmsTwmrk8N8TnV63o1xvWq
Sc1aFs869kGDWqGVuiXuVau0UycoXZvjHvg8b1Kh7jG/VwW6TJeryPrPHIv9
Vmtcu+7TZzpZJdZHY++ZwgnOci9Pjf3kr3EGmMrf+S+neDrLORFngWn8QjPG
Q/xcu3SmFllrYzcf4nbu0z9q0oHWZvklv9ZXOkfXWXsu7lWb9Kye0RLrG+Oc
8Ok4K9zAa/lUnCGuj/PEJ2M/uY6v8HH28InYaz7Kx7RWj+jh2HvrZ7OSv/Fv
btNZxn/Gs3K2/opzrwfiPeCDrOAZvIp7Oc2uOJsaN7+Sp8W7wjFOsjP+h34x
L+UpXMA9HGdH7IFGzIt5Eq/gMhUZF6o9/j6eqfFovAPxnHgbV+v2OPs6Md4F
jcQ7wj08nscp3/hG5RtfqnXGLbyEeXG+NV9t5jcwj7m8SDmqVY1yrTfGOYln
o93xGR7FgdhTVcVexVm0viTOI2c4xCzOjTMTz1/zrDXEGVd5nHNWcA0H9YNx
Nut1p6bM7+Jqva/vzbNYF89Dk/E8uEL9+sY8g7XqiTMS+xTvn3lG7GW8j8bf
MpMHsTm+kzRsPIdV2hz7kvr/d+1+bmTEow==
                    "]], 
                    LineBox[{724, 1015, 723, 784, 585, 993, 660, 768, 769, 
                    586, 885, 661, 841, 842, 843, 590, 791, 668, 739, 1025, 
                    738, 797, 740, 1018, 741, 671, 798, 595, 904, 676, 903, 
                    677, 905, 596, 799, 674, 742, 997, 594, 630, 672, 1011, 
                    673, 669, 792, 734, 1017, 735, 845, 844, 663, 730, 1016, 
                    729, 789, 662, 728, 994, 587, 786, 582, 991, 726, 658, 
                    785, 725, 965, 964, 834, 657, 878, 722, 767, 766, 724}], 
                    LineBox[{733, 664, 790, 731, 814, 627, 819, 818, 817, 732,
                     967, 665, 886, 666, 969, 736, 820, 821, 822, 793, 816, 
                    815, 794, 670, 737, 996, 592, 628, 846, 847, 1022, 591, 
                    887, 588, 995, 733}]}}], {}}, {
                  InsetBox["\<\"\[Mu] = \"\>", {-1.8, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["0.2`", {-1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {InsetBox[
                   SubscriptBox["C", "J"], {1.4, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["\<\"=\"\>", {1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["4.54`", {1.7, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {
                  {PointSize[0.05], PointBox[{-0.2, 0}]}, 
                  {PointSize[0.0125], PointBox[{0.8, 0}]}}, 
                 {PointSize[0.007], PointBox[{0.4463998339305619, 0}], 
                  PointBox[{1.2771956561278897`, 0}], 
                  PointBox[{-1.0806611991222994`, 0}], 
                  PointBox[
                   NCache[{0.3, Rational[1, 2] 3^Rational[1, 2]}, {0.3, 
                    0.8660254037844386}]], 
                  PointBox[
                   NCache[{0.3, Rational[-1, 2] 3^Rational[1, 2]}, {
                    0.3, -0.8660254037844386}]]}},
                AspectRatio->1,
                Axes->{False, False},
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                Frame->{{True, True}, {True, True}},
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLines->{None, None},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None, "TransparentPolygonMesh" -> 
                  True, "AxesInFront" -> True},
                PlotRange->{{-2, 2}, {-2, 2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.02], 
                   Scaled[0.02]}, {
                   Scaled[0.02], 
                   Scaled[0.02]}},
                Ticks->{Automatic, Automatic}], 48->
               GraphicsBox[{{GraphicsComplexBox[CompressedData["
1:eJx1m3l8jNf+x1MUzTWkWkuHWnJxU62lSyhXHdfYqrjTNFTRsfRSV7RKq+6o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                   "], {{
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[0.3], EdgeForm[None], 
                    GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxNmwf811MXx7/33tKyVcqIqEcplZGyqayEispMPLKze8gsGSkzm2xCRnYi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                    "]], PolygonBox[CompressedData["
1:eJwtl3n0j0UYxd+ZoUXJVjqkTiqK0qJFOGghEulQtsiSPSXRTwhF2bei7IQW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                    "]]}]}, {}, {}, {}, {}}, 
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwl1Fm0j2UUx/GXIxUX3eWi0VRdI5kSWl2k+RQhcyHiYBElCSENmksTMkuD
KVOGTjlUypi5jA2ijKVuKj6/5eJ7vnvv/7Oe9333s59Ts3v/0rJKRVF08Wd6
SVEsrFwUf6Mnpsqn4R4MkdfjWZiNRfJSHsr1eQ4+wKfye/kxbsBz8SE+xke4
D21wPT5BL+vmcQkWi+fzEl7Aj3MVbsY/8nIejhvynKzH0qzHBfjMb8t4BS/n
J3k1iipFsYqrqn3OZ7icR2ENKvn9S75QvSLfz2t5LFaJV2dvrMzeuCj7oDse
RDc8Y+3X2C9uwQ/zs9yEm6KvuCWqiatjU57NG7mCL8kz0Q9lWY8B6I+v0v/0
Go+mL+kvvsk3YgSGYySewnpchlJ7H+Yp/C8G5WwwPu+G23A77si5qP/GP+Xc
8Zz4BTyfd8SVaKf+O0/n/7J3LP+Vr+YH+DjP5P+zNpYf5VrcmU9lfvgstoqP
8ybegs2og65qr2Zu+JXMEP+FP3NW8gK7cUa+g3dhJ65DD7Up/D7ew2RMwkPq
7/ICfpvn8zs5P36L5/GbmUmemLPlNzK3/Fpml1/PWfM1fC1Oi7fzKa7L23I+
4u/57twH8ct8gkvM2EmegwlqL+FFdJHX5k58ko/xLPyBE/KOXJM78DE+wjNy
Vlkjb89X8f18lH/hafgZR+Rt+YrcOR6Mu8R3pj/iQ5kL8UEek37lTvDTGI0N
uBzfYb/fvuUDXIMvzT7igWgtvhVPYBhaZ9ZzD3ATJmQd38JlaC6+EX3QGzer
9cM/mTscUGvFF3M5eqJXzhDj1XvwuqzP3eDG3Chzk37mmWqPYBw6Zu7SX4yR
f4F94ubcB6MzV/lmHomV2Jv3494YgdO5VzwMS7FH3jh3HAvT4/QfDbEIy9R/
4CbcPn3hdrkfOUc0lVfmGbkrJef/754DYxbFeA==
                    "]], 
                    LineBox[{715, 1016, 714, 780, 582, 994, 654, 762, 763, 
                    583, 882, 655, 834, 835, 836, 587, 786, 661, 731, 1026, 
                    730, 792, 732, 1019, 733, 664, 793, 592, 902, 669, 901, 
                    670, 903, 593, 794, 667, 734, 998, 591, 626, 665, 1012, 
                    666, 662, 787, 726, 1018, 727, 838, 837, 657, 722, 1017, 
                    721, 784, 656, 720, 995, 584, 782, 580, 993, 717, 652, 
                    781, 716, 962, 961, 828, 651, 875, 713, 761, 760, 715}], 
                    LineBox[{725, 658, 785, 723, 809, 623, 814, 813, 812, 724,
                     966, 659, 883, 660, 968, 728, 815, 816, 817, 788, 811, 
                    810, 789, 663, 729, 997, 589, 624, 839, 840, 1023, 588, 
                    884, 585, 996, 725}]}}], {}}, {
                  InsetBox["\<\"\[Mu] = \"\>", {-1.8, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["0.2`", {-1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {InsetBox[
                   SubscriptBox["C", "J"], {1.4, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["\<\"=\"\>", {1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["4.53`", {1.7, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {
                  {PointSize[0.05], PointBox[{-0.2, 0}]}, 
                  {PointSize[0.0125], PointBox[{0.8, 0}]}}, 
                 {PointSize[0.007], PointBox[{0.4463998339305619, 0}], 
                  PointBox[{1.2771956561278897`, 0}], 
                  PointBox[{-1.0806611991222994`, 0}], 
                  PointBox[
                   NCache[{0.3, Rational[1, 2] 3^Rational[1, 2]}, {0.3, 
                    0.8660254037844386}]], 
                  PointBox[
                   NCache[{0.3, Rational[-1, 2] 3^Rational[1, 2]}, {
                    0.3, -0.8660254037844386}]]}},
                AspectRatio->1,
                Axes->{False, False},
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                Frame->{{True, True}, {True, True}},
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLines->{None, None},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None, "TransparentPolygonMesh" -> 
                  True, "AxesInFront" -> True},
                PlotRange->{{-2, 2}, {-2, 2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.02], 
                   Scaled[0.02]}, {
                   Scaled[0.02], 
                   Scaled[0.02]}},
                Ticks->{Automatic, Automatic}], 49->
               GraphicsBox[{{GraphicsComplexBox[CompressedData["
1:eJx1W3l408W6Li6APUQrFoVcZBHEyC40LLXyAeFUBMRQkU0MIKA9hkWhVILF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                   "], {{
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[0.3], EdgeForm[None], 
                    GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxNm3f819MXx9/33kSKrFRERUUqs6yMImSFaBihYZTUzyxbRvbee4RkR6TM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                    "]], PolygonBox[CompressedData["
1:eJwtlncYz1UYxb/3XtKQ0nqerBIJlRVlVUollb1SRMhI9gwpe89ERmhrkFHS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                    "]]}]}, {}, {}, {}, {}}, 
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwl1FWwVlUYgOGfuJMLumGGO0IBQcqhpFPhICVdIkMj3SUiId0dSnenSjfc
0N0pDAjS4vMNFw/vt9Y5w+y99t4nV8vOSZ2SJRKJRv6ZkSKRWJY8kXhEE6ZZ
T6cSna1z62zmsNy6snbRPDqXeaywrqJdNa/OZwGLWMhL+69YyWHr/PqaQtSy
rs03dLdO0sJ6TNdoDz41/04z8xJ9o2tZal6ny7SnbuSpeYO+ZRN3rDdrX7bx
zHqrvmM7d6136EBWmVfHfbIy7ov39tdoQ76jAYPt7eakuZg206FaQAvSylyc
DySs9+sG3RfXqCnZRGvaxO/Tlu/ZQqc4ezrGmcZ5s40ecZ9xTvSmF9tJTVX/
91mdFvdIe6ox2N4QylCWr6hu/5ye1xkMNQ9nGLtJF8/D/kWdpf9wmcfWlzSD
JumVeC/0Odd5Yn1NM2nd2Iv3Q1+wx3xL/9C/+JMscZ72xuhYRsf7Yv2QBxyy
PkhFRvELB+J8/Kw+N8z3NafmoLF5qi7VybpEp2gjnRTvkE7Q33RiPE8dr4v1
13hfdVw8a82m2bln3q93NWs8w3gu5r1aId5z80i9Heegd3Q+P5l/ZgT1rDPr
t3pNb+rcuH6uWtfRjPEdxDnrVZ0d58sl61qaXr/WC3pRZ8bMeeuamlZraAfK
m8sxPZ4zf5vPan+drH20H33ZRRp2ctrPdugZTaWfxNmb21HaXIof6Rbvkb22
FDF/QTt+oKS9NhQ2F6IFzfnSXuu4FoZxyl4J/S++ZXMTmsazivfVXuO4Jr0X
16j59TPqx3lS1F5LBlEn3rc4XwZYb+GEuYi2oB+3rPvHvbOe43Hd2pxe3Ixv
SrvF3wGOWBfQpiyO74tq5Iv3h9X2j2pBrRHnotXjGcXz4HPrf+M5xTeU4uPf
2f8BTqPANg==
                    "]], 
                    LineBox[{705, 1001, 704, 769, 573, 978, 646, 752, 753, 
                    574, 874, 647, 822, 823, 824, 578, 775, 653, 721, 1011, 
                    720, 781, 722, 1004, 723, 656, 782, 583, 894, 661, 893, 
                    662, 895, 584, 783, 659, 724, 982, 582, 618, 657, 997, 
                    658, 654, 776, 716, 1003, 717, 826, 825, 649, 712, 1002, 
                    711, 773, 648, 710, 979, 575, 771, 571, 977, 707, 645, 
                    770, 706, 946, 945, 817, 644, 866, 703, 751, 750, 705}], 
                    LineBox[{715, 650, 774, 713, 799, 614, 804, 803, 802, 714,
                     950, 651, 875, 652, 952, 718, 805, 806, 807, 777, 801, 
                    800, 778, 655, 719, 981, 580, 616, 827, 828, 1008, 579, 
                    876, 576, 980, 715}]}}], {}}, {
                  InsetBox["\<\"\[Mu] = \"\>", {-1.8, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["0.2`", {-1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {InsetBox[
                   SubscriptBox["C", "J"], {1.4, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["\<\"=\"\>", {1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["4.52`", {1.7, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {
                  {PointSize[0.05], PointBox[{-0.2, 0}]}, 
                  {PointSize[0.0125], PointBox[{0.8, 0}]}}, 
                 {PointSize[0.007], PointBox[{0.4463998339305619, 0}], 
                  PointBox[{1.2771956561278897`, 0}], 
                  PointBox[{-1.0806611991222994`, 0}], 
                  PointBox[
                   NCache[{0.3, Rational[1, 2] 3^Rational[1, 2]}, {0.3, 
                    0.8660254037844386}]], 
                  PointBox[
                   NCache[{0.3, Rational[-1, 2] 3^Rational[1, 2]}, {
                    0.3, -0.8660254037844386}]]}},
                AspectRatio->1,
                Axes->{False, False},
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                Frame->{{True, True}, {True, True}},
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLines->{None, None},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None, "TransparentPolygonMesh" -> 
                  True, "AxesInFront" -> True},
                PlotRange->{{-2, 2}, {-2, 2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.02], 
                   Scaled[0.02]}, {
                   Scaled[0.02], 
                   Scaled[0.02]}},
                Ticks->{Automatic, Automatic}], 50->
               GraphicsBox[{{GraphicsComplexBox[CompressedData["
1:eJx1W3t8jFf6jyp1G+JuZ9NQpZ1NKVtCqXrUrDbuU6XS1I5bpWqQNLGtUbU2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                   "], {{
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[0.3], EdgeForm[None], 
                    GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxNm3f819MXx9/33qisMjIrUiQiOyNCEpJCZUZl7y1b2SGyKSUlySxli0jG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                    "]], PolygonBox[CompressedData["
1:eJwtlgf0z1UYxr/33kJJUapzaFFERsJByWjg2CMJoWFFZllFhZKdvYWKhmwp
KonWQdlUZEVRRjS00+c5j3P+z/k/z73fe7+/773v+7xvoYe7N+kWsyzbBc4D
SxHrU5bNDVl2Cv0TfCtjw+C5+f8+KMvYvcwXAovQfUBH+LVgAfxT5l+CH2PN
1fBrQAX0d+gOzFdEN0c/gu6Nbp689iT6Pu2dzDswNgxeC+SDPwGehz8H8sL7
ga6sr4l+GL6MNdPRQ5LnaoIf0Fdpj+DfcAu6WfLe14BR6K7obvDu4En4E2Ac
e/VCXw8vDHLB7wanef4U+Iv5Iuh5zLWOPrv66IHoyejc8DLgMPxrxtbDLw9+
12jGegS/82P0R6AA/FbQlLk96E3w3ezZGP0V+jP0JvRn6M3oxeiz6G3Rd6S7
iYzlg0+E54RfBB5HPwYG8exj6PHM7Ufvgg9nbAO6EPo2dHGtgY9l7Pzgbx4C
b5f8rX/zfF14PVAbzV9WFV4FtEK0FsRBceaaot+AP8AeF+tb0IvRi5L3Koqu
wtwm9EJ4G8ZGwkeAPfD+jNVhfjC6j+4O9Ib3Ar2ZfxC9jvnD6EPBdzId3pKx
I/ARjL2LvgzUgE8Dh5g7pviC5we/o2ejR8KrghnwmWA4/Ch71IG/AJ4KvqOj
PP8SGAAvD/bDf2T+eHCMNoY3Be3hx1n/PfPvoWegZwbnSunks1DOzIHPAgWD
f8M0+GvRv12/oSe8BGN14W3BGPSF6JLwBG5SroFRwXcyET4hOdcGo8cqlsEz
ikXFAOtLJsdqO70TnSv57gPoq9xJjn3FzB7mf0D/iL4YjEPnTY7tHPo98FcY
Gxj8jinoFujvWfs8ujP8zuS7GszYQ/A24Dd4Z+Wzcic5Fv5hrB56aHKulwM1
4NMY6xuc43rXiehc0TurMV9de8KfYv2z8LuSf6tipq28QX6T2XM2RcesYlVn
+Ci8c7IXtZQnae9krhirDL8dlED/l/ldx8HZ4HdW4Pn/QHX4dWC14hXcAS+s
HIV/AGplHnuatZN0h/CyYKHOJvksJur8mBuUnLvykBXwzYyVCvaMUvIeUA1+
FfgD/mc0lweViY5pxfIJdCV40JmgbwA5FdvR3lFMniPzZ+xO+J/QQegHkr1d
d3S/zgL8DO/EWDHFSrIX6jeVgr8uz4A3BAdYvwu9Fn4ZaC9/it5bd6BY2o1e
mjmm9uquo2vFtuBc2hftdcqpn+G/gBvh/2bO3W+jvVE5fAK9DF0AnYP/q+Rt
yrHgnD+JfgddjPlc/L9HaxnbGOwxXaI9Rt5SWTHOXJ7kWNUe8uI5zF8R7Mny
3mo6o8weLK+ZytjQYM+ZgVZBvT24RqmWlkNfkrmmTkbPi86NIcHeNzT62+SB
G9Dl0QXRrymm0Ncme1Gl4N/+XXQt0Td8gf44OnfmK0ZU36KfrRKci5N45tng
nFTs3qX6kzmGt8srGTsSXON1N/mTa6fuaDR8HZgd7IER/qm+OTimlqJzgI48
OwW9BP5JNJ8cHFuKccW2Yky1+EN5XnBNFu/O8y8Gj22EL0+uxTeBN+FLGJsA
Hw8WoPsqpjKPrVEtAlcG77Ea/n6y18lz1YuUVj3L3JMcQq9Bn0EfRDeCf6kz
1N1mvjt5kLxHd6iz2RHtdTqjfaoF0b3RjuBaOiHai1VTD6BXoE/rLNEN4Dv1
TvjazLVqbXStU83agv482nuXgQHJNUu1qjc4KK0c4Pl9yjF0o+Rc0ze9Ff1O
vUs5sFW5Ge2FKxjbpruMrvUr0W9Hx5hiSzl9gerbud5BHrcleg+tVQ/QBT4s
2vuUgx1016BL8J2/Gh3TimXlQPXob9K3KMbUK96S3AuoZxzIfItkL1GPcLNq
CWgS/I0jmF8f7U1dQSd5s+pR5nfOZW58cm1TTKsWD0/uFVSTp6J/jc7lPMGx
q5xQLiiGv4HvUIzALwW10dt1xsE93xn5dXKtVs73130n34U8W16uGFLsyNPV
++g367eqByqKLpIcu+qpVLu+jvZ61bDK0TmrXJWH7Iy+I92NerYe8J7JvZq+
+WX4GzwzOrjGK/eUY8ot5eBJdKvoXkw9hJ6tn9wraM18dIPkWj8m2JsbRsei
PFrfrjPTWekMFkfnnHJNPduq6BhU7MlDlSsHo71dOaPetkl07qjHbRtdE1UL
dafqXWdF91rqYZULe6PPXjmhu6gf3bvrTlTb1KOrN1eNWxnt4bnO5VS76Jqm
WtYMlJNfJnPldL/omqJaIs9Vba4YXYtVo1WrFqKvDq5Z6q1eUQ4E91jLo2tK
jnMeMyA655Xr8uS5yWeqs9SaJorN6F5Pe96TXINVe9UDvgwfldwryqP+B/vs
t8o=
                    "]]}]}, {}, {}, {}, {}}, 
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwl1FV01nUYwPEXOIc7uEAECUFvpZtxvKGlZdRoNunO0SFdBj0B6c6Jk0a6
uVPZGI1BxwWggMTnOVx8+D7Pj3Pe7f3HPk0blDwwTyKRSPHPinyJxKa8icQj
OvGjvQlN+YzVrGGz/2umQ7SMrmUdW+zNdaiW1fV0Nm/Q//QFWzlpL6cvqURb
ezvaMMKeopX1jO7QdMrHz6WreYu+0p3xeeZM3aYj9Wcemnfp/2Rxw/6LjmVv
fD/7Hn3NPm7a9+tEKpgr8pW5Om+owXlnh3Qyb/mVP50d1ilUMVelu7kmecx5
OWXO1JP6k+aP342e9KIHfehNFoPjujKIYXEt2R3fjVGkM4bR8R0oRCOf/Ztm
6FP60zh+V2dTqEs9Lju7q7laWJfqNJ3OVJbZB9KUGfaZNOQLrju7p9e0qLbU
HF2hz+JacN9+S4tpa72sq/R5XC/zP3ogriMHKRH33dn3Oo/v4lmK+8cDTtiP
05hv+YZjcY3imeGK+b5+oqXpaF6my/mBjfal2kEzdIMujudSl2h7XRTPrs7X
hSwgxf6xluKe+aje1ZJ6JO6N+XBc93gfzHP1tj7RO7qaWeY5zI7n2l5cW2mu
/q0r+YtL9mT9SL/UbL0Z7148t1y0t9Ai2lz/0Ku6PL4/v9ub6YfaRAfQwFw/
rkF8PnfMOTpBF8V7oOMZF889H7CPi/F+aLYW1ALxOea+1DHXjveT4TE7602S
uSb96MvnznrGO2OuHu8RadRy1oPHTOWCsyRN6Ha6kUoXvnbeVQ/orXhWtLJW
ojOdqOYsjUm0j3sf95kJ9t2cM1fVVMZxLb6zjon3kLP2KtqNUVyNd0qHxd8S
TtnLaxc2xj2I+0M5NsXv7Py0VtDkuCbaMp77uM9UtP8b9znegXzv/7a+A2pK
vE4=
                    "]], 
                    LineBox[{706, 996, 705, 771, 573, 974, 647, 754, 755, 574,
                     876, 648, 826, 827, 828, 578, 777, 654, 722, 1007, 721, 
                    783, 723, 999, 724, 657, 784, 583, 896, 662, 895, 663, 
                    897, 584, 785, 660, 725, 978, 582, 619, 658, 991, 659, 
                    655, 778, 717, 998, 718, 830, 829, 650, 713, 997, 712, 
                    775, 649, 711, 975, 575, 773, 571, 973, 708, 646, 772, 
                    707, 943, 942, 821, 645, 868, 704, 753, 752, 706}], 
                    LineBox[{716, 651, 776, 714, 801, 615, 806, 805, 804, 715,
                     947, 652, 877, 653, 949, 719, 807, 808, 809, 779, 803, 
                    802, 780, 656, 720, 977, 580, 617, 831, 832, 1004, 579, 
                    878, 576, 976, 716}]}}], {}}, {
                  InsetBox["\<\"\[Mu] = \"\>", {-1.8, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["0.2`", {-1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {InsetBox[
                   SubscriptBox["C", "J"], {1.4, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["\<\"=\"\>", {1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["4.51`", {1.7, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {
                  {PointSize[0.05], PointBox[{-0.2, 0}]}, 
                  {PointSize[0.0125], PointBox[{0.8, 0}]}}, 
                 {PointSize[0.007], PointBox[{0.4463998339305619, 0}], 
                  PointBox[{1.2771956561278897`, 0}], 
                  PointBox[{-1.0806611991222994`, 0}], 
                  PointBox[
                   NCache[{0.3, Rational[1, 2] 3^Rational[1, 2]}, {0.3, 
                    0.8660254037844386}]], 
                  PointBox[
                   NCache[{0.3, Rational[-1, 2] 3^Rational[1, 2]}, {
                    0.3, -0.8660254037844386}]]}},
                AspectRatio->1,
                Axes->{False, False},
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                Frame->{{True, True}, {True, True}},
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLines->{None, None},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None, "TransparentPolygonMesh" -> 
                  True, "AxesInFront" -> True},
                PlotRange->{{-2, 2}, {-2, 2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.02], 
                   Scaled[0.02]}, {
                   Scaled[0.02], 
                   Scaled[0.02]}},
                Ticks->{Automatic, Automatic}], 51->
               GraphicsBox[{{GraphicsComplexBox[CompressedData["
1:eJx1W3l4jFf7DsVFany2tqRprY0Ra1tjjTx0UNQyfLavTcdWscSaxjKhqqrh
U7SYiqXUWEqVJLYghoeEtEktaYohNLFMJCWSGIlsM+bzm+M+87uOK/55r3vO
+57z3M9+zolmE2YNn1TVx8cn/xUfn/97tqn9+z923RVeEXqzOMbi5NIE39VR
jgSJrQITsL94X+Ku9fcbbYZ8bvev7i2N+jJeOnHqSZ05R+ILRwIamW23JcZ6
wFgPGOsBYz3gc2I+iSPFehJ3FPJIPH9cyRJrlIPTj20crskulvICQ15gyAsM
eYEhLzDkBYa8wJAXGPICQ17gz4W8EuMJHuoTfIDBBxh8gMEHGHyAwQcYfIDB
Bxh8gMEHGHyALwk+VJldVF7qE/yAwQ8Y/IDBDxj8gMEPGPyAwQ8Y/IDBDxj8
KosL1e9Uu6k81Sf4AoMvMPgCgy8w+AKDLzD4AoMvMPgCgy9wa8GXKssDapyp
fqraVeWtPsEfGPyBwR8Y/IHBHxj8gcEfGPyBwR8Y/IGRJ9W8p+YVNS5VP1bt
rPIGBl9g8AUGX2DwBQZfYPAFBl9g8AVeJvhSZXVFzftqXlXzkhrHqp+DHzD4
AUN+YMgPDPmBIX9ldVCtU2odUPOomnfUuIT8wJAfGPIDQ35gyA8M+Sur22pd
VeuWmvfVPKnmETWuVF7qE/yA4X/A8D9g8AcGf2DwBwb/yvoGtS6rdU2tA2qe
VPOGGleqH6p2VfWgPqEPYOgDGPoAhj6AoY/K+iS1D1HruFr31Lqg5kk1j4A/
MPirdlZ5AqtP8AcGf2DwBwb/yvostU9R67pa99Q6oOZJ8AUGX9WPVTuqvIDV
J/gCg29lfaPad6l9ilrH1bqm5n01j6p5SY1T1U9Vu6m81Cf4VdY3qn2W2oeo
dVmtW2odUPOqmmfUOFP9TrWLygPyqn2R2ieodVStS2qeV/OeGvdqHABD3srq
tloH1bqi5tm7nvEMzvA8yzldYAJO9chTyEs8cpRwK8/3dvk++AM3EePy+2Tx
PeH7lp7xIvlsKp4EjPew7iKBSZXjb8/8D+Q4MPIlMOSA3NcEJpUH9IBxYPX5
j+eZKrGP599pKzDmxXvAeO8P8TthHPoCvirklhj6UzHmw/yYV31ifmB8Dwy5
YXfMCwx58D78D7gyv1F5YVz2jS8w9K1ifA97Qw5g8ID9MY64AMY43lf9Tn2q
fqeuo/qR6jeV8VDfR1+H94GRX6BH5ANg5ANg6AN5CnIC4z01b6nxgTiGnOq+
BHLDfqq/43f4hdpHqP6u1l3VvzGO+ZHHMD8w5gPG92rfovqr2v+pdqtM78gv
qj+CB/Sv9iOqXlV/QD7Guqo/YRxyYLzapB1jHH7l3NEj1z98wVO3suk9D69z
fKDu52f9UiuonUeeTBp+4s+ClLBSWuqZL0/+jvd6CswHBWaMA48S3/NK8T1j
PmAfIQ9BHnyHedV1Mk8t+s3tLpDyQv6GAhPGgVW5wF8r1iOsDwx5wVeVA34H
OwMjHpEPMQ6McdWvgDGOOFPrVmV+BIxx6Pe+0EOlcqo8VDnVvA6MfgD4rMf/
0mib5719lfICfv2k5z0ea9UH6k0uhp2AIz391F3pB+ECSzvCTrAj7AW+eA/z
QB7ELcajPPqzSazmZegHcQQMvuCB+IM+IC/GgaEf+CfGgTGO9TEf1gfGOPSJ
cWD4rer/kAP6wrrwF+DK+iTZT76IU8QN5kV8qHVUrbNq3EGvlekdcR4i/OMl
Pah6gl7xPvQKDD1VpkfoDe8j/uHHkAf+iroDjPWAUVeAoT+Zh1/kfcQz7AA7
4Yn6DHuqdQH+DTvAv4Hh3/AP8MD6wFgfvIDBA+ur5w2YF7xgd8iv7nPhH6of
Im4hN3gCY11g6AX6Qx7AuujP0Mdhfwk8JH7sUYPxCVeM7/i2SVMsf8d32G8D
/6Kpstxifcrbfb8bpI19zGpfDD0Bwx9gD/Qnaj8kz1Ve8E8TeUbOj3H4pzqO
PC3PKV9grD9frC/zM/I47Ilx+BPGoWeMQz/om6AfYOjnR6Ef+T72ydDzQKF3
2T+jn4Z9gGGfEvGd7LuxHjDmx3vq/Nifw267hZyk9sHwH/ijug4w5gNPzIc4
gP9Bv7CX6leQB3pT/RT6gh5gb9gH/oC6pO5bVDtBTxiHnrCOuq9R7QLeGAdv
8FD3Pcj7cl/7Iu9fEX2bzGOIB+RbNV7gz8DqeTTG8T38FfKg74c8wJAHfST4
QW/gBztDf9AL9Ae/gx6gTzzxO+wF+WB35EHYGfMiDyNukafhV4h3jCPeMQ49
YRx+gnH8jnXwO+ooxtX8r/bbKg/kY+hNzQvQC/Smxjn0hfyD+EF+BA9g6BP+
gfWxn5L7rhf1F/EJv6ns3AHzQh+QB/lYPVcBhl/CHvBLxK96DoP3oVe8jzhF
PQVGHYUeoXfEJfwXGH4LvcK/oBfEH+o5MOq5Go94D3EMfeJ9yK+eAwKDL77D
+/06+T1bH50l9w1/ffm1nzHp5Xv1vXOePkhp4+2DTjcLrGea4ZR9if+e2SMc
kU65Dz/ko29g6lnB3y+d1NR08YnMv/4Hb/uZHj2V+TYit9n3Ue+VvXSf33Zg
oskS5D3XbZCQH6trmM9de20+rPNxSvtNyI7rqi3w3v8+PFTQS5MdK/3F4by+
Imq466V766hq+xMMxjTe8t2HzUyD78lxxJ1vxMCl1uQ/+fqjnPGODO95CObD
e/geGO8DQz7kBcin3tO8udR20GA8L/u1RxkHmxr1J6VdMn7LWx0VniF51Z94
c5DmnRtSrk4DjEstITdkX23u+8aOsL3XCPqCnaBveX/ywh7q38UcTPctTUl6
QrAf8jSeq8Tvsk61NKW6Y6qUEPwHdpP3Er2P2O2vec+9gtv9FWENLSP4H+SG
XE/Pv7PUssh7fj5h4/a+mp4uybfpW0v8jTtdUs8XHuX20ex2Sb2um7+ur6av
i4773VtuCbrGbQMnvGVs4eLtb8wZrO3wJ+1t8djfONHFe/XDTJZF+Wzfs+pd
/X/KODPxSKC+2yO6Fq8L1l4u4+AFsQ/tzZ7w5suGU7olTzlwR5c65vlP+dLA
DUH6xk/YOvTyUot/GdVf+5XFsC2fw98c0Eaf7eRLWYtZ1+cqb4jrUNX8oYvz
D7T6JWxvItdoXzBM0/c+ffT+zDz70UTevboB+zV/RHtn5ZzTdUrkBX3c/sZP
XBx1bJNOGxtD0yNc42w+Ll51hXrqT6TTrMR3brjdR6nWpUtB+rJ0OrbHdsav
uZNGzQwOscVl0YKPQ2qZu5TRhb2FWn23fNLW8xmsnXWHRx2fedM+0klF57a6
Urbcpq35G3JTvnbS7io9Jjr8dnFg93V/uGNd3D9n3niH33lKju52w/6Di33/
5agV2/sxnznV6YDhWQkXzL4RaPw6m4NnrG+n31TBOxaGHjRsy6YfHTdmW3+u
4Omf7ovX9XlAAasymhm3lHPtttVOGIY8puSMfiEO31IZ91rhL3wo/lEL08XH
Mk+tOG1YablVJJ++Nea/bcouojriKfPIUeGfHNy+838ti7z7CN9o/8amRyU8
IvfGXFvHxxzXPneZJa+Enn25+467w2M+PvytjvrW5fKcJ61Hfn3TjAquW+e7
4pQ22aztsHmJJaScFu9sHWFN/oenpL/3t31kBQ3o0WilxWmX+9IHIh556dLQ
V8zRTpm/ix4266aNvcAhzd3xuoYZPLP0vska9TPfunnRFdPsOk/7u/pxQ+Yd
eR50uNX7iTrrPb79VrfslLA1PO72fEfKw2RaLJ5co3bKBbf7Ao1Y6XClhH3P
txY3aWG89w/V/OPTbPvRZG65Z9YcW9w9Sv2p9quxlu8lztjmwdRjaFlZyq93
udFvly/6pZ4jzI9nh9TY3lqbjZuIp4wn5+ee/Ed92876whp1Tu7bweeC4EOQ
50GqRx6CPmsKfRL0MUjog+wzpvzlphQ2mLt11DfOoPjYguiwKU65f9qVkDTS
kVBBy2qPGqPZfZfGnpgYr5tezpnHrFn27H8I9pkn7EOwt0HYW/abr4p6QU7H
5Cz7a+XyXAR+tUw8Kfrwogt+K737HPi7Vfg7TTsbuS8s97Hsa+ueHHbOL/AB
F3aP2WtYU06Ih+4iHgj+31z4P7k29eumLzvHr695vyhmrUvGm1bEG4U/PXDL
7d5Ji3ckj7XFuQjxlyjiT+5rq42bVhxzx/t3Ps1F/pN155LIf7Kfim/Yv67p
kVPufzYG+RamfFTKiTWqNjKtzpV95sOAX341ZOZ6+1k/+zRrjQJ5zoC4yvPw
9O5nOol8ztAP4nfjwKHVY+88kXUEeh005eMc+w/FMs77Tz1VkfLrY1lXUGdg
D6zbd7TO6HA8lXUGdsD31Qtajnb8v/sT8Mio1qO2OTqHYX/Eez97dJrbVv7S
uf97l01htrrev/tqLuorF41/t4rZ9vdL9yyhn0a1NuqvSXv0EfVX9qMnrz4I
s6VdY/g3vkM8If4jGncL0hZ472MQZz3jvqhhtnnvZ7qJ/kDez/jOq7fGYj0k
v1fvX6qI7+W+69Jcz/uyb1og+h9CPsJ34Is6CrnHCL7y/G+/4EfIf/A72EO9
B0sX9iDoX70nCRT6l37UR9iXYH/4HeyPceR/9Z46V/grwR/hZ3ivv/BHQv1R
77HNIl6kn+wS/S8hfiD3upV1LYbMTFbv631EvMq8dkjEo+QdI/pjQvxhvrAG
o/YZtt3g0O9XzLQ+dTLy332R/xj5Gs95njx+jTfc/3iZJeg6I993Fvmeqzaf
PcmRcZfr18gerclO5Jl94rtpP3FSgP6nLyy1bxHqK56o14miXlPy75uGaJc/
75cLG9YzmZx8uuui6+6x1+jgnBUHdW1dnO3qsTVsyg0699rlg7pqLkZ/YRH9
BX8yJNO9PjqfPhD9Ho+e926Sru0Tir+Ybo5a+ZQX62uNdUQ+pYC8yast/k84
b/nc47peZXzklRbLowbmM/qZK6Kf4YTjzgGa8+V0YvI3vbUFOWxo3fywro+T
Q7ofWWfxv83XH2yODtvo5J2/1K5hfuMmoz8KFf2R5N9Z8Oclswf9ZMjM4oYN
fhujmZTOE3sZHtl1hzjI3/8dY9J1Rr/VSPRbHORu94r5mJN8Z9VvYlp9hf0X
TH6Y8jCVRvUaluZ2J/CKw1/E6kbk0+Hz0Q1MmpNS/0XVPfonvO8n3if0g+1E
P0j4fr74ntBPnhb9JEHeakJegv2XC/sT5G8n5CfI65zpkZegrxFCXwR9rRf6
Iuj3oNAvwR77hT0I/W+q6H8J9msu7EfolzeIfplg70PC3oR++7botwn+gf0A
/G2p8DfZv2tF/y7jY4KID4I/HhD+SPDHM8IfZZ6N//S1hZZFLpmfl4h6K/Ne
wuWhRTFfubz3gcZ3xzg+9p6rrwp4s6d2VjnvG/7tVJu2VOaJi/NdzpjoUprx
1oNCe5tCTh/jk+gXWSHPG9DPrBL9DA93hZbEnK2g892y8uxz78o+cJzohziq
58yclDYu+fv9TgU7DcHP968fTvc3aZKlPPWu0327LpnLGz/soh3r5VV6e/BC
S4iLLw0eGmMw7qHV2wrbGZPuyXH0mz7+nn6Tnv6cNUpjusfvrf2tOOXVo4R+
E+8Df/ZfT/9JkA96W9w0pKu2iYsXefLgJQJ/1B30z71F/0zQH85L0J+Xi/5c
6m1Cl29HOjK887D1z41huc/zb9LllqbBf/KOBY1zUp7vkwqH3brr/jKNsZ+7
1PLfQ7SxcZy+8UykZb+L/dNufWkNSKLMFl910W5xcYSFTvttfsRrPpwdYd1W
xheyl6+MMubx7l2lzY1lZfLcJFSszyGJmZaw3+/z9FfTNoWNqWDspz4W+yme
32VluK3uPe64KKi79l9OWZ+ThLxc86u2X1v73aHQJWPO+E1zsrZWZJC+9T2q
PalTE+ObTo5KH7ncsuo+jfy64R7DvArO4A8KU9p471ECHK3mWjuXcf9BaVa/
ac/3l0WLClK2lHLdzVPvuTsU8oY6kxZbfqyQcndsQc2MT8r52jqf9VHrcjhi
TuxhXVEFO7Yt/jHqved1oPfa7tqsCg4++/7ntri73H7V9NyULU5ePGzoaEdG
BmO/+aPYbzLsu1nYl3ccP9LBmJTO/5lcku7+8gbX1o7IsBd772vzImeOt51x
0rcJC3voT/zFqHsj284eZzNc5CehFYH6es/jctw3BfbiMxzaY9wuwzMnXW9g
b2TS/C73v8/E/pfhz/2GePyZ4a8zhb/ywuJX1kYdyiV7+PbOelMyp66fuCds
7z3pv3ebLF8XtqBAYvPCyeawKfl0a1aHLLsuga+87fM4ZnwBRab2eseksTDG
t4txwnhVMU7IQ5gvMuf0Qou/i+J+TW9v1B/mPZ79vItW2qu1Mmm2M8YjxDhh
vL4YJ5wPpInzAUK8Z4h4J+gX8Qb9/SH0R9BfgtAfQf8Lhf5l39FF6F/ug57Y
PPmDoL9koT/CecRKcR5B4U8a37R/k0dplLjYmpxE8Df4OfzrgfAvgn91Fv5F
8MdLwh+ln2D/B38aIPyJjB69nOHxJak/hu29QciXp0S+JMQH8gfio5eID0J8
1BbxQeniHIe0vlXP+vnmyfuHFEfTvYbMB4TzG19xfkPI51NFPvfez4t6QMgf
K0X+IOQPi8gfhHwxReQLQvxPEPFPiP+aIv69+1JRXwjnT5C7vq7zTfvcPOp/
YehHmure+/ojop7JfLhd5ENCPtwl8iE969g43GZIYuwn4bfYbyJfpol8SQW/
bFprscZRQJXiOqYD3vv7eFEfCfn0lsinhPM0rNfvZHQjc3QaOV1jA/VTXfL8
LlSc37HvpctNjEk3efivqzLsV52M/hnnKjiXvmvKYb99Tsb+uZHYPzP44HwK
+2fUc8ivFfIz5PF55pFH7ms2iPNBec+P/hT7+yKxv2fof5DQv7wHKBfnkxyR
s+nV2GGFdKv3gTdMp7x+uata0RX32FKut6bOMmtyobyfDNzq3mcILpPrmt/+
oa2+tVOeS+N8BP0A4mGOiAee8tnFQ7oIJ0UcSl9iCfL+XdpOcd7L6QddGfYf
nPL+O/fyhjb6E97/LzTN0y/el39/gPjOF/Et+bW+6Tl/5qwRQ33Mo71/hz9v
7rKq5je857AYx/4T48BYH3oHX5xHb/umabD2ZhnHe/r0PO+5gzj/p/DBkTXN
x7x/74DzO8QN7j92ePZnDwn6BQ/Y57qwD+F8A+dEuMfZxRXHdUXevmS7sB/B
frifRr1vK+q93E8niPsQgn8PEf4tz90bifsRwnnpRnFeSqj/w0T9p5OevuEm
VW11sas2y8nhqctDNH0L+VrLLVNscaUccjf4WcydHO4XObe9vnEF13n0xzKL
M4d2uU/OsQY871d8jpzVVSti3/3LAo2Hi7l/QNwCa+cS7tUiOFjf2sHQ92mh
b0ae6SjyI8/77lq4NWoztZ5bHGfIvMrX/r0z3z73Dtft4rqfEnaRA04ZW5pW
n6VDHj1e5qp+D0ZofrDTjY/K39eXHZN4q8CE+d4U8xH6jZmi3yD482fCnwny
Bgl5aXKH6l31scV89OtOl/18igj8agh+FNLwxGndkWKKmZI7UlO9iMIjph0z
dHbwvPm3HqfoSwj6Sxf6o6KidjVjezvIWfLTB9qhJVLfzwI8+pbfR4rvGeuf
EOtL/mbBnxrUWljfrCmi80c+Wmi1FvPmNfba5i4ltOHb8HS/QIc8n7r+x9ah
mh9yuOknI4O0WeX0+q5njU0zcri49JXu2g63OHjg2Q1R4Vflec4Azz4xQWKN
wIT3O4j35XlLmpifMH8dMT9BnnVCHinvWSGv1IdPqUcfDH0eEvqU9nd09tif
4H8fCP+j/wEdjsLE
                   "], {{
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[0.3], EdgeForm[None], 
                    GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxNm3n8l8MWx5+ZkTYiVLZoT9mTS5aUnVKKrCEVskX25UaEa0skQsiuIiVL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                    "]], PolygonBox[CompressedData["
1:eJwtlwm0T1UYxe85hxJSq0FKJZqlpEyFlCFkpoEGimT2UCHUQ3qZQpNhlUyl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                    "]]}]}, {}, {}, {}, {}}, 
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwl1FlQVmUYwPHPHC/ad1u0haamZkzDyBAri6xkycrdzAhNgxZZsmwBUdvU
tFWNCpRyS1uMCFooLXItLywRhJIAtcmyqGzvoun3TBc//u/zfg585z3nmDSp
cERBt0QiMc6PZ7snEisPSST2cSPPmC8mlVNYzHOs8tlAvVNP1XKe5xVzmt6l
vfQFxlu/qF36E6vZaO6jP3MB6eYruYJC8xBN1i36mhZxmvUSJlgv1V/0daqs
X+Ylis1vcsB6rR6kmnbzW3ovtfxgflt/pY4O8zv6AKdbn8Et1in8zgC22Xtf
S/mDevbY+0BncKZ1EmfFmZn/5h8aWGVvdZwP/5rX6A0M53pGMiK+c/xdcslh
EhOp5jbymMLt5Mc1cSgZfmejLtTvySMzrtfeIk3W/jRa79cdekTcS30w7lNc
e9xDzSeLEnMpF5JCs73vtEmP1ut0l1bEefNl/G1zqx4b1xZ7cc/ivPnQel2c
YZwZ9RzPKJ89oo/ycNxH8944WzaYP2EADzGbBu7w2Ui+su7Uk/Ukxlk/pU/z
BCvMT+pYXaDL9XFdpvN1jM6L50cf07nMYbT5RO1Jh/XH2q4n6Edx/tbr9SKq
rGdpm3bp1/F8xjNhPZOyuLfm4+Kea6vu1sr4/rTEM6DH6DBt1pZ4Z+J8aTJf
q0dptu7UnVrOdOv7uY/3OJJa6uL55t14rlns337Bt9afa3GckRZoUbxz1HAY
h7PdZzv0au2h6Tol3lXrfkzmVgbbm8x51ufGucX9JM3eRM6xPjuuK66BVHu5
lJEd56N/8SfLzZlkMZQSexlxDdoZ16ffxPPKZ3H2+hvL4ntyDVfFedir4dN4
djUnzom2OCe9hzfYGu+E3szd7DZP06nxfrLJfL7eRIX1IC6hN5W8an+z9tXL
tEAv1cvjXOKczD+yMN7B7v//3/of/e63tQ==
                    "]], 
                    LineBox[{702, 995, 701, 763, 570, 973, 642, 744, 745, 571,
                     854, 643, 809, 810, 811, 575, 769, 649, 715, 1005, 714, 
                    774, 716, 998, 717, 651, 775, 582, 883, 657, 882, 658, 
                    884, 583, 776, 654, 718, 977, 578, 614, 652, 990, 653, 
                    650, 770, 711, 997, 712, 813, 812, 645, 708, 996, 707, 
                    767, 644, 706, 974, 572, 765, 568, 972, 704, 641, 764, 
                    703, 933, 932, 803, 640, 846, 700, 743, 742, 702}], 
                    LineBox[{806, 646, 855, 709, 938, 610, 573, 975, 710, 647,
                     856, 648, 713, 976, 576, 771, 579, 875, 655, 874, 877, 
                    876, 580, 772, 943, 860, 861, 857, 859, 858, 941, 768, 
                    940, 611, 939, 806}]}}], {}}, {
                  InsetBox["\<\"\[Mu] = \"\>", {-1.8, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["0.2`", {-1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {InsetBox[
                   SubscriptBox["C", "J"], {1.4, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["\<\"=\"\>", {1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["4.5`", {1.7, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {
                  {PointSize[0.05], PointBox[{-0.2, 0}]}, 
                  {PointSize[0.0125], PointBox[{0.8, 0}]}}, 
                 {PointSize[0.007], PointBox[{0.4463998339305619, 0}], 
                  PointBox[{1.2771956561278897`, 0}], 
                  PointBox[{-1.0806611991222994`, 0}], 
                  PointBox[
                   NCache[{0.3, Rational[1, 2] 3^Rational[1, 2]}, {0.3, 
                    0.8660254037844386}]], 
                  PointBox[
                   NCache[{0.3, Rational[-1, 2] 3^Rational[1, 2]}, {
                    0.3, -0.8660254037844386}]]}},
                AspectRatio->1,
                Axes->{False, False},
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                Frame->{{True, True}, {True, True}},
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLines->{None, None},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None, "TransparentPolygonMesh" -> 
                  True, "AxesInFront" -> True},
                PlotRange->{{-2, 2}, {-2, 2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.02], 
                   Scaled[0.02]}, {
                   Scaled[0.02], 
                   Scaled[0.02]}},
                Ticks->{Automatic, Automatic}], 52->
               GraphicsBox[{{GraphicsComplexBox[CompressedData["
1:eJx1W3t8zFfaD0nJdjtuS62hhK3soMrbmnWpeugIFaqpW1E7wTbWmqBCEdVQ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                   "], {{
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[0.3], EdgeForm[None], 
                    GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxVm3kcl8P2x5+ZyVIS2eOGUsqSSkrKUnYiSYsIZV8jsm8l1xIJWctSdpJk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                    "]], PolygonBox[CompressedData["
1:eJwtl3kQT1Ucxd+7t41QQ0oRLRNS2ictRLLvIUKWyJ41CdmXCJFdyJp1hhGy
ZImIyjottpI9hLKvMX1Oxx9nfufc+97vvfu933u+3/dgwzZVW4ckSf4AN4EB
MUkGgm5pktwJ3mQyO7o8/DbQDd4TfAi/FQyGz+OarPBKYB36ezAV/pzugZdm
/mF4SdAMPRZ9lWflR78FP6J74EMYWwXPCsqiJ4LfmD+IXgMP4A/0dXQOflN0
d/gXwe/yFLgXPQ19CzwT6Ieegb4d/gzYCr/A2Cl4KZ53AP0nej06A6iOvgtd
Dv4EmII+iz4M/4jr16PPoY+h70NfRA8FZ+BFGOsALwEegtcBG+Hnuf4kPD/X
5Ip+pp5VAfRC9wFd4RlBNvjEG2srCGbBr4Gi8MxgLfM5o++dDDbA5zBfMXXM
e0TvmfZKe/QuujV4H57oHuZyRMfiZvAz+iL6DPxi4nfXnmmvtIYM0TFTrEqh
T8PzMlYF/iLIB88fzfdzTT/mn0TXRjcHHdGF0HXhTZkvAx8JeqNzgmfhz4FH
4OeY38L1w4KfpZypAN/L/DJ4XeY3o39HL0SfRTeFN4n+7/qM9WW+BvoB+F+M
FUNXRzdD5wFltbegavp/OJKK8EqKmeKBfgNeLfpe3fMDPA+oDJ8G7ofX4z8n
JY55Z/hL0c9+j7HC8CLRe6ccL6ncRJdInSOl0JeCc6WQ3ln/B2omjlEv5gqi
a8CbgMLoiH5NzwYndHbQ1+DZwQfwjtHPfgc9gvm66Fap//NzxSs4lzuAw/DL
zF+GZwGj0Xeg88Evc31P9OPo6ujGoAw6E7pM6j3ajl6CHgcfD36C92DsVeUq
OAq/wthV5TKYi+4GiqX2iKLMvQLehjfUHsBD9NrkP0VlRuji6GPQCeiW6PaK
L9iB3odeDv+X+cXwr8ClxGuYA28T/F+K4Tx0O3SWxDl5ResPzvW86JHyBnkU
vDXogi4eHcseih+8JWMH4IMY+wa+XWcOfkS+Cf81OHaLU+fqGMUgcc7u0loU
Y/RcxQd9MPisbwS7tbfonMzPT722Suh6idd4WLkQ7D3rUnulPEFeIM9sG33G
lcwdQS3lEviboRapvbMa13dO7KH70TuDY7cqtffVCl6rPFBnSzmq3NQZO4b+
M7gWbNGZ0t6hVzK/DX1cZ0WeKS9J7XWb0P8k9jx559Rg75aHnkDPD87d7eCk
Yo3eyPU70X/r3dF3KzapY10k+Gwq5qu1v9FrnaQcgK8L9uJsN7x9W7CXyOPl
bT8Fe4c87hJ6X7D3XUh9Fg6h5yU+E8rdI+gfE+ewztpx7XniM3cN/UOwl2fX
OtEL+L2HuT2gvc4i6CTONbuDc1i5W0BnSuuNnmur86d8AX2194w1hDeKnmuC
HsW9DaJzVTk+SvnOWL/U94xDfxbtvf3Rj6negU9Te9xM+Ap5auqxKdoPMAR+
iHsmK39UY+FDFVN5bTDXNbPRK9Ej4MNTe8OsaC6PmKncjK61qrFDVDuiz353
cIr5haCX/A4sgg+P5jlAc3krY614fjt0V/SH0b1AF/krvEs0787Y+/AO0Vwx
Hs+9LdCPwq8n9pZxwf8lj5F3yAPlffKQReg6OtPwsal7iT2KZ+KeQt4pT5AX
yEPrwz+JXsvzYKFqRfTZGgOGKdZgh7xT+Ryc08pl5fBb8NrRtUrPVO+wQdck
7iHOoAejT6APok+jBwR7y/7U3q8aptqlGjAd/TU6V2qPvKB3Da5lGvuF+Z+j
a2th5dCNHFVuKoe1lxWia4v2VLlRPtrrlSPaC3mEvEF7MgG+JNj7Bqb2+mbg
5dSeL28cr3dO7ZEFtBfRuaVrPmC+SnDuvwLmMrcanVvemzqXzwe/q3J6afAz
9azBYDF6bHRu6xn94bODa9ez8sBgD5V3yvP2B3umvFI9YLlgj5Y3y1PXBnuy
vFgxV24Ojd475WjjYA+S92hPX4+uSapFTfX84D3S3sjTv0XPR49OXWOegj8d
3fvJA38M9ozsN/Z8UPCea6/l+VXgfRg7mjgm3wV7mrzseOKzOTE6FjqjVzUf
3DurxjQM9mB5rzxUvYZyVLmpnkO99EqdgdQ9davoHlu9tXrCzfAtYHpqD9um
XOc/Z+hsg4zRZ0ZnRTVyK7x09NnVNSvgL0SfvQnoY8E1QrVBNeGJ6D3XXqvH
WgZfGu1t6iEyR/cU6iXUY+yCL4/OFZ1pvXun4P/WGhagv4yOjWJeGV41em8U
Q/WmWoPeXT3qJvjGaG/VGhsE1zTVMtUw9SY64zrb6lHU+9cM/pbQN4BqZ7Ho
XkU1dG9wDVHtkGeoduSO/vZRDRkR3ROpF1KPq15RNV+1Xj3jmuAeWb2xelR9
W6mmqZbpG6t3dI+v3l7fBB9H96DqPfVNpl70OzAldU+6PvqbS99aGusqDws+
G/pmaBRcc1VrVdP+A0cO3Cg=
                    "]]}]}, {}, {}, {}, {}}, 
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwl1Gt4l2McwPFnyzF60RsvhEpS6CC5uHTlsFboKEssUuQsLZaVrel8bi1r
OjnllFKkDOuASkWGVqk5v0FrbdohooPU53d58en7u59/17X/c9/31nLYyIys
lCRJMv3zZqMk2ZCaJH+TxRvWPenFFbzFMj72WW+doO10OW/ziXUfnajtdQUj
zSs1hVQ+td6rXbWR3qR36EAGMMX6Tk3T73WzTqWjeRVPmd/T0/jMvFrfZw3T
rLfxr3mrnq6f61/6hc6ijBPWX+oZ+pUe1q+1kCvNnXja3J2zzLfoL7pDizjb
XB77pDt1HleZO3M1t1qfq02oMJfqOtbSlPUM4wHu5yEeZCPZjIr3JCe+R+wB
ueTxDPmMjffnfAb7GfvjHOLdyOdepse5aLp2Z5/5qP6uF+lKLYh91dn6rj7L
UOZYF9KDm6ny7Jju15bx3fUPXa3/xcxx6xptpQ9rXZyNnuSb2D/KYq9j32nN
Yz5boAuZz4dxHnFm7LH+NvaT5ylmN+N99ij15j/1cr2MEebX9HWWxJ5bv6pP
6Cux//qSlurLOlxf1I90kb7AYh63bqNtOWTepQ16aZw348zlcS/4IM5f6+I9
tV5LmGsu4jkesb4kzllrtVbXcDDE2evFcSe0RqvjjnOA6rgj2kLvi2daqe8w
wzyLmXGfac62uPNx/9ke954V/u+FOkSr9DddykTzZCaxhWZcwK8+q9RBep4O
1Dy6mdMYw2hu9yyXLubr4j3j3Ont2WiuNV/D0PjZ9PQsh+K4n3Gmeo42jn3k
nrjL3B37FneGn+P+6RH+iX3lp7iXeqaWkBnflbuY4/l2fjSn66i42xyyLtCZ
bOEH626aHb8nNFjP0ElspML6en0y9trcl350iN8TNnn+nd6g/WMf9TbNiH3h
RutEl7I+9f+/racAvsnBZA==
                    "]], 
                    LineBox[{723, 1015, 722, 782, 588, 991, 663, 763, 764, 
                    589, 872, 664, 827, 828, 829, 594, 787, 670, 734, 1022, 
                    733, 791, 735, 1016, 736, 672, 792, 602, 901, 678, 900, 
                    679, 902, 603, 793, 675, 737, 997, 598, 635, 673, 1011, 
                    674, 671, 731, 995, 595, 832, 831, 830, 666, 873, 591, 
                    993, 728, 665, 727, 992, 590, 784, 586, 990, 725, 662, 
                    783, 724, 950, 949, 821, 661, 864, 721, 762, 761, 723}], 
                    LineBox[{824, 667, 874, 729, 955, 631, 592, 994, 730, 668,
                     875, 669, 732, 996, 596, 788, 599, 894, 676, 893, 896, 
                    895, 600, 789, 960, 879, 880, 876, 878, 877, 958, 786, 
                    957, 632, 956, 824}]}}], {}}, {
                  InsetBox["\<\"\[Mu] = \"\>", {-1.8, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["0.2`", {-1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {InsetBox[
                   SubscriptBox["C", "J"], {1.4, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["\<\"=\"\>", {1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["4.49`", {1.7, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {
                  {PointSize[0.05], PointBox[{-0.2, 0}]}, 
                  {PointSize[0.0125], PointBox[{0.8, 0}]}}, 
                 {PointSize[0.007], PointBox[{0.4463998339305619, 0}], 
                  PointBox[{1.2771956561278897`, 0}], 
                  PointBox[{-1.0806611991222994`, 0}], 
                  PointBox[
                   NCache[{0.3, Rational[1, 2] 3^Rational[1, 2]}, {0.3, 
                    0.8660254037844386}]], 
                  PointBox[
                   NCache[{0.3, Rational[-1, 2] 3^Rational[1, 2]}, {
                    0.3, -0.8660254037844386}]]}},
                AspectRatio->1,
                Axes->{False, False},
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                Frame->{{True, True}, {True, True}},
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLines->{None, None},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None, "TransparentPolygonMesh" -> 
                  True, "AxesInFront" -> True},
                PlotRange->{{-2, 2}, {-2, 2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.02], 
                   Scaled[0.02]}, {
                   Scaled[0.02], 
                   Scaled[0.02]}},
                Ticks->{Automatic, Automatic}], 53->
               GraphicsBox[{{GraphicsComplexBox[CompressedData["
1:eJyFW3l4jFfbT+1CbC365kVbVKckqAqp4laDr0W9Q1tbXWPfOlqqitFYqxOl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                   "], {{
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[0.3], EdgeForm[None], 
                    GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxNm3f812P3x9/XdTWohJAoVEilSBrCbdxEZkhmKntUViWjmwgpWVkZv8oe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                    "]], PolygonBox[CompressedData["
1:eJwtl3f0z1Ucxr/3XhqIJNFATp0GmkqKSERlZcuMpIyMslc2pcguqyKzIVHW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                    "]]}]}, {}, {}, {}, {}}, 
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwl1Gt0z3UcwPGf6YYeOPVAHpDRTYSkDo3pakUlwmLIJZduqEzWbYvSGtoo
lSgVJo0wK3SjiFxiq1zO6RwPXLe11VYb1RO9PqcHL+/P9/f7c87v8/v/pY6b
OnhKkyRJMv2xsmmSfJWSJH/zOCucB3I/17GKj/navUGap110NZ/wjfNgfUm7
aglPmNdoCk3Z6lyuPfU87a0jNIvhvOw8Uvvoz/qdvsL15nVMNa/X89lu3qAb
KWWO807Omr/XC3SX/qE/aAF74/mc9+iFuk/r9Ed9ne7mG3jKfAvNzLfrET2g
C2huLtd6rdCF9DDfyE3c4TxeH47npBfTXcugpfk+Paq/6qV6SeydbGbEZ5nJ
M7FTWnEZxT6fqyv1OTLJi32TwV0871oW+fFO9G7tzylzg57UdrpG58dOdZ5+
qi8wKvbgXMgA7qHatUat0g46Vk/rBj3H75xxrtUr47m1Ot6LJrF7dsc7iffB
Tq5mkvtv6zu8xefx7uLf4oDz/tgVi3gz3hG57k3kN3OjdtZOPGb+SJfzAV84
f6iP6jLdou/pZn1fH9GlukkX6xLeZbJzR72WBvM+/Uuv0b28aN6j9/KZ+Q2t
13/1Ty2jyLyQBUxwvkrHa5XWaWl8J6l0HqdX6Bg9pTXx/Y7n46TzQ9peR+sJ
rdS1vGaeSwE7SOXb+L2wjdM+s11L9HIdqcf1hK5iVvzWmM1W2tCW4+4d0we1
tT6gOfQz38mz5DDQtZmkm/vEnmOn8R10LZs0883xjpkYf9e1p2NfTIj3qRdr
i9hjfKdiF7EHitzbz2HzbbFb/qGQQ67dqhdpWewldsQo5ru+m4Pmvvokc6l1
nhc7Ywe/OKfrNF6lxjk/dsI2Kpx76ZTYdeyAIXSL30ns2fWf4vl0WOxQh8bO
yCTNuYkW82XK//+v/gfsnL1g
                    "]], 
                    LineBox[{724, 1010, 723, 781, 585, 986, 663, 765, 766, 
                    586, 875, 664, 831, 832, 833, 592, 788, 670, 735, 1017, 
                    734, 794, 736, 1011, 737, 672, 795, 601, 902, 680, 901, 
                    681, 903, 602, 796, 675, 738, 993, 596, 634, 673, 1006, 
                    674, 671, 732, 991, 593, 836, 835, 834, 666, 876, 588, 
                    988, 728, 665, 727, 987, 587, 783, 582, 985, 726, 662, 
                    782, 725, 951, 950, 823, 661, 872, 722, 764, 763, 724}], 
                    LineBox[{828, 667, 877, 729, 952, 630, 589, 989, 730, 668,
                     878, 669, 733, 992, 594, 789, 597, 892, 676, 891, 894, 
                    893, 598, 790, 957, 882, 883, 879, 881, 880, 955, 785, 
                    954, 631, 953, 828}]}}], {}}, {
                  InsetBox["\<\"\[Mu] = \"\>", {-1.8, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["0.2`", {-1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {InsetBox[
                   SubscriptBox["C", "J"], {1.4, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["\<\"=\"\>", {1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["4.48`", {1.7, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {
                  {PointSize[0.05], PointBox[{-0.2, 0}]}, 
                  {PointSize[0.0125], PointBox[{0.8, 0}]}}, 
                 {PointSize[0.007], PointBox[{0.4463998339305619, 0}], 
                  PointBox[{1.2771956561278897`, 0}], 
                  PointBox[{-1.0806611991222994`, 0}], 
                  PointBox[
                   NCache[{0.3, Rational[1, 2] 3^Rational[1, 2]}, {0.3, 
                    0.8660254037844386}]], 
                  PointBox[
                   NCache[{0.3, Rational[-1, 2] 3^Rational[1, 2]}, {
                    0.3, -0.8660254037844386}]]}},
                AspectRatio->1,
                Axes->{False, False},
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                Frame->{{True, True}, {True, True}},
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLines->{None, None},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None, "TransparentPolygonMesh" -> 
                  True, "AxesInFront" -> True},
                PlotRange->{{-2, 2}, {-2, 2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.02], 
                   Scaled[0.02]}, {
                   Scaled[0.02], 
                   Scaled[0.02]}},
                Ticks->{Automatic, Automatic}], 54->
               GraphicsBox[{{GraphicsComplexBox[CompressedData["
1:eJyFWnl0jNf7D4o2NZZUtYaWWKdERSuplnq0o6rWKVqlDIqUDkUs7USqC52S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                   "], {{
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[0.3], EdgeForm[None], 
                    GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxNm3nc18MWx78zUyJJskuUUkmRSJQlSQnJXipLCanITtZkK2vc7Ev2LAkJ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                    "]], PolygonBox[CompressedData["
1:eJwtlwf0l1Mcxt97b0aKdEh0jj0iM2lHRiUtLSkNSkVKi0KSBqKhqT3RoGwK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                    "]]}]}, {}, {}, {}, {}}, 
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwl1He0z2UcwPGfqz8c/lB/JDOEknFk7xUVISMj68oKGVc2mVmpZEXJVigX
hZK9oozslb33qnPsltfn9Mfrvj/Pc3/33HOf7/O9udukNOiWJpFIJPsyPW0i
sTQpkbhFW6ZZv0YN8jGTdvZn6TKtqf30eZ3NHJZbz9XXqcULfEV7+1/rQ33E
D+y3Lqp/UYL61g2oxwDrN7WkHtQV+j75zQt5x5yq/+hPLDIvYTEDrddy37xG
/2Udt63X6xA28cB6o/7HZv6w/lmH86K5AJ3MZUljrqBHdauOJsn8i/6pv+qH
FDQXojAVrVtoS4rwEp3tVSFdnK2e1n2aQdOzkm6k0JX36M5qMvIk032+n07T
HtSjf5wZlahMT3sNGRrPJX6nVuWE+Y4e18zxbHSkztcROk970ZhR1qN5mWqc
sXdXT2s2baZX9Bu9x4Wo9XnNoS30mqbGs2CHeWecFdvZRk6Sfe8THcvH8Qyt
b3KDfdZ7eZWPGMMe+vpeS66br2tezUMb81T9kil8wee0tj9Zv9NJcVf0M31b
J+hEPmU842hlP7c+xzXzbr2quXQXfcy/6Sssimevl+Nu6xVdyNa4H2zhkvWz
cb/oHfdNq/Ot+SJXzc01uzbVy3pOF3CWS9ZvaVZtEj+jp+KdYph5OB+wiSxx
z9nAOk76zEadq89oo3hWekxnxntlnqEDdW28MzxNJo7aP6/19Smtrd2pGO9D
3DN6UMNeCiXNJWgbzyLunL0uFDMXjfOOs417au9dxpAcz1af0LR8z9I4D0bZ
b6YjdQu/m8vHOxfva9xZjtgrp4l4vnFOcYZxTnEm9jdw2FxGO8Y7EXfLepgO
ZjWHrEtpB1Zyy3qVDor3yNw4zo3S1n8z37wg3pd4hvEOcNv+jxwwF9M62l9r
a13eoHj832FG/J1J///PfQzNK8Hy
                    "]], 
                    LineBox[{714, 1010, 713, 773, 578, 987, 653, 756, 757, 
                    579, 868, 654, 822, 823, 824, 585, 780, 660, 725, 1017, 
                    724, 786, 726, 1011, 727, 662, 787, 594, 894, 671, 893, 
                    672, 895, 595, 788, 665, 728, 994, 589, 625, 663, 1005, 
                    664, 661, 722, 992, 586, 827, 826, 825, 656, 869, 581, 
                    989, 718, 655, 717, 988, 580, 775, 575, 986, 716, 652, 
                    774, 715, 947, 946, 814, 651, 865, 712, 755, 754, 714}], 
                    LineBox[{819, 657, 870, 719, 948, 621, 582, 990, 720, 658,
                     871, 659, 723, 993, 587, 781, 590, 885, 666, 884, 887, 
                    886, 591, 782, 953, 875, 876, 872, 874, 873, 951, 777, 
                    950, 622, 949, 819}]}}], {}}, {
                  InsetBox["\<\"\[Mu] = \"\>", {-1.8, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["0.2`", {-1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {InsetBox[
                   SubscriptBox["C", "J"], {1.4, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["\<\"=\"\>", {1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["4.47`", {1.7, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {
                  {PointSize[0.05], PointBox[{-0.2, 0}]}, 
                  {PointSize[0.0125], PointBox[{0.8, 0}]}}, 
                 {PointSize[0.007], PointBox[{0.4463998339305619, 0}], 
                  PointBox[{1.2771956561278897`, 0}], 
                  PointBox[{-1.0806611991222994`, 0}], 
                  PointBox[
                   NCache[{0.3, Rational[1, 2] 3^Rational[1, 2]}, {0.3, 
                    0.8660254037844386}]], 
                  PointBox[
                   NCache[{0.3, Rational[-1, 2] 3^Rational[1, 2]}, {
                    0.3, -0.8660254037844386}]]}},
                AspectRatio->1,
                Axes->{False, False},
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                Frame->{{True, True}, {True, True}},
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLines->{None, None},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None, "TransparentPolygonMesh" -> 
                  True, "AxesInFront" -> True},
                PlotRange->{{-2, 2}, {-2, 2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.02], 
                   Scaled[0.02]}, {
                   Scaled[0.02], 
                   Scaled[0.02]}},
                Ticks->{Automatic, Automatic}], 55->
               GraphicsBox[{{GraphicsComplexBox[CompressedData["
1:eJyFW3l4jFf71kjTUFOxVHVqb/mG2opBVT1thy5KOhS1pqgopj6tUkJKWv2N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                   "], {{
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[0.3], EdgeForm[None], 
                    GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxNm3f811P7x9/nnEISZZSMFCq6i2jYIcrKys5KRKnbJqtbcVtlb7dRMior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                    "]], PolygonBox[CompressedData["
1:eJwtl3n0T1UUxd+9V4UGY61G0kTSTDSLigxlJpmpJBlKZM6PZSplSsaKhCzK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                    "]]}]}, {}, {}, {}, {}}, 
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwl1FmUz2UYwPG/kSUXDhflAlnbEHIw2UuolIkJwzCyTtmXc0iSfd+jxVrW
so6sUZaxxFiyK64cu2xlKXIO+jzHxWe+z/vOf86c3/t7Z0p17J3aK1cikUj3
ZUnuROLnpETiLt1YbN2EFMrzA93tL9VlvM9Q6wq6nBWsYiVNacYrZNHD51br
Y03oL3pMq2sufU1bahotGG7dSmvocd2mI9jOCeuamlvraIa2oy2jrXfzn3mX
PqW/6i3do2PYxwPrHM2j+/W2HtAJVDRXore5HvnM9fW0/qZTyG8+pHf0sE6l
svlVqvCmdWftQlWq0ddeIwrGueoZPa2FtVA8IwP4hP58ykCyeYZnWeTzw3Sh
DowzY7j1iPidNIifs5fOOPNSbaiNuGD+V8/rc/HOdHK8M50U700H0Tae0Xoq
b/E2V+zd08taStvrFV2tD7nOfetrWkY76TVdp9O1MV8wLc6QwfY7ctX8l65l
Ixv42t5XvMeXzOAoQ3yvCzfMd7ScvkxX88I4G75jAfP52P63uknn6k86Tz/S
2TqHb5jFTDLtv6gvcdt8RG/pC/GO+dx8SN9lvfnveG5zZ31e1+gBPRh3ipvW
ZXUfn5lz9B1+jGfgT3MHLa0f6mW9qlnxPS7FvdaSmqEX9ZKuYLx5IhPYSwl2
x12Pe89Fn9mjy7S4ttELek6XMNK8WEfpTnZQlGKctX9e07SIpuoA6pvfiGdh
ECn2+lPTXIPudIs7Y68fyebq8R7izONu2uvDNDLjPmgBfZqN8X7i3jA57oZO
0oOcit8b9yvuIBP5w97rmlc3xH2Ms4xzZLz9vfxurqu9GMtN63HxzOzkpHUt
7Ul2vM84hzgbWseZkU5t66R4v6yN9xfvP+42/8TfFFvYGn+bpNpvzgckWz/i
e/PmpCf/Y/8HSq+/Tg==
                    "]], 
                    LineBox[{722, 1012, 721, 779, 584, 987, 660, 763, 764, 
                    585, 876, 661, 827, 828, 829, 591, 786, 667, 733, 1019, 
                    732, 792, 734, 1013, 735, 669, 793, 600, 902, 678, 901, 
                    679, 903, 601, 794, 672, 736, 994, 595, 631, 670, 1007, 
                    671, 668, 730, 992, 592, 832, 831, 830, 663, 877, 587, 
                    989, 726, 662, 725, 988, 586, 781, 581, 986, 724, 659, 
                    780, 723, 953, 952, 819, 658, 873, 720, 762, 761, 722}], 
                    LineBox[{824, 664, 878, 727, 954, 627, 588, 990, 728, 665,
                     879, 666, 731, 993, 593, 787, 596, 893, 673, 892, 895, 
                    894, 597, 788, 959, 883, 884, 880, 882, 881, 957, 783, 
                    956, 628, 955, 824}]}}], {}}, {
                  InsetBox["\<\"\[Mu] = \"\>", {-1.8, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["0.2`", {-1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {InsetBox[
                   SubscriptBox["C", "J"], {1.4, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["\<\"=\"\>", {1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["4.46`", {1.7, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {
                  {PointSize[0.05], PointBox[{-0.2, 0}]}, 
                  {PointSize[0.0125], PointBox[{0.8, 0}]}}, 
                 {PointSize[0.007], PointBox[{0.4463998339305619, 0}], 
                  PointBox[{1.2771956561278897`, 0}], 
                  PointBox[{-1.0806611991222994`, 0}], 
                  PointBox[
                   NCache[{0.3, Rational[1, 2] 3^Rational[1, 2]}, {0.3, 
                    0.8660254037844386}]], 
                  PointBox[
                   NCache[{0.3, Rational[-1, 2] 3^Rational[1, 2]}, {
                    0.3, -0.8660254037844386}]]}},
                AspectRatio->1,
                Axes->{False, False},
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                Frame->{{True, True}, {True, True}},
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLines->{None, None},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None, "TransparentPolygonMesh" -> 
                  True, "AxesInFront" -> True},
                PlotRange->{{-2, 2}, {-2, 2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.02], 
                   Scaled[0.02]}, {
                   Scaled[0.02], 
                   Scaled[0.02]}},
                Ticks->{Automatic, Automatic}], 56->
               GraphicsBox[{{GraphicsComplexBox[CompressedData["
1:eJyFW3l4zNf3TmvXDilaOpRSy6AEFfu3pzWqqsqIfQtSlARBbUE1Wqb5pbYy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                   "], {{
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[0.3], EdgeForm[None], 
                    GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxNmwnY1tPWxp+9d8kQSSmlVIoGMiVjJWUsROYcpAElZS6ZZ5UhMykplFQq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                    "]], PolygonBox[CompressedData["
1:eJwtl3m0z1UUxb/3XopQrUTUKkkpSqTBGMsKIVOmTKESlTGZpeJlGQqJSGg1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                    "]]}]}, {}, {}, {}, {}}, 
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwl1FdU12UYwPE/0kXHLqyLhmaDbDkqsLDSSMu2liU0KC1BRUuPEJlaCWoU
hpajYZMWCYE2zJGaYmkJtLzodKGAjHAmpjdqZePzHC8+ft/n9XiU931/puTm
j5ySlEgksv1ye3IicRHvM75LIvGB3sEwLuZD8uxX6HDu5BI+YoL9pfqn/sUq
6s1X6N+kMdKcyT08bc7S/tqga/UZ1vG9+Ur9hwFkmx/kAYrNtRyy3qj/som9
5q91Fls4bN6s//Et+8zf6XNcat2bPlxjTtJBuk3r9AW6WNfrfm3QMvpa9+My
rjM/omPiZySVSfYGc7L1Lfqr/qKnaFdW8TiFFDCVJ1hDN06lPM5B39FCRjDT
XMT1DI4/Yy+TkrgTHaI3sNO6U5v1rLgXnasfa6lW6VTujZ/RXK036lDarQ9q
m56t2bpTl+kRdvOHeZeeo6O0TT/T+Xoz8yhjC9PsP0Sr9X79lC9YwUJ7C7iV
l3iRrcyIM6XDulMv1F6MtS7Xd3krzoa3ybX/hr7Ja7zOEnLsv6KvsoiXWRx3
Zf8CfVh/0wOaoufH22B6vJW4Oz63/p1269F6nn6im3WffqN79dx4dzwZ71Bv
Yrn1Hlri3WrPeLvarB1aE38/Teb7tYfep43aqpXxTq2X6vNaG2+d7qznK9bR
4vc3aIWeqVm6Q5v0PYrjzOKbiO+LLzmdM2i0v13v1tN0mBaQEW877i9+prgj
e/mkW19FHuMZYm8y/a3T4o7iPsiw9xjzyDHP15M0Oc4lzjDOn7n2R2upbuVn
64Hx3ca3HT83P9m7VhNaE28x3h0l8bb02bgHfrS+Wh9lNrvMc7Qozocf4t+u
E1kfdxNnGN9VfAtxB3H+pJuPUxXfDJVxZuZqPRjvn9Ws4SnuivNjBKnmoxxj
JXX2LtdxcRfWtyWf+P/1fyMDupI=
                    "]], 
                    LineBox[{716, 1003, 715, 773, 577, 977, 654, 756, 757, 
                    578, 871, 655, 822, 823, 824, 584, 780, 661, 727, 1010, 
                    726, 786, 728, 1004, 729, 663, 787, 593, 897, 672, 896, 
                    673, 898, 594, 788, 666, 730, 984, 588, 625, 664, 998, 
                    665, 662, 724, 982, 585, 827, 826, 825, 657, 872, 580, 
                    979, 720, 656, 719, 978, 579, 775, 574, 976, 718, 653, 
                    774, 717, 943, 942, 814, 652, 868, 714, 755, 754, 716}], 
                    LineBox[{819, 658, 873, 721, 944, 621, 581, 980, 722, 659,
                     874, 660, 725, 983, 586, 781, 589, 888, 667, 887, 890, 
                    889, 590, 782, 949, 878, 879, 875, 877, 876, 947, 777, 
                    946, 622, 945, 819}]}}], {}}, {
                  InsetBox["\<\"\[Mu] = \"\>", {-1.8, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["0.2`", {-1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {InsetBox[
                   SubscriptBox["C", "J"], {1.4, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["\<\"=\"\>", {1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["4.45`", {1.7, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {
                  {PointSize[0.05], PointBox[{-0.2, 0}]}, 
                  {PointSize[0.0125], PointBox[{0.8, 0}]}}, 
                 {PointSize[0.007], PointBox[{0.4463998339305619, 0}], 
                  PointBox[{1.2771956561278897`, 0}], 
                  PointBox[{-1.0806611991222994`, 0}], 
                  PointBox[
                   NCache[{0.3, Rational[1, 2] 3^Rational[1, 2]}, {0.3, 
                    0.8660254037844386}]], 
                  PointBox[
                   NCache[{0.3, Rational[-1, 2] 3^Rational[1, 2]}, {
                    0.3, -0.8660254037844386}]]}},
                AspectRatio->1,
                Axes->{False, False},
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                Frame->{{True, True}, {True, True}},
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLines->{None, None},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None, "TransparentPolygonMesh" -> 
                  True, "AxesInFront" -> True},
                PlotRange->{{-2, 2}, {-2, 2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.02], 
                   Scaled[0.02]}, {
                   Scaled[0.02], 
                   Scaled[0.02]}},
                Ticks->{Automatic, Automatic}], 57->
               GraphicsBox[{{GraphicsComplexBox[CompressedData["
1:eJx1W3tUlNX61jQzdApLzSbFW+akmMZhSk19U5SUOEWEl1ydUSk95NgNTRp/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                   "], {{
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[0.3], EdgeForm[None], 
                    GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxNmwf8l1P7x+9zTnZUIhlllFDSoCVEZGVGsrMekr2yt4hsMiKSSFZGKCtK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                    "]], PolygonBox[CompressedData["
1:eJwtl3nYT0UcxX8zg1QqT6iobJVI9VQehUpChCRblCVZU9kpa5ISskVZyhJJ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                    "]]}]}, {}, {}, {}, {}}, 
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwl1He0j3UcwPHHvTIq/qiDP/RHKlRSGTkZyYwkhKJkj2zKMbOyuRTZ2YSM
kL0qI3vTQMaxi7JXHPT6HH+8vD/f772/6z7f53lurkbtqrdNlyRJXf9USU2S
l5lFm5Qkma1VqcYrfEdb+3P0ParzKnNpZ3+eprLCPF9X6iOanhLmWlqbD+hl
/SNJ+iRZqxnt9dafOGx+QzNpKa2r9fiYvtYbSedzGzSzvV/0tm7Sfmwlxde3
6KP2t+l/ul0HU8BckEKUsX5cy+tx3anDyGLepXd0t35JYfNrFOEt6+bagtcp
ymf2KvKE+UkOxfXoQf1Zs7GOznShE93oygZyUsv3/q3T9D6dqU1fe/0oS7n4
vL06DIn7peXjd+K0+Z6e0lxxz+J31/lxXTpPu8aZ8pX191pBK/JX/J96Tp/T
hnpRF+oD/olaX9A82kSv6BL9WisxguEc4HP7jblsvqyLecH8iV7XZTpaKzOK
kfxOj3gu9Lr+odf0oOanlXmGfstUpsdZ0dL+ZJ3CBCYxMe6P/fH6DWMYx1ia
239Jm+k1var59EV+o7v1r/oOS+M6uWpuqs/rD7pfL+k+vah5dW/cU/MefZtF
5n+5ZG6kubVB7Ol5XRD3O87Wur4+G8+6XtCzOpc08xwdGs9iPJc8E88zO+L5
5oyv79TZ+nS8K3peT8Z50T/OSgfoVrbQM97DuE9x5nHNbOapeKfifWIjR3wu
h2anmrkjJczFaR33JO69vQ7cZQQn4vo1a9znOOe47zSOM4xnJ56bONs4F4b6
3oaapjs4Fs95vNfciueco/H862Nx/iyOs2SQvfo6UDdzxFxaP43r5ob1AO3D
ev60Lqnt472Mn2+9Tr/gQ3MdPuJN6wy6IN6BeFdYY2+R3tCbrGI1Palh/31q
xtnE3yhNYbn5kBbT1sw0v5v68O/t/4pVwWc=
                    "]], 
                    LineBox[{721, 1019, 720, 783, 587, 994, 658, 764, 765, 
                    588, 877, 659, 829, 830, 831, 593, 792, 665, 734, 1027, 
                    733, 797, 735, 1020, 736, 667, 798, 601, 904, 676, 903, 
                    677, 905, 602, 799, 670, 737, 1000, 596, 630, 668, 1014, 
                    669, 666, 730, 998, 594, 834, 833, 832, 661, 878, 590, 
                    996, 725, 660, 724, 995, 589, 785, 583, 992, 723, 656, 
                    784, 722, 951, 950, 823, 655, 874, 719, 762, 761, 721}], 
                    LineBox[{826, 662, 879, 726, 952, 628, 591, 997, 727, 663,
                     880, 664, 731, 999, 595, 793, 597, 897, 671, 896, 672, 
                    898, 598, 794, 961, 884, 885, 881, 883, 882, 957, 788, 
                    955, 956, 954, 953, 826}]}}], {}}, {
                  InsetBox["\<\"\[Mu] = \"\>", {-1.8, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["0.2`", {-1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {InsetBox[
                   SubscriptBox["C", "J"], {1.4, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["\<\"=\"\>", {1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["4.4399999999999995`", {1.7, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {
                  {PointSize[0.05], PointBox[{-0.2, 0}]}, 
                  {PointSize[0.0125], PointBox[{0.8, 0}]}}, 
                 {PointSize[0.007], PointBox[{0.4463998339305619, 0}], 
                  PointBox[{1.2771956561278897`, 0}], 
                  PointBox[{-1.0806611991222994`, 0}], 
                  PointBox[
                   NCache[{0.3, Rational[1, 2] 3^Rational[1, 2]}, {0.3, 
                    0.8660254037844386}]], 
                  PointBox[
                   NCache[{0.3, Rational[-1, 2] 3^Rational[1, 2]}, {
                    0.3, -0.8660254037844386}]]}},
                AspectRatio->1,
                Axes->{False, False},
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                Frame->{{True, True}, {True, True}},
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLines->{None, None},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None, "TransparentPolygonMesh" -> 
                  True, "AxesInFront" -> True},
                PlotRange->{{-2, 2}, {-2, 2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.02], 
                   Scaled[0.02]}, {
                   Scaled[0.02], 
                   Scaled[0.02]}},
                Ticks->{Automatic, Automatic}], 58->
               GraphicsBox[{{GraphicsComplexBox[CompressedData["
1:eJx1W3l4jFf7jl1TIVVapvZS01ZrqdFa2qcaVaJlmupn+emIvV+naFFM6iNF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                   "], {{
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[0.3], EdgeForm[None], 
                    GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxNmnf819MXx9/33sxESyqhiIaGMpNQZI+MkPGT7E38zB9SRkrZm8pMkpCs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                    "]], PolygonBox[CompressedData["
1:eJwtl3m8T1UUxe85R/JMldKgNKc0Ty9ChkaZkql4kagkvGfoRZKQBg0azdGc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                    "]]}]}, {}, {}, {}, {}}, 
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwl1Hl8z3UcwPGvrZI/8qA/8odSJBIlPSxKh6ZSOkStLUdqk6vkIdVsqW1p
I0e6CbXL0oEOkjU5ouSqKB0PdM61Nro8VBTP98MfT6/35+P32PH5fr5rnT2m
//2NkiQZ7J8+qUlyHmUMT0mScr2BG+lIBSPsV+pN3Ewn5jHSfpX+p2/xqvlt
Pcr/XEx/e7fSjzzr9/jXvEQbab4u5StzN03RSzVL7yCTR61rOGz+QFN1uf6h
H+pjrOKI9Uo9QVfrn/qRTuR88wV05jLrk/RK/U7X6snamI/Nf+knOokLzV24
iJ7WOTqUrqRxn710TjE3Zav5fd2iy7QZ1TzAOMbyEA9Sw2lxNj77i87Wvxkb
5xa/l72C+Dnje8fXsJdBsblUr9J0vjcf0p16up4Rz8c8WSt1HJk8aV2lvfRq
fo7vpz/pWTpQ9+p8/YfdUetd2kbv1F/1TZ2m1zKVKWyM38v+YOrMdfoG55jv
1v26UGfodTzFdL7g4bgT8Rm2WDfoVu3APeaX9ZU4H+YyJ56B/Vn6Ei8wkxfJ
sf+cPs/TPMszZNs/V+/SBq3X9tqOz/iczWyiNwvid6XePETb6uu6Qffpet2r
Z+un8TzN6/QaXjPvYZ95kLbWAbGntfGexPOO8407rmdqlu7SH7WCEnN53MG4
i3EvaRX3mTVxv/nB/6/VMm2pt2ut7tC5FMZZaZFuj3dE88iPM2c8ufHO0CLe
JVawnG0+f6o2p495DN3N3RjOsLhD9kZzkClst9dLm+iieO5x7nFv4tzjHOMO
sC7uiZboIC3WNXxrviLea37nCb6xd7meGPcunkvcUx63N0CLdAVfm3vovRRw
wLpQJ1DNNuvuOirez/j61sv0EW6LsyODS6yTeIbxvONdYHHcZT2gv/EO75JL
3zhHvUXT4m9U/B1iEV/a66rDKDVfn3r87+0xKOnCNA==
                    "]], 
                    LineBox[{714, 1013, 713, 778, 581, 988, 651, 758, 759, 
                    582, 872, 652, 825, 826, 827, 587, 787, 658, 727, 1021, 
                    726, 792, 728, 1014, 729, 660, 793, 595, 899, 669, 898, 
                    670, 900, 596, 794, 663, 730, 994, 590, 624, 661, 1008, 
                    662, 659, 723, 992, 588, 830, 829, 828, 654, 873, 584, 
                    990, 718, 653, 717, 989, 583, 780, 577, 986, 716, 649, 
                    779, 715, 944, 943, 819, 648, 869, 712, 756, 755, 714}], 
                    LineBox[{822, 655, 874, 719, 945, 622, 585, 991, 720, 656,
                     875, 657, 724, 993, 589, 788, 591, 892, 664, 891, 665, 
                    893, 592, 789, 954, 879, 880, 876, 878, 877, 950, 783, 
                    948, 949, 947, 946, 822}]}}], {}}, {
                  InsetBox["\<\"\[Mu] = \"\>", {-1.8, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["0.2`", {-1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {InsetBox[
                   SubscriptBox["C", "J"], {1.4, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["\<\"=\"\>", {1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["4.43`", {1.7, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {
                  {PointSize[0.05], PointBox[{-0.2, 0}]}, 
                  {PointSize[0.0125], PointBox[{0.8, 0}]}}, 
                 {PointSize[0.007], PointBox[{0.4463998339305619, 0}], 
                  PointBox[{1.2771956561278897`, 0}], 
                  PointBox[{-1.0806611991222994`, 0}], 
                  PointBox[
                   NCache[{0.3, Rational[1, 2] 3^Rational[1, 2]}, {0.3, 
                    0.8660254037844386}]], 
                  PointBox[
                   NCache[{0.3, Rational[-1, 2] 3^Rational[1, 2]}, {
                    0.3, -0.8660254037844386}]]}},
                AspectRatio->1,
                Axes->{False, False},
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                Frame->{{True, True}, {True, True}},
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLines->{None, None},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None, "TransparentPolygonMesh" -> 
                  True, "AxesInFront" -> True},
                PlotRange->{{-2, 2}, {-2, 2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.02], 
                   Scaled[0.02]}, {
                   Scaled[0.02], 
                   Scaled[0.02]}},
                Ticks->{Automatic, Automatic}], 59->
               GraphicsBox[{{GraphicsComplexBox[CompressedData["
1:eJx1W3l0zNcXj7Wo+RVVYkQURbSoLXZudWqp0s5RJUfbqaU0xNYokaD2aRpF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                   "], {{
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[0.3], EdgeForm[None], 
                    GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxNm3f819MXx9/33qIobaOMQiorI1JGsktllBEhe0ZWlOy9QylZhfgVUmSv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                    "]], PolygonBox[CompressedData["
1:eJwtlwnUV1MUxd89t0hkRVhmMkQpEqkMob6EaFYUSQMNVEqsslJECSFJZo3K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                    "]]}]}, {}, {}, {}, {}}, 
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwl1Hl813McwPGf4iF/5I9QVFSomCskM3KnY2m2kqwtLA821oouZTNUjorS
uTZs5YqOtQ5bkkU5lqhHCFlsKWePytxnnu9Hfzx7vT+fttr38/t81ylnZEbB
EYlEYpg/rmmeSJzKXLKbJRLz9Fp6cRrzGWa/RK+jN6ezgFvsl+ov+hJl5sX6
G79yNqn2CrSfjtRl/GReqn8wiuW8b+8c/ZNupFnfwADGWK+iybxS/2I131uv
0bHU8LN1tf7NWn6wfk0n0tncha5cYP0vF7HN+nU9xH+s50d7b+gDnGE+kyR6
WGdqcTxb/LwMNydzpPko6sxLdTnLOJpKcsnjTu7mLqpoGWfqe3bqLD1ALn0Y
Y28sF5PMJaTavz8+F03RS/nEvF8/1uP1BMri59dSzeN6iq2f1su0Jzvj/9PP
9URN16/0WT3Il1HrXdpWB+luXaQP6xU8xIO8Gc9kfyCN5t26kJPNN+lefUEn
61U8b56k7/JOnEncC77hPeu9WqedGGqepbOZwVPMJNP+E/okU5nONG62/5g+
zhQe5RGG2O+og3WP7tEOegqbeJuNvMWVPOfvvw7mG7W9VugGbdRabdB2uj7u
TNwl1nE55XGeNJgz9KS403GuWq/P8AW7rNO0Tdx3rdfPdAGF5hItirvMWlpT
ww771fqpHqet6B//pn6kcxgX56bjdbu+Gu8ho8ingBHxHnEsq1gd7xlbfP0x
2iLOw3xHvJvm88gmixR7t7Mv7gTb455qIs4vzjw+jzi/uAdx9nF/qPU1g7Qo
7owW6jq2mrtrTrzfcdf50N6F+g8V5oVxnkywTtf74rn4wHy+3hbPHXfJeryO
poot1ufqrVTynfUKvYf+5nvjPYnn09/j84l3Id4ZlliX67fxfbzMK+THuxpn
qH31LG2K30W8yGZ7SZoVn4f56uaHf+f+D8xNvyA=
                    "]], 
                    LineBox[{706, 1004, 705, 769, 571, 979, 643, 749, 750, 
                    572, 862, 644, 817, 818, 819, 577, 778, 650, 718, 1012, 
                    717, 783, 719, 1005, 720, 652, 784, 585, 889, 661, 888, 
                    662, 890, 586, 785, 655, 721, 985, 580, 615, 653, 999, 
                    654, 651, 714, 983, 578, 822, 821, 820, 646, 863, 574, 
                    981, 710, 645, 709, 980, 573, 771, 567, 977, 708, 641, 
                    770, 707, 933, 932, 811, 640, 859, 704, 747, 746, 706}], 
                    LineBox[{814, 647, 864, 711, 934, 613, 575, 982, 712, 648,
                     865, 649, 715, 984, 579, 779, 581, 882, 656, 881, 657, 
                    883, 582, 780, 944, 869, 870, 866, 868, 867, 939, 774, 
                    937, 938, 936, 935, 814}]}}], {}}, {
                  InsetBox["\<\"\[Mu] = \"\>", {-1.8, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["0.2`", {-1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {InsetBox[
                   SubscriptBox["C", "J"], {1.4, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["\<\"=\"\>", {1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["4.42`", {1.7, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {
                  {PointSize[0.05], PointBox[{-0.2, 0}]}, 
                  {PointSize[0.0125], PointBox[{0.8, 0}]}}, 
                 {PointSize[0.007], PointBox[{0.4463998339305619, 0}], 
                  PointBox[{1.2771956561278897`, 0}], 
                  PointBox[{-1.0806611991222994`, 0}], 
                  PointBox[
                   NCache[{0.3, Rational[1, 2] 3^Rational[1, 2]}, {0.3, 
                    0.8660254037844386}]], 
                  PointBox[
                   NCache[{0.3, Rational[-1, 2] 3^Rational[1, 2]}, {
                    0.3, -0.8660254037844386}]]}},
                AspectRatio->1,
                Axes->{False, False},
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                Frame->{{True, True}, {True, True}},
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLines->{None, None},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None, "TransparentPolygonMesh" -> 
                  True, "AxesInFront" -> True},
                PlotRange->{{-2, 2}, {-2, 2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.02], 
                   Scaled[0.02]}, {
                   Scaled[0.02], 
                   Scaled[0.02]}},
                Ticks->{Automatic, Automatic}], 60->
               GraphicsBox[{{GraphicsComplexBox[CompressedData["
1:eJx1W3t4zEf3j8qLppY0VFnqTrcofmpbJXXoohUpW1W36rqrWpf+QtVqeL2p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                   "], {{
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[0.3], EdgeForm[None], 
                    GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxNm3f819Pbx9/nnJBKQmZRERJlFUpLCAn9skrZKxnJyuonKyskysqIkl/R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                    "]], PolygonBox[CompressedData["
1:eJwtlwf0z1UYxn/3vRpGdSqKTiUhKiuUptAyMtOgZGUmDZRKUlpSNBxJmSEi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                    "]]}]}, {}, {}, {}, {}}, 
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwl1Gf0z1UcwPEfzukBEZEZsjIKxyjZsvfM/nNwjGRm77I17OyRSiF7z7Ln
k8qMQvY4dsp84PU5Hrz+78+9Hv3u9165OvRq3DNZIpFI8ufDFIlEVqbRPHki
MV0rU4VsfEML+zO0KtV4k5m0tD9L7+liZpt/1AfcJx+17H2iNbWb/sx18zJ9
SHeWs9fe2/ofBaln3Vvr6qe6hhvm1fo/a/nHep32YSM3rTfoIzZxwXqzDiS7
OQc5ecf6CUU4ZL1Vn/GUbVy0t12H8pY5F7kpat1ch2lezUcbczFamluRnwK0
s1eazuYuFKM4HexV4GNzV0pQko72KsdvMfflPd6nVJy5/cE6XT/Q0hw1X9E/
9FVNzSzzsPg22okaDLeerWW0LKfMV/WkptU6elLn6i3+4pr1GX1d6+tp/VY/
0/IsMI+Ic2MLneN78af5vC7kDXMj/Vu/15Fake/Mn+tOfo2zsb7NJXZZX9Td
moWm5sk6ha+ZxEQ+sv+lfsV4vmACTeyP1XGMYgyjaWw/szaM36cXNJNmZAe/
xPdmGxVYFHeLM+YGmkHn62Y9F3dLz2r6uG9sZH3cRcoxL343p8x1NZ3W1hN6
WufEWXHcupa+pjX1mJ6It8aQeHtxB3Uta0gT959j9lfpcU2lKaluPqq/6xT6
mSdrf/1NV2oPesZ7pHu8R1bwCss5FO9TD2tyTUYZc3sKmQuSROu4t/baxpuM
e8GRuN/6nEXx7WgWZx/fK75N3KE4b//eSIdoQx2sWzhoLqxJcT8ZxAF77+pj
FpgXxvdggHV97a/r2W8upK3py1nrftorzol91vm1FSs4b71Se1A7zkTraAH9
l7nxDZnDUuv5ejneGz+xJN4v1e13jXemefUOd/mBPfbyaDOmmiulePl/7QsI
PbaU
                    "]], 
                    LineBox[{703, 995, 702, 765, 564, 971, 640, 746, 747, 565,
                     861, 641, 811, 812, 813, 571, 771, 647, 715, 1003, 714, 
                    775, 716, 996, 717, 649, 776, 579, 887, 657, 886, 658, 
                    888, 580, 777, 652, 718, 977, 575, 611, 650, 990, 651, 
                    648, 710, 975, 572, 816, 815, 814, 643, 862, 567, 973, 
                    707, 642, 706, 972, 566, 767, 560, 969, 705, 638, 766, 
                    704, 930, 929, 803, 637, 856, 701, 744, 743, 703}], 
                    LineBox[{806, 644, 863, 708, 931, 607, 568, 974, 709, 645,
                     864, 646, 711, 976, 573, 772, 576, 880, 653, 879, 654, 
                    881, 577, 773, 937, 868, 869, 865, 867, 866, 936, 768, 
                    934, 935, 933, 932, 806}]}}], {}}, {
                  InsetBox["\<\"\[Mu] = \"\>", {-1.8, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["0.2`", {-1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {InsetBox[
                   SubscriptBox["C", "J"], {1.4, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["\<\"=\"\>", {1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["4.41`", {1.7, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {
                  {PointSize[0.05], PointBox[{-0.2, 0}]}, 
                  {PointSize[0.0125], PointBox[{0.8, 0}]}}, 
                 {PointSize[0.007], PointBox[{0.4463998339305619, 0}], 
                  PointBox[{1.2771956561278897`, 0}], 
                  PointBox[{-1.0806611991222994`, 0}], 
                  PointBox[
                   NCache[{0.3, Rational[1, 2] 3^Rational[1, 2]}, {0.3, 
                    0.8660254037844386}]], 
                  PointBox[
                   NCache[{0.3, Rational[-1, 2] 3^Rational[1, 2]}, {
                    0.3, -0.8660254037844386}]]}},
                AspectRatio->1,
                Axes->{False, False},
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                Frame->{{True, True}, {True, True}},
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLines->{None, None},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None, "TransparentPolygonMesh" -> 
                  True, "AxesInFront" -> True},
                PlotRange->{{-2, 2}, {-2, 2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.02], 
                   Scaled[0.02]}, {
                   Scaled[0.02], 
                   Scaled[0.02]}},
                Ticks->{Automatic, Automatic}], 61->
               GraphicsBox[{{GraphicsComplexBox[CompressedData["
1:eJx1W3l4k1X2Ztitht3KRKlaWTIVEZGwCR4wgLIIlWXYI4sgTlgrA5RByrAU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                   "], {{
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[0.3], EdgeForm[None], 
                    GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxNmgn4l0P3xp+ZUZbKlrL0RmQXWUOFQpYs2VKULXsiSWRLdspWlEj2FEKU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                    "]], PolygonBox[CompressedData["
1:eJwtlwm0T1UYxe85J43UWg3SnDKEzJqUKZVCpgaz9GSIIkWmUKFBKkU9MkSm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                    "]]}]}, {}, {}, {}, {}}, 
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwl1Ht012McwPHfdPqDyCW5xaG0yG1EoiGhVVp3pDa3HNrsksp02yjX7jVd
lqiVcimxyGxW7spWYbpRrDW5nVMbpXL7x+tz/PHq/Xmedc5vv+f5ftd2+MhB
+UmJROJe/6Q2SyTOpJg7j0kkntPruJ6zmMtQ+/P0BrrRhvkMs79Af9NXKDG/
qgf5nQ7cbC9Hb9JcXU2j+XX9gzzeoNreBXqYi+hpPUrTdLS+TZP5LT3CWn6x
fkfHUGpeyossYTFH7S/Tl+jLo9bpOlYr2GS+RP8ihS+s39N/+Jvl1lU6UCfq
AC3U9XxpvlyHaJGeq+dxt7kTQ+N8aMf53GevKw+aR8Tncin32+tGljmby0jh
gTg7RpvHxGdxBZ1Is/+t1sa9MD7uQyfo1jgbbcHxLLT+SUvis+nFbutv9Hkm
mhdpoZbHeXIi6fbq4jx1P99xwHq3nqz9da8u08e0C6XmIn2f9fE9rftRb67X
pZxqHqT7dIVO0mtZbn5cP+UTsuLz+IHPrDeygTO4w94snc10ZjKD2+1P1Wk8
wxSe5Tb7T+nTTOZJnmCw/dN1YHyONuhp2pqP+JgP+YBr4jmK70yDeYC2imdN
1+kerdI6PUUr41migne5Op5JP/uePfE86knaJ/Z0l74Q9xpnbX2rttTe2lmv
4koWWO+MOzHv0BN0W7xvul2P02Ppad6lX2sxj5jnaIF+Fe+T5pHPQ+SSE+8X
zVlDtf9XpjWapAlSzcNJNrcnk4z4/ezdw69xp9TG76v/8nLcTdxb3H3cR5x9
3D/r/Ly/TohnRcdrJVviXdC74vllHJvjndE/KY/PirPVc/RsCsx99GLNjO8c
z3ucZZwjD1uvocZ8oWbwJj9bl2k+t5hHag/tqIfiPYl3JN4lVsU96T79kddY
STY3xllqd03WRpri+/N5nFf8vWCOuWuz///2/gf087nD
                    "]], 
                    LineBox[{703, 1001, 702, 764, 565, 977, 641, 745, 746, 
                    566, 861, 642, 806, 807, 808, 572, 770, 648, 715, 1007, 
                    714, 774, 716, 1002, 717, 650, 775, 580, 887, 658, 886, 
                    659, 888, 581, 776, 653, 718, 983, 576, 612, 651, 996, 
                    652, 649, 710, 981, 573, 811, 810, 809, 644, 862, 568, 
                    979, 707, 643, 706, 978, 567, 766, 561, 975, 705, 639, 
                    765, 704, 935, 934, 798, 638, 856, 701, 743, 742, 703}], 
                    LineBox[{801, 645, 863, 708, 936, 608, 569, 980, 709, 646,
                     864, 647, 711, 982, 574, 771, 577, 880, 654, 879, 655, 
                    881, 578, 772, 942, 868, 869, 865, 867, 866, 941, 767, 
                    939, 940, 938, 937, 801}]}}], {}}, {
                  InsetBox["\<\"\[Mu] = \"\>", {-1.8, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["0.2`", {-1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {InsetBox[
                   SubscriptBox["C", "J"], {1.4, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["\<\"=\"\>", {1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["4.4`", {1.7, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {
                  {PointSize[0.05], PointBox[{-0.2, 0}]}, 
                  {PointSize[0.0125], PointBox[{0.8, 0}]}}, 
                 {PointSize[0.007], PointBox[{0.4463998339305619, 0}], 
                  PointBox[{1.2771956561278897`, 0}], 
                  PointBox[{-1.0806611991222994`, 0}], 
                  PointBox[
                   NCache[{0.3, Rational[1, 2] 3^Rational[1, 2]}, {0.3, 
                    0.8660254037844386}]], 
                  PointBox[
                   NCache[{0.3, Rational[-1, 2] 3^Rational[1, 2]}, {
                    0.3, -0.8660254037844386}]]}},
                AspectRatio->1,
                Axes->{False, False},
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                Frame->{{True, True}, {True, True}},
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLines->{None, None},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None, "TransparentPolygonMesh" -> 
                  True, "AxesInFront" -> True},
                PlotRange->{{-2, 2}, {-2, 2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.02], 
                   Scaled[0.02]}, {
                   Scaled[0.02], 
                   Scaled[0.02]}},
                Ticks->{Automatic, Automatic}], 62->
               GraphicsBox[{{GraphicsComplexBox[CompressedData["
1:eJx1W3l4jFf7jn0dQVPaqf2nOpaST6VS26MdDVJltPbqFEVbSa3RdnyxVvOV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                   "], {{
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[0.3], EdgeForm[None], 
                    GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxNmwnYl0MXxp+ZSUgpJaVQCpVosSRbspQlWbITpc+SNTtly5YllLILRSEl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                    "]], PolygonBox[CompressedData["
1:eJwll3f4j2UYxd/neVSujCtEe8dFJFkhpciqbCojsomQ3bAru4mSlbIje4SQ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                    "]]}]}, {}, {}, {}, {}}, 
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwl1Ge4zmUcwPHHOb3xIi8IUbJddkPZRdkrO/OQI1e5ZCYryjj2KmRvki0r
MjOSURmv7J3scSF7fH6XFx/f330/53gu9//+y53auUGndIlEIsUflZMTiTxM
oVVSIjFVq1CVvEyjtf3pWo3q5GMGn9qfqfd0BbPMv+gD7lOU2va6ai3tpr9y
07xWH/EV69hnr5g+5i3qWffUutpLN3HLvFGfsJnL1lu0NwvMPzOPn5jPU/sL
dRGf0Ne6sfbTbfxtfkcT+p4e0B2apOlYzE7r5jpAm+lA3cVBc0ltrWlaUAvx
mbk0bcypFKEon9urQGdzl/i++H3a26tM1zgfSlGaDvZq0Mf8DWUoSzlq2z+m
R3QGA8wzdaAeizPWV8jMHOuLOlu/5GNOWJ/WuQyKM9M0Xc86XqWBvdNxlnqb
89ywPqfZtbGeizPSIVqRhebB+jtb6WjdiLPmi7qIHOamekGX6TD9iKXmobqL
P+hkfYcr/Gm9h93kpqW9iTqJ8fzIBFrY/0HHMYbvGUtz+6N0NMMZyQia2c+l
TfRfvaw59Y24B/Hs2c42PmSJzy/FWcR90tfjzukW/S/upF7Q1+KesokN/EYF
FsT3cMbcULNpfT2lZ3V+fMZJ63qaVevqB/o+5ZkVP89180nNosfjGekJzaQZ
qWM+rkfjnaaveYr208PaI84p3j/9mu6s5WUycMhnR7SKpo/nq19Q3FyMdnHX
417aaxfPjrbWw/QlTY7zIoVW8WwY5LOW8Xy1qfbXJvqdbme/+d34e+Lfx7f8
Y6+EPmNr3Ie4X1pA88e7EXdM39bUeF+oH+cbd5ge1hv4y1w83kvWx3OM56Ld
qRNnEO+GvqkPmWNerbN1TbwrelWvsZJV8S7HO2q/i9bUInqX/1nOXnuFNYXJ
5krJL/6/fQ4Jt7yC
                    "]], 
                    LineBox[{713, 1004, 712, 773, 570, 979, 649, 753, 754, 
                    571, 870, 650, 815, 816, 817, 577, 778, 656, 724, 1010, 
                    723, 783, 725, 1005, 726, 659, 784, 586, 895, 667, 894, 
                    668, 896, 587, 785, 662, 727, 986, 582, 618, 660, 999, 
                    661, 657, 720, 983, 578, 820, 819, 818, 652, 871, 573, 
                    981, 717, 651, 716, 980, 572, 775, 567, 978, 715, 646, 
                    774, 714, 941, 940, 807, 645, 864, 711, 752, 751, 713}], 
                    LineBox[{810, 653, 872, 718, 942, 614, 574, 982, 719, 654,
                     873, 655, 721, 984, 579, 779, 583, 888, 663, 887, 664, 
                    889, 584, 780, 948, 877, 878, 874, 876, 875, 947, 776, 
                    945, 946, 944, 943, 810}]}}], {}}, {
                  InsetBox["\<\"\[Mu] = \"\>", {-1.8, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["0.2`", {-1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {InsetBox[
                   SubscriptBox["C", "J"], {1.4, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["\<\"=\"\>", {1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["4.39`", {1.7, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {
                  {PointSize[0.05], PointBox[{-0.2, 0}]}, 
                  {PointSize[0.0125], PointBox[{0.8, 0}]}}, 
                 {PointSize[0.007], PointBox[{0.4463998339305619, 0}], 
                  PointBox[{1.2771956561278897`, 0}], 
                  PointBox[{-1.0806611991222994`, 0}], 
                  PointBox[
                   NCache[{0.3, Rational[1, 2] 3^Rational[1, 2]}, {0.3, 
                    0.8660254037844386}]], 
                  PointBox[
                   NCache[{0.3, Rational[-1, 2] 3^Rational[1, 2]}, {
                    0.3, -0.8660254037844386}]]}},
                AspectRatio->1,
                Axes->{False, False},
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                Frame->{{True, True}, {True, True}},
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLines->{None, None},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None, "TransparentPolygonMesh" -> 
                  True, "AxesInFront" -> True},
                PlotRange->{{-2, 2}, {-2, 2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.02], 
                   Scaled[0.02]}, {
                   Scaled[0.02], 
                   Scaled[0.02]}},
                Ticks->{Automatic, Automatic}], 63->
               GraphicsBox[{{GraphicsComplexBox[CompressedData["
1:eJx1W3l4zFcXVkurqYmlqA61VXXaaqNq2iKcMl83lKGIBqmlVBMltupo2toa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                   "], {{
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[0.3], EdgeForm[None], 
                    GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxNmwf819P3x9/3XiWlSJHVEJKiRaTsLVklRUoywg/ZxY9URsoMPyMyI7Iz
S4gkM4rkZ4/sXUbqh/959np9/3k83M793HHuufee8brn/bXBoCE9T8xVVR21
UlWVoP9KVfVh0A+ibB/1NaK8G/X3o8SQqkGUD6NtUpT9ojSN36tFWT3KxsFo
oyifRXsztzWMsmG01fbv36Lv1yj7RPlv/A5SrexxtV3fPMZvFmWDKE/GgGlR
PqE/a/31oqxvWVi7TrSvHOWAGNfcvNZwgV+dKI1MV4myU4xrHOXjqLfwOPrb
+/cGyBxlzShrRamC99cx/ssoLeNnY/f1it/rBN0kyqZR1rVsrSu187utZW1q
vo08v80/9rGZ+zmzDh7HOh1NkaWT6Uacj8ey18+jtIrSOUo7t7GHgVEOiNKT
Mw75TwlZT44yNn7fEGU8skT7GlE+j/atvQ9k385rwG97U85mW8tK35pZv3tE
2cH9yL6Nz4L97eg29tHNZ8H8ru7n907uZ38HJe1jtyh7VpKpS5Tu5su8fyfx
2jvKXu6nb+0sufeJsrP5bRFllxjfJMoXUd/KZ8U+9/PekH160rx+UYZG/Ywo
u0T9qyi7RjnQ57iTee/rM2J+hyx5e1uW1t7/Qd7H7r6HHT1/f6/J7z7u3wNd
iDW/9V7Xy1rj0CgDLCvzDjOFX3/LQV+TGP9UzP8u6n3Nj/P7NtqeSTqnw72H
XuhOlrxHRrk1yhVRxkVZHGNnRfkx6s8nrX9slMGWFd5nRDkuyr+iNI8xP1mW
oW47PsoG0f6zZT/aZ8H8o3xO/F7k/cCrX4w/IuiJUU72OOZdFO39k2RY7LGn
Rzk/2s5Lkmup5w3z+vAcaDkGet8nea/wPdPjh0QZE+UsdCrK2V77lCgvBe8X
o/zmvpPcNzvaTgs6IsoSy3Iedxjtm0b5PeoX+IyGmvcQzz/f4+lbZnkvrGSP
NeuXuJcfg8/3UeZEeS3Kn9G+apbco31X51qGi7wf1mkTY5pH+SbqryaNudzr
H+H9j/O8kVGuNB0V5Trzht/1ppzNkUnt11byF2Ms741RLo5ySSVfMta/V8vi
NSnKf7xnzqNetNeNMij4rRL0smi7KcptlglZbrG87O92t10Fn5hzdRK/nCTL
nVGu9tmzxs2VeDJ/oufRf5f3xp4mew/I+5hlpP++KBMsz/2m8HvAFLnuNg/m
P1TJZpD9Xp/FBK85yjI96HmMwxbxO/iye7w+cx72PpH3ccvCOoOTZHs0yhNu
Q/Zpns+aT5oi+xTLAq+VYm6JckfUp3oec/AxnS3HdM9jr0+ZstcJSecyM8rz
PiPkmhvttZLkmRvlhSizo8xyPzISY4mhDd3/hNcfH/OuT9rrDJ/dFM+f6j29
bJmQ5ecYOz9p7DtJa7we5Q2vB++Vk+SbE2Weeb3oMs1n85IpfF+N8nSUZ6K8
5T7WnGRcAx7YKur1ktZZNWmfb3NmUa+bJMObXoP5tyWtvaBSfNuxkk9/PNon
Jo3dImidpPXfC/pK0PlRukS9fpIsYCDODgwEzvooaN1K+AlsA94CT4GfwDmf
VsJh9SthKPAXmKZhEl6rVQm7gavAUq/4XJ/2b+4HDFaDh7gzcNBnlXAOOOsA
YxpwwceVcA7YCuwFnkEOsEoN/oKCY+gj7hH/NjOmaOz1mnkO6zf3b/iCZ1pa
FjBPi0oYa0PLc2ASxiJmr2PexG5wYSPf3RqeB18w2sJKGAmZ2lgm1gZ3tPVv
8EIXzwO3tPP6Hfy7Bnt18P7amhf4qZP5N/e8zT2H+9++WoHVOrrsZP1o5rHI
wX6wxc7m29UytbZcW3vNbu5jHnhj22oFJuP3l5Xw35Y+l63NdzOPZT5+GX9z
g+Xa2TIR32Y7TjAPvICvArMQn3ubF227Wz6wyV7+3cfj6O/r313cv6f3trv5
9UnCdmCpLyzDFj4XsAyYBszV031gKjDXrpa1p8eB8Xp4b+Cavl4LTNjdZwUu
3dt754zASPtYVjAFGOCHStihr/vBL2AdsNQA/waD9fPcryvhiF7VChzGOOwK
3/mg5RvoPrAYmPKQqH+XhMO+9T4O9zhwFhjrmEoY6ljL0NsyHmleYBpwz25J
uGqRz3qw90PMB88R45+xLPjZHSxrDc7dz3tl7ePNd4Dx1aleA2yyHNMk4Z2j
3UYMP99zhrqN9cAWYKlf3H68ZWduDeY66R/jwCrD3A/eAfeAmUZUwlV/V8JV
oywHaxJPwVZ/VcIrf1ieoeZ7lvmeZH41v8Ewo80D7AAeqIwjmA/O+l8l+0jG
WZdWwloXWk5sAzwCrgCLgavAGd/7HcUevve+uddDk7DsCVH/1f2nWC7Gj/Fe
x5nveZYL7HBUEt66plqBw67znPH+Pdpt13qfYzy2Bs+N89ld5d/4X3wZvg3s
hR8As32cJOsgywFOucXzb/Pvy912s3nd7j6w2MR/yD3RfYxF97CHyzwPLLVX
jG+XhN3Ah3dafvwR2GSy9wbOAQMh473uq8Fk91UrMNn9lu8hr3ed54GZJnjs
vT6zyeaL3FP+MQc7wXaPScJbj3g+mAecU4xZJpr34+6DN5jiScsH3pjqNZ7w
uBp8Nq1agbGYs06SH+llOWZYjuuNd5APrAUOe87rgXNmet9Pmxdn/bDHs94s
j2P9F/x7suWqwWGz3VeDjcAx841NkGFREvaqnbQO7WCH7vG7YxLmgi/4CCwE
NptTs24S7gHTPOV5L3u9uZ7D+vP8G0w03+OQBRwEXro1CW+Bw8BXb3s8eGqB
508375o9vOn2HkkYDuw2zX2suR06l4SH7gk62figVRaOAr+0y8JO4KMdon/1
pD7aPnR7oyQsVC/KX1H/wliNPniD4f6Ed5T3KmEbxoNh/hdty6KcGGXnKGsm
xey/g35l7PW724iZxD9iJPmHdZNyEMTCtiFnyyzMekISFgQHrpU0nniKb2yT
5N8ODtrUOtci5o1IehvShs/CXx0C1vLvtbLyB8TOGUkxkvhILCQ+EZtmoptJ
+YFPkt7H+EhiL/GN2L9NtLdImkOM/Nk8WiW94fHrLR3HiDmsT/zAh26U5Dfx
mTnk+cG/N06KE8QIYuIi8x4Y7Zt4/sVJfFljRKXxI30elc+EsZwRsePwpD5+
4zOJO/jjV6Lt5aS8QuusuIA/a5v0bic2tHY/MYL4QRy5xOv9ZX67Jt0fZ35V
UowhvuD7sv18e/tFfCJvtmLfCo+/zWePpLNDvq5BOySNeyPK60lvszdtuzMq
2ST2it/oZNvFVt8Ouopt/l1sIult0y3Klkl2ia1if9g4erd2EgbDRrFv7A2b
XNVj3w/aIKkfO8DWOG7sBztayXrL24Z3zY5JtlTP9sK7pZZthXcI9nJakk6j
z1vbpvEF2Ae208r2QU4PG2E/yI4/OTPJz+JjyYdw/tgOer1+km5/bRtA/9Hx
ZklYCj0ln4Wu3hf0LN/fOUm5ue62A3T7WOsgeAw9fM9ngG96IAmrtbRdod/o
9tgkPUaHHwx6ie/1wiS9P8U6SBs28lDQPZN0bbFtBnv5xXqMDi+zLg6zvoOT
0MFxSfqKrn4Z5/BXUQwu1p+HrSMdrSfXJekieojPw29ynw9bP3jL3p30PWD5
m9ltr1qX21mfufzNkzBWHevVfOvLVtYZzhgfwVluYf6M5V28bZKekcfoannx
c/jl962bna2fjwZ9xHwbeD53gH6R30en8Mu8sXnvjkqyyW98ltwRd4iukSNG
p7gfcnm/+1w5/6W2RexwiW2qu+2K9xc+/XPbMlgne997e+9879g3Lf+EUO2f
9GanjkzUV7Ge97Cu90x6g69aaR7yx3/L8/en2S74/gIvvtc85nNj/7yRmctb
/Hjzgs9HSW/ptW1DvZPsqLfbqS9JikO80/omvdmwfQptvOPAZuBIcBZzeJtv
4rmM39I+o6/nLg36R9IbA58KNuYdsFJW22kewzuEd9ARSfwvsczETNYAr47w
/MM8njfLlUlzGN8geNbPwtDE3CFJ34xoB1tjCw2jvnoW5sN3QsF75Cfhc6nH
gAuxhaOT5qLbfGPiPIm5xyaNATfi+zezDIxjfXw8Y0/weM74JJ9/L++LuwKP
kFMgnwA9xfd7qusbV/KRxyXhkSGeC59OnsN4cqvkVbkX7uF038XtSVgK/MR3
DfwjvhG/hn/Dx98bdFiSL+VdxtsPX8T7mXd1V7ed7/azk9rxpcwb6rlnuN7L
8xjX3X53uMf38z3ydhyZZJPY42CvwXuT/pFuv8Dr0j/cPPe2DOeY/0jz5C2D
L7/A47nPq3yn6NpF1rcxruPD0aPR1j38+hi344Pxz/hdxo71XPzuZUmYAbku
9Jng4y9N8s1giitS9f9vTd5LvJUmun6H6X9cR7/GWT/xndd4Hjp1pfWq5nzB
htd4LmOIY+cmxRnarjVPdPM66zD+/oYkn08+9sYoz1ZqG+923hoTbAvQm5Le
IFB+z7SvImeKv7rec+Fzi8fP9PibPRe9Q/+I3fP8G+wAhgDTzzO9w/pJzLkz
CUOAZ643f2LULebPWOa8E/W7LE9xnfj0rnk+7jGNs3A/doTvJ66j+/j++5Pi
Nzzu8lx8PLGZ+2cu300n+4yQhzcXOJMYTwzp6XtB5xfanrFl7mGK76K+5WHf
+Hji1lZue8Jy4r+nJo3lrUAeFv9weRIOaO05xLt6HvuExx/g8fh56JOurxuy
r5OVh+KNzNsbv4T/oz7JutfAPpOcCbmPYbadev5eg09t4JwIfoZ2bIp2xo/2
vPoeU+Nb8Y2/JOVNhlfC0dTB0mB6sP3y/ElSLuZi+8765sk48i3kITbx9/36
9qt1/K2f/N7a/g5Nzq2J84Psm3Zyd+x/Hdeh63oM750mfvPAu475YzsNHSNY
Y2XnvTfNeg/U+FnoTT7X1Z3X2NTfuTgfzq6ux8JrdZ85Z8Lbib0RE3lvkC8C
Z/Cb+Mj769kkfPp00t4O8Z1S7+H90of8vLvIh+7p/T7n8fCh/eBK33ZpJ6dZ
KysGk/9tGnT9rFwksRqKD2TsTPN5ISlfiZ+E8ps3IHNnmSfvQPiNqCT7DK/7
jOu8JbHrt5LeKmN999x7LevMo9aROdaZfj4jzmdGpZwF+QrGvmEdgx98n7WN
Umcsb1Ny3Od6v9RPtb6sYx2g7SW34+fmWgbovCS55rkdn4a+rOW5a7q+t3Vp
TbcTo8EfxGliN+8ccgJ8mwD4NamUPyCPwDtoocfwDlrmuZ/4/Kf7bE+0X8An
kDMgdwAfMAI+Cv/GfbLPU30P/CZmFb+jz/FcZPjSPmOZ17rcPob3xBHRf3uR
X7oh6hcUtT8c9V+z3ozXRdu1RTmb8UF7FmHwG4MenuXzb4j6hKIYcEvQ24r8
92PRvzTLz0+KtruK/P6tQQdlxYJPg15U9Ia5Jepjit7E/b0v9rh/0LFFb55r
gu5X9C65I2ivIsw8OuiFRfvj/Yv+vGbfw7mgf9TJNZxjP0NuqLb1pZZthG9t
4Hhw+76ug8v3cx/t+Ajm8d2J9wBYGgzG/TT2HeEDGtpX8H2Mb2w1uSLq9Uwb
uY6eUGcscayx49G21r9uXmeJ1+rj+kEu9HW2zS62LvW3nWPj0KW26wGu0z/Z
enWyfcbitOJvQv7wePKFi3ye2PPPtrt9fCZ1bMv4O3zdjz5zzvkTt2PjtP+U
hKPnmw88f/Icxh/FvovOeb7vkrcnZ/PFP+yIvz/j22lt32MDnzPfI8k/QDd3
nW+I/CZHztuGb068WVp6DP3kzfi+Al7lOyz8a/kc8JnkxKD4wX4+56b2pZ2C
dswrvs1A+R7SyTzJSzT3GmBdvvGSiySnCNZv57UY08bjiSebOga9G+fxVhbm
vSno+CyfNy7o31mxgzdzK8c1+LU3z9bmQ5z6078v9d7b+nzI2VAHF4GZ2lhO
+G1iniu7XtsywYe4DR5v4X239FmCG1fzPvkmfGDI36HInn4KOj0rZ3RQ1DsW
vW87+AzZ+4BoOysr73pnkR/BhwyK+oisPCpn1cln3sxz+Z62OMa8kvU2fTvo
1Vn6vE20X5OV+3kT2bPi6aJofyHrrdzRPJHh+aAjs7DeeUEHF73r+gQdluXn
0Z2WPsNG1jN0rL3vd0PrKPq0mts38r286/NaxfrW3uORoYP3MjrocUVvPPzu
I1m+986gVxRhz4uDHpCVt7gn6JVFuB8f+WCWn9y/yKfjz78Pem9WvNsu2rct
+j60e9A9ANjEnKA/Z+FxcofkEMkrYtvYM3GWfCC5sJr8PnVyYtjrgqR163r+
6/YDnybp7Ttuh+cs/yaX+an5D7dekQsY5LU+SNo79H2v+57ry3OSSXxYC1/A
uXPm3yTFY2IolN8L7W/xF9xdY/sO/PNH7qtrPwOflRxPiaXkLfEN9HGP73kc
Y/h7AMbwLvjMc9Zy29duByPxjRi8dKj32M9t37md/Dq/wXo4wq8sP/GLOAaW
XmDfiP8k50AOpSbfQJ28QZu4x8VZeawvov5t1hvxm6j/kpW7urkofhO7JxbF
b2L3j8TrrPxcu6gvycpdtYz63W5fGPUDs/Ld92NrRW/CKVlxGh14CD9TlCO7
j7FFMeSzoAuz3r7kLL/Kyi1+HvXPs3OLQc8serd/AE7Jerv/L+iFWTk5fPJ6
9s9886YO/gczg6HBVfgX8mjE8Eewi6IY+2bQLll5x/nYgnnCY337efDIrVmY
ZFrQobb9SeaJyXwcbTdmxbUTomFsVr7l16jPy8qLvB31F7Ny2cdH/aKsnMqj
WbgK3f4py/awu+eCblyEdbHpmbZr7uGVors4N8snomvDs/bDXmYFfb4op/tM
tM8typW+FvTVojziC0V+ARv9LcbMLsq3gvVeNN7bM2hv38UH7KMoRu8X9ZOz
7PT1aGtvDPlFtD1b9B5eEvTrrFzpwfi9Igw/MOjZWTlLfPzT9vNzov2Norcu
9zPFd/RQ0HpFmOrlLP+Ob5+V5bvx29tnnS9ni15wl9xjf3xb0d+5P5kVe4g7
3CF+nHs8L+j5Rbke9Bq9R7d/IN4V2dfsqL9VlD+eHvSpopwCsesex697mVek
DzvGPzsU5S87x9zDimLszsSQrG9Zj0f9payc3CFR71eU+zszK/5xJtOK4hYx
a26WPqFLTYP2su2sG/X1ivLX2xEvsvBh32jbIutdguzdsuTvwnlkfTPsFnX+
hwC+DZ4V9QVZOXv0ZassnTk16qcV5Z72irYhWW807n+CdWA34l7R+5ED2DUL
q8wJ+lrWN5UFnEnWN5sHivQAHXg92tYo8ns7oxdZPh96ueuNivbP3j+Meves
7yhdgx6b5esei/Zji/KpW0fbMVm5EfpHeQyy/GV5/gz6RpavPTLrLRHN1eCo
T83y5+CUZVk6A7/7i3geGvVWRe/EpUEX2cf+XvSe4S3D++amojcOejQgS5f2
5R6KzvDjoD2yvkU8S3wu8vO8qzYvelthW7zTsC/s/nf74TOC5qJ8ErIckiXP
YUE3LYqtuwY9Jev7JzH/u6y4f2KRLWFHR2HTWW9DcHfvIuwNXru7CLMdnaXf
6DZ6h+9G9yZmxQD8P77hoyz/MJX9ZX374W53ybpf9r2X9QdfuJptFh+D38fP
NMRGi3J4dYL+O+tb4hlF+oE+cM/nZ901+G5+FsYDGz6X5Q+3CXpE0bdGdHPH
LP28mPMr+jZ4ZNCji97xwzmHopwfmGhoUXwmXv2YFbOw78ezzuGS+OfSovzv
uUFHFOWRb+Yss7D29UE/zMqBgdnfzcI/r2bZA7bQPyseE4v3yIpzxLh9g+5T
9P3hv1l6j87jCx+1Pzw92l8qyhWODDqqKDe9NzZS9E3jmyxfjB/GbpqYz2dZ
+oqughHQY3QYP903y1cTf/plxSB0ZIb1BPvmTYKNv5elx+hwnyycAcYAFzSz
bhDbWxTFdzD1w0UYrHbQWkXfGvENJ/tMmgc9KOsbCzYxM8suhuA/i75n/B+R
pzJ+
                    "]], PolygonBox[CompressedData["
1:eJwtlwn0T0Ucxd/MRIlCpb2QnLKksoSkCBGRJLu0SvakUFHZsy+RspOtQray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                    "]]}]}, {}, {}, {}, {}}, 
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwl1Gt0z3UcwPH/LEkoPfGAB5pCpQuaS1gd6Qi1xaqR2VbTSGorrFWkjC2X
Oq07ut/oZmsp1p3lkqx79MSTOLuZNZdk5MTrc3rw9vp8v39n////9/39/in5
RZmFSYlEIts/a5ITiQ0dEokTulPvWN+sWzRQ76nA/vu8VVkapA80w/6HPEMb
zetYwzPZUUPMeXyIuXyYX+tf81c8i/P5jX4xD2VnXsXpfJT5fIy1OmnezLP5
LQ9xCxdpvfkTfaSPVa0u+jS+n2Zpif93F8u4Xb+bR7Ibr+ZufsdzeU58J+2w
vodLOZvLWKc/zNfwfq7gMA7XbPNozTXP04h4DxXaGxef1Vyq0bpW99lL1+L4
fBqj6zTHXqaeMD+psbpe4+Ic7NezPs5LT5nXsIIN3MwU9Ynzs27ju/GZNFkN
1i1xpno6zpLPxDVVrfoq214z1zGJbTzOv9ifuWyJa80XeFNce/Pz3BrnEt/f
Okf7zX+zWgPMt7M1zoarmRlnZ17FH1SnB6w78Dh/5M/6SVdour23+LZe15t6
Q/n2X+Vrekmv6GXdYf8yXq52804e46X8XsXmHZyklXox7gP9E/cJt2mi1lsf
1QFzHi/mJToSzw8P8yIe5CkeYpWeNVfyOU5jP05lE1vjGYq/qUbr23ghpzCD
6bpRa+M6qt3czAvYyP/YxPPZW1nmGzhB4+PaWO/TMfNeLo1rwzI+rnJtUk/1
0h6v/ckM9oi/wSKlmUepJM4m7t14LuLeU7F1Bc9jd9WoKO5t3avlXiuMa80j
3MmhHBKfwXw308J4xlWuXfF+7Br3Ew/HOTCVV2qxeSZHcJZK4/fLeoYK9Ij1
Jv1qHhbPvSrNVXH/aYH14Lg3tND8G4ezE7/gQX4Zv1XxPvpMn6skniGvPcgp
8Vk4NZ6XODvlxBkr1X5ynFs8e8n//86eBpaAvLc=
                    "]], LineBox[CompressedData["
1:eJwl0DtOAmEYhtFf2IGa2IiJGwESGQsoNMoKWIBGKtiDTIJCofFS6HbAu0EB
EaW2EjvBM7F4ct4vmWJm1iv7O3sLIYRt3aZC+E6HcMNFbvCFTc4V7AJf+cgj
1ezj5Dm92UWu8CS59WsPucoRf/jOM2XsXX5ywitFdqxre8Iy13jJsT7sLR7o
XF/uC54m76WRu8Q8c8qq7a5zkwM+s6Un9d0Rl5lnjw+MtWTfccp7NlS1D9lV
R7PkG1P//+4Pfjkzfg==
                    "]], 
                    LineBox[{825, 662, 890, 727, 953, 621, 583, 989, 728, 663,
                     891, 664, 731, 992, 588, 792, 592, 906, 672, 905, 673, 
                    907, 593, 793, 959, 895, 896, 892, 894, 893, 958, 789, 
                    956, 957, 955, 954, 825}]}}], {}}, {
                  InsetBox["\<\"\[Mu] = \"\>", {-1.8, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["0.2`", {-1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {InsetBox[
                   SubscriptBox["C", "J"], {1.4, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["\<\"=\"\>", {1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["4.38`", {1.7, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {
                  {PointSize[0.05], PointBox[{-0.2, 0}]}, 
                  {PointSize[0.0125], PointBox[{0.8, 0}]}}, 
                 {PointSize[0.007], PointBox[{0.4463998339305619, 0}], 
                  PointBox[{1.2771956561278897`, 0}], 
                  PointBox[{-1.0806611991222994`, 0}], 
                  PointBox[
                   NCache[{0.3, Rational[1, 2] 3^Rational[1, 2]}, {0.3, 
                    0.8660254037844386}]], 
                  PointBox[
                   NCache[{0.3, Rational[-1, 2] 3^Rational[1, 2]}, {
                    0.3, -0.8660254037844386}]]}},
                AspectRatio->1,
                Axes->{False, False},
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                Frame->{{True, True}, {True, True}},
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLines->{None, None},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None, "TransparentPolygonMesh" -> 
                  True, "AxesInFront" -> True},
                PlotRange->{{-2, 2}, {-2, 2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.02], 
                   Scaled[0.02]}, {
                   Scaled[0.02], 
                   Scaled[0.02]}},
                Ticks->{Automatic, Automatic}], 64->
               GraphicsBox[{{GraphicsComplexBox[CompressedData["
1:eJx1Wnt8zMf6DkIVq6FxOds0bbVl604brVa92Natqls0bdFVt1AJelC6qUuo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                   "], {{
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[0.3], EdgeForm[None], 
                    GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxNm3f819Mexz/nnIaMJmnILiuuayUhlBVKycrOyKxsWaVSZK9IkYq4RhnZ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                    "]], PolygonBox[CompressedData["
1:eJwtlwf411MUxr/3XjMaSoWiHQ1JS1rakmiJBpXQLg20ZJT21DBKpaIl9Fci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                    "]]}]}, {}, {}, {}, {}}, 
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwl1Ht0znUcwPGfTSoVyskf4tRmRjZGMhVNNqPSxdZUjlK5xYjoKKWUe9dl
NSkUo3IpculKV9cuxFq26eIcrWhJ/0vh9Tn+eHl/vt8dz3me3/P9PmnDJxZP
aJQkyRD/PJuaJItTkuQnBvGMdRbZnMcLFNkv03r9nSV8an2p/kE6PaxzuZKr
6Ek7+9foSL1aR+lyDpsr9QijWcFn9jL0TzrwpfVbWsoF5nJeooKXabD/NgvM
C3mFcdaLdQmvsojX+Mv+61pAP/J5wN5qvjJfrn+TzTbrNfoPx3jDeikDeNC6
v07StWw3d9ab9CG9SFtyuzmH28wlXEwr7oznxHDzCFpzCUPiOTHWXEob2jLU
Xh6T4/XjeXMZafS1X6U79DmmmJ/Xh/Vd3uGE9X+8yM/WZXoXBfxg/a3O5xHz
o0xlLafsDWB/PHM9xAbzRtaxnvdoxI3+9kQ8f31cF8Rrx7kwV+kwbqDGuloX
cpb5Zj0Q35HO0k7xXZln6gHdovfp5vh+mMFTfMK98cypM9dpUz2XW83z9Glm
M5c53GL/bD2HWvPHWqNN9CPuMX+oHXmS6XzAfvvv6yY6xJmy/pFa80BN1cbs
i3uhezVF92iDfq8VPBZnVqfp9Zpo/3gt3a3lfEe1daGepB93k2mvfdxD8zfU
m7/W/9kZ98V6l/7LcfLJiLtHejyLONP8Zt6qE+JZ6ri4A4yP8879jIm7ymhG
sSrOLIPjTJPr/92hlQyiKL7HeO7xjFkW5yGeTXxOJsd3H2dRD8a51Au1BRPN
hZqlg/kl3htb4yzoUVbya7wPba7N4txzXXxX9koYz7XWfciLz2D9Jp/Hc4s7
GOffPJ9e8Tmtz9fejDV/oZnxm8TSeB/xOeK+UBy/G/EbEHeWzv42QrvEPdSu
2o0cunNF3M141nEn4z6mnvl9PQ1z6avT
                    "]], LineBox[CompressedData["
1:eJwl0L1KQnEYwOG/ehHWEngDoTUUNNQliJuOXUAtallDYjXkxVRqH1BoBfZF
Us2BllOjhZCNPYeGh9/7vpzhnJNaXc+txUIIWRrxEN4TIRzriDR39o3ozgcZ
7t1OdZO8uaIXPJkXdMwOHT7d2vrDFUP7tdaYsMyLW1cPmDEXqZtfdUV/2eeG
Z7clLbDLm31Pq1zSsy/qtE6RZDt6Xuf1Uc91izMe7HP6zSy39hMt80Uz+m63
lpbIRe+nRxwyoB///3d/O8Ay9Q==
                    "]], 
                    LineBox[{788, 636, 859, 696, 930, 599, 564, 970, 697, 637,
                     860, 638, 700, 973, 569, 756, 572, 880, 646, 879, 647, 
                    881, 573, 757, 937, 864, 865, 861, 863, 862, 935, 754, 
                    933, 934, 932, 931, 788}]}}], {}}, {
                  InsetBox["\<\"\[Mu] = \"\>", {-1.8, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["0.2`", {-1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {InsetBox[
                   SubscriptBox["C", "J"], {1.4, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["\<\"=\"\>", {1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["4.37`", {1.7, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {
                  {PointSize[0.05], PointBox[{-0.2, 0}]}, 
                  {PointSize[0.0125], PointBox[{0.8, 0}]}}, 
                 {PointSize[0.007], PointBox[{0.4463998339305619, 0}], 
                  PointBox[{1.2771956561278897`, 0}], 
                  PointBox[{-1.0806611991222994`, 0}], 
                  PointBox[
                   NCache[{0.3, Rational[1, 2] 3^Rational[1, 2]}, {0.3, 
                    0.8660254037844386}]], 
                  PointBox[
                   NCache[{0.3, Rational[-1, 2] 3^Rational[1, 2]}, {
                    0.3, -0.8660254037844386}]]}},
                AspectRatio->1,
                Axes->{False, False},
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                Frame->{{True, True}, {True, True}},
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLines->{None, None},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None, "TransparentPolygonMesh" -> 
                  True, "AxesInFront" -> True},
                PlotRange->{{-2, 2}, {-2, 2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.02], 
                   Scaled[0.02]}, {
                   Scaled[0.02], 
                   Scaled[0.02]}},
                Ticks->{Automatic, Automatic}], 65->
               GraphicsBox[{{GraphicsComplexBox[CompressedData["
1:eJx1W3t8zMcWD/XoVau4rrZbDaIiKElbQVt62q5X01xdGqGq61HctuuWBtXV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                   "], {{
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[0.3], EdgeForm[None], 
                    GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxFmnfgl1P7x+9z7jREoZISZW8lkVWJoiVKdsp8KCp7PSGikJ0kJTIaQkko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                    "]], PolygonBox[CompressedData["
1:eJwtl3m0z1UUxb/3XjSplNKEokclRZ6UzE/IlHqhZ0giUTKExJPIXIaKoswy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                    "]]}]}, {}, {}, {}, {}}, 
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwl1Gt0z3UcwPEfE6UL0cmD4phLU1YqVKMpDG2obUy1pHKpNZfNOY6iuy7K
3FpFrK3YEnaU6OaaErrfNlvUqRTKwnO66PU5Hry8P9/v/4H///v7/pY6viR/
WrMkSQr9U5aSJC83T5IfyGWedTqXczYLybO/SH/T31nGh9ad9SBducb6WvqS
wXV0s99fJ2g/naiv8qe5Sg/zB6+xw173+Iwe7LReqUWcay7nBV7iRY7Yr2ZJ
fH+Wcr/1K1rJMipYTpP9Ks1iCIOZbG8Vn5gv06McY3V8R3tvxPfS47oivgs3
Mc16mJZoLbvjrHSkTtd22p4L6GU9Wgu4kA7caq8vE82TuIiLuc1eBpPNU+hI
JwrtZTLD/Ix21lS6cKN1ne6M58ZMc5k+oG/xJn9bD6LevEB/4Q4Gs9fep7qQ
B82zmcV6/ovfGffCvFh/5R3zu7zNRjaQkOOzR+O56CPxnPTbeLbmb/ROstln
/Z2eoS0Yaf4pnp0+pT1ZYn5SG3W73q3b4hkxhyfYyl32R/CjuUFb61ncYn5W
n+Np5sa5cbP9Vnome81btF5b6mbGmTfppTzOY3xAnf339T16xP2z/p795uHa
XFP4Ou6zfqXN9Av9S7/Uch4yP68Pxz3SUwyl0frzeL/4jIa4o/ovWYwlzd4l
zDfv4ZB5t/4T95cm6116khMMpHu8f3SNM7D+KN5V8w4tjd+nU+Mex51mXbw/
FHMvRdxHLbfHPWRM3NO4w9SQR36cLblx9lTHuTCCbEr9Pzm6Ju6QrtXztS1T
4ww0XQviTJnCrrgLcX7UxJ21fl3b6HkMYmA8q3i/KGZAvA/cEN8/3tn4zXFu
OorFcf5cH++d9TmaGb/R/LGmxbnG3w9+tq6M+0o+y6ngHq7w2XjtFe+hXqVX
cyV96E0X+weYH+9cyum/sf8D32utnA==
                    "]], LineBox[CompressedData["
1:eJwl0L1KgmEYgOFXOwlriU4g1MCgIU8hdJKaOoCC0rShUFvsXOy/wDANWvqj
sNYysCankiAbu6Th4n6eZ/k+3qnl1cxKJISwwEE0hN5YCPv6SZwbe0G7vJHg
1u1EN1g0F7XBgzml32xxQd+tqT+0+LC3tcyQeZ7crrTG5Oh77JqfNa2/7HBJ
x21Oc1RG/2Wv6jbnPNpndULHibFpX9IZvdczLXHKnT2pA6a5th9rni8OeXc7
0nWy5jXdo84rL9H/t/sDJRgyzA==
                    "]], 
                    LineBox[{789, 634, 861, 694, 933, 598, 564, 972, 695, 635,
                     862, 636, 698, 975, 568, 756, 571, 882, 644, 881, 645, 
                    883, 572, 757, 940, 866, 867, 863, 865, 864, 938, 754, 
                    936, 937, 935, 934, 789}]}}], {}}, {
                  InsetBox["\<\"\[Mu] = \"\>", {-1.8, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["0.2`", {-1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {InsetBox[
                   SubscriptBox["C", "J"], {1.4, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["\<\"=\"\>", {1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["4.36`", {1.7, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {
                  {PointSize[0.05], PointBox[{-0.2, 0}]}, 
                  {PointSize[0.0125], PointBox[{0.8, 0}]}}, 
                 {PointSize[0.007], PointBox[{0.4463998339305619, 0}], 
                  PointBox[{1.2771956561278897`, 0}], 
                  PointBox[{-1.0806611991222994`, 0}], 
                  PointBox[
                   NCache[{0.3, Rational[1, 2] 3^Rational[1, 2]}, {0.3, 
                    0.8660254037844386}]], 
                  PointBox[
                   NCache[{0.3, Rational[-1, 2] 3^Rational[1, 2]}, {
                    0.3, -0.8660254037844386}]]}},
                AspectRatio->1,
                Axes->{False, False},
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                Frame->{{True, True}, {True, True}},
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLines->{None, None},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None, "TransparentPolygonMesh" -> 
                  True, "AxesInFront" -> True},
                PlotRange->{{-2, 2}, {-2, 2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.02], 
                   Scaled[0.02]}, {
                   Scaled[0.02], 
                   Scaled[0.02]}},
                Ticks->{Automatic, Automatic}], 66->
               GraphicsBox[{{GraphicsComplexBox[CompressedData["
1:eJx1W3l4zFf3DyJKBSW2lGi1dFCaYvzQcDAtv1qnKKm207e2age1M3lVFZ1q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                   "], {{
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[0.3], EdgeForm[None], 
                    GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxNmnn8lkP3x6+ZIYVKUbJlichWSrKT0IJWZBeeRKjsy0MiJGsoS4USsi/J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                    "]], PolygonBox[CompressedData["
1:eJwtlwnUzkUYxd+ZSYW0KFFSUWTJFtmVnUKWKGXJTsgWJZR9SSgpsoVQ9rIk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                    "]]}]}, {}, {}, {}, {}}, 
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwl1Ht012McwPHvVqRyCakOf2QOa2umMWEYkiy2Uk27INZEqlkl+qOTaxGi
bLaKTcsKy3UHRSqXamy5VaLL3MmlGvF/eH2OP157f55n52y/fb/Ps7TK6eOq
U5IkKfeltluSPJOaJF8znhrrHM7mOOoosV+v+/QXlrPF+gz9lQwutL6IPPK5
mEz7l+pteolO0VV0mVfq7+znOdrsDdYDZNNu/YJWcbx5Kct4mqc4aL+Fhvj8
NHK79bPazHJW0ESX/ZV6FVczkun2XqLDPEQP8RevxGe093J8Lv1bn4/Pwmhm
WY/SO7WVrfGstFhnaz/tzwByra/T6zmZU7jBXh5TzdMYyKlMsJfPTPMdpHEa
N9kbxhzzQj09njvpXGG9S9t1MXPNT+jd+iZv8I91AXvMtfojFYxkr71P9Enu
Md/HvawhlSL732i9/sQ68zus5W3eojvX+N6D8X50frwr3clB8xdayWi+tf5S
e+pRjDP/oA26MN5DvF/zo9qpm/UW3aRn8QgP8wGT7I/le/NePVaP4dp4FvEc
eIxFPE6x/d56NHvM7+tu7aXvcbP5Xc1mAQ+xkV32N+h6zoyzZ/0V35nH6JHa
gx1xdnW7HqGf65+6TZdwv3keDzDKupsWxr3Tz7SOT+mMM6opcV51IllxN6gx
fxx3xrxV/yUxd+huvVIPM4JM6wwGxXOw/jDum7lNZ+t8naV3xVnm9bgTzKCK
6rhPtMYZpCLOLjfGWWU1pZTFM6eE8bQwNt5tnIv4+X7PGH1V9+lrepL2jXNu
LtKcuCfMoNB6Zjw7/mA1P9t7UU/UEyiIvzXOhL1yqhluPSLuBFPjzsbfbM7S
sngH5ssYRh8uZ5r9j+K96m/xvyPOuXVznHtKaWIFt3KO703WXE3XoXoe53IB
58fzjs8bd8rcmPr//9f/AIbArpQ=
                    "]], LineBox[CompressedData["
1:eJwl0L9KAlAYh+Gj3YYF0R2IKRQ01A1Em4ugF1CjmdVQlC51L1rZH0gyhYbK
KKoxsyGdWkyEbOiBhof3/L7xTOfWVlYjIYRljqMhfE6EcKQDEtzZG/pOl1nu
3c60SNZ7Uy959J7TETs0+HK70h+u6dtN3WPMIi9uN3rAjHeRQ+9XXdJfyrR4
dlvQDPt82CXdpc6TPa9TOkmMbTunKX3QC93inLad1CFxbu1TLfDNCT23mq6T
9s5rlQod3qL/f/cHC2M0OQ==
                    "]], 
                    LineBox[{793, 639, 867, 699, 938, 603, 568, 976, 700, 640,
                     868, 641, 703, 979, 572, 760, 575, 888, 649, 887, 650, 
                    889, 576, 761, 945, 872, 873, 869, 871, 870, 943, 758, 
                    941, 942, 940, 939, 793}]}}], {}}, {
                  InsetBox["\<\"\[Mu] = \"\>", {-1.8, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["0.2`", {-1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {InsetBox[
                   SubscriptBox["C", "J"], {1.4, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["\<\"=\"\>", {1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["4.35`", {1.7, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {
                  {PointSize[0.05], PointBox[{-0.2, 0}]}, 
                  {PointSize[0.0125], PointBox[{0.8, 0}]}}, 
                 {PointSize[0.007], PointBox[{0.4463998339305619, 0}], 
                  PointBox[{1.2771956561278897`, 0}], 
                  PointBox[{-1.0806611991222994`, 0}], 
                  PointBox[
                   NCache[{0.3, Rational[1, 2] 3^Rational[1, 2]}, {0.3, 
                    0.8660254037844386}]], 
                  PointBox[
                   NCache[{0.3, Rational[-1, 2] 3^Rational[1, 2]}, {
                    0.3, -0.8660254037844386}]]}},
                AspectRatio->1,
                Axes->{False, False},
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                Frame->{{True, True}, {True, True}},
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLines->{None, None},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None, "TransparentPolygonMesh" -> 
                  True, "AxesInFront" -> True},
                PlotRange->{{-2, 2}, {-2, 2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.02], 
                   Scaled[0.02]}, {
                   Scaled[0.02], 
                   Scaled[0.02]}},
                Ticks->{Automatic, Automatic}], 67->
               GraphicsBox[{{GraphicsComplexBox[CompressedData["
1:eJx1W3l4zFf3D/IWqVG8qE4Jaungp4llvI1GT4lqG8RUW1FtxxrFUErfMhpL
lUjVUkxRWjqtvZJUSmzDSZRIQuxMBCGylARJRtaZafOmc33u/J7riX++zyd3
O/s599zRftz04RF1fXx87tXz8fnnW3nYb0WU4zBHT7xeFmt1s01gAl40fvIR
veVP7v5M347GkCo+s69zK4v9tsTdGqXcy9Vflhj7AWM/4NZivsQnxH4SzxXn
STx7TMVCW5SDLx7YMFyTV8YvN9tjtBseSgz6gEEfMOgDBn3AoA8Y9AGDPmDQ
Bxwo6JF4lqBXYtCPL+gHBv3AoB8Y9AODfmDQDwz6gUE/MOgHBv3AoL82uat8
qF/wAwx+gMEPMPgBBj/A4AcY/ACDH2DwAwx+gM8KfiSGnal2pOpF5QtY/YJf
YPALDH6BwS8w+AUGv8DgFxj8AoNfYPAL3EXwS7X5tepHql2qelX5Vr/gHxj8
A4N/YPAPDP6BwT8w+AcG/8DgHxj81xbH1Lih+qFqx6qeVb7BHzD4AwZ/wOAP
GPwBgz9g8AcM/mqLy2ocVOOK6peq3YJ+YNAPDPqAQR8w6KstT6hxWY1zapxQ
/Qj0AYM+YNAHDPqAQV9teUvNE2rcVeOW6teqnat0q1/QDwz7AIZ9AIM/YPAH
DP5qy8Nq3lPziBqH1Til+q1q56rdqHpS+Va/4B8Y/AODf2DwDwz+a6s71Dyv
5k0176hxWY1Tql+Df2Dwr+pV5RNY/YJ/YPAPDP6BwX9tdYxaF6h5Vc07ahxW
4xb4BQa/qt2qelT5Ala/4BcY/NZW16h1gZo31Tyixl01zqlxRfVD1S5VPal8
qF/Qr9Ytal5X85yaF9Q4rMY9NU6ofqPakSpnYNBdW92h5mE1b6l5Qo3LahxT
/Vq1c+y3WNxn5H7A9zw4jTM9XyefFpiAX/SclyvHb3q+BbzQc04F3/HgTDkO
foAvinG5X1uxn8RXxH6E/Tp6xkvlF/rGeDvxd1LnpXnkUCzHgeHfwNgHfEQK
TMCgC3xdFZhUPiE3/B1fH8+/YzZ1vSpnzIN8MQ75A0NewJAXcLLg6wmM/XE+
sKpnnA+sfnE+MPYHxv6q3UDvkAMw6AAGP1gPf1L3x3xZxz3G0Cf2gT6BYR+g
Gxh2gi/G4bfA6jzVbtRzIU/VblQ7UOWm8gkM+avr0Z/AemDQp95roBfED2DE
D9UfsR76UP0TcRlyAcY8NU7D/yAnjONc0Ak+VboRV/CFXGEPqpzVOIR50I9a
h6j+puZt1b8wjvOAcR7iLM4Dxv7A2A8Y+wGregO9qt3Upld5r1PsCuPQF/iE
ftS+juo/yHPQv1pfqHEV+Ug9B/am5kdVj6r9I3+Bb9WfMA4+Mb5LU2ep1VbO
+UcjT1VXF/EZD3951NOzzwkefuhCUaqpkhZ51t+nirGB/mZNGf3gt2qILq5E
/h3zkjz7n6eYJrOStGkuOi8w7xWYMQ68TKznEWI9Yz9glziPfxLnMc4Hxjzs
s03wQ+AHdGE8S/xd8gd+mwtMGAdW6YK8MA/nAYNeyAfngg7IA/JR8xAw4hfi
hJrXa7NDYIxDXmEJo/cbjI9kPIIfIq4B+0b8PNKhdfJcj/3ekXRCXmregr0B
Q7+bPfN2SztQMebVltdVf8Q46AUGvdBjP48/ZUl7i/Kst0s8W2Bpf93FfImh
P8gLdqTqHRj0oa6FvQR66LwnMfwe9F4W9LKaJ+H3wD5iPmE+MPRTG5+q30F/
kK9aZyHOYB3kiHXAtfl1yyMe/UoMfYNv2AfkBAy+sB4Y62EnGIddYP1MIQc5
Doz10BfGgVV7VOmH/6txC/PVcdgV9As6ICfYGeQJDP3DnqF/YOgb+wHD3mGv
ocJeZTxCHID/Y7y2ewHqEti7uk9tdaEaB1U7gVzUeKfW4chPyJuIZ6AbfOKL
+gryg10hzsL/ZJ59jDEOu4T+kFeB1XoHegO/GMd81CcYB8a42i9EfkAcgVzB
n3rvh/whD+gVfg/5gg9gnAsMu5P6eSxHyBtxD3SgfkA9Cb6A4UegA3EF48Cy
7/U4bsEvsD/G4VcYR75BnAI/wPBLNT9hX8wHxnycg79jnew7P8bgD3aMeI+6
E/FdJ+xL+jPGYW8YV+8JkDf0CXnVlhfUPIA4UVscQZzAfNgd9Av6sa8qN8gJ
cgM9tdUROL+2vI08A/tAvFDtB/IHVvvlGMd66Ad0wn5AP8bVewT0Cz9V79VY
h/wA+1XrDmD4J/QKDP+CPUDe2A90A+Nc1S7xd/CFOKb2h4ARz6FvxFv1XgcM
P0K+gR7V/gLyMOwH82H3mAf5YJ68Tyh1gKx3HmPoGfqBnmvr02A+5IL5tfVd
5HveY3nCXiA3yBXxGhjxGvkE+0p+H9Mh48Rjfap1IPbF/UDVD+Sr1jU4H+tU
vWMfjIM++B/kAnpM9dtm5OrPyn6J9M92BdsNK715ceWAl5uaI9zSD6c41gTp
prulHQy4lb7dsNnFI7Ov30s9XSj9/YUeY3aZop/83cDfz/psMU2qlPm18fCO
f8V+WckplzqMcWSWPfF7g0SfAYHGWd6+96eRi1ZaIx28pG7+6qielfKeXdp1
vjO2jlPW43cnTp5gb+Ly3qPnfJWiTTsg9e8bP7CZOd2bNzFv4vkOBwzGizzq
vRvfWN05sh6AH04d1GuBLeoSD589uLFZc9bbRw8zfWMN9vrVmvCe91K7uSXG
ftgH62Xf/fF6YKyX/ZDH9Kv9j4yPz8yxdT4l+wn5zyWf0lsSCfyp78yXc2Zv
Mk3yxjlHeGK4Y2MmQV7QK+Sp/g6n+7snnrLEefsUHY6Orm8JLyDoA3RAn6hj
YA/Qo3xPi67zhS2/jGA/2BfrerZ/N9rq9r4fJL2z9UI1OQn2i/oRdKY/vzJB
/663D1W6fmETc7pXjuUNj3wdddFNm39OHm3/7SjX61S/niW9xr4/Ke+viztA
w39dnpl7xc1Vfv6bTXfv8t1xlhbmBzX5K6VbC8tSB+vapefn1tjlxGGv9TDm
lNDtlGE/m6LLudG3Va3NR8uob/S6BEOsg89fTBysOVnFKQWf+1nW3+WLmzSv
64rySBtZ2tasOcEvD+zc1tjBTZnTX3KnmpLYkjp1nD3QTVcK243Q5P1OGe8U
NrDMPkTjeya+qbNfoikr+iZpC1x0cMfAZy3hFyhx77Whmu8qyRheuFdfep/S
Xjdeq75VRjMe2urHfemg8uHRpbFjH9DyAF1R6ulKyj4x9x1NxBUecfCT67nv
uWnfn77ntctq9v1xynTb525ypqy3aZdl0Zi/H2wwZbjo/qQ5M+zBudzv3rjz
1WVO9k9oNd/WOZezIu4c1zqd7Pjog3Paghwqbtp/o6mVi39f0exGdXgubXUF
PGWp5+KYk7qK1JBS+R31xeTO5gjvu8PHpZF3qvcXU/tfeIl1ZgVnbNVWpA4u
pRviyyvfTYw1+FfIvsf2VaZYQ1gFld7WPR23uljGNb2wRz7z7KGP7YFVMs5u
HEObTNFO3p5oTNf65XGXiZ/Wtwx10qL9ztLUBXk83HSmvfEXJ/lPG/xvy/oc
fvlr/1d0q1w8qvT91zURNzk53NzOON5FP7x0MjN3/w0e8ceA7007T/Nz3Pnf
5qHXuWPTOoEhQWl8YtWqV3TDrvOkNkF5qabN3KzLgYepT1/jrNT4BMPmO/Ke
/frCJttNk3K5UdN/6DZLPETjwbRuaBLpilJon/iyrfuuv9baz9Hfp83H9ZZf
uPW1gubmoQXUoPc3ewzGFI5ambjA1ieHtvxe9Jomb4vEcfEeTHFTu2VVv5jD
D4M3GB2Hk+X++ILfUMEvWcqX9QxJzeAo8ZX+8pGId9TN4x+nZN0MfusKfgn0
FfTy0Edpi4/Ms7oLqXzNG2natGTavXHPjVyrixa98lWYRp9Bk57tVhWb5OS+
Jxsc11/OIci3oZAv1b+S/qtJlyTzNvTVUuiLoM+5Qp/kU7llgG5YBQ9666Mt
UWuKyTbs3CJr6yrZV4X9FAv7IdjlLvGV99ppIr/QyKZvLLZtL2a/xK9fNI6v
INhrG2Gv0j+ChH8Q/OG+8AdqvuLX6fbfvO8V1z8Im26LOiPfK2AXt+vHDNJs
875frAw13E391ft7y5Mi3nGvy3vPakO974+XY3TLo2YWSj+A3Q/ofukz20Tv
7xguiHjIoEd933Ce7LTIGlkl64llfx7dEDW8lAvcv7eyLC2W9VzmKw8CjL94
f8+YG7aqlblf5RPvkk02Ts6pDijmZcJ/n3jvGBOe3D+kS7H33VfkD4a+wMe+
oNvnqsn1xLvN5oP7Aox/3JF98NJThbtNO7NlvZIr8huHLnmzYZz1gqyD2tRf
PdmWfOuJd5P7/zoeY4i1yzxfd6QnHzLsT33PDBrbvL8uIEPeV669N8WZaopn
+If6ftneUe9urv6k1MeQ8z4ay4unZN29aFvxAqvN+x7zo9hP+lk9sV7e7waJ
+bKuGSHqFUK8wTrwi/wPPm4IfmX/pYvghyBv9R1snZA3QZ7q+8l9IX9C/IVd
wT7Ud7NGwj7kvfVDYQ/ynhQl7E/WdU5RLxLyB9bB/mFHsJtXhf3LOsRP1JcE
e1bfW8qF/RP8S313yxL1sPRf9fcCN4T/Sn0tE/4r66hXRX1MrX3bBoQcSuNx
NzeMte9082WPXxZwvHHOqqg1VYz4FSriFyMe4+t4sVGivvQya7ckJ+h7ZzLi
e6N+nvjOYSsc2013czhpb8IvBuNR/qBN4aXqskqauXln95AVhVSvqm64JuIS
H2vftal5mpsXR7/1nenuUZrwzuhBmgtu7jG014XqBWkU/O6I9Oo4N6M++ETU
BzzgGeNe/cAHHK9ZO1RztJJjl+b9aGpwj95sP6eF+a+a+8XnP93KLbtHc3oU
OWOTqhj1x7ei/uDrM08kGCwOeiUtItrqKOMXgkeWpl4v4+TchBfM8xyM+uUz
Ub9w2ndhr+m21Nwv215ZZ2rwgGfHHPvR5F/Fb86vs9EUXMiofyaK+kfyO1fw
y+ufGfW+I76KjBN2dTLOusuZ2+Y9HTf2Nr/58L/ntaGXeJVvzI8m3SF+w8N3
JqPemiXqLW72Z6DGHFNjP+N61LHYj0r5LhHyJdRz7i889Rxh/tmxnvmE84LE
eQT9+Qn9Ec7/jzifUC8minqRQP8IQT9BHlOEPAjyeE3IgyDP40KehHq1o6hX
CfL/j5A/QZ+xQp+EejdX1LsE+4wV9knQ90Chb4K+PxP6lvZ1WNiXrK+rO3rq
a2n/RmH/BPsbI+yPYH8vC/uT8SnDEf+JLcv7HlZpLb5aTRWyb/rUjeb6kPcr
+Nt+03zjxnp/D7Pg+dXdjM+XkX164nH91EccX9wswv6b93c8qD8GiPqDL6/+
cb410iXjJOqVNaJe4UH6ec3MMS4qLFtdHdveLuPc6cHOXiFVpzgy6PsNpgb/
73dEx25dz23hpi3zuh/VW5K5vPPOFH3z85Iv1HdRor6jsE6flsS2P0cJef1O
6C3x9PCX69Ntfbxy+GN60jZDDd4RN+8pi30j4TzEnRmfxv2uL3XR3h76YboA
7/vamDGV4+2G6wT+EL9R3y4X9S1tfP6NBdbWLgp+FNPL+NVtgryQd1BPbxb1
NF09sSVBH+rkGbPXNraE5BPkj/4m6nl8IfeXPrxxM7fM+3uQzhcm+FrquyVd
i0f8+oamRm44t2/H5ONaPxelf9VkmCbvADvF/Y1ve+rPlXw8Y9vXUTX2gf17
iv15ZI8dt6s5m9tVhX5qm+iSebyrOI+Lqzv30Y3OYv8zb1fEpru4R+hxszU4
i/ctiumrO+di3JdGifsSN3p9gDu2zjVu9taupuZObpkHowW9/GHcmEG6gCt0
sN9+f+N4Nze/0iJZ2/Uateru72sJcDPuVxPE/YpLujyfn1p4kxJD17c15rik
nF8V/LJfcO+PHZnZNH/+6n36z1w89cLukZr/OvjGoLy5tvIyLth9zZW6qYQd
MYP7hOwq594LvvaNe9v7O7CCvzfvNcwvY+NzJe3NDxx8JePB19bmZazr3qa9
OeIRo75tLOpbjhz1YUPLf2rqxreHhTsyCxj6nSP0y+uE/qUeD/5VGmEPdNLA
e/2m2Zvk8+Fx65K0CV45f1Y0cHnUOBfr10/opSu6xTOS7fOs910cvfxqqtbP
zpN2nTxbfcvFE5N/L04ttDPsb6CwP/bZNq6peai3Tg4W92V2L3q00hp8kcOK
F5fH9ndzwtRjS6Mc6dzyD9dY+ww3d3D4nq6uPir1Nu+tbYf0lhS5zwzhD4z7
dIq4TzP8J1H4D7819OR600K3rPtCJhu2GWryYEz+qMXW4IPcu9fBeH3N+F+7
v19ttS1kjH8qxgnjbXZ5xqnYYD6rneLtc8LfHcLf+eGwlof1796l1g3D10Q5
TvEZ2/n9Bv8c6f9RrX/93OouknjItAOHtRuLqO2duD2mnb9x4lu9nzanF1Gg
+Z8+0Q7GeE62Z5wwftDTR9pB6Dc0ve/pNzDiy/rfPPFFyh/xBfL9s8QjX4J8
Rwv5EvRzX+iHoJ8NQj+EfodN9DsI8fFLER8J9gO/gr3MFfZCsJcRwl4I9tVJ
2Jes52JEPCbI8+8GHnmS+0FApPXGfarooq0X1/4kIZ7fFPGccJ/fJ+7zBHuH
X8Leg4W9E/wN8Q7+Nkr4G8HfOgp/o7vfBi21/lBOWStODdGtKiHcj5DH8I76
xzeHGsaNLSH0k/qIfhIhn10S+Uzeq0pFPiTEhwwRHwjx4aGID/KcuiJfEvpX
N0T/igYEtqOQXSU0pNcasy2hnBAftSI+EuLjbyI+EuLdPhHvCPGuuYh3hPg1
V8QvQn/oJ9EfknZ8WeR3Gd/Rn0N8PybiO6E/Fyb6c3S4c7LJFrWSsB73t0rR
7+M6g7NGOLSneXlGi+m27W757tjxr7aJ2mVuxnrUF+h3IL+gPzlf9CcZ8jEI
+ch32j6iP8l1h8Uf13/2iOKdi7oZO5RJu/CpGtw3JKKUD3vqae97dpvVC4/p
L3vfs09Mze4R0qWKmn/+/k7DsQLe2iC1g/Er7/t1z9gEZ2y29/9r4V1v6f6Q
jOoF+RwYGdxX94xb3m9bujf4G2e55b02a3xFF2O9fPnOg/5M87We/gzDP1p0
9fiHvLf5aj39ZNZPiPrCGvxArs//cvVH9mLv7/pxHuSIcfk7/8f04T4KfnAv
Bj8LBD80eGj425pN5dwvNK+lZUWJ9/8DifcAymwzZ6p9Ybl8T0e/EHaO95JW
RwzZ1aNLCPKG3qCvWKEvQn8DfSC8301ce+XlkKAyWde4Kz36JOgT77foj2aK
/iih/mgt6g8aO2WyxrzC+/sI1BONRT0h+/PLxHsLwX6jhf3KPv5E8f5CqB9s
on6gC/4+JbFjb8n3/d1t3juuDT1NufGLI6173Bzrud8X0sazW09qp9TcN039
zmunPOI9LRsHhTxXxhdTDEuihhfxmWNHwjQtKrnH1kG9ddOLaOGePp2NHSoZ
+ugv9MGIZ3dEPOOEZh/NtpVXUOyMtVdzWxSx4dVLOww1dduxIweG6upn87Ko
L7ebdFvJ13Nfvcr+vv5DdEXZ3Kvyzw/thnN8MPOFc1q/XP4iIPuA3nKIN76y
vTLV9AetPfPdlqiZ53nRv0aeqaZ0mmjY9rR5BfPnMd/3DQnKpX6efHVYriex
njC/q5hPmF9HzCfQU+rpj14lS5NuO0wpl7gvTwvVLMmk6kDtew6tjQ03n9pk
2plJ4CdB8EOol2aKeongv42E/xLksV3IgyDvnULeBH2sE/qg78f+HGfYnM93
gl6sb5ntlPq7LfRHQ6YG9Ak5lE+veehzEuSzRMiHziVtOq59oZC3r6lLug+q
eFLr8R86nBXccPGWnwz+Rez3U9hLIQEu/r8FsaM0b2dz18vxe/XNb/KsTjMa
W8KvMvgdI/iV4xPEOGF9R7GesH8dsb88/2dxPsF+IoX9SPoHCvql/lsI/RPs
L0XYH/0PMDVuwA==
                   "], {{
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[0.3], EdgeForm[None], 
                    GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxNmwnYltP2xp+9n04UZUiSkMg8hIRKJURSETJkiAazMvyL4k9FEkWRkimq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                    "]], PolygonBox[CompressedData["
1:eJwll3m0z1UUxb/33kppUKykopWhSKZHIZSZIhXhkcxKRQhFkTIkY5JSocxD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                    "]]}]}, {}, {}, {}, {}}, 
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwl1Ht0j3UcwPHfRiqi29EfLqcWZWizLpZUk2xNrNvMzjqKNWpjtS266jYV
um22IqukQqGtCyqlwsKUS5FZqePWhXT7H6Ven+OP196f7/fsj+f5Ps/zSymp
zK9ISiQSRf7UtkskGpITie+4kRrr/lxAR+q4yX697tP9vMRq63P0J3ox0DqT
SxjEpfS2P1gn6GV6u77GQfN8/YVfeZ019s7TA6TyhfUCLeMU8wsUmGfrQV3I
HPNcXmSidWftwmhzXw7Rn/X23tJyFrMh7k//5C+Wxj3ZW6Iv69/6is4jm0rr
YVqlTbSY0/Vanayn6xmcSUacY5wZXTmLInuZFJtvoxvduTnOh1JzGT3oyRh7
WVSZZ+rZcdakMNR6h67XZ5lsfk6n6NK4B45YZ7PTXKt7uIUc2ux9qbN4wPwg
91NvfSvXMNX6oXgenM8KPuB9lrOM//zfCKrN03gsnpH1N/EMzV/r2Dgjvrfe
pu21HdeZf4znpjO1H3PMM7RNP49z0s+0L9N5kk8ptp/HD+aderKexA1xHnEW
PMUzPM319jvoibSaV+kOPUE/YZz5Y03lCR5nJd/a/0g/pA+zrbezyzxSkzSZ
rfEO6xZN6KZ473SzPs/D5kd5hOHWx8iN7836K63jHvN93Mt7/GuvUZt4m3d5
hxr7G+O7MbfoUf6J95lWe8P0MFfT27oX58Z5xPfEz+ZmvVOrdaKWM4nF8X1y
ByVMYDxvxvdEIfkUMIr58RzjfBlBXpwLr5Ib90oOd8c7Ffehe7VRT9NTqYhr
1TQtjOtiqPVd+ge/syje37iOOHsmsS7eGf2NBnMWQ7gyrt/eG6yNd1dHxXMw
X84VdOIqSu03x7ONc2Eeu+P6430lP34L4neAEtLiPDRdUzRDL2QAF3NRnHXc
Y3xb5rnJx39b/wdZNav4
                    "]], LineBox[CompressedData["
1:eJwl0LtKAmAYgOFfuwhzEbqCMAMFh7qDosVo7AKMSO0wFB2WuhfNjpCYBQ5Z
UVRjKZRTm0VgjT3i8PB+3zf9/GOLS3P5SAhhlmo0hPeREA61R5KWvaRtOkxw
63aqq+TMa3rBgzmtP2xyyadbXfs06NqvdJtfpnh2a+o+CfMyB+YXndY/9rjm
yS2rC+wM3mXf1S1qPNozGtdRYmzY53VS7/Vc1znjzp7Sb8a5sZ9okS+O+HA7
1gIz5hWtUOaN1+jw7/4BMHgy3Q==
                    "]], 
                    LineBox[{788, 635, 857, 695, 927, 599, 565, 972, 696, 636,
                     858, 637, 699, 975, 569, 756, 572, 878, 645, 877, 646, 
                    879, 573, 757, 934, 862, 863, 859, 861, 860, 932, 754, 
                    930, 931, 929, 928, 788}]}}], {}}, {
                  InsetBox["\<\"\[Mu] = \"\>", {-1.8, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["0.2`", {-1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {InsetBox[
                   SubscriptBox["C", "J"], {1.4, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["\<\"=\"\>", {1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["4.34`", {1.7, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {
                  {PointSize[0.05], PointBox[{-0.2, 0}]}, 
                  {PointSize[0.0125], PointBox[{0.8, 0}]}}, 
                 {PointSize[0.007], PointBox[{0.4463998339305619, 0}], 
                  PointBox[{1.2771956561278897`, 0}], 
                  PointBox[{-1.0806611991222994`, 0}], 
                  PointBox[
                   NCache[{0.3, Rational[1, 2] 3^Rational[1, 2]}, {0.3, 
                    0.8660254037844386}]], 
                  PointBox[
                   NCache[{0.3, Rational[-1, 2] 3^Rational[1, 2]}, {
                    0.3, -0.8660254037844386}]]}},
                AspectRatio->1,
                Axes->{False, False},
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                Frame->{{True, True}, {True, True}},
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLines->{None, None},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None, "TransparentPolygonMesh" -> 
                  True, "AxesInFront" -> True},
                PlotRange->{{-2, 2}, {-2, 2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.02], 
                   Scaled[0.02]}, {
                   Scaled[0.02], 
                   Scaled[0.02]}},
                Ticks->{Automatic, Automatic}], 68->
               GraphicsBox[{{GraphicsComplexBox[CompressedData["
1:eJx1W3t4zFf6j0tVNaOqpEwRFL8pKhaTonitIdWihq5LsaNsZdUgWrY1lrp2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                   "], {{
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[0.3], EdgeForm[None], 
                    GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxNmnf819MXx9/33pQio6U0NJXMMqLyI6QSIdkze0aIrOxkr0T2rkhGMkO2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                    "]], PolygonBox[CompressedData["
1:eJwtlwf0l1Mcxt97Lzoh0j5kRIeipNJAGlIZbRUN7YWGUUZCkaJdVmkvVNqU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                    "]]}]}, {}, {}, {}, {}}, 
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwl1FlQFVQYwPFrPrZnu2ZSTT4IZKBRSaVpm6QVUSoQGqBtChIqmT047bSi
aRYFRJohZuZWjktpuy0iGqCglraMlqbZRqv9vunhx/87Z+Au5x5uUmFpdkmX
RCJR4MclXROJ7rzAqCMSiRf1oM6jxvyKHuInzmOIvSsYzFVcSV/71+h4vVon
6EL+NjfqL/zKa7TZO19/I51t1ou0lDPi+cgzz9dOfZ1XzQtoYKJ1Tz2TfHN/
/iSDDntLdBJL2W59of7DvyyP12BvmS7Sw/H4uphs7rG+QafqW+wwX6wjdJqe
pWdzDpnWBTqac+kds71BTDSX0YdkxsS5URHPQQqpFMZ5Md1cpX3jbEgjy3qP
Nuss7jfP1gd0Das5iuH2vtc5uo8iruMHey36HI+YH+Xh+Jyti7meSuvHyIhz
4jM+ZwOf8gnHx9n43Sf0SR6nJs6Wv8wdOi7OLZ7feoeerCdxk/lHfTnegw6g
3vyMfq1f6B26Jc6ZmcxgE7fb389umq136WY9nRHxvvT5OJN47zzLzfZP05z4
W/1KT9VTaOI26416ES+Zq3SnHtYvtY6nzLX6tN6o3fRE2uOe6TY9QdviTunW
+J/hI/PHfEir9XH6AWPN7+sFVJsfjNetD+l7vMuxvM07rGU96+I9xRnxh3mL
Hq3HsNm8V4fpkXpt/B9oP9LjDK2b6DRv1Pu0UqfGPeZeVjGZKdzNJMpZSRHF
cW/jjnIrS8gjn5HkMoo34nOOs4/zisf2PDm6Ir439E1N0l5UxL2L89dbmBx3
NV5DfFfEfWJxfNfE4+p3lNMe5xfnQKN5Ydz7eN3WWVqmQ+M84iziHKx/pz7u
XnzWzGMu39ovYas5TX+O7xcOWjfoN+RSaz1fL9U7tYfWscDcqik6UO/Sy/Ry
BpEad54DzKXFXrKOpNqc2fX/79z/ADa6v7k=
                    "]], LineBox[CompressedData["
1:eJwl0DtOAmEYhtGf0ULdhR3auACCGgyFVoTeAhItYQOCioUGpMHN4BUtIPGW
sAKvKGJDIQmViYdYPDnvN8VkMvP5YrYQCyFkdB6F8DMVwhkDk3zmLgf61rJe
PGtxT1v2Ptt6t1Oc5iHv9Gvfcob3HPOBVc3a6/xklw0tTd6nE7vPDc6xzkd9
2GnmVNPQfcwjddRzr3GRC4rrwL3NVb7xhhVd69W9wogJPvGKZcXsC454yZI2
7R2eqqmvyXdG///uDwJrMDc=
                    "]], 
                    LineBox[{708, 1013, 707, 873, 645, 872, 646, 874, 711, 
                    1014, 712, 774, 773, 582, 894, 654, 893, 655, 895, 583, 
                    775, 953, 878, 879, 875, 877, 876, 951, 771, 949, 950, 
                    948, 947, 805, 644, 871, 706, 946, 606, 747, 
                    708}]}}], {}}, {
                  InsetBox["\<\"\[Mu] = \"\>", {-1.8, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["0.2`", {-1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {InsetBox[
                   SubscriptBox["C", "J"], {1.4, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["\<\"=\"\>", {1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["4.33`", {1.7, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {
                  {PointSize[0.05], PointBox[{-0.2, 0}]}, 
                  {PointSize[0.0125], PointBox[{0.8, 0}]}}, 
                 {PointSize[0.007], PointBox[{0.4463998339305619, 0}], 
                  PointBox[{1.2771956561278897`, 0}], 
                  PointBox[{-1.0806611991222994`, 0}], 
                  PointBox[
                   NCache[{0.3, Rational[1, 2] 3^Rational[1, 2]}, {0.3, 
                    0.8660254037844386}]], 
                  PointBox[
                   NCache[{0.3, Rational[-1, 2] 3^Rational[1, 2]}, {
                    0.3, -0.8660254037844386}]]}},
                AspectRatio->1,
                Axes->{False, False},
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                Frame->{{True, True}, {True, True}},
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLines->{None, None},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None, "TransparentPolygonMesh" -> 
                  True, "AxesInFront" -> True},
                PlotRange->{{-2, 2}, {-2, 2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.02], 
                   Scaled[0.02]}, {
                   Scaled[0.02], 
                   Scaled[0.02]}},
                Ticks->{Automatic, Automatic}], 69->
               GraphicsBox[{{GraphicsComplexBox[CompressedData["
1:eJx1WntYlFUaJy/okiSaeWG95ZLNauVlGUlTX2taKzVC87ZWmFakjmkrlA1a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                   "], {{
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[0.3], EdgeForm[None], 
                    GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxNmnnc11MWx7/3ftuslUSJFIrJUrKlLCGFlFEmKlsNQmRPhWQNSVkqIZUk
WUurrawhY0t2meyyJRrDKM159/n8Xo8/znPu967n3nuWzz2/p2nfc7oNyEVR
NK1WFGXw81JRvBX8zaA6QTWCagZ1iPqNgl6P8kfBpwcdH7Qm6I+gE4PeKDTH
xkGNgmp7jv9FW/XgmwZt7bq6Qc9H/XNBr1EfQjQKqhO0VdAGUbdZ0DtBGwVt
4fmqW6YGXmeToC3dh++tvA59G7qd746xTu2gt6O8jddn/p393Tjo8GjfLOjd
KL8fVD9ou6Btg+oFbR60veuRp5nXRpYdXMd3r6DOQUcGtfCeK2ts5rl2tHzI
+zefF/12cT/WbO656dc55Kof9GGUd3V7k6CdPAfjt4hz2zTo4yj/HH1XBZ0c
tEnWPnYPau09sY+9vQay7Oe1mXsv7422fdzOOm29H86sjeuQfV9z2vb0WTC+
nfsyb7WsuToFHfwXWfqGfK2Ctw/a3+vvFnSI2/cIujxJ1o5BHVzHOoeaI2/N
LJkOCzrCMiFvwxj7qft2CzrI63fxnvf3PbXz9ydBBwYdFfSfGDskaHDSmtt7
b393n/a+57Yef7TrWKO712EfNUK2F2OOz6L8WfCXkvbxQpK8PYKOCzrcsvc0
Z+7elq+L29t4bxtmfR/r9Vr5TJfHnP8O6hrldcH/DOofdJLlRsZt4/sbr3Oi
90rbyW7nnL6IPv9Kmr+P69jTSuw16Ksofxt0StCAoMZR97X3MSLKpwX9k3mC
TgjqF3RqIdtgTytcZvzp7oMsw2PctUlrnuE6ZD/THBlP8xzHB53jOZj756Dz
0Jeg870mc19gznzfu55+F7qOuZfEmoOCXxf0Fb4s6OwoX+T2/kHneh3W/3u0
7xi0MsqX+QyQpchae1jQUNcx7if3uTToCsuHXP+NOb7lPoKudB1yXWXO+kvx
W0Gro3x9ITkHMx8yBo2K8o1Bl3j+WwvNxRwjgoa4baTbkfdmy4gsP8Qc3yfJ
y3zUjw6a4HkZd4v7Mu9dnpe2tdF/ePBxQWOCrg66Jug2r8/37YX6cLZ3Bt3g
8eNdx57uMKft9phzXNBNUf7dskwMetDjWf8ey8Rep5iz5mTvjbZ7XYdc9wWN
tZxTXTfW6w32GU3yWoyf5r7Ifr858j7k9TmbByw3Mv3h8Q8HPWo5kHGGOTIu
L2Rr6Pp0z8f4RzyWMTPdF9kfM0feWebsY65lYo4nvR7rzLHctM1zOzKu8xqP
B813HWe5NmiN93R30lwvBD3h/sybk76fD1poOWYHPW1ZkfEpr8/3M25HlpT4
ozWfdR2yP2eOjAs8B/O+6P0wHxgEXEC8f9n9WP8Vc9Z5yXLQNiVpjcVFVUzC
V34Q9TWCFkW5WvAyaf1FXmf9+KibljTfvsFrJa3znDEOeGPDJExUjXmjXDNJ
runGRGAkMBAYBAwEVloSvFbQ0kLYCIwCVgIPbeK9gVPAJ6xRx9+NjIHAKMRv
MAN4iDFggQYes5W/mRfcAf7Y2O18rzLeAW+8VwhL1a+s4fFgHbAE2Ib1wCng
ENZs7G/GEPu2s4xbezxY6YNCOOSjQpipqdfb1uPBc3V8Psi3g+dCRvBFM8sB
lgBnVPBNE+9tR/dr5HvdyfOCKXa2LC3cto3rWnj9Xd0PTAQGauVzafYXOYjr
rf29p7+3c93u7ruX25AFDAMW2QdMm6SzzV23l+Vr437YAfY6zTKBE/a1TGAN
MMOyQhhkt6IK03Sw7Pu73z+TcNKBlgtMAbZgP8T+9pb1YH/Tj3h+lPfTwWPA
MV08LzKCH8AfYLOO3gNY61DvBVmPcD/kYOyR3kdnt7VzXWfLcbTXRo5u/kYO
4jh+7/MkDAQmAxOBgf5RCBN1t5xgmx5FFZYDp1TwEfxY33M7y8K+u3s95Ojl
McjV29/IdJLlWI+RCuEH5DvZbV8Wwh3M9ZrxT99C2LKT7xRs1dtn0c39Gf8W
/iHoR+ZJwk9fe20wAxjl80LY4XifBZikn9vACQPc91x/g4PO9Pz9jKnO8h7O
8PgKNuL7O49ljR8KYYf+RRUGOt/9LvQ3+OU/hWJfP7eDi940/gFnfGWMM9jr
XOTxvb0O8v5aCN9cYrnBEWAMsNDlnvO3Qvjl2qBV7nOu1wRXDCuEga7yGsh3
pdsqeIhvsNIvhXAFmGiJ8ccAr3mpZSWuX++9jfD3INddZ1lvdBvYZ6THH5WE
j1d4rpHu92MSTvpvoVhxf9CrheIDMaCm5QOH3OL1wAXEd/A3eOMay00ZXILc
4ApwBjgdLAUmgfAbUy3r+L/0m+a2qzzHrd7DXV4PWSf4GxwDpphUVGGs8UUV
ZqpgqHvcb4zXrOCme91vtOeYWFThoYoc+LhZXhtM8YDXfsjfd7gOLPI/10/w
fGAM8NI/Yt+7JmGodkmxqn5RhXses9zTvXYFVz1aVOGkmZZpjmWa7PZHPA6s
UcFNc91visfNsIzz3Q/sOcF3v8b17OXYqG+VhKcYB3YAQxTGFPM8F3VPWq4F
7sd64JNnvKeFbpvtuoWWl3FPFFU4iTFTjEeecTsxB5zWK+r3SMJodyXhrT+9
/iL3q2Cmly3HS25b4Dq+wUSLvdYHxkLoNnEc/AA2APuAyaqbwGZglnuS8BCY
6dCgDZKwzpbglyxs9Ij3BP4Eq9AOTlmYhL3AUptlrcHc22RhJzBP2yT8xLhN
jGc2DOoU5U2TME2dJByDnMR9yk2Cjoj6ukm4pHdSzAYLoluMA4+Ae5+3fA2y
+hL/W/osufv9kvAN2OayKDdIwvLEaPAKsfvIqNs8KfcyM/iMpNheO+a8yPVb
uI7+xDHiA7GM+cg7ECdf5S6S3teNkmIG8YKYTMwklm/t9Ykhp0a5qfu9nBTD
iF9XJ/Xj/b2dOT6+elYegnhPjPzGshwdfXZI8uM3BW+S9L7fwRz/2sR+kXjF
msQbYgA+ljiCT22e9MbG558R5WbuRxxc4TW3T4pPxKZljpmDPJ71Kz58pef+
lXU9hvmIH8QOfCmxAL96ZtTv5La/JeUCiD2bZ8Wd4ZbxV69DXMH34SPfRY+S
3pr4J2weex+bFLeIWTu7HR84qZCvovxekl/DXxwQ5V38jT5hl+j8bvZt+Dp0
CjtFr7CLda4/Juk9xvoHJukfcuxuf8M8E6LcPlWNx+/gc6hrnfS9p/0BOo3/
wLaxa+yG/Cc2gl8Au+JD8AXYBHU9k95IjMM3YJf4B+wVu+Zdgy/B1mnfyfGQ
WH5QlPdKWu/hpPcSbyX8AG8h3kGHJdkqMmB/2C92jc3VtV3ynqiXZL/kM7Gp
pq7D1qjHN2yc5B+w9c3cn3ZypNhXlyR7o4xtbZmEi9H9rZL0H30k1qOTVyTl
CrEzsCG2h91hT9sk4bw5wYf+xa7g2OATwW9J0n3siVwYNvWd9RVdnR/8miRb
xJ6wJexoXhLmaGK7ob2f7QDbw+6uT7IZ7OXx4KNsq9g8dogNou+sf571bg/r
3m1J9nC5baVFkr2s8v1xd92T9Bt97pP05uRseyTpLvqJTqPb6Cd2CXYcYltp
aX08LklfH7feoQ+LraetrVfocivPiQ7ubT18OvjBSbHkqaAnU5W/3sf6Wcvt
6N7UpLf6K9ajttYl9GU/6wz3sH+SnyV2HZIUtx5M+j2D2IS+H2S9bWMZ0Pu1
tsM1ttf2ti9iEXEOmyAmEGPQXzALMekd29lh1nP0sYv1kPjF7xBvW587W6cv
ToofxAjsg98h3rVNtLNdoMtdk+IHPgx/jY6Am7r77jjjnj5n7rNbks/i3o7x
3XE/4BjugbsFe/3hO+nhe0F3jvM94k/AGdk6iq5iN8R+sC+4l9+DTkjr4f56
Tj3HdVJSTgS/cW7SN+U/LDcygwPoQ25jjfvgN5YXiovERHIR6CR4hN810FEw
APbMu7h98NOT3ki8jz5Oirm0nZL0fqbv6uC/JL2jPnZ9S/uGU9znoSRZkfM3
9yUPnLPyrdjRGNZJsiN4f5dXWwbejOvch9hxTtLYUZ4nZeVZiTlw8DU+8vxU
5dsuSLJBfAw+Z7n3yr5498MHWmcGur6lyxe7HgzCm5/3Pnsd5D4X+AzX/8YW
/MIkv8ublv5dzYe4XMkLkBOg7lLXD0uqx5demfTd0fX4U3wpbwrOhzfNJZ7z
AM83zH2GFYrDnAO++UrPgy/EZ+JreXvyHu5vPtxl7meE7+hGl/ndgfbr3Yc7
ucH3cp3H9ink169zmXEjPQ93dZvvGv86OsmX41/x8/hpctO8E3gj4Ivxyfh1
/OuYv+jGWOsAceDWJL/bx3s4uRB+YJ67ozw+KffN3NjrnUl+aGLwSUkxnfY7
3B/MDybAP4FjJ7oPbwS+n/BYyvjYye5DGb872eVxXpc57016b+C34XzjY5/1
9zPB73M9fcAHvBfAEcTMq5LiEu1TPZa3Mn3+xT0n3Stn+EDS2xm/sXf8qV4q
ztXLypPiB+pnvY05Q+rWuP4kl/EdtK9zn7NcRuf4/a7M0jdsLjsfUdgGK78T
8U3cxBapH2YdyLbTmZ5nhvWYd/o4z1m4f3/LQTt5InJq2A05K/JZ5LLIKW2c
lVci97VBVv6L3werO8dUK6ueMnZO3pLcXsOs9wnfG2XNQ46McdXcv5rn6eg1
N3If1qPMWwO+ocucLfh4reWp4Xno/4Xt6NNC+TreHbyhiM3E40eCHk3yw7wB
id9tvCfm6mS9WOB75/y4j8q7CI5f6uO5mIdzfizpvmb53JdZT4jZr/veH7YO
MOdM92fNRanqN1byjMcUqqOtkmPkjbT+t9ngzybFet6hz1hO+nzmsWAFfgOo
xDrKqdC4hR67wGXGVr6xiVe8FvPAX3KZtx13zr1wVrWsA8z9vOfvYDkO8f3W
8JuNnG1N/47OuJrWq1lhN02yMPf7wb8oFcOHBL8my6/ciD6Wen9cFnxoKf/C
XRMT+9qX/uJ7xwZ5k/NbBXm2n5JybcRhfleo5AZW+e7gP7vcx2X6HoKdlcKI
zL3aay2K+gtKYdO2vJFLYcoRwQ/Pyj/cHOVVWf7hhijfWMqXDA9+bSm9uz74
mCyfdGuUx2fF8EZRHl0KjxyZNRfzXIE9lXq37Bfli0vh4CH4gFI4+orgw0r5
11HB25a6l8ujz4Wl3pH9vBfObIh9zQE+Q3ADOIS8IjlD/PlQf5NjZG3qh5r/
6D4j3YcyuVBynbxx4d8l4ffvXD+wkO/DJ4Kd0KFa1oea1itskDbukN+LyOv+
npTb5XfnFZ7nKq/HWmBlbP9Y8y+tD996zEDbLvsd7Dmo/8bzsndi6G9ei3Og
z68ei+8A24P9l1mvLrZvXGm7+MFjyAMzJzlo8gHwr5PeHyu8Jn2+dp+zbV/M
Q/6EPAbvK3AreJm3E7GaGMR7jDjE72zkm8BC8MZZb9XGrqed37D4TY7fxyDq
wKSN3J/vX4MmZmH8t0JHJme9Szax3yanBMePNy30m1RD+/M3scWsN3a7UrqL
3jb2usjD/0fVdZm6rV2u6zIyrgz6Keudc0TwkaX80rZR7pylwzcHv7oUnvgs
+JtZWPyy4IOycjHYweAsW1gU5QOy8iBgTPJZxKVXov71rLfFwCi3y3qXYFut
bV8vBn85CxMt8fnWsj7iW8j1kfOjjD9/3fvhTfFC8EuydB6bG5ZldwujPC8L
u10Q/MRS2O6g4MdnrbM0yg9n4fq5wQfYfz4e/Pws3biW+UthqTbBb83SyYHB
+5bCgs2DX5j1pj89+JGlsO+hwftkYeZHg/fPyhmcFvzwUjj77eDTst6j5J+I
s9d6r/W837q+N/bLb6R1rGPYdD373vetN+jMGzHnqKw3K/OSHwHn83Ygz8L5
LYk+U7PejqxZ3+uCTeo71q9123Dr4RaeH3m29B315jxL4e/Pgy/NeiNeGuUR
WbiU34D4PYw8yRLbM3m8T5N+Y+vq9uXuA6eNs6q08eZg3CdJuvd+Eia+2z7h
ddvy7/Yt+AOwz2v2Fdg7OVPiO+8pcnm8s8Z5HvJyzEF/4s4nlhOfQzvrkdsg
rzs76c1JvCZ+k/shj0reh3cYb9+5STkj3uJglGX2vYstw0qXkY1c+odJOQw4
38Q13mK8P3nPTXM9+BkszFuaOHWCy+COi9yft9uP9uOcM/GU+I1/5kzAdnxv
Hnf0UdbbfXGU38vKDbwa5Y+z8jJPRHnnrBxG4yhvW0qfbyoVa4mzjxMbs3Ib
c6PcLCv/Ab74IAtjgCleM64YE3xsKTw3O/iErLfsPGJ1Vl7kvSjPyXrnnRP8
26xz3j7qdyilG0+yflbupPJO5k6JFW/77n73fY+2bnAmxJpBjhnEC/oudf8v
Y85Pst49q92G/g+37vI7W5foc0ZWvhC7qG37wk9vahup7XIry4MuLfH6b1mG
XjFPz1K6w52CX7HNB2Lc+FIYtye+NguH4vu/sP9fHvzRUngUHNSwlM50xG+U
et9NDH5UVm7rm+CzsnB61+CnZOnJjOArsnKa+P5RxjCf4wuzcmf7Bu+WdT7z
wV9Z+acOvMN8d3cHH1cK698ZvHOpd/xuWeuxVreoO7qUDTUJ3iIrv/VUlHfN
yl39GXxdlt1cE/XLfBdzuPesuLlplGuXylttGHx/x47mWTqE/hBjGUP/KVly
I3PfLJ1Gn0/M0ld09Z7gU0rZ7XTGlfIt9+OfS+VuiQMPOBbskqV/6N7JWTaA
/nMe6DRnsjz4h7avZcTYrHzbR6VwLZj231F+Jyvf9kmU38rKtxE3GtvW7srC
7uD2GcH3LZXj5H5mlrqj9txDKf2fVComEY+6Bn/IMe65Uu9n3s77RblXVg5r
bfA1WbnFX4L/nJX3BFOPy/IzvdGjUnF4r+B7lspXHRf1D5bCai2Dd8/6jYXY
vjgrvpMku6P0+zr47llvnKHBX8yyM+LtfMfci4M/l4XvwBoLsvxZGWNbZvnP
mlGuUer/KzdA37NwIxhko1I4hPM4MOtMuM+Dsu6UN9ABPs+ZWTaA/renf6n/
be8YvFOpnFez4K2y8hbf4SOzcMUeWTIhD/ZxqW0kR91s+66T0J2sHPNjWftn
789myY3M2Oj3ttMfOJus34i2KoXPwGY9onxsqbzJ6fifUvmmXbGprN/Qzony
uaXyR/jvLUr58AbBtyz1Lq8f/LCsnMxOnF/Wb4M7Y4+l8qP4kk5Z/uTgKB9S
Kuc4PctW1/8+meUrsc3RWZgDvPF0lp6hY29nYQLwwL1ZmAO8cVrwfqVyYegm
OAz9fCMLa4IziUvYD7aDfYMRsfHXsmwJOzo1+Cml8Dt3AubjXq7OwqPowH1Z
GAsctCTLxrCvd7NsD7vDV/XL8lcvZdknttmduyqVV52UhdfB6gdn4VowLZiO
mEQ86hP8oqz84qFZcZTzPyt4/1LvibODDyiVH0RHiHPoyZlZcYWY0iErHhOL
7wo+oRTmuCPrDYD/J5buUyqe/h/2xNYc
                    "]], PolygonBox[CompressedData["
1:eJwtlwkUj0UUxb95o02lPdrTihRFCSWStNBip0goVLYKJVosRdZChQjZSog2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                    "]]}]}, {}, {}, {}, {}}, 
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwl1Hl8z3UcwPEf/hVy3+aKMuQoI13YmismV7l1oGULf/Sg0kVEzgmbq5D7
yH3k73LG2pybbZXyV+hQQur5fvjj6fV5f+bx2/f4/NZ4bPaArHKJRCLDP09U
SCTqsZA+5ROJRfqbLmOx9XL9g99pQjd73XmW4eYe2lT36iodQQPrz1jK6vgs
val/sYZ95mb6Nw9xwLxWR7GOg+YW+g8Pk2Z+jlTGmBtqI5J4xHyHZL42b9KX
2cwRc2u9x39sZbm9LZqrCfJYQW/G2e+l47WP7tCzulMzaRrXTXMeNQ/WIXGt
tKS/vccYbz2B5Pj9ZNhLIdv6TdrQlhfsdeUt6w+0nbbnuHWxHtNpOlOn6sf6
dlw/m3kg3oO9ozpbf2VgvCOO2ftOP+Fd6+m8w1zzILrznvlTfVxP0Smug/f5
kMHxfjlufV7ns5DT5gU6hFROmIu1ptYgPX5vnAGdrUv0J35kl/krOjMr7ont
vOhn1/iBHeYy3al16WU9T+czJ6457oOe9uvE2dCTWqq1tRbbGBrvXFPIsZ6p
l/VnLYnzzUfWi3SGpmk1rU6RdZle0qp6Qa/oxbgWzlFqPqsPakHcoxbqHL6n
xJyvVfR03L+e0Vmc4rL5pFbSypyw/laf0Yr6dJwn7UiHeCfxc4qsv9EpOk0n
6VSdHOefjUwki9d5g0y+ZFh8b+PZ8FI89/iOxllkYJxhBsSZZSWr6Bef4/P7
xrnW5+P5amG8u/i7oI15zbpnnO/4P7xCuvlV/Ze7bKAgrlGvMpbD5lZ6m/Xx
7OJa9RdGcyi+X3qLz8k3fxHvkZHsj++k/kkeZ8wr4n3FNZNjzo3vWtyz1o8z
GfdnvUeT9Kl4NvpkPP949nFP5uvcYCm77TXS3iyw7lLh/t/P/wFY365w
                    "]], LineBox[CompressedData["
1:eJwl0DtOAmEYhtGfmViIq6BUC0UNxgLXQEgstaDm4qWABLSRBYF4LRAQJFaU
mtjRKWyCM6F4ct6PTDFDplQrVlMhhIJ6UQjfcQgPTDHLd9a40FIHGvjthZc6
t6/Y14ed4wbrya25PeImx/zlhE2l7Tw/+cV77dsNte0pT7nFu+Q5TewTFtXS
zH3LRvKuGruPucsdbevGfcEjjvjGa71q6D5kzL3kO/jMqiL7kT98YkVndpld
dfSvv2j9360AX4osLg==
                    "]], 
                    LineBox[{700, 984, 699, 865, 629, 864, 630, 866, 703, 985,
                     704, 775, 774, 570, 885, 639, 884, 640, 886, 571, 776, 
                    934, 870, 871, 867, 869, 868, 932, 772, 930, 931, 929, 
                    928, 806, 628, 863, 698, 927, 591, 748, 700}]}}], {}}, {
                  InsetBox["\<\"\[Mu] = \"\>", {-1.8, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["0.2`", {-1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {InsetBox[
                   SubscriptBox["C", "J"], {1.4, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["\<\"=\"\>", {1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["4.32`", {1.7, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {
                  {PointSize[0.05], PointBox[{-0.2, 0}]}, 
                  {PointSize[0.0125], PointBox[{0.8, 0}]}}, 
                 {PointSize[0.007], PointBox[{0.4463998339305619, 0}], 
                  PointBox[{1.2771956561278897`, 0}], 
                  PointBox[{-1.0806611991222994`, 0}], 
                  PointBox[
                   NCache[{0.3, Rational[1, 2] 3^Rational[1, 2]}, {0.3, 
                    0.8660254037844386}]], 
                  PointBox[
                   NCache[{0.3, Rational[-1, 2] 3^Rational[1, 2]}, {
                    0.3, -0.8660254037844386}]]}},
                AspectRatio->1,
                Axes->{False, False},
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                Frame->{{True, True}, {True, True}},
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLines->{None, None},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None, "TransparentPolygonMesh" -> 
                  True, "AxesInFront" -> True},
                PlotRange->{{-2, 2}, {-2, 2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.02], 
                   Scaled[0.02]}, {
                   Scaled[0.02], 
                   Scaled[0.02]}},
                Ticks->{Automatic, Automatic}], 70->
               GraphicsBox[{{GraphicsComplexBox[CompressedData["
1:eJx1W3l4jNfbDo29U3vpVAlFo0VSRPHh0U5pa2uaUqo6WiSW8UMt1Wj4aht+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                   "], {{
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[0.3], EdgeForm[None], 
                    GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxNmgn4l1MWx99738qgtFlCkZIlIlSSrVHKVlR2UkiICCFlCJMSEVFoKG1k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                    "]], PolygonBox[CompressedData["
1:eJwtlwnUT1UUxd891xKaB1NJotGQKFMhqZCQDE0KUck8pFRSxiKFSghJcyGp
SGlWSlFU1pIGKqJB88Rq/O1vt5a97H3vfe9/373n7HO+w3sN7jQoiqL4GpQC
jXJRNADvwwemoriSyRfQG+AjGKuMbpg9VwZci34FHAW/FXSCN2a+bPI7psNr
g4xeDMbBv2dNOebuRx+BPlKA/8jYCPjVYA18LmMdWXsQuhu8P+iMLo++GD4I
XAKvkf3sZHR7+JlgK3oUegnrLwej4QeD8cw9gH4I/mDyu8aA+5LfORZ+V3hv
GjsOXRdcAOdfMQ1+HrgZsQhk+FWs/4W5P8CV6NvQdzM3C1yu70H/ytwR6Dno
2aA0vEHy2o/DXM+sg5dlvrN+G6xCl0a3hx8D3tW3gHPgdcBa+DjQCV4bvA0v
w/qO8FrgPfTNoCu8LrgB/iVoAt9d+NmbwL+F3/EWfBToAK8JXocv5X1vw3ex
5k30jeBs9LHJ754EIvk3RrH2dvS98Hngeng/xqbBbweHwauC3vBLQV/4yPDZ
TUHvkf2b+i198w3oG7Pvnv9KYmE0mJ8cEzXhx4K+8H7geZ5dh94J38n6beit
YDv8EMYmM3cL2IGugu4CPxfclJwD3RRbYBL6W/Th8OrgMvQ36P46e/Q4xZJi
Hj0EXT85xivDDwaV4JtZ3535FuiD0J+ix6DPAieh/9Ke4D+CU9HlwCb4TNY/
BX8aTIH/rWfgC8Cp6B7hd5VH10OfCAbA1zP2D3MDw99ejbHl8CXMr4J/x1hr
+CWMXafc1Z2gu+tM4I8rH3UXoC38QPAS/EnmVyfH+CT4GWAE+lEwTHePPhr+
M/N14MPAjOQYX8T8KvQm+GfML0O/if44+U76oJ8J73WMYoK5oeifCntKb/if
oCL8c8auk9ewpo9yB2xA76k7VHKCpvBmYDi8OUOvMb8GvQ39O3oxuhcYmfzO
Vsy1BFsKf9MFyv3wt58JPoTvp5yHlwInKz4Yuyr5N+RlP4TvTp5WF94z24uq
g6nouehl8HeYn4BuB05OzrlrmLs22+vWoicy1x40Tc4p5drYcKwo576D36EY
R7dA3wM/D7SC7ysPUa6D0+B7gSqKhfDaDTzzVXhP2ktz5aPOGrSEb2SsurwM
nIH+CF0V/jM4Hb03mMBed4fPVh5aCb4j/K73lC/yOtAavZ/ugPWPyE8Kn1kb
9KXoLwrniLziW3BKsmfUVzFiTTv4b4XvSjGrWNWd6dvvQS9PPoMr4NeE71Y1
5L7wHeruDgAzmD8b3Qy+BAyW14W9+PvCZzcvvFedoc5udvhbdYYfwMeDLvDj
wQh4n+y9ydPllW+EvVmeqVw7Dj2gcM7Nh28GjeH7g2XZHizvXYueq1wGjeD7
gMXKfXk08yvRs+CfgIbwPdP/sRP2csVQQ3itbO+byjOPw2sqBuAvJ+fu8eHa
rRxuCn+OsXfhrzFWTrU+/G3KIXl9o/C75PmKxWagXnJMKlZmhveimFGszAnv
XTHzm7w//K1tkr3t0HAsyuOeha/mNz6FD+Q3esPvyPaeGspxxUa4Vm9jfh/m
9lb9KbyHF5h7C/05/GrGns/OUeXm+uReZXjY69SznBJeozn1FCvR/bNr0ZTC
3qAxcXmEau874dqqGnxbds1QrXgsOTbVA6j2K0YXqjaE9/oi+i50h3Cv84Ry
MntMXB7SNdvT5eWqOW2zPVVeer3yFz4r2wtUA7aHa4JqgWL4IuamgoXJNeo0
9SLKMZ1Hcq24NXuvqhm6a3mkvFF3vkB7CXvpimQvXoruXdiT28KbhGu7egT1
EqvDvYB6ipLaFe41VMOmh3sy9WLq+Sqw/iL0MHiP5FytEK7dJTkLWRG+O9Xo
1/Xt4Vq5MblWLFS+Fa4ZuusXw7VFdy4vLR/uxeSpiqXnwrmsmJL31Ajnvjxo
YnbNVK3UGU0L9yjqTXQsU8I9m3q12WCyvgV9p+4yOffXh3sxeYB6DfW86nXV
c6i37KAeJbnHVK6fH/ZO5fxn8C3h2lchuTc9K/uutzJWW36FnoiumlybF4TX
qkb3yO5J1IuoRqtWnZ5916pZVeCHqqYne+rQbM+T16kGn5/d46i3Uc96QrZn
y6vVMxwTjmHFrs78ybCHyDvkQUPCOarcVE2uDz8n3GvswdjD8IqM9UzucS7M
7pnUK+mb1KvdGV6rnk2965pwb6oeVt53brj2yANH6vvCd6OeW97XJVy75IGN
wx4q75zHWBOdD2ND0UPAxvAd6u7Uk6nX7Isem9xz6q7Uc6jX0J0p9jtl93LK
gVphD5b39lLNzR4T1zvahGu8antJTxj+m0h/C6mG7YI/CB5O7qEG8vyA7L2q
Bz4JfqTeUThH1EsOQE9I7in7wTtm96rqUV8N9zzqddRjqbZUy+6dVWM6Z3uq
vFTvUK1VTimXVHN1Nr+HvVhnJO9ol/23kTxkMLx5uBZM1/2Fz1RnqT3qbpXT
ymXdsb5Nf0Ppbyd9o3ox9fDq3dWTtQ7HdEksaz7sOfIa1aQW6OHZuSZPV67d
Ev5t5Zx6jWrhXkY9x3/rBccZ
                    "]]}]}, {}, {}, {}, {}}, 
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwl1FlUlVUYgOFjaIMN2qBAQaXW0ookS4ki0ASUQCpJyyiziItWJWBZUREQ
aYZZFJIVqUmG0n2D1nIIaTLAAM3mu3KozOa66/lWFw/v/jaLn3POv/8zrqK6
rGpYIpEo9iMzKZE4nUcpOCaRqNND+hyPWT+vP3KYVLLsXc40yszZeqa+qm16
A2OsH6eJF8xP6BH9hTVsMJ+lR0nnNfPLOp92NprP1t84l07zOr2J9Wwyj9M/
mECXuUNvjmvxhvk8/Zt/eJ1l9jbqcv1Xn9SryCWHhfbydLP2aJfeTop1arxH
JpqLtFLTNJ3Z1hnxv63L43UxniJ7mXEN6zuYEK+J87nM/l1aqxN1ErusP9Vu
vUfr9G5dzL2sZgTZ9t/Sev2eYq7gbXsfaQNNbIt7oCVcyTvm3rgX8d7Zbl6u
c8hhi3lAV9DMDvNTWkou75r36Sl6MjOsl+qzer8+o1/zFa+Y27mY+1jCGq7z
ux/4khfjnvMSpzHTXq0+zAM8xINcbf9Una7v6Rc6WkfF2eJac5tmsMq6Rj/X
Id2vT1NlvVKrNU9PinuvW3WvnqgjGbQe1KE4L3xGv3mPnqB9OqD92hj3iz7z
bj1eP46/0U/i2eFDes0f6LF6HD3Wb8YzpMM1Sy/SC7kg3r95J7utd2hlfH5a
oTV6p7bGc8ltLOKWOL/cSgtzKOUaSiimmUJmxWdNAfmsiPscn3Ncy/Wnx3V1
hnbqLt2kyTo2/kecpzjHOovyOH/xGvQv/ozvArrtbdDvWMDmeC709zgfvG9e
q99yYzyj5nP01zgb8RnE2dBvmEeHOU1/4mdaWRevSQupt27gEq43n6GN8dxY
r9dkvVTn6hSdGs8hKeYDHKSFtfbGaD6PWE9O+v878j/TwZ6f
                    "]], LineBox[CompressedData["
1:eJwl0EFKAlEYwPHneA/TTaSRtLAzRJsSb5BS6SIFrU2dqDSdRihQC1oUtOoI
WcewiH4PFz/+3/dmeANTavYa3VwIoc4oCeE1H8JQV2wxtJ/oF9+UGTlL9ZRD
85k+MDHv6B/nzPlwNtOcLvRdn7RPYq5ppi96xaa5w7V5qnua10t95t68qwcM
WNgvtMsjqb2qRd2gEO+zH+m2jjXTdryLO3tFf+O3ubVPtMVPfM6bs7E22Tcf
x/e4Yclnsv53/9oWLNI=
                    "]], 
                    LineBox[{693, 967, 692, 850, 619, 849, 620, 851, 696, 968,
                     697, 623, 767, 561, 870, 630, 869, 631, 871, 562, 768, 
                    912, 855, 856, 852, 854, 853, 910, 765, 908, 909, 907, 
                    906, 795, 618, 848, 691, 740, 739, 693}]}}], {}}, {
                  InsetBox["\<\"\[Mu] = \"\>", {-1.8, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["0.2`", {-1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {InsetBox[
                   SubscriptBox["C", "J"], {1.4, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["\<\"=\"\>", {1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["4.31`", {1.7, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {
                  {PointSize[0.05], PointBox[{-0.2, 0}]}, 
                  {PointSize[0.0125], PointBox[{0.8, 0}]}}, 
                 {PointSize[0.007], PointBox[{0.4463998339305619, 0}], 
                  PointBox[{1.2771956561278897`, 0}], 
                  PointBox[{-1.0806611991222994`, 0}], 
                  PointBox[
                   NCache[{0.3, Rational[1, 2] 3^Rational[1, 2]}, {0.3, 
                    0.8660254037844386}]], 
                  PointBox[
                   NCache[{0.3, Rational[-1, 2] 3^Rational[1, 2]}, {
                    0.3, -0.8660254037844386}]]}},
                AspectRatio->1,
                Axes->{False, False},
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                Frame->{{True, True}, {True, True}},
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLines->{None, None},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None, "TransparentPolygonMesh" -> 
                  True, "AxesInFront" -> True},
                PlotRange->{{-2, 2}, {-2, 2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.02], 
                   Scaled[0.02]}, {
                   Scaled[0.02], 
                   Scaled[0.02]}},
                Ticks->{Automatic, Automatic}], 71->
               GraphicsBox[{{GraphicsComplexBox[CompressedData["
1:eJyFWnlYlFX7RjEjY/zM8MsmP8OtJnOLHE0zn2zKlMQmw6W00TBxGVNTCzHF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                   "], {{
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[0.3], EdgeForm[None], 
                    GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxNmgf8z9Uax7/nfI2MSLkaSqjQUqSShnRDRiktI9LeqTSuJFTa2loooumi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                    "]], PolygonBox[CompressedData["
1:eJwllwnUV1MUxd89l6QyRaOSSEIqQzSIQrNGoigqDRokRKXSXEolmpQhMkZR
hswpEplWq4gSITJLhrXM/HZ7rW+vtfc9773vvXvP2ef8q/e+qvOQKIriR7AP
GIjYA45ORfEt+jT4ylwUG9F3on9CXwG+hldj7XH4MuIb4N+wVhpeClyC7g5u
Ir4J1Nf94Ab4GPA717ZB/wF/EfyKboWuxr1Hgb7wN1m7kdh48Be8XfK1K4i/
m3zPR+ht4HN4Zdb2JVYCVIBvY60q/FqwEJ3B0fBjQX/4W8Trce/PoCV6D3oV
fDnxt9G70UvRS9Gvoj9DT0MPQ9+BvguMgN/M2j7wu8G78FtYexy+ErRCnwEu
h68CBxM7BNSAf8/zRhF7FRyPPg9MgQ8kPgc+DwxDPwuOgc8AY+FvgBPhHcAL
8HVcvwv+M897G/0P6IT+G70cvob4x8l7dKX2GtRMPvNKxIaA+egCHAlvG977
vd8Ez6x1hR8KeqHboMfCx4Eq8KvB7fAA7xHvCDZz/+no++GriX8E385ab/Rj
4dwZD66DlyV+GXwm6AkfzNoPhb95M7w92KhcRDchfjF6K/ow9EL97+yzVY7N
IrYTNIEvAefq2ehPCudEVfgX4Mzkdxyh9wPHolsr/+BfgXPgB4Hf4EPDufCL
3l/fi/6pcI3cCu8AzoKXBuWJlwO94L21n8R2gWbwLdxzCrGTlL86C70/sfNB
c/ghYBqx3egW8Ef0POUGawPgJcAx2Tms3O2Hbkc8obvAh4A2Kmb0+fA+4AL0
OPSD8A8JvRXOIeVOXd0DX0V8i86CeCf0/PC3nw0u1VmA8vCPiZeFn8D1A9FX
gHLoGtnvsm/yu9bKjumdtTe3gTLJe3Qe/FTi+yfvQUX0ydl7UVL5D58MdhI7
XB4U/ga9e1n0cHg/4rO19+AV9J+gbXINTYcvIv4CfAP31IHXBu/AB7E2gfgk
8C+6I/p1eYtyLLmmeujsuX4kfFTyvfWUk8nPqKDay37WfmBd2KPkTSeA9eGa
Vi3XBi/J68Lephw7gHsPBD3gu3heFWJfgqbJezQvfAba+wNBPz2b6yfCJ+mb
wt+gd6+TnDuLwnujHOrLtdeHc3UWem04x5Xbx4GXwx4s760FnoRv4J7vkz39
Ing3MA39lfYI3hlMQX+J7iM/DXuNPGym/Jy1e3V+rH2A3hKu9XI6c2ITwEPw
68Fpyl/tIfFr0E9ne5a8alNyrxmJ/q1wz1FuXhXuLcrRvtrbbK9Xjmhv+rM2
OXmP2qKPQ/ckNiHZW7Qn2gt5jLx1MvG5yR4rL5MnyYvkaepdfcL3qocNUC5n
9z7lnHpPfeIzC/eg58IeJu+Sp6pX1FJNF+4Z6iV1wrWlnvKg9iJcS6vRD6F7
oj9Fr0XPRv8nj0evSO4l74S5eson4R6j3tJY50t8ZbhX70j2+mXoXoU9X957
H7pzYQ9Wr66tHlO4Z+vsn0APK5wD6iXPo2cU7imvoJ8O94qdymf0PeHeulUe
hX4k3BvXJ3ufepZ6lTywA3oFelDhM5qObgXGwB9VTsCHZ3sVf3t7q2YGzQrq
sd3gZ2T3Hnn+aPio7FxbrDPP7gnqBcqxE7m+u3oyvLrqGX5Qdq/V2gz1DzBd
ZwMawRcrp4hfp/MJe4BqX553NvEz1b+ID0/2hu6qoWSPmIRulh17GLSGNwc7
Cn9jZeUvWJA8A8ibNTNoVpBHy7tHZn+LPHwqzx4sz4H/pxoIzwSaBbR2SXaN
qjb1DdcQuzx7dlFPGgRvzNrawjl+PLyL9hReFdwGb8HaE6p9cEF2jau2p6Iv
zPYoeZPuGcS1l6GPSu7JY+Hf6UzgD+ibwzOBZoFK4Gb1nuxnLQM3wu8IX3t/
sleoR6s3yzOuzH4nvYtmkLnwlsSfkjeAW9EVs/dC7zxRvTKc+/Jw9SJ5srxY
PUlnqRxVbupMVQvts71TNdE0vCfai26gbnYPUu+Rx9fM7rnqtZoRNSvcAkol
zwyaDaqHe7VmhK/hC8DB8HPB5/DDw7OAZpAGPK+haiJ5z6pn90z1Ss24qsUy
2bOyarJZOIf35m7y3s/MzlWdgWpJNa9aV00pN5tme6ty9H3VenjWaJCciy3B
6OScrBn2HHmNPKGkenH2XmhGqkx8h843eeZSbzoi3IvUoy6UF4e/9WpQI+xp
8jJ5nrxXniAvkAc3kfdlz8rytC7o+uihyT1As2Uop5NnzDvDOaNc0czyabin
q5frnVR7S8K9RTWo2WoOOCB5xpobnkE1e2ptXvYMrtn7GTA0e01cM+sCeGvi
z8KfUz1lr4nrN8P87BlXs62uUS0rR5WbqukW2R6g2tcea3abil6aPMPNyZ6x
ZW7Kaf3WUI2oNvSb46bsmUezju7plD0DavZTz+2a7ZnySvVkzTaHhr1SM87e
vQv3Uu2h9lZnpLPRHs8Iz4iaDTVzjYafAxom/wYbp7MEjZJ/Y21XbwrPBurB
t4dzSrmkHJ8dnsk1i6smPoRvDde+ethT4Z6hXqGe0ijc49Xb5Umnoitkz8bq
oXqXBuHZSe+kWey18OykmUzv1jA86+gdNeutCc8ymvn+hr8ZnmX1m0e9q3/2
bKgedjq8a9jbVYP/A/V9zSQ=
                    "]]}]}, {}, {}, {}, {}}, 
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwl1FlQl1UYwOEP0SYvLMvcogTUyrTc0oAUrFxo1TQtC0vHcSqVwJISoYWA
XFAUaCE3sKx720YDqVTCXHCpvDO1zUrvy7LM550uHn/nPY5/+Z/vfGTOL55R
lJIkSb4/hqQmyc1c3SVJhmlfvVWHcwsjGUE/+6P1NkbxgHmM9tfNulYfJMV6
OWW8RDk/2K/lZet1+hM/kkaTvXqdRgPN5uv0Fwbwrvktnc7bvGdO11/J5H3z
Bn2YjXxgHqhnmUmFebO+opv0VT2nr2k2OWQx294d2qxtulUL6Grdjcu4wTxJ
5+rl2p07rYcyy/oRenAFd8U5Msf6Ca6kJ1fF+dlfoEu1l15Dq3W7tujTukyf
0oU8E+fGn/Zu58M4Yz3B92Txkb0vtCzOmR1x/jqRbD42t8c5xHdnp7kivg85
fGLer5VUU8VkTnKY9f6+U+v0P83lBevVWqKr9BuOscH8DtfHd+R5Grk3nmE8
X55jSTxb7rE/nq+t07iWYt4k3/4bcc8o4lkamGK/Pu4lK60L9Yh26lFdwSLr
13WxjtOL8Yz51HxI/+UfDnDI3sG4H/FzsM+8Ty/wFQfNHVrOXjrMe/RvvozP
MO/WUj6Pf2Nu0/P8xS622xurf8S7Q19zH3pTEs8kPtt6h87TQn1SF+tcrY33
jMcp4FEei7tLTZxjnDGT49zijKiOu8jd5MV9ZQKVVJEbn+fzx8VnxXPQLfHz
apOmapf4v+Lu6SCdEPedsXHn9Xd+o5HWePZ6nBlsM2fomXiOtMRz1e94iK1x
T/TnuGN8Zq7Tb5nKlrgPeorT1LDRXi/N48V4VxjAfeZES1ljvSneLc3Q+zVd
B5IZZ24eHO90fCdu4sZ4HvE+p/7/e/ESnWWZAw==
                    "]], LineBox[CompressedData["
1:eJwl0LtKgmEYwPFX28ypOwikA0lD3oFutUizSnkAG1IXvR+tPFUGnaCloM0b
KLuHDKHa/X04/Pg/z8P3Le9muXnciIUQ8lzGQ3hdC+FCv9liYD/RGV9sM3Qb
6imH5rJOuDbv6YI6D0zd7vWXR97tT3rOHwfRv24v2mbDXKNjvtOM/tPimVu3
fc3SiG72pp5F33NjT2tS10lQtR/pro51rBVGEfuO/pCibx9oiTlXvLn1tUjO
XNAeXT75iK/ebgnVrC2d
                    "]], 
                    LineBox[{685, 960, 684, 846, 614, 845, 615, 847, 688, 961,
                     689, 618, 753, 559, 866, 625, 865, 626, 867, 560, 754, 
                    907, 851, 852, 848, 850, 849, 905, 751, 903, 904, 902, 
                    901, 775, 613, 844, 683, 731, 730, 685}]}}], {}}, {
                  InsetBox["\<\"\[Mu] = \"\>", {-1.8, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["0.2`", {-1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {InsetBox[
                   SubscriptBox["C", "J"], {1.4, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["\<\"=\"\>", {1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["4.3`", {1.7, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {
                  {PointSize[0.05], PointBox[{-0.2, 0}]}, 
                  {PointSize[0.0125], PointBox[{0.8, 0}]}}, 
                 {PointSize[0.007], PointBox[{0.4463998339305619, 0}], 
                  PointBox[{1.2771956561278897`, 0}], 
                  PointBox[{-1.0806611991222994`, 0}], 
                  PointBox[
                   NCache[{0.3, Rational[1, 2] 3^Rational[1, 2]}, {0.3, 
                    0.8660254037844386}]], 
                  PointBox[
                   NCache[{0.3, Rational[-1, 2] 3^Rational[1, 2]}, {
                    0.3, -0.8660254037844386}]]}},
                AspectRatio->1,
                Axes->{False, False},
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                Frame->{{True, True}, {True, True}},
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLines->{None, None},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None, "TransparentPolygonMesh" -> 
                  True, "AxesInFront" -> True},
                PlotRange->{{-2, 2}, {-2, 2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.02], 
                   Scaled[0.02]}, {
                   Scaled[0.02], 
                   Scaled[0.02]}},
                Ticks->{Automatic, Automatic}], 72->
               GraphicsBox[{{GraphicsComplexBox[CompressedData["
1:eJyFWnl4jNcap3JVNaOWuHSqhFqmtYVKLRdva3AVZepBSd2hioq0qJY0KK1l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                   "], {{
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[0.3], EdgeForm[None], 
                    GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxNmgn8l1P2x597n/YoYdBCCtlCki1re7KWLIlUpKQFkSEiy2ASSbJkqWSd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                    "]], PolygonBox[CompressedData["
1:eJwll3f40FMYxb/3vdkzikSloZ2dorQTifSLSEOD6PczGlK0VVKptKNsCiVS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                    "]]}]}, {}, {}, {}, {}}, 
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwl1ElUl1UYwOG/sjDzpGYGIoqRpWhlICqKZZEWWZYFmU224BxzxiyalJQK
Z4Q0NUCkMtuW6FEUbCK1CCunVjmUQ8MyKy2bfN7j4uF338tw+O53IaN4bmFJ
h0QiUeDDXR0TiQu8mJRILNcN2kN7aYGmaG9SucrcR/uSRj/S6Wk/Q6/lGq6j
P1fbH6ADuZ5BZJJs/wa9kcHcbb5JU7ReV+h4/uYl83zKWMD39lbysnWlnuQH
UmmwV6338jpvxe+up+P35h3zG3ofa9kUz6I/0o/N5jf1AWp4L55Hf+ZBXjHX
6kItZxG/mF/VHIYxlIfsDdd6bdGNOpn/+J9EnJHero9rR01itHUmRfEz6MRl
3GJvMI/F19OZy+nCEPvFOlev0K60WH+mzfqUlupUnc40VnHW3lA+sH5Bv+Mo
OWyx93HcCRawPd6B3sYwGs17tIxF7DAvjOeJ52aruU3L42zi3MjnGF9T5fNf
abX+pSN5znqpluoSPcRBas01cZd4lmfiHXGnz62Pu8c8nmYd4+Ldxl2NM6Ek
3jlj7a+Ju80cZrOaO+Ku6JUstp6l32i7HtAKZli/pjM1V/9kBNvM+/U85/gy
2GuP+8kX7DN/rn+wlzbzvrjX8Y5iz9yqv/NJfI/5U32ej9hj/lB/izNiN+/b
y9ZfyWIM3e11i3Ow3kmrdZM+Ge9dn4h3r1O0USv1ER5lEpN5OP724gzjfMmP
c4szoiLuIbcyKu4qeXEuNMQ7jO+Pc4mfp7lap826Qf/lH7LNWWRY51HIEHOR
3qwT9SfWscu8Xr/lft41p+sZVsdzmtfoESbwtjlNT7GKJnOVHuYeNpp76XFO
sIy6ePc6Ks48/hZITrr0f/Ei+Lea5w==
                    "]], LineBox[CompressedData["
1:eJwl0DtOAmEYhtEfRCo3IUSNsXAFYgdYkVihUSSIBWog6IK8y91CxcREY6zY
gbgGKHQJnAnFyTPvV0wys1xp7NZjIYQCt/EQPhZCuNEJK7TtA/3lkU/7QXN6
qFktaV77+qUDrfLCyH7WP175toda459NBm7v2mTJ8zFVLuxLznmj77ahW5xG
77PP9IQneva6JnWRBGV7R9e0q209okXHXtUp6ehm3+s+d9H32ind1j3NaFGv
uWLMT3z+32YlDCqb
                    "]], 
                    LineBox[{683, 958, 682, 844, 610, 843, 611, 845, 687, 960,
                     688, 614, 749, 556, 864, 621, 863, 622, 865, 557, 750, 
                    907, 849, 850, 846, 848, 847, 905, 748, 903, 904, 902, 
                    901, 769, 609, 842, 681, 730, 729, 683}]}}], {}}, {
                  InsetBox["\<\"\[Mu] = \"\>", {-1.8, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["0.2`", {-1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {InsetBox[
                   SubscriptBox["C", "J"], {1.4, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["\<\"=\"\>", {1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["4.29`", {1.7, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {
                  {PointSize[0.05], PointBox[{-0.2, 0}]}, 
                  {PointSize[0.0125], PointBox[{0.8, 0}]}}, 
                 {PointSize[0.007], PointBox[{0.4463998339305619, 0}], 
                  PointBox[{1.2771956561278897`, 0}], 
                  PointBox[{-1.0806611991222994`, 0}], 
                  PointBox[
                   NCache[{0.3, Rational[1, 2] 3^Rational[1, 2]}, {0.3, 
                    0.8660254037844386}]], 
                  PointBox[
                   NCache[{0.3, Rational[-1, 2] 3^Rational[1, 2]}, {
                    0.3, -0.8660254037844386}]]}},
                AspectRatio->1,
                Axes->{False, False},
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                Frame->{{True, True}, {True, True}},
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLines->{None, None},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None, "TransparentPolygonMesh" -> 
                  True, "AxesInFront" -> True},
                PlotRange->{{-2, 2}, {-2, 2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.02], 
                   Scaled[0.02]}, {
                   Scaled[0.02], 
                   Scaled[0.02]}},
                Ticks->{Automatic, Automatic}], 73->
               GraphicsBox[{{GraphicsComplexBox[CompressedData["
1:eJyFWnl4jFf7Vnu1o5qqZahSqqG28gW1PRi01g4/1VCd2IspUW3pKF8tNXbt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                   "], {{
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[0.3], EdgeForm[None], 
                    GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxNmnn811P2x9/3vlto3yRZpkTZihaUlFRI2Woy9q2iIqKETFEpa0OTQpqU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                    "]], PolygonBox[CompressedData["
1:eJwll3f811MYxT/3udkjKStFm0oqSWmnvUhSERpCAyUlIiUtSklLUyG7oeyd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                    "]]}]}, {}, {}, {}, {}}, 
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwl1FlQ1WUYwOEj2DLpRWVTUmYCQuBSaiopWgQlUZaKleYSLl3YjAmmLaZo
UlFBWgpEQiEh0OplU2gTiqUZ7q1WV9pmlnqZmuXzThcPv+/98Jw5/+98mDqv
tHhRj0QiUejHvUmJRI/kRGIV661bNEVTdZIO0HTSuNqcoZkMJIvrucb+IB1M
NkMZQj/7N+owbmAEw7nW/kgdxU1MNo/W/rpJa3QKSdbPsJpnqeA3+7U8Z12n
x/g9Pidt9l7XqWyg3Zyqx0nnHfMbej9v8m48h/5FJu+bm3U6b/FBPJ+e5EFe
NLfo8/oClZwyv6TjGE8us+zdoq26Q9u0hAutL+LiOB/znTpfL9Fe9I6zMs+M
9+BSLuN2eyOYZ12ql2sfrmC0eYE+pVfqVXRZf6nb9VEt14XxWhZRy2l7uXwc
Z6xHOMo4Ouzt1NVxznwa56+FjGeLuTvOIc6EzjiPeJ54braaD8S5UE0VRfzM
N9T5/df6mia4zXqFvqrL9RU9zPc0mzfG3eBpltHEPfEdxl2KZ+fJ+G6ZaL8x
7h5P8DgN3B13Iu4qS1kSd4W77NfH3Wat9WP6rR7S73QNZdYv62LN0/+4lU/M
X+m/nONgsHdIK9nPXvM+/Yc9HDDv1Yr4jmLPvFvPsiteY/5CV/E53ebP9Awr
4z7xkb2x+jdjmECKvb5xPtaPaI5+qJ3xuZlvXaYPa4fW6BzmMpsSHmJdnGGc
L0VxbnFGVMc95I74viggnyravV9evD7OJd4v/o7ZbJ2tF2hPkuNzM4Ys+wXM
IMc8U2/WaXqCJrriu9efeID3zBn6Jw1sNzfqj9zH2+Y0/SPuFtvM9foDxbSa
r9Nf+JV18Xce56b5lFuvjH+T/P//i+cBLLScdw==
                    "]], LineBox[CompressedData["
1:eJwl0DtOAmEYhtEfrNXKBdhq1BAbN4B2gq5ACBfjBRPQRt0PqIiAQIFCLCSG
xh0Ia5BCWs7E4uSZ9ysmmVnPXh2XYiGEFI/xED6XQnjQX7Zo2jmd0mBkP2tK
83qoBU1rR7+0qxe88W339Y93xvZAy8zZo+f2obeseT7jnDv7nhuGdNx2NUmF
gX2tl9E7eLUTuqorLHNqH+mOtrWpRV5o2ds6YzO62XXN8hR9r72hB5rRfT3R
GlUm/MT//9sCsXctFg==
                    "]], 
                    LineBox[{691, 966, 690, 852, 618, 851, 619, 853, 695, 968,
                     696, 622, 756, 564, 870, 630, 869, 631, 871, 565, 757, 
                    914, 857, 858, 854, 856, 855, 912, 755, 910, 911, 909, 
                    908, 777, 617, 850, 689, 737, 736, 691}]}}], {}}, {
                  InsetBox["\<\"\[Mu] = \"\>", {-1.8, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["0.2`", {-1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {InsetBox[
                   SubscriptBox["C", "J"], {1.4, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["\<\"=\"\>", {1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["4.28`", {1.7, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {
                  {PointSize[0.05], PointBox[{-0.2, 0}]}, 
                  {PointSize[0.0125], PointBox[{0.8, 0}]}}, 
                 {PointSize[0.007], PointBox[{0.4463998339305619, 0}], 
                  PointBox[{1.2771956561278897`, 0}], 
                  PointBox[{-1.0806611991222994`, 0}], 
                  PointBox[
                   NCache[{0.3, Rational[1, 2] 3^Rational[1, 2]}, {0.3, 
                    0.8660254037844386}]], 
                  PointBox[
                   NCache[{0.3, Rational[-1, 2] 3^Rational[1, 2]}, {
                    0.3, -0.8660254037844386}]]}},
                AspectRatio->1,
                Axes->{False, False},
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                Frame->{{True, True}, {True, True}},
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLines->{None, None},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None, "TransparentPolygonMesh" -> 
                  True, "AxesInFront" -> True},
                PlotRange->{{-2, 2}, {-2, 2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.02], 
                   Scaled[0.02]}, {
                   Scaled[0.02], 
                   Scaled[0.02]}},
                Ticks->{Automatic, Automatic}], 74->
               GraphicsBox[{{GraphicsComplexBox[CompressedData["
1:eJyNW3l4jFf7jjZV21hSlGlrX6aL5aOj5Es9jSGIpUPJp6kOYqk2JYpiUBQd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                   "], {{
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[0.3], EdgeForm[None], 
                    GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxNmnn811MWxj/3XpQoS5slya5BUZYSKQopFCNZIqSESspuaBSVNSSyk4Sx
pFRD0qLsjSX7Wpaxrxl7zHl7nt/r54/7Ovdz13PvPctzzve7ybFDDxqSq6pq
tEpVlaB9U1WtGuWpqB8TtE6UZ6LeIEoMqVaNcnS0rRbl6agfF7RulGej/kvS
GmtGeTDq06I8GfXfgv4a5QDmxWYtoq11lPqVxrPuep5HW/sYt0aUJVFfO8pq
UepEWcv78/18lNXhO0rTKGt4fmO314vSxJS+JbHehCg9o6zvfTjTVpW+N2Bu
8NYoyupRNvd81m5mPtaJslvMbxDlhahv6v3Z86UoDSudbRPX6dvQfDN/M49t
4v0auG9rfzN2S98FPG3h/flu6X542SP2XyfK0qj/zW0bRdnGtHmUPlH2i9Kd
veM8daK8EvVDo3RzX1vzxFnbew/Wa+Oz0bej++FlF98X/O7kNvjd2ZS+HXx+
5rfzWNYdkrRWF/iP0soy0MF8bxtlV+/Pdyf3bx9lZhKve0Xp7Db22dO0jdtq
7v7fSfx15V2iPidpbDfzxFkPjNLRvOzrs7XzvbQ3Lw/FvBlRXvM97mp+v422
E6MMirKPz8/86UlrHhBlb98RfY2i/S3z08tn4xw9vT/fb3vOwVF6myf4rbL2
+HuUQyrV6Tso6Q7Z74WoPx+lR9Trx/g1o3wY30eaF866fny/77WPiLK/+/q6
H15eizGPJe31StCXk/j9NOi8KO9E/cMox0Q5Kcp60bbcfJ0V9UOi9Iv6e1EO
j9I/yrGVZA55/MB15h/vMfByWswbEeWoqA9wG7wPNIXH47zGYVFO9hqsvSjm
DQ16bpSStS7fp3gP1vuveRkSZZjbWPuImHt4lEu4/6ALeNeovxn0jSgnRH2w
92H/z3zuM6OcbT7o/8df9vws5i2O8gV34vGMO8/97H9B9K8I+l2U8912apQV
0b4syrvs7zfijr6KMiLK6CgXcV9RTo8yzrywz3ivNTLK2ChnuO/jWOu/Sfxe
bl7hhXNzZ5dGucz3R98Yr838KzyWdSd5XfZcI4uXCfAW63wZpU+UP6L8jpxF
ucb8XhjlOq/L/Ilu4xzXmo5x2wifbXTMHxXl4qhP9TjWuNlngK87vD/73OQz
0HeL+7mP26NcFeXqKLe67coot5nSd+Nf7mCyx7Lu926/Icpd3p87uNNngKcp
3p/vH7zW3VHuNa/wco/b4fFfpvTd5374ut8Uvh4whfcHzRNnnW7KnrO8LuvN
NmXPn6L8aH5/9piZUWZ4Hrw/ZMq9/tvz4GWu92OfR8wTvMwxnRbl2XiT37z/
w57HuMc8j31+jfKL93nU81h3mv0//hgsAFbALy80H6z3uCn7LzJl/1Yxtkoa
2zpoShr7e5SV3n875C/ogiiLPY/9L0q6o/lRto96Tlq7jjELeGIV4x1w0KrG
NcVrzTZ/O4BtktYG7zxXCYf8pxLGAXOsZqwEnrkj6pcn3StrgTfAJ/h5fOJW
3hv/38Brre3vGuwCVuCOmvr7xUq4p6H3ox+MAaZhLhhpgnHTOt5vPc8H0zRz
ewPzsb7329DfrIv/bGF+1/d8MBF4B2zxciWss7H5beb5nAcfuLPP38BrwDf4
YTPzsYW/WXdLf9dgF3z/Utebe92Wvq9m7m9pvrbyfM6/qfkG44AvW3kP8EZb
94ETtvfYNv5ubL429Znpb22edvL8Gnyzk8e29XzkGh2dbP7a+fzwCE4AQ7xa
CS+AbWYag7Tx+Tp43MFJvnx37w8u6FTpDGCDjuapk79fT/LTy6taDMQcsEh3
rwu/4ATwBFioi88CBtvLZ4DXfT0OPpi7n8/RzX3t3dbN52c9MAyYCKyDfwJ7
vF7JL88xXujsOfj63uaddjDG0iRM9qb3BjuANzon4SRwEIp4sPfbw/MONE+9
Paej28Aw8AFmwFeCg/r85Tx9zAfjjvS4V5PwzTKv0dd94J2+3m+esdDR3HES
fgK/tPS9tPPa4ALwwbuucw+9jYUGVcIp+P+TqlpMA/4A7wz03vANVulv/gb4
m3UHez54ZJjng3OGeDzjwBXgDzDMp5V86EeeC0/gmY8rYYyFxjkjvM8wzz/U
+8HvJtH/dSUcAN/gC7DE55VwBOuCU76shDdOdjvjwD5gsnO8NtjhPPMHvjjX
+53nb7DO+eYNTATWGRXlm0p46wyfB5xwoXka4+8RbhvtcWPdB94ZZ34eTzrz
Jz7DOI/7JAkbfRv1i4PeneRD8DX32N/AI1gCXAGmGe/z1mCXiT7feI/73Tjo
SvMENgBLgI/A4+ANsDn4CZyBr8ZPTvU5JnpODUa5tRIGAT/cYL7BIDV46jrz
AXa5yePGe94t5vtm913hNr7BVpN8F/B0+1/2w5/fZ17ACVOqWuxyj/mj7Q7v
PdXj9ok1t0jCQfB1l/v+5/ok3wXzJptX1gMvXe22Gj4eMB+3mJcaPHWv+WDc
NI+DF3DHdK/xoPtqMBPfayX5leZVLQZizrpZvqyF18bPz/Y8MMXcqhZjzTIv
D3sce4Av5pjXR9xXg5ke8fmYN9N8zPWcy40jHvXa4Iz5UfaP9m2MsX4xDzO8
30KPY23mLqpqMdPCqhYz8b1frLF1EgackoRFwEm7gr+SMMRlSXgITAP2AM+A
Hy5NwljgJDAG2AY8gk8H24BZGmThpeLytPsvsf6AzxgHvmLti61b6BQYg/3x
222S8BP7rBNr1svCLmsm4Y11o+we9fpJ7wROeMHv2DYJD7EeuBScN6+Sb+Wt
t/X9rfS9r5vkj2l/JOoPJ8XkdWPPAUm5keuCXutxTZNiMGxzw6QcAH7m5KRv
+jawT8BmzrJPwx9jS2nHV52atBYxcWP7txrfRh1/2sz9/T2HOB0f96h9VC9/
4/PxlU2S/A2+5twkPojLm2TZT2zPeUnrEvtubIrP2DDJN+AXvmNf+wZsMfYC
W7JXtG2UZH9b2HZiazfyPvgE7C392NTvuQf7A+zz1+7vkjQfnpon+Y/B7v/G
Y/6XZPex+ZvaHp/t9o+SYuQdk3AnmPOpqD+ZFJ89nWRfsC3YGOwpNmfnaP9b
kg5taZuEndkp6lsljWtp/UA3906KnVgDnf3Z47FRzMX2YjNYD31E/9Ab9K1H
UhyCrKHrv3nNbkmxEPPQW2KT+ZXmoFs1eotO0M83ekPbZj4f+16VFJ9kyzV5
P2QY3apr3UUnyEmiF+hoHesfOr16kl53SNIrdAr9q5dq9W4Nt6PHxDDoMvpW
3/qKrhMXoeudknQJHsgrrp30Lh2T7Cw8oBvoCPpyYxK2Q/ZviHJ9qsV5UOT/
U/ejF69bvpHtm4IOtv6gE+Sb0AN0CzyGriDXyDm6c1vQf1h237WsI+e3Bh1u
fbglCc/V6Az0GMsy85Dtzy2LyCH5HPQH3fnK+jDCcoG/440+snwj212T3o92
ZHPzJLkCl4Gr0I+fLIvI4a+W118sd9htZK97kozOtNwhz8jYv5LwSY2dbWWZ
Ab/clWrt7HaWK+RxG6+zb5I+sP59Qe9NsvXIQhvLwwNB70+1vmF7yzm8ojsP
WX5bW4aRkbaWE2RhR8vD+KSYebFlf9sk+UdXdkmyy/wucKBle2JS3h/7j13H
VyGnyBT57hrZ72TZwx7gG16y7He07CHLHSzPyDv5evSjseXwbb/J3n4X7BD2
jvfHDmGzvvJZu/m8G1hmkDvuD6zzg99qX98nstDV735YEg78ZyX/1i7Jj/KG
PfyOnJt8CM+Ff6VOrH980F5JOrvE9bqVaE+3E3dTJ5Y/0nfIOsgLvh85+k+S
XyO2/CkpHiG3+fekmHN3j6G+nWWku+XkB88jxjo0KZ4hlvnC9aNd/9zr4rvQ
UXwl2JWzgyvJDXIXF1Sy2eQcL7VNOt5n+Sbo1+6jTk72HNuwY5NzNEGPSrX2
qV+SnQPHkiu8vpIt7J9k8+AFu4EdGhj0hCT/fpDvpJXbB/js+HziZ2Jn8von
JeXSiSEHuQ490XXmDfSaNXE1MfXZSXnwflEfGvSUpHib/PYZSfnkYUl9XWy3
hvv+iAdP85ij/E1sOND1E7zPUK95uscf5b2GeE32P8dvfYj5oc67nem3w85h
J7F/F/seiQWwc+cn2VTeYaTfAj87yvd8oe+cef/0+yLnY5IwGDoO5Rs8dkUS
3n2iEuV7se3BOI+f6z7w8DjPne81x3qdKz2Xda5JynPVtR7hI7N15Gq3v+p3
7WAexntf5jF/ideZ6HpPr4lOzfYZ8Ocrk37vYS3qYMTdKtkS/Bk+DJtxe5Jv
4BsfB7YE++HDkEfwGH6IN8eW3Jzkw8Bv+CRsDHYIH7aR73Vyku5M8r6cCbsJ
np9rOuUvd3uH61PdvtK2dqrrxN7gO3SQ/js9Hl+B78BOE2vjq/BT4Hn8DT4G
e4+/wOdgT35OsgnoFPYCezLd9Y6WvZ88hnzRj0n9YDqwHXhvgccgnwu9Jm1r
ZeWIs98XP3GA72Cl3+JXtzPmW7fvZtv1o/lhHWIVcs3YdvYFTxKn/2G5Jc+T
s3I9q2TlVshVfOAxxP3kWGgHY5CzYtO9bed+9zoNs+JJ8o91/XsrdmaR12VN
6KrO3bDeKq6TM6GdscxhDXJ+73t9bOoBPjM+gsKZyO+SfyCHMrKSHWUN3hl/
Q84d30KsQx6wq887P+m3vLfc19Vj+c0+ea9prhMnggnAAa/5LcF1P/qteVNi
xvssI4wDP2SPo5/c289+6wW+b/gA742wHJzmMQstM3OT4p+DKlG+l1XKMfJN
TES+650keSWO4R5O9fg5npuy3ou4CX/FO/fzuYkDu1j2Hve+n/gbvrizhz2G
O4Nn7Cf8J8vMnuapc6UcKXPwCfQl71t5POcdEiB6WJENPSXozUV29fSgpxXF
ykODnpVla8+M+hlFuvhetC3LwhMjo23DIv//XLS9XuTD2fdz83mI6/189i/c
jtySk8JH93Y7YwfHGicX/T6JLwD78jvmach2UWx2Ivxk2f7RUV+eZW/Pjfo5
RfJyXtBLs2x2G+LrIuw7KuiFRTb69mjfrShO6Mj4otj6kqDtinT5zBhzUpHO
ns2dFMna2KCfZY25mDvMspFjoj6uyE7sGG0nFOH4xT4Luvahz45dhX7lOlif
vOFZpuQG8XGcmTr9462T6CO24QPr/jjPYTy/v2PjsG/QD70+Y7/3eGR1heV1
mevDK70H48mHfef5zP3Yc2p+I37P47/0uiOr2rWo47vBUmAqbCX2cZDnfee5
J7qdOzzM94BcYD+wI+dYd7Ll9muvSTtYmpgNG8Key1MtL++bh+XmZ7jv7xPf
zzzPZc3DvRf2aljsc1yRvPFbySzr1mzXwTzgcnIc3C25osb+r04j18H8rHFK
1jr13I9PJwZo5DGs0dTr1Mwnt/RkzL02K6ZZzfa8RaWcbVPnbSlN/Ps3Nr6h
bX6DmLtWUez4VNAbHBujNw2tOwODts2KORZF/fysWBDdXZKlv69G/fGseOK1
qD+VFWecG/TtrJhybNDhRdjojaAvZeGpxVEflRVT3hj1m4owRD90K8u2rRH1
NYti1jlZOoasjQl6UVZ81jj6GxXJ0RPoa1aMuK7PS3xH3LWu6w/ix7Ls8G1B
j8yK4+9Hf7Pk9/hYZ0RW7qd11PfPwuoDgvYswqbHR/3AIqy8StCBWXF/E+xi
Fj6ZnSUrvO8g7GsR3iU5cXSWT7s76DFZ8omfBAOQu4CCCXAJT/mbOn51LeME
5Kie5QQ95L0nWC+RA9qaWgboOyzKrkUxA/31LVezgp6apRdLLIvreO6aHoN8
kEMhjiBuJRezxHK1tu/2z3nmB3vA+vDSzLKL3KIf6An5xwuK7Cw29r6gV2TF
W/x+9KZtCL8fvm6/QNtbSW/0lscQa+CT8a/4ZX7HecNzT3CduAS/x295+Fni
A+IEcnHPuI5fI+4jZ8d/bMA4i22HX0z67ZB4Cso3MvO954BRl5tXfChne8k2
AQzCf7N295rgKOxWW9uONr6TmbYbYJUZHv9EEg/YsXd8RvAnsRa//x3lfZb6
XPjT13xXvTymp+krHr+sUr2X6atufy4pNz3Ptu5J3wP7wwcy3Dd436soVkxB
c9E9dA3azzL8IH4sKy+yatRXK8pvTUbPsu5mOn4vKxdyXNA3svh6INonZMnX
6UEHFcV1C4M+m5WTWBD1J7JyHvOjviArR9Ih6odn4b6Hor5FVt6lfdR3KfIh
faJtx6IYm99D+f2V3B15BfILxAfP+61pv8h3QmyFjCAr2LQenkvMfX+st3FW
7mSA1yFOJ74jJ0KsNjPG3JiVE2IMmLuVdaeudQpbVcd6NMFzwSrsz9uQGzsg
1umfFU+/mGVPsaWfRP162/Dto22HovzCymjbueh8exRhlz9/Ewg6N8vOt8i6
d+78wKzzcJbmWTqJPl4e9XuLcrs7Bd0664xHZN07d44dTZaHd7Azfpel0fZ0
Vr7npagvyspLdYp656Lcx97R9m5W/Pd80FuL4r2lUb+nKDd3d9ANivJ82OmH
bKs3y5InZGk8NqQoj3tNtE8ryqt9Dr9ZOsI94fO4qxVRb5+l+1vhE7LyxeC1
S4zrvoOvLF34JujMLJzQK0vWkfPNg25W9F/jq4r8Ab5gQtBriuLne7D3WXlh
5PQWyyp292HbXvD1CvNzVZY/w5e1y+IDHuBlL9f7R//0LPxbJ+qts/LIM7J4
hc99g04uysN+lYVxwbfdgk4pipM3Dtq86P/UbYrennevz91n5YvvyLpH7rAl
MlD0n+uCDGblwfcJeltRfL4N7UV5sfWx/ZafXkV3wT1sgq0oypcRH3TPihF6
BG1W5PeQO+YzFztxl23FiCIdQP47BT2/KAb8IOrvZ+VnX86SIeSnY9Cfs+wb
ccD4LP16E9nOst+dgx5q2cZWTbG92i/o1KJYEdnv7DGziuQGmZkR9c2zcsDI
3SZZsvdi1Odl5dnXLsL64PxWUd+u6D/pZ0fbY1n+ZEvWLMobLszCWOCrE7Pw
EFgI7HBnFn4AO2B/sb28/+FFMtA9aI+inF0X7jgrn8db7VP0Xrtl2Vbsat+g
RxblftBdbCv6u17W/XK39bAHRXnWY7PsO7b90KC9i/JDfYIeVpSzuz7oDUX5
poOxu1l5x0nwU5S/A+s9kIX3BmfhP+odsmw9dn54FiYDj/0U9R+zfn9mjaO9
DnJ6bJGsDs3CuODbJ7Ow6Z+/MUd9d8vAyCxcC6bdL2i3ohzYL9G+R1auacss
243dHp2FWcGre0b9sqLc2aSst+fdb8qSCeTh4Cw/hA+amIXXwerPZNlE7CFy
8b1lY36WrFBfnGUrsZN/RP33rFz4/wEtoc5E
                    "]], PolygonBox[CompressedData["
1:eJwllwf4l1Mcxe+IMqJQMtvRMkKKFE0ls1REWxQpSpOWtEtbGrLalN1WhHaZ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                    "]]}]}, {}, {}, {}, {}}, 
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwl1FmUj2UcwPH/mEMXSk4KGYwZjSzJkiXLMHOiSdZosXfO5EIuDKnsDGYq
RNEiZd9SKlK4yT6NGdlm7OeQtcKlpazl8ztdfOb7/J45Z/7v+7zvf9Jy8/qO
TEokEjl+dK+QSNxhWnIiMVe/08e1jvbQ2ppKXWqZ0zSdejxBfVLsN9AnyaAR
Daltv4k+RWOepil17DfXFjSjp7llfIZ+rx9pL+4y3TyDQgo4Z+9j3rOepxc4
Tz3W2/tU+/AZG8xp+gf12Wj+QvuykJ/iHvSvuH42mRfpKyxmc9yTXuZVZpmX
6Ps6kw+4Yp6tz9KOtgyw116Xaaku18EkWVcgOc7EnKO5WlEr8UCch3mgjtDK
+iAPxVmZczVPq+jDVKWVebi+o49oNbZaH9JfNE/H60gdzai4B67Za8d260l6
itNx3eywt1Mnk0+Reap2oQM7zcXxzlDAr/GMtCsd2WX+TQvjrOJZ8Ty/x3Wx
1O8P6jK9rZ2ZYv1hfKbO1iMc5lvzN/HuxXUykbW86Hdfx7vKhLhH1tDN/mqt
yTjGsooX7K/UGrwb58UKcuwv1+rMsn5by/SklutM3opnrWO0k94ik93mA3qT
f9jHCXv7471lb9yDuVT/Zg/HzSVxv3FulJuL9EacG8fMu3ViPAfKzNv1OhPY
FuJ906u05Tkes/do3Jv1m9pat+oWHc0b8ex1mG6M91+H8jqDGMJgFtA9vvtx
ZnHOcabxXSOLbDLpHGcRzyzOMZ57/J14P3RgPGO2WDfS//iXe7SJa6OhdTav
8Yy5v7bSl/USX1Ji/irOjH78bM7QP/k8zjOuN86Ml/jRnK4XmU+x+RM9Sm9+
MKfqGc4yh3XxrmgWU63zSUn+///ifalRoLw=
                    "]], LineBox[CompressedData["
1:eJwl0DlOQmEYhtFfbJDOJdhqNFQuAIfOIRZ2yOBQOCY2ugmH2qESRAqwQA2i
K5AQG0l0DVjADjh/KJ6c781Nbm7uVPFk43gshLCpciKEr/EQSuxpVi17m396
UtuucJU7XOEu11hjh3Ue6EU/doN9verbfuOp3tW1m9znGSd5p3u17A+dx/fZ
RzrUvD3QjftWhfjMzsfnfNanO80UJ5TUnr3OufheVlnQkjvPZV7rSv/2JTO8
YFDO/Ri/2z3DRW4xwywXOM0mH/ibGP3TIcCnLu4=
                    "]], 
                    LineBox[{684, 972, 683, 851, 616, 850, 617, 852, 688, 974,
                     689, 622, 750, 562, 870, 627, 869, 628, 871, 563, 751, 
                    920, 856, 857, 853, 855, 854, 918, 749, 916, 917, 915, 
                    914, 772, 615, 849, 682, 731, 730, 684}]}}], {}}, {
                  InsetBox["\<\"\[Mu] = \"\>", {-1.8, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["0.2`", {-1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {InsetBox[
                   SubscriptBox["C", "J"], {1.4, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["\<\"=\"\>", {1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["4.27`", {1.7, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {
                  {PointSize[0.05], PointBox[{-0.2, 0}]}, 
                  {PointSize[0.0125], PointBox[{0.8, 0}]}}, 
                 {PointSize[0.007], PointBox[{0.4463998339305619, 0}], 
                  PointBox[{1.2771956561278897`, 0}], 
                  PointBox[{-1.0806611991222994`, 0}], 
                  PointBox[
                   NCache[{0.3, Rational[1, 2] 3^Rational[1, 2]}, {0.3, 
                    0.8660254037844386}]], 
                  PointBox[
                   NCache[{0.3, Rational[-1, 2] 3^Rational[1, 2]}, {
                    0.3, -0.8660254037844386}]]}},
                AspectRatio->1,
                Axes->{False, False},
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                Frame->{{True, True}, {True, True}},
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLines->{None, None},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None, "TransparentPolygonMesh" -> 
                  True, "AxesInFront" -> True},
                PlotRange->{{-2, 2}, {-2, 2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.02], 
                   Scaled[0.02]}, {
                   Scaled[0.02], 
                   Scaled[0.02]}},
                Ticks->{Automatic, Automatic}], 75->
               GraphicsBox[{{GraphicsComplexBox[CompressedData["
1:eJyFWntUlNX6JlMidI5Uajp50LwUmpSiWJn5kqOliDpappm/KS2QHEszTzrm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                   "], {{
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[0.3], EdgeForm[None], 
                    GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxNm3f819MXx9/3vhtSIZmJsiOVBhpGAyGrRImopCFJsncJZWUns7JFKaI0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                    "]], PolygonBox[CompressedData["
1:eJwtlwfUz1Ucxu+QtFRK20okI9mEVFZSFBWS8JJZNMiIeMlIEiFJhES7o4zS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                    "]]}]}, {}, {}, {}, {}}, 
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwl1FlQlWUYwPGD6IWajalp5YJCbpWhJYQYWUKGZu7bjHEhN6AGZBtpSGa7
lpKWuGeLLVamzjSjIBFImQLaelOaLW6XleXe1O+ZLn783+c9B4bv/b5z+hWW
TSlNSiQSY/zIa5NIXGBRciLxkr6rXbWn3q3X6Rjtpd20j6bQm3705Wr7aXo9
qQygP93tD9LBDORGbqCH/SF6Mzdxjzldr9H39GXN5yJPmCuoZDHH7K3gSeuV
+gs/x//JNnurdByr+cDcU3+jNx+Z1+h4qtlu7qMn6MsO83qdyAZ2xjXqKSbx
tHmjLtGlPMVp8zOaQSbDmWrvNt2sTfq6zuBfEuakOCPrXC3QZG1Luzgr8zQt
0vbagY5xdubZWqJXaCeujDM0z9GHtbNeRa11s9ZosZZrkc5jLtX8Ye9WaqwX
6Q/8yHBq7dXH2VNJfZy93kEGe81NcQ9YymdxFjqKTOrMB+K8eDbOhzs5wiHW
er1V1+l5HUG59TJ9TF/Ub/iarea349ngUR7hLXK99mY8S3HtPMQbjLa/JZ49
FvBgnD932d8czypllMa9ZBMb4r7H880L3leih/U7/UqfZ771c/qAZum5uMd8
am7Rs/zNQb611xzPCV/GNZv36198Htdm/kIr2EeruVHPxFnGdZsbdGH8fVrM
dfonj8f5s8feLfo7w8ihq70ucUbWhZquu/UTLeP+uG4t0B06S4t1us5kBlXx
eSSfvPjsx/dA3BNuJ4fseL/fG6lb4v7pdM3SabqJXdZp+g+XuRTPW/zPpMbv
Mpmh5ilxDTpBT8bzEediXqffcx8fm1P0OK/SaH4t7hH38qG5l/5KFQ3mV+Je
MJb3zdfqUX5iOe/EeWl2nKv1wnhP8v/fif8BVmmcug==
                    "]], LineBox[CompressedData["
1:eJwl0Lsuw2Ecx+G3lVQ31yDRaEwuQBSbw9RBtBo9IUGiFu7AYUd3xw50aFVx
ARWx1KTXwMAdiKfp8Mnz+y5v8v+Plirp3UgIYVlX0RA6QyFc8kvjerTX2NOt
Xu0bLjDPeRa4yDu+8Z5baqprN/ijB73bLe7pSR92m2Xuc4TnqurZftGB1u1N
bWjS/tWp+0xZ7dgZbrPef9s9wTiHFVPRXmKSbdaY06x7lXM80bG+7SNO8ZB/
zOpaLTvBGWY4zRWmONb/Tl7wMzr4p/8ahC6N
                    "]], 
                    LineBox[{682, 967, 681, 847, 611, 846, 612, 848, 686, 969,
                     687, 620, 748, 556, 863, 625, 862, 626, 864, 557, 749, 
                    913, 914, 851, 614, 849, 613, 850, 911, 910, 747, 908, 
                    909, 907, 906, 770, 610, 845, 680, 729, 728, 
                    682}]}}], {}}, {
                  InsetBox["\<\"\[Mu] = \"\>", {-1.8, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["0.2`", {-1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {InsetBox[
                   SubscriptBox["C", "J"], {1.4, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["\<\"=\"\>", {1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["4.26`", {1.7, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {
                  {PointSize[0.05], PointBox[{-0.2, 0}]}, 
                  {PointSize[0.0125], PointBox[{0.8, 0}]}}, 
                 {PointSize[0.007], PointBox[{0.4463998339305619, 0}], 
                  PointBox[{1.2771956561278897`, 0}], 
                  PointBox[{-1.0806611991222994`, 0}], 
                  PointBox[
                   NCache[{0.3, Rational[1, 2] 3^Rational[1, 2]}, {0.3, 
                    0.8660254037844386}]], 
                  PointBox[
                   NCache[{0.3, Rational[-1, 2] 3^Rational[1, 2]}, {
                    0.3, -0.8660254037844386}]]}},
                AspectRatio->1,
                Axes->{False, False},
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                Frame->{{True, True}, {True, True}},
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLines->{None, None},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None, "TransparentPolygonMesh" -> 
                  True, "AxesInFront" -> True},
                PlotRange->{{-2, 2}, {-2, 2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.02], 
                   Scaled[0.02]}, {
                   Scaled[0.02], 
                   Scaled[0.02]}},
                Ticks->{Automatic, Automatic}], 76->
               GraphicsBox[{{GraphicsComplexBox[CompressedData["
1:eJyFW3lY1NX6p8T7GDqpZKmjt0yRJldcpoWbvipmSmYTuZDRuKLWVPoji+gq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                   "], {{
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[0.3], EdgeForm[None], 
                    GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxNmnnYltMWxp+9n5LIWCGJZB6KEmWIVFJ0SiRCSVERmTKGSqaMKSGhZKZU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                    "]], PolygonBox[CompressedData["
1:eJwll3f8UFMYxu95DymRMkuUHxkZhSRCewgpK6ulEg0ts0Ha0RAVTaWyVSgK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                    "]]}]}, {}, {}, {}, {}}, 
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwl1Gt0z3UcwPF/1vWk0oa2TC6lsaylJoVmyKLUxiLniAdRqLbVFMutZBRD
brWtcumeW4cHW+XaUCxmQz2pFF0fdkPFOfL6HA9e3r/Pl/39ft/fd/9Oj5QO
L7kgkUjk+yMlKZH4p0Ui8awu1Hf0Km2j/bW1DtC22kpTNY1raMe1XG29vV5H
Oh3pQLL1zno9nejCDaRYz9CBeqPerV21tb6ri3QQ/zLFPJXnKOd7a4uZ5voV
PcYPcX+8b22Z3sNyPoj71B9JY635NR1CFevi/vVn0tlgfl2H8gYbze31V+5n
lvlNna4zmcFv5uf1ZrLJotDaLbpKc7RIb9MH4/nY7Lqz5upoPcv/JGKPtEAf
1Qv1Ii4mwzxSn9BL9FIuI9Ncq7X6NA+7LtMxulXH6xQdp4/F58Ye8Ye1bD6J
vdVv+Dbum0+t7Yw9Zibb41m1Nz3YYt4T+8Fsdphf0D7cylZzg77IXCroy3cc
jHfj7xt1hZ7Snkx2vUDLdL4e5hBvmdfEGePleEZdHXtLP/PKOJc8RWm8H3Lj
/cU5poTieK/cZb1Gr+TJ2EuqqI5zwatcwUv+3ePapM3arPOY4HoSE8kxn4z3
yjbzAZ3DCb6kydr+OBvsizXzXv2bz2MfzF/EWWI3DeZd+hef0Wiu1/LY3/gM
83b9k6nxf/JxnDv9nSzupKW1y5nseqzepHVap8U8FM+uo3STFsW50EIdzjAq
43c+fj9jj+N7gDwq6MUd9GSEn7s93ke89/j5OB/xGfFe+Ci+B/QMp/mP7nFP
8V3huhcP0M1coJl6n/5CNfXmGv2ae1lvbqc/xdmJfYp3pl8xmA/NqXqcJew0
L9Uj5POeuY0eJY9K3o7zEM/BM66Tk85/J54Da4uZ4Q==
                    "]], LineBox[CompressedData["
1:eJwl0DlOQmEYhtH/XjpXIZFQuQAnOpTeKCpREBq0wUZ7hx50B4hRCyUOkDiU
GGKhtW5BClyBBYdYPDnfW/zJzU1W9pZrUQghr1YcQi8Rwjl/NKVHe5PfutKb
fclFbjHLIpd4wz5vWR2/1Yf9wKE6ere7rOlZn/YTS9znBE91phf7VQfatisq
a9r+Vd3d0Kp27RXusK2uO80EY0Uq2Tmmxt/Caxa04N5ghic61sA+4gwP+cd1
XejeTnKea5xlnnOc5B2b/Ir//+kIjvEtpg==
                    "]], 
                    LineBox[{682, 964, 681, 842, 609, 841, 610, 843, 686, 966,
                     687, 618, 747, 552, 858, 623, 857, 624, 859, 553, 748, 
                    908, 909, 846, 612, 844, 611, 845, 906, 905, 746, 903, 
                    904, 902, 901, 765, 608, 840, 680, 729, 728, 
                    682}]}}], {}}, {
                  InsetBox["\<\"\[Mu] = \"\>", {-1.8, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["0.2`", {-1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {InsetBox[
                   SubscriptBox["C", "J"], {1.4, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["\<\"=\"\>", {1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["4.25`", {1.7, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {
                  {PointSize[0.05], PointBox[{-0.2, 0}]}, 
                  {PointSize[0.0125], PointBox[{0.8, 0}]}}, 
                 {PointSize[0.007], PointBox[{0.4463998339305619, 0}], 
                  PointBox[{1.2771956561278897`, 0}], 
                  PointBox[{-1.0806611991222994`, 0}], 
                  PointBox[
                   NCache[{0.3, Rational[1, 2] 3^Rational[1, 2]}, {0.3, 
                    0.8660254037844386}]], 
                  PointBox[
                   NCache[{0.3, Rational[-1, 2] 3^Rational[1, 2]}, {
                    0.3, -0.8660254037844386}]]}},
                AspectRatio->1,
                Axes->{False, False},
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                Frame->{{True, True}, {True, True}},
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLines->{None, None},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None, "TransparentPolygonMesh" -> 
                  True, "AxesInFront" -> True},
                PlotRange->{{-2, 2}, {-2, 2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.02], 
                   Scaled[0.02]}, {
                   Scaled[0.02], 
                   Scaled[0.02]}},
                Ticks->{Automatic, Automatic}], 77->
               GraphicsBox[{{GraphicsComplexBox[CompressedData["
1:eJyFW3t4jNf2DqJVDGmKtkNd0tBxC1VDaVh03KrESLWUdtCi1SiOujSpW4NB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                   "], {{
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[0.3], EdgeForm[None], 
                    GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxNmnn8VtMWxs/eR2kyU5mTKUJUUteUkCQ00EVRihIaDKGMSUSKZMhVISoZ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                    "]], PolygonBox[CompressedData["
1:eJwtlwn010MUxb/zJmuLLFGotJAoS2lTpJJkSwtZ2kMSlXYpLZRKSosSSlni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                    "]]}]}, {}, {}, {}, {}}, 
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwl1HmQj3UcwPFfu824rdASkbOQs0OWkitnjt3sTDQjYxzp2N0Oi7XCkpty
lLuW3Jppmtw2ct/SgX+UDuRP95l4fcYfL+/f5+u3M7/n+32ep+aA7IyshxKJ
RCf/VE5OJG4lJRLDdbou1dJaRdvoY9pWq2oZrabVeZwaPEFZ67W0NjWpSx1S
rD+l9XiSBtSnnPWG2k6f1vbaSB/RZTpDO3CbEeaRjCKPM9Zmku/zpzpaX9E/
qcBy82ztxBxWmCvq36SyyvyFdmEeq82V9GxcK2vNC/VVzrOI7dYWa3fu8B/P
x57wb+wJ3/jOl5rBBb6K71h7TZ/T3vFb+Db2TV/WNzRJk3k49s+crgO1mBan
ROyn+XV9W0tqqTij2Ffz97pRc+jn8/v6phbpRYYx2DxcB2mupsX+M8T8VpxH
7D07re3TH/UKebG/bLGWry1pzEbzPv2YcWw1j9VWNGGT+bAW8AkT+J3TzPZ/
x/Uz/Uln6U19Jn6rz1P1I52iv/Fr7GXsLalMNn+oS+JMaB1npI/yQVx/nB8v
WV8QZ08O2cznxTh3rUAW7/F53BPMZQ7lmeR77+rPekx/0YkM9fmdOAuamW/Q
lM3mYzqe6xzhqLWjOoZDHDAf1Gvsj++YD+go9saaeY9eZReHzbt1JDviO+bt
ejmeC35gg7VGeimeJVqQEs9k7IfP/eOZ0/W6Ka6JPnEN2le/00wdFPdu3Kdx
z8b+x3NJh3gPxLMa7wEKaEEazcn0dy9ooT6r6XGW2kuXsC7eFXqP/7lLM2tN
qRLPBj3ivjL3jPtHu+k55sc1mhfoKbqyxlxZ/2EuRXF+epLOrIx7Qf+Ke4xt
5ll6go58Heerf8QzyDQK45mK309uvA+SH7wX7wN7L5pK
                    "]], LineBox[CompressedData["
1:eJwl0L0uQ3Ecx+G/Sru5BdLG1Asg8bZ56Wo4RapJW8GCgdnLTl0DFQwq7UGi
7UCkS11BewkM3IKnMXzy/L5nOCc56fLB6v5ICCFSLRHC22gI1/xSWg27wIHu
9G7fcombXGSRy3zgB+vc1pN6dswfPatrv3BPLX3aryzxkGOs6lJtu6Mjle0t
VZS1f3XuvlBeu3bEHT4qdk9yWil3UjmtKONZk/fc0Lx7nQs806m+7RNO8ZhB
a+6b4fvdE5wbfpszjDjLcdZ5xX7i/5/+AWOkLMY=
                    "]], 
                    LineBox[{683, 961, 682, 844, 608, 843, 609, 845, 687, 963,
                     688, 617, 748, 550, 860, 622, 859, 623, 861, 551, 749, 
                    906, 907, 848, 611, 846, 610, 847, 904, 903, 747, 901, 
                    902, 900, 899, 769, 607, 842, 681, 731, 730, 
                    683}]}}], {}}, {
                  InsetBox["\<\"\[Mu] = \"\>", {-1.8, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["0.2`", {-1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {InsetBox[
                   SubscriptBox["C", "J"], {1.4, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["\<\"=\"\>", {1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["4.24`", {1.7, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {
                  {PointSize[0.05], PointBox[{-0.2, 0}]}, 
                  {PointSize[0.0125], PointBox[{0.8, 0}]}}, 
                 {PointSize[0.007], PointBox[{0.4463998339305619, 0}], 
                  PointBox[{1.2771956561278897`, 0}], 
                  PointBox[{-1.0806611991222994`, 0}], 
                  PointBox[
                   NCache[{0.3, Rational[1, 2] 3^Rational[1, 2]}, {0.3, 
                    0.8660254037844386}]], 
                  PointBox[
                   NCache[{0.3, Rational[-1, 2] 3^Rational[1, 2]}, {
                    0.3, -0.8660254037844386}]]}},
                AspectRatio->1,
                Axes->{False, False},
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                Frame->{{True, True}, {True, True}},
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLines->{None, None},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None, "TransparentPolygonMesh" -> 
                  True, "AxesInFront" -> True},
                PlotRange->{{-2, 2}, {-2, 2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.02], 
                   Scaled[0.02]}, {
                   Scaled[0.02], 
                   Scaled[0.02]}},
                Ticks->{Automatic, Automatic}], 78->
               GraphicsBox[{{GraphicsComplexBox[CompressedData["
1:eJyFWn1clFXaxo+XWHTUWNMcDT8WdfJVcSnMSL0t1MUvQmprM3cMTTNHwzTX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                   "], {{
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[0.3], EdgeForm[None], 
                    GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxNmnncV9MWxs/eR1KhCWVOZnUNZchwVcZKiULmUilDiGQopIiMtyRTpNIk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                    "]], PolygonBox[CompressedData["
1:eJwll3nYV1MUhe85J6mQIaUkDRpEoZRKg0gSzSQpzWlSKanQ8KU0aVKkWZPI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                    "]]}]}, {}, {}, {}, {}}, 
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwl1Gt0z3UcwPG/TeQcdQ4tmVK2hlgYaylbax1qGSWKsi2jc9iTMl2Upa2y
IdNtSrlEyC0tl+IcD0y1USsxq6WLdPGEii4eFun1OT147f39fLezs//3+/st
7YGKCTM7JBKJQl/SkxOJZJ7mGZYlJRLLGcPV5rGaoSnaT/vTlwFcw6X2M/Va
BjKYQfSwn6VDGUI2w7jMfo7eodfpnXq99tQtukLH0dH6WfKt5+mvupIa6ze0
Vu/S3+hFg/lNncAa3jVfrqfpzTbzW3oP69luvlL/II33zRv1Xv5kEy32Nut9
XGDdiYI4F/6iL7vsbdH7OcM75Nubojdpme5gd5yXFmq5dtWLuJhM82Sdpd20
O5fEOZrL9AlNibOOcyXLvEebtIrp1tU6Q1v07zgzHjLX6oNao6PizJlprqBX
nBGf22vVA3qOhdSxz94ivZXhfGhu08W8yH7zC3obN/CR+Yi+xBLqOcmJuDvf
OxrPln6nKzSJPOuntIq5vGb+gWNsNm+iD0vNT8YdsYHRcY96FZXMifvldvvr
4m7j3HictRTGc6G9mc1jrI5nhlXxTHEFr/q572m2ztVH9RWdpY/wMCPMHfRG
bdJv9WUS1l/rEf1Gn+cr2sztep4vYs/8pT7H4WBu1X85SLv5kC7gbLwffGDv
M53Pp+w15+g/ZDOS1HiP4l22Lo93Txu1WSuZGuek07RRS+MzaXF8Li3RJdQz
Jt79OE+K4rzjWaCOW5jm52/WqVqgDZqnpZqrJfo2O60ztIteSOc4vzg70uN3
xLMfz5e5OJ4jnaQbeC/uXo/zMxPjXYo7199ZyyfmdfoTd7M17lFPsYqP4571
R8bH+2lO1V8o4vX4O+N9i/eVauu05P//L/4Hq32bmQ==
                    "]], LineBox[CompressedData["
1:eJwl0L0ug2EcxuGntXVh62zREFPPQIvNV4duDEXTkjBgMemgnICPkyiCtFpJ
kVRFI4Y6hDoDBjbXG8Mv1/9O3uRJ3tHCdm4rFkLI6zIewutQCBf80riadomf
ulHPvuY8y5zjBhd4xzc2uaMH9e02f/Sod/uJ+3rWh91hiQdM8kzn6tovqqhs
b0ZvKW3/6sR9qhXt2cvcZUv37klmNOIe1pIWNRF9w1sWNeNe5yyPdaRvu8op
HjKhNfeVGu4Up7kavcECsxxjnTUO4v//9A+8wjAl
                    "]], 
                    LineBox[{695, 971, 694, 852, 620, 851, 621, 853, 699, 973,
                     700, 630, 758, 558, 867, 635, 866, 636, 868, 559, 759, 
                    915, 916, 856, 623, 854, 622, 855, 912, 911, 757, 909, 
                    910, 908, 907, 779, 619, 850, 693, 742, 741, 
                    695}]}}], {}}, {
                  InsetBox["\<\"\[Mu] = \"\>", {-1.8, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["0.2`", {-1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {InsetBox[
                   SubscriptBox["C", "J"], {1.4, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["\<\"=\"\>", {1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["4.23`", {1.7, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {
                  {PointSize[0.05], PointBox[{-0.2, 0}]}, 
                  {PointSize[0.0125], PointBox[{0.8, 0}]}}, 
                 {PointSize[0.007], PointBox[{0.4463998339305619, 0}], 
                  PointBox[{1.2771956561278897`, 0}], 
                  PointBox[{-1.0806611991222994`, 0}], 
                  PointBox[
                   NCache[{0.3, Rational[1, 2] 3^Rational[1, 2]}, {0.3, 
                    0.8660254037844386}]], 
                  PointBox[
                   NCache[{0.3, Rational[-1, 2] 3^Rational[1, 2]}, {
                    0.3, -0.8660254037844386}]]}},
                AspectRatio->1,
                Axes->{False, False},
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                Frame->{{True, True}, {True, True}},
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLines->{None, None},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None, "TransparentPolygonMesh" -> 
                  True, "AxesInFront" -> True},
                PlotRange->{{-2, 2}, {-2, 2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.02], 
                   Scaled[0.02]}, {
                   Scaled[0.02], 
                   Scaled[0.02]}},
                Ticks->{Automatic, Automatic}], 79->
               GraphicsBox[{{GraphicsComplexBox[CompressedData["
1:eJyFWn98zdX/30fSWi4jxCW/QjcfSnJJn+UVV5Jf3cQSumrZkktbSLbwQXVF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                   "], {{
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[0.3], EdgeForm[None], 
                    GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxNmwn0ltMWxt9z3lQaFJkVCaGERKGkQklFMhNRyRglJGODm64pFRqQFKKU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                    "]], PolygonBox[CompressedData["
1:eJwll3cUz2UUxr/vfZWi0iGVKBmVRDSNikIklRANCckIkZFCGVllZCeVEY3j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                    "]]}]}, {}, {}, {}, {}}, 
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwl1FlQl1UYwOEPKFucSSeMKCsiiszKoiDQRNtLWjS0laWRxrFuQNtsQ1mS
siwt0soWMBaBFmmZ4aLQBC0qCzXTNsu6ac+sS7N83unix3Pew/yH+Z/zfWRX
1ZRWpyRJMs2Pk9OS5GDVq0ErUpNkpUp0ivlK5jKd43iaTtXpGq8x9s/kBJ2h
s3WWjrJ/Ds9VngqUrwz7hbyK5/FqPqtt1s+wiNdwBBtVbP0Qf+FzWmy9ik2c
zl+VqVfML/JavaRXzcfwd43V6+bVnKmXtdZ8HPcoS2+a23m9/lSHhux18gYd
Yn2oplpna69y9La9Lv6tv/SwuZsXsJxTWRF/T33WuZzGOTyCozQ6ztVcxmqm
x7nGGcY5m2fzbmbwaGXGeZvf4QAf0FzrB3kbh7iK+/iP6lVtruPFcS+qMc+L
M9Dx2mxvmB/zvzjz+C7aaK+Jl6hA681b+Yge0ybzo7w07lPvmXdwqZbpCf2k
H+Ne/O4rPh93pRd0kM63t5CL4juo2VzLSRzkt+ziSXoqvi93cQ2vYCezdb/u
U4cut9/OE3WvFqhNl8X9M0v3xLnGc6Fv7LeyRSfoSfPXGrCeyLu4nPN5p+5Q
kTmNhdzAL/m4Uq13cie/4BJ9rq3m7UzhNu7gZ/FMa0tkHmbCT+Iz/JSN+lf5
WmfvIzboQ/XHO8b9ytNF8bzbO1a11rfH+8h3OcgFqorvzlvZz8p4FljOGlaw
j83xfsb7qJJ4Z+P/gZaqN54l3sILWRl/mz2cwjIW8+a4J70V98eRPFyHaXLc
fdxRfEY3aqL5Jk7idWzTG3En/EHfa5Z647nlH2rRB+ZW7lapXosz4G/xvOn9
eN74nWaoJ94l/hzvo55Wt70jOVl11jlp//9/PABDD5x3
                    "]], LineBox[CompressedData["
1:eJwl0LtKwmEcx+FXW11qawyKoqlLKLDDVim4ViYqdqJcmnTtsFteQwdQMbSh
A5RhRIveQV1CDTX1SMOH5/d9pz//sfReYjcSQkjpKhpCdyiES35pUi07y0/V
9WrXuMIcl5nnKlt8Y5v7ulfPvuOPHvRuP/JQz+rbTyywxFGeq6qO/aKytuwd
bWvG/lXFfaZ1Fe01HvB2kHuacxpxDyuphKa8tdlgRovuTS7xVCf6to85yyPG
lHZf68Y9wQVuMD74Bs5znE1e8CP6/0//ALp6MCc=
                    "]], 
                    LineBox[{694, 971, 693, 854, 618, 853, 619, 855, 699, 973,
                     700, 628, 759, 556, 869, 633, 868, 634, 870, 557, 760, 
                    916, 917, 858, 621, 856, 620, 857, 914, 913, 758, 911, 
                    912, 910, 909, 781, 617, 852, 692, 742, 741, 
                    694}]}}], {}}, {
                  InsetBox["\<\"\[Mu] = \"\>", {-1.8, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["0.2`", {-1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {InsetBox[
                   SubscriptBox["C", "J"], {1.4, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["\<\"=\"\>", {1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["4.22`", {1.7, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {
                  {PointSize[0.05], PointBox[{-0.2, 0}]}, 
                  {PointSize[0.0125], PointBox[{0.8, 0}]}}, 
                 {PointSize[0.007], PointBox[{0.4463998339305619, 0}], 
                  PointBox[{1.2771956561278897`, 0}], 
                  PointBox[{-1.0806611991222994`, 0}], 
                  PointBox[
                   NCache[{0.3, Rational[1, 2] 3^Rational[1, 2]}, {0.3, 
                    0.8660254037844386}]], 
                  PointBox[
                   NCache[{0.3, Rational[-1, 2] 3^Rational[1, 2]}, {
                    0.3, -0.8660254037844386}]]}},
                AspectRatio->1,
                Axes->{False, False},
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                Frame->{{True, True}, {True, True}},
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLines->{None, None},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None, "TransparentPolygonMesh" -> 
                  True, "AxesInFront" -> True},
                PlotRange->{{-2, 2}, {-2, 2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.02], 
                   Scaled[0.02]}, {
                   Scaled[0.02], 
                   Scaled[0.02]}},
                Ticks->{Automatic, Automatic}], 80->
               GraphicsBox[{{GraphicsComplexBox[CompressedData["
1:eJyFWntYVNX61kxFdMo6eszREBONY4qmoGkeP2s0ldTQTIxoLG9Rkx4zb+Mh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                   "], {{
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[0.3], EdgeForm[None], 
                    GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxNmnkcllMWx597nyJUorImKUv2JaJsMbIUJY01UqmIyBYSCqUiIlSSRFkq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                    "]], PolygonBox[CompressedData["
1:eJwll3kUVlMUxd89t4TMQ4lGkUqlVKRUkpQSaZBGaVY0sKRUJFNp0mBKEVIi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                    "]]}]}, {}, {}, {}, {}}, 
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwl1Ht012McwPHvtlDhHHWOTKlsXRDdF4vSUrpsCkVly9ZxpHOSFRUmqbY1
Cl2o0E2ULluiizr1R0u6sFBsY+Wuyz+EIv7k9Tn+eO/1fJ79zvnt9zy/7zIe
mjyiOCVJksF+tE9LkqaarTl6LTVJXleuOpjz2JFX8XreoOt0ozop3X5ndtFN
6qauutp+D/ZUd/VSllrav4V38WYO43LVW7/BbA7npSxVP+synuUKlVuv5Fze
zd/USu+a3+QIrdEW8zX8Q230vnkt79M6bTW35Xllaod5PUfrT23QEXsbOUaX
WV+uHOt2uhDnol32KvmP/tbz5ir241jezgfj/bQnzo9DOJ5XsJmax9nF+3AK
r2SLOPM4V3Mhn2J6nGucYZypeS8PcKYetn6O41kTd8hEKSo3P8YyDlCWis2T
44zUWp/b+5KfsRErOE+HrV/gwLgvfWiu5Xy9rI/NL/HOuFftNzdwgRZrkX7V
L3rL777haq6J+1IT9Y3PEH+/Zmip+Vn24SH+wCpmaon1M/yelRzCTcxQiZ6O
O9PguENeG2enJ+N+Ncj+O3H3mq5pWqfv7K/l22qjV83f6qD1bZzKVziFT+hx
3WpuzN48wBNcqOP6yJzNS/giv1ad9Ve8mHXxOtbHdybOXrXmL3gRj7KBx+K7
rrR4hriPn7JUE60n6VGtUqqWa0U8SzriNSs5i//G86hq80GWqCjOi+NYzYL4
bHwgPh/zuZt5nMChfIS53MY7WMQcFrI/N7MvC9iH+XE/2mndgWd0Ot5DH9hr
z79UEecZZx3nqVFxT9oed8tTOqn7tS3ulefiO6WauDf+rJF6L77T/F2r9Il5
NX/UT7pH98bn0TJtjuctnlXNsm6X9v//xf8As6qdaQ==
                    "]], LineBox[CompressedData["
1:eJwl0DtLQnEcx+G/trvk1tRUFE29grTLkiUOTQWlYZehhmpp0q3LWvoquoAG
pQVdoAsY4aIvoV5CDUXPweHD8/vCgXM4g/nt3FYshLCgi3gIrb4QzvmtETXt
dX6prne7xgw3OMtNzrHBDza5owd17Hv+6lFt+4n7elHXfmaRJQ6woqpe7TeV
tRa9L/oWjdt/OnGfakl79iJ3eas79xhTSrr7ldW8RqNneMVVTbsLnOGxjvRj
H3KCB0wo777UjXuYU1xhmsuc5BCvecbPeO+f/gMCPTCC
                    "]], 
                    LineBox[{696, 974, 695, 851, 620, 850, 621, 852, 701, 976,
                     702, 630, 763, 559, 866, 635, 865, 636, 867, 560, 764, 
                    914, 915, 855, 623, 853, 622, 854, 913, 912, 762, 910, 
                    911, 909, 908, 783, 619, 849, 694, 746, 745, 
                    696}]}}], {}}, {
                  InsetBox["\<\"\[Mu] = \"\>", {-1.8, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["0.2`", {-1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {InsetBox[
                   SubscriptBox["C", "J"], {1.4, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["\<\"=\"\>", {1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["4.21`", {1.7, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {
                  {PointSize[0.05], PointBox[{-0.2, 0}]}, 
                  {PointSize[0.0125], PointBox[{0.8, 0}]}}, 
                 {PointSize[0.007], PointBox[{0.4463998339305619, 0}], 
                  PointBox[{1.2771956561278897`, 0}], 
                  PointBox[{-1.0806611991222994`, 0}], 
                  PointBox[
                   NCache[{0.3, Rational[1, 2] 3^Rational[1, 2]}, {0.3, 
                    0.8660254037844386}]], 
                  PointBox[
                   NCache[{0.3, Rational[-1, 2] 3^Rational[1, 2]}, {
                    0.3, -0.8660254037844386}]]}},
                AspectRatio->1,
                Axes->{False, False},
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                Frame->{{True, True}, {True, True}},
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLines->{None, None},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None, "TransparentPolygonMesh" -> 
                  True, "AxesInFront" -> True},
                PlotRange->{{-2, 2}, {-2, 2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.02], 
                   Scaled[0.02]}, {
                   Scaled[0.02], 
                   Scaled[0.02]}},
                Ticks->{Automatic, Automatic}], 81->
               GraphicsBox[{{GraphicsComplexBox[CompressedData["
1:eJyFWnt4jNf2dueE0bRSl6HqbtxVjVuxSErVrdMU1bSmpTg0LhWKUeraoUrQ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                   "], {{
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[0.3], EdgeForm[None], 
                    GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxNmgf819Max7/nfLWUkktIKCsRSkJZpUFCCpWRUVRGhbIlZaRoWBkJFaJC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                    "]], PolygonBox[CompressedData["
1:eJwtl3n0T1UUxd89l6hWg1Ihc5IKmSKzKIVSKSJDJRlSlEIoRIaQBqFBKWU1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                    "]]}]}, {}, {}, {}, {}}, 
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwl1FWQl1UYwOE/rOSMMCwhILWAIN2dCi6ghITEDDOAM0iDSncjKiAt3V3C
DBeElIKAIN0pN3Rf0s87XDz7O+/Zndn9vnP+m/Jtv1Z90yQSiVRfiiYlEukY
xnBmpk0kZtGQT8xfaDFN1k81VYtrSUqQ3Vxay1CKcpQlh/0KWpHyVKYSOe1X
1UZaRRvrHE5Zz9Zq2kTT6whqWo/UuzqXUda/62j9Uu+Ri3XmBdqMhaw3f6QP
yMNG8xJtwVI2mfPqI/Lzh3m5tuIxKzhob6W2JoN1RmpZF+ApKWyzt0qf84yx
5tVaR9tqbW0Xv4/t1kU1VTvph5qFrBQ3t9WemhzvNd5hvGNzR/1Bc2queC5K
m3fofh1EZ+vB2kUP6Wx9qa/indHdPDL+LsrRI34X+cjPUXv/6RF9yxjGs9/e
OK0b58ku8wmdwE8cME/SelRkt/msTuZXfuEOt1nsexd0gS5iIR9Q3d5gHcJA
psczaTXdp1d0jRbmN+sBellX6+e6SlPoz49xZnwWZ6iF4t3xfZwv9e0v04JM
s+6nl+JOxP2gAFPNF9lrXVX76hTtpX3oTRVzUtxr3aPn9WfO8WfcdU2rE/UM
J61Paxo9GT+np+K+xHvnhPm4JvRfPavH4p7zhvLstHdYR9DVuhvfMZ/X8fmI
zwZz+Mc8L96pvqAMec15yB3vKc6KY9a7tEM8l7bTXtpet2sT7aKNtLM21s1a
XzvEvdD2cf66Rg/pWs2smfjGulacg97if9qwNc5An8Rds64Rn/W4C7SMM2JL
3E+9yQ2+ZrO9j/Uhi/jbvFiv05wN8Xx6P56fv+L96FWu8RVNacAM1vp+Nq3B
UOsiSe//J74DRqOa6A==
                    "]], LineBox[CompressedData["
1:eJwl0KtOgnEcx+G/GCmYTep0JK7AIkjxFChuHAwvVCGYlOaxergJwU2dDCwi
E53OjSKXoJegAZsPM3z2/L7/8m7vTFTLVSdCCJtqxkJ4nQyhwW/Nq21H/NKN
3uxrrrLMFVa4xjbf2eG2uvqwHzjSowZ2jzvqa2g/MeIup3muCz3bL9pT2a6z
whR/deo+U0E1O88q78e5k1zUlDuhDa1rwVuHt9zSsrvELE90rB/7kEc60L7i
Knq/Uss9x8z4+1xinmnO8o6X/Iz9/9c/2M8v3A==
                    "]], 
                    LineBox[{691, 968, 690, 849, 614, 848, 615, 850, 696, 970,
                     697, 624, 758, 554, 862, 628, 861, 629, 863, 555, 759, 
                    910, 911, 853, 617, 851, 616, 852, 909, 908, 757, 906, 
                    907, 905, 904, 780, 613, 847, 689, 741, 740, 
                    691}]}}], {}}, {
                  InsetBox["\<\"\[Mu] = \"\>", {-1.8, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["0.2`", {-1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {InsetBox[
                   SubscriptBox["C", "J"], {1.4, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["\<\"=\"\>", {1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["4.2`", {1.7, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {
                  {PointSize[0.05], PointBox[{-0.2, 0}]}, 
                  {PointSize[0.0125], PointBox[{0.8, 0}]}}, 
                 {PointSize[0.007], PointBox[{0.4463998339305619, 0}], 
                  PointBox[{1.2771956561278897`, 0}], 
                  PointBox[{-1.0806611991222994`, 0}], 
                  PointBox[
                   NCache[{0.3, Rational[1, 2] 3^Rational[1, 2]}, {0.3, 
                    0.8660254037844386}]], 
                  PointBox[
                   NCache[{0.3, Rational[-1, 2] 3^Rational[1, 2]}, {
                    0.3, -0.8660254037844386}]]}},
                AspectRatio->1,
                Axes->{False, False},
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                Frame->{{True, True}, {True, True}},
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLines->{None, None},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None, "TransparentPolygonMesh" -> 
                  True, "AxesInFront" -> True},
                PlotRange->{{-2, 2}, {-2, 2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.02], 
                   Scaled[0.02]}, {
                   Scaled[0.02], 
                   Scaled[0.02]}},
                Ticks->{Automatic, Automatic}], 82->
               GraphicsBox[{{GraphicsComplexBox[CompressedData["
1:eJx1W3lYlNUax6Wblxr1lkpOPm6pTWqF5lRuvdmYmVdppHLLRrNcx1LRFpRr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                   "], {{
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[0.3], EdgeForm[None], 
                    GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxNmwn4l9MSx99z3tKiRRttkqUsKRFaREVFJLTJXikhCilrVyLZs2QJZV8S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                    "]], PolygonBox[CompressedData["
1:eJwll3nYVlMUxe85x5QMZVah0VBK0khpluZo0iSq70PRF6WUJlSaEc2lUUj6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                    "]]}]}, {}, {}, {}, {}}, 
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwl1Gt0z3UcwPH/LFE9pXMKsdEmxVq1smkztkn32qb7zSwPavKAkMgl15lU
dHEplXJrrdtKLrVGRYa2oamt4lBRkWeVXHp9Tg/eXp/P1znD9/f7SSkbXfxY
UiKRKPJLv+RE4mzN0Vy93C6RWKzblWEv5uXsyitYwkxepSvVzX41r1GWstVf
FzkfwGuVo1J7LrtzIIcxj3dwqfablzCfd7IDK1VonsefuUxV5lc4n3fxdR0w
v8Zfda/eUJ2zHjysVNXb3+L9WqnN9p78TWn60r6af+h3rdG3ztbyIXU0n6Mh
5nQdUx9tdfY2j+tPLbBXcwhHsIjlvI4fcB8/5KPqZO6s85VhH87HeQEvVBdl
2kfySfZgijab21gfP4dT+AinsoJbWc1/eEKzNc4+izeqv8bbJyhN6Wpw9gO3
87TOqFLN8V7wJuWowd4Yz0TPaLd9Pm+O560d9r1xD0o25/EbPsdDqjXv4/tx
D3Enaq/BzmbG31FP60X7DA5iE9v4KS/TC+bpbOUmbtSlmhZ3oA261e+tZ5+4
Hz2lT3SL83W8RIvMk/k9P+ZH6q2F9u/UaM7nJD7PJ+I5aKIG2s9iLnexhc/G
O6Od8d6zHau4Rz+ZdzOJTXEXbOacuB/9aN/FBHfwIHfylE4qW9udfR33pDHx
rmis3tO/zmr4rt7RNvvf+ktZ6hXvu1I1yf65Ws11LOd4lnEcR8QdspSjWMwK
lrCWN3Akh/JhXh9/JltYw/N4rsrMhXHX8f7HdxrvuL6Ke+bReIfi2asgnrUe
dLZKX5gvju9H+/WAtjjrxSNaob32N+NudV/8m+L74C96Ne7dvjze67hf3a17
dJte0mfxjbEgvhFz3+T//z/8D//CqRk=
                    "]], LineBox[CompressedData["
1:eJwl0Lsuw2Ecx+GXrqhadHCIwdQSMXALdS4JJTFJBE38SydGhwvQOt6AYwcM
LLqphktgdAcGZo8Ynny+v7fp8u9ZKsxEDSGERZpiIYwzxgGZxhBSTNiTtBDn
0du7PuicRjqrBc3pk35oVbfosDsZtQf5Zojo7z+ss+Ou8Wk/64buaq/eUOHF
XWePTfe+FnVYf7iwLznnmiu66WLb78s6oCMk7XYWmKffW5smaCXvPtUzTrh3
f3FkH3NImWbWvN/xZvfptK7qlK5oVtP6qrdaiv1/618ZBSu9
                    "]], 
                    LineBox[{697, 921, 696, 860, 625, 859, 626, 861, 701, 929,
                     702, 930, 634, 755, 563, 872, 637, 871, 638, 873, 564, 
                    756, 931, 932, 864, 628, 862, 627, 863, 928, 927, 754, 
                    925, 926, 924, 923, 787, 624, 858, 695, 739, 738, 922, 
                    697}]}}], {}}, {
                  InsetBox["\<\"\[Mu] = \"\>", {-1.8, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["0.2`", {-1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {InsetBox[
                   SubscriptBox["C", "J"], {1.4, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["\<\"=\"\>", {1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["4.1899999999999995`", {1.7, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {
                  {PointSize[0.05], PointBox[{-0.2, 0}]}, 
                  {PointSize[0.0125], PointBox[{0.8, 0}]}}, 
                 {PointSize[0.007], PointBox[{0.4463998339305619, 0}], 
                  PointBox[{1.2771956561278897`, 0}], 
                  PointBox[{-1.0806611991222994`, 0}], 
                  PointBox[
                   NCache[{0.3, Rational[1, 2] 3^Rational[1, 2]}, {0.3, 
                    0.8660254037844386}]], 
                  PointBox[
                   NCache[{0.3, Rational[-1, 2] 3^Rational[1, 2]}, {
                    0.3, -0.8660254037844386}]]}},
                AspectRatio->1,
                Axes->{False, False},
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                Frame->{{True, True}, {True, True}},
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLines->{None, None},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None, "TransparentPolygonMesh" -> 
                  True, "AxesInFront" -> True},
                PlotRange->{{-2, 2}, {-2, 2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.02], 
                   Scaled[0.02]}, {
                   Scaled[0.02], 
                   Scaled[0.02]}},
                Ticks->{Automatic, Automatic}], 83->
               GraphicsBox[{{GraphicsComplexBox[CompressedData["
1:eJx1W3l4jFf7jlqbGlvTRseuobH7YVRRT2tQjeg3nyqqjKUomVY1FJNaYvmG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                   "], {{
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[0.3], EdgeForm[None], 
                    GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxNmgn8l1P2x597L21KqZS1QohkyRahInuUkkm2yhJFtmRJlCRrtuyMkrIW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                    "]], PolygonBox[CompressedData["
1:eJwtlwf4l1McxX/3fktkFkqFVIpC0SCiVJJKJESK0qKhJGlQQlNob00RKlFC
RYjoiQaSvWeSvbI/p9Pz/M//Oefe+76/d3zv+Z63Qqc+rXvnQqGwExQBUxHT
wDq4xp/l37tRKGxPhcLn6CPgZcBF6E/Q45nvjx6KvhXMRX+E/g7+MvPHwYeA
29B/o4cxXwHdFj0YXI1uiO4E7wzOhXdh7A3WHoKuh74Y/RI6oVuhe+qa0Iej
Z8A/ZGxn8poi8KLgPPQW9HvMXwE2wk9g7COtB++hS6Cr617QL6D/BX3glzF2
PXN9dQ9ai/4A/gPz29DL0LPRc8Cb6M3oNfDdzFeB3wyGof9CD2b+GXAE+kaw
mrlV4WdRFb2vrhV01bkYu5O1W8Gx6EbgMvjl4Hnm9gOXwoP1TZm7CrRFz9MY
/BTQnrkbdI+sLYVegH4ATIeXBcXg+4Dm8BagD7yvrhm+i2M6wQdlv+vSjHWD
t2DsWngPUB5+NGija9NvwuuA9vAXOeZ11r+CXoH+Hd1F52bsK3g5xnrBL2Ls
OnhvUA5eVu8Yfgk4k/lN6KfgT3HM/apF9CL0ZnRHeH/GPi74mU6BP83YwuRn
tAL9FnorervqEz4OvAU/SPWiZwHeR5dEj9T1qibhDcBJzJ0MrkiuiSvh/VTT
8MMYWwp/mbGlyedsh14I9kHXBgcydwBoCb8APMHcVPQ98PG6Rl07+nv4Do5/
XM8q9tYOY2OYvwv8hj4bPQTejfmb4ANADXg5xv4r+BonwgeFj/2Tsc/Rx4Ci
6JpgOvzMcK0UY/4L9HxQBF0LfAvfCZozVxx9Drwy2C95D82Ej+b4UapV1ixC
b0NvRJ+I/gZ9fPaxp4Gv9a6z54ppj8A/y67NkoydC68KDtTxYBl8O+fbBG+j
PYpuGa61Ruhq2vvoh9EN0Su1H8J7cxxop70IJsIPBZ8yfy/I8JNVQ/C3mX8D
3pXjV6PnoCejr0GXzz5Ga+URX2rvZV97HbAWfk342d/E/Cg9K1Ad/TO6Pnxg
2PtWo2vp+Yf3xgD0L+ifs/lRekbwDcw/qtplbKz2F6iR/M7XyYvAN/ChoBn8
VFBetal3omsFZZI9eHj2Gs19X7C3TQvXmjxuNvodUC35mTSGv689pnsHC7I9
Ut6omng323PkNTrm7vA707u6E3wMXx72vj9Y0wT9AXgdXg80gG9hfi3zz6J3
o//Ivtdj9M7hB4X3RnvGjs6uWdWqPKwKfIfuOfmcFbLfid6F9th92XtOe001
/gh8F6gLP1iac/+OPgs+K7mWVaOqTdX0r9pb2c9qJKgD/0l7JLkH6tn+COol
P+M/4X9lv+sFOobzN8reC/Lg/7I9S17VGN0UfhhrWsk7GduC/gc0TPb0V7P3
uPZ2RXlatgfJeyqBxdkeLW/eH5SAlwx7zzucbyPzf4P6yZ61HN467KXtmL9X
vZex05P3xEDda7b3fsp8XeZPBevlbYxVhVcDTeBJfhv2ZHmxeoa8pia6XbLn
1Ap7vrxeY0fq2YbPpRNUzPYYeYtqrJVqJ9xb14Ga6B/AGfIKeRxzx2XXTse0
NwuguyRngkt1LeFa0TMtBS8d7k3y5Na613A20D01gJ8V7hUdVLPw+mE+Jrn3
dcz+LfXAzvAm4WetzNE47EnyIl3Dc/Be4awypODaqA2OTK4RvYsN2bWtd3IL
vGv43tTz1AuuZaxnck/oAb8wnG2UYc4Pe5y8rXva2xvRfZJ75MPoh8K1OhDd
Nuxh8q4b0H2zPVDep56/J7tkzynDqHcMzT5WPeRGeIdwdlIPlRetz+798iT1
NnmwvFc9Ttc+mbG7ku9BWaBr9rUqE6h3D0D3S+7hygbKPMo6yghT0JPCe1Pn
uBpePXtv6Bh5+5Ls7COPVxhtE85m6tE94d3DvXIQY8PCHiNvGa77QVcMZ7Nb
5LnqlWBVwZn0dtb2Du9teaq8tF94rTy1adjj5G3KYJOYHxrOZv+w/lb1iuzf
ukP3GO4p6iV6R/KeCYyNTfag2+C3h9c+V3Ct9Ahfu2pGvXQWY6OTe6q8TjWq
2pTnZfhwMCJ5T44IZ3L+9oxNDGcaZRn95li9m3B2Vg8fA2+Tnb31G8piZ6CX
FZzJXlUvzM5mK5Oz1rhsL9+TuZRd0PPhC1TP4TFxZfgnwxlX2VZrBsOfAPOS
M+9KeOVwFpmLXgpfHO59M5Oz/yIwI/kbQMeen71W55B3zWRsQrKHycuXhI+V
pz+m3hl+tsrg6p2ng8rJPbRe9j3q3lQDuvd/s7O0noG8eFO218qT1cvrZnux
evr14R6i3qFMrKzSDN0tObM0hxcPZ0uNzQpnSmVJXbOynjKKsokyn7LGGvW/
5Myh7CdPkZcoA+pbSRlJ2UjfTPrWUuZQ1tA3l749XsruPfoG0beGMoeyhr45
9O2jjKdsp28gZeVK2b1dmVnZuEy2tysjqze/nV3b6tHKyuoh6h3KzMpKq7K/
7ZSZ1BvvY2xaco9cGP6m0LeExh4MZxZlFb3T2uGeoB/UN8HccA9S79EzmB/+
RtG3ydTkXjAvzNUTlAUfze51yoTKmg9mf8spc74Gvzu71+qd/w9ZitPG
                    "]]}]}, {}, {}, {}, {}}, 
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwl1Ht01nMcwPFnG/oX5+DQXMZWS+bSmNnC1OacCptJiGWNQzjHYk3mMrqs
yUYKuV8iCtVQjMzmslWb2azN3NWiXP+jVIjX5/THa+/v5/s8Z3ue7+/3W1pF
ZenNSYlEosiPE1MSiWTmU8fS5ETiMYoZbS7Rk/QoPVkv1iw9lVMYbh6j2ZzG
GZxOqv0zNZccSs1n6dGar5donk7WJ/je+nEdq5dqii5gnHW9DumT3Gf9lC7U
KfocW6yf1R+4gud5394x+iPH0WZ+Ua9kOR+Y03QH6Xxsfll/5idWMGBvpU7j
AOsDKbTO4Fcy6bD3iv7ObzSYG+NzM918nlboeG3SQX1db+Bg60M4lCxzmVbp
YXo4R8QZmyu0RlPj/Giz/lpb9Xq9W6/TWp2hr8ZnYqd5F3XcGtdYJ5BDlXkW
x3MCG+19oxt0L3/HWfOZvXqdSC6d5u44fxrpMzfopLi+dJn79AH+i+vJp/YW
6VbetB7QJn0jzoIkCuzN0bncwyPme/Vc7dUv9T3N5GHrWv1C1+u7jIxz4C7e
4UKvNesI7uQO3uYC+29pBkusa3RQ1+la0lls/pwe63P0dn1Iq3U2t3G2OaH5
2q39+iCb+cScp/u4P86Q7+z16r9xHmwz9+iCeD/fmrv0HzYxZO7UPeyOZyn2
7XXoPCqtb2Ema/jL3ipdzWu0m//kD7LjGbB3bDwTcRbxfPCVdYuWa3Xc53FP
6NXarCV6k16kN2pxXDM9X6/VQr1Gi+KeizOLv63D9CDKrQvi2sR74gzid9Me
10V/ifOJM47rHGdKmb2X+Cjuy3hu4my4ig/jftXtLKPf/ELct0ylNb5jnC1P
x7UwPxPfM54XLuPy+D48SovXj4xnNM7UelTK/v+H/wM3Iqkf
                    "]], LineBox[CompressedData["
1:eJwl0Dkyw2Ecx+GXNPaGgqhSCmMUXEFCkiJbp5GZxJZER2npLSEuYC9QRENn
meEIUbqAghN4jOKZz/f3ZibFP1Zaz9U7QggLdEVCSJJgj9nOEMaYs+fpoZd7
b21taU6rmtWa5vVBP/RRNxi2R/7+257im2lWva2xwpb7mU/7Sau6rTG94poX
9ys71Ny7WtcZ/eHMPueUSy4YJcqm3xd1UhMM2YMUKTDhbUD76WPZ3dQTjrlz
f9GwjzjkgG6WvN/ybo9rRiua0rKmNa5veqP7kf9v/QtHeiqg
                    "]], 
                    LineBox[{694, 918, 693, 856, 623, 855, 624, 857, 698, 926,
                     699, 927, 632, 751, 561, 868, 635, 867, 636, 869, 562, 
                    752, 928, 929, 860, 626, 858, 625, 859, 925, 924, 750, 
                    922, 923, 921, 920, 783, 622, 854, 692, 735, 734, 919, 
                    694}]}}], {}}, {
                  InsetBox["\<\"\[Mu] = \"\>", {-1.8, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["0.2`", {-1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {InsetBox[
                   SubscriptBox["C", "J"], {1.4, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["\<\"=\"\>", {1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["4.18`", {1.7, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {
                  {PointSize[0.05], PointBox[{-0.2, 0}]}, 
                  {PointSize[0.0125], PointBox[{0.8, 0}]}}, 
                 {PointSize[0.007], PointBox[{0.4463998339305619, 0}], 
                  PointBox[{1.2771956561278897`, 0}], 
                  PointBox[{-1.0806611991222994`, 0}], 
                  PointBox[
                   NCache[{0.3, Rational[1, 2] 3^Rational[1, 2]}, {0.3, 
                    0.8660254037844386}]], 
                  PointBox[
                   NCache[{0.3, Rational[-1, 2] 3^Rational[1, 2]}, {
                    0.3, -0.8660254037844386}]]}},
                AspectRatio->1,
                Axes->{False, False},
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                Frame->{{True, True}, {True, True}},
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLines->{None, None},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None, "TransparentPolygonMesh" -> 
                  True, "AxesInFront" -> True},
                PlotRange->{{-2, 2}, {-2, 2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.02], 
                   Scaled[0.02]}, {
                   Scaled[0.02], 
                   Scaled[0.02]}},
                Ticks->{Automatic, Automatic}], 84->
               GraphicsBox[{{GraphicsComplexBox[CompressedData["
1:eJx1W3lYlNUaR+taZqOmXupOhcs1m3BNRc3It6TsSmmTmWtNiWuNhSs1pmgu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                   "], {{
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[0.3], EdgeForm[None], 
                    GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxNm3f8z9Uexz/nnAaRUWjcBqGpQgMtIQ0VkhItaQ9xpUFLJQ3qat8mSlLR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                    "]], PolygonBox[CompressedData["
1:eJwtl3f0z3UYxd8jo52GNAjZKzNlJEQq4yRUNJCRLUWEBkmRLQ0rUTLiJDJK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                    "]]}]}, {}, {}, {}, {}}, 
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwl1Hl813McwPFfTfo3Ho8iZrZKVEbYdCwdiOlgW45SjD3wwB9bKKRjFx1z
VpSjclSuUXRuQ21L6bBqbQ1FpVSq/7rc8Xw//PHs9X5/tsej/T7f75ZWUJRX
2CqRSGT7pzQpkZjZOpF4Vlv0O17mFYbS3fkw7aHnaboO18v1Sq7gfPtVejU9
yeAaOjq/VnuRya323nqB9tXbtI/m6Gz2mmdpluZqkj7Hdeapuk9fZZr5NZ2u
efoW+8xv6n5uZx5rnSXrAVKos7+td/IO9faL9SCdWG9/Tw9ziIXsdLZIR3GW
uQ0DzZ05Qle+cbZYj3GUCvvz3MgY+w16jw7Wyrhj/UQfoJ35HM6lhz1fC7W9
dog7Jz2+V8dpsl7EF+bdWqOP6NP6sE7QR/UjPuSk/RQljLMXx89BBuPtT9KJ
zqxz9qPW6x/8STmNzsr0pniebLFvjHcmngs74jnpzfTiW3tDPCf+jWfMVmcV
uoeV5kZdpitYTmv6OSvWEibzkn2KZul23alrtBsvmidps36lX3IZE3km7och
vlajl8a9xB1RzS3Oq7QrL5if0iZdrau4JJ5ffC62mftqK52hn+t2/Uy3aUKX
km1eol2YHp+XBnNv/YczcS/x+Z1t0b/ZFO+mfbOWxnvET/YN+hdfx/tsX6+/
8xuZbHZWF3fDY+YneJxPOe2sMt4vPqbWfoLj8TtKarzzpDDeXs0uc5UW6Fi9
T4v0/ng2mqcPaY4+qLnxf2m25sd7offG89f3tUU/0LZ6NqPN18e96qB4b7mb
DXFf+isz4veKQQxgpLN34w7MaTogfk7uYp2zVP2F+TTbF+gP3EFt/I7oz7xO
k/0N/Z7+zGEuI+jna/3jbwwX2vdSZi5P+v9v43/5MKs7
                    "]], LineBox[CompressedData["
1:eJwl0DsyQ2EcxuGPNO4NRUR1KmGMgh2gIcFMgjQpIimYQRJKYgeEYAPul4Im
OpeWHVDqFezAM6N45vf+v9OdqFjJlFtCCHnaYiHMMM0eE60hDJKy03TQyYO3
D73XBV3RrK7qojb1Ux91k7jdz5Q9yg9jrHvbYI1t9zNf9pOWdUcjveKaF/cr
NSruXa3quP5yZp9zyiUXDJBgy/eSjugkfXYvOZYY9taj3XRRch/rCUfcub85
tBscUKedovdb3u0hnddlndWCzmlS3/RG92P///oP/b8qNg==
                    "]], 
                    LineBox[{690, 917, 689, 858, 618, 857, 619, 859, 694, 925,
                     695, 926, 627, 750, 559, 870, 630, 869, 631, 871, 560, 
                    751, 927, 928, 862, 621, 860, 620, 861, 924, 923, 749, 
                    921, 922, 920, 919, 783, 617, 856, 688, 733, 732, 918, 
                    690}]}}], {}}, {
                  InsetBox["\<\"\[Mu] = \"\>", {-1.8, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["0.2`", {-1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {InsetBox[
                   SubscriptBox["C", "J"], {1.4, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["\<\"=\"\>", {1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["4.17`", {1.7, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {
                  {PointSize[0.05], PointBox[{-0.2, 0}]}, 
                  {PointSize[0.0125], PointBox[{0.8, 0}]}}, 
                 {PointSize[0.007], PointBox[{0.4463998339305619, 0}], 
                  PointBox[{1.2771956561278897`, 0}], 
                  PointBox[{-1.0806611991222994`, 0}], 
                  PointBox[
                   NCache[{0.3, Rational[1, 2] 3^Rational[1, 2]}, {0.3, 
                    0.8660254037844386}]], 
                  PointBox[
                   NCache[{0.3, Rational[-1, 2] 3^Rational[1, 2]}, {
                    0.3, -0.8660254037844386}]]}},
                AspectRatio->1,
                Axes->{False, False},
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                Frame->{{True, True}, {True, True}},
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLines->{None, None},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None, "TransparentPolygonMesh" -> 
                  True, "AxesInFront" -> True},
                PlotRange->{{-2, 2}, {-2, 2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.02], 
                   Scaled[0.02]}, {
                   Scaled[0.02], 
                   Scaled[0.02]}},
                Ticks->{Automatic, Automatic}], 85->
               GraphicsBox[{{GraphicsComplexBox[CompressedData["
1:eJx1W3tY1MX6x2sedDtq5mUtTfOyeTmatZZmvirmMS3d4+GYlW5pouR6l7I1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                   "], {{
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[0.3], EdgeForm[None], 
                    GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxNmwnY11MWx3/33mSpqCwZsiRkS0oSWmzZQyWVspWsKbJkS5FQIkJCSlFJ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                    "]], PolygonBox[CompressedData["
1:eJwll3n4j0UUxd+ZEa1SIRL1U1JZslR2UtkilagQyZJ9J4UolLImyRKytVBa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                    "]]}]}, {}, {}, {}, {}}, 
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwl1FWQl2UUwOE/rAL3KB3SsHR3CkuDICmN4IwwAwzS3Y3SrQLSLd3MUNJI
lwNIg3BHqSg+Z7x4+J3zzl7svt/3katr7+a9UiUSiRT/jE5KJGanTiTG6TW9
zkxmUY8CzutrQf1Ik7WBFtKGWlg/1qJajCKUoDgZnJfS0pSkkb2MZtRy2ljL
ahOdy03zHL1LU+ax21km/Z0sVLZXoRLN7Eu4ZV6s92nO9+xxllUfkJ199qXa
gmXst+fQxzxhBb85+0mfspKL9lXahg/MH5KGT+x/kIdD9tX6gudMsE+kFu3s
NbW9fqob4+/SL7WJdtPtHDYX1E7aS9PHXce9kmw/onu1H93M/bW7HtAeOli/
1iHaU1eygtf2N4ymv32U1qIkA+xjNIfm5Lj5mh7Tv+I5cdw+Tm/H7x/Pil+c
ndLxTOS8fYLWjmfKCft5nUTCXFFP6zQdrLkYxMC4D1KcV+CU+ZJOJclcWc/q
DB2l+fnOPFKv6i7dST5GMJwd1I071bwMYyhb2cbPbCEP3/q5IXpFN+smcjPd
fpkz8Y5pap2iG/SirtcLmkrXUce8Nt4JJpt/5aS5vP7Le85xw9lZ/SfuI+7U
fkbHxs/Hd2c/oX/zLu6ZY/Ht6J/xHXHUfjTugL7mfnzDGt46W62HdZUe0Ve8
pBjZ4nsgCwPi/eeqeZ921T7aWXtrl7jL+Jb0K/1Mu2uzuCdN0Y7xzLWD1onf
QS/pWk2nafnCXCPuVavFd0pbDsZ7oM/iPTJXozpVae1sOQfivdSqtIw7tLfS
RzzkBy44+1Fv8jl77dn0HgvjWdgXxd1ThfksiL+H8vFuUoHM9juMMY9N+v//
xP8AQEunoQ==
                    "]], LineBox[CompressedData["
1:eJwl0Lsug3EYwOE/nRxKGIrB0MQhYuAOMKnT4tRFotqBQVu6OszqVDfg0NqQ
6MRG3UONbqEDN9CnMTz5ve/7JV++fPF0fjXXFkLYoiMSQoJ5zphpD2GEBfMi
XXRTdavrq67rrq7pnm7om37rux4SMw8wZ57klymybjn2ObJ/8mP+0Lwe67BW
eKRm/+KEA/tp6/06rX/cme+5pcwDQwxS8DyjEzpLv7mPJJuMu/VqD1HS9pLe
cM2LvcGl+YoLzulkx/259W3mMV3RlC7pti7rqNb0SYuR/3/dBLvbKcM=
                    "]], 
                    LineBox[{691, 913, 690, 858, 618, 857, 619, 859, 696, 921,
                     697, 922, 627, 752, 556, 871, 631, 870, 632, 872, 557, 
                    753, 923, 924, 862, 621, 860, 620, 861, 920, 919, 751, 
                    917, 918, 916, 915, 784, 617, 856, 689, 733, 732, 914, 
                    691}]}}], {}}, {
                  InsetBox["\<\"\[Mu] = \"\>", {-1.8, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["0.2`", {-1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {InsetBox[
                   SubscriptBox["C", "J"], {1.4, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["\<\"=\"\>", {1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["4.16`", {1.7, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {
                  {PointSize[0.05], PointBox[{-0.2, 0}]}, 
                  {PointSize[0.0125], PointBox[{0.8, 0}]}}, 
                 {PointSize[0.007], PointBox[{0.4463998339305619, 0}], 
                  PointBox[{1.2771956561278897`, 0}], 
                  PointBox[{-1.0806611991222994`, 0}], 
                  PointBox[
                   NCache[{0.3, Rational[1, 2] 3^Rational[1, 2]}, {0.3, 
                    0.8660254037844386}]], 
                  PointBox[
                   NCache[{0.3, Rational[-1, 2] 3^Rational[1, 2]}, {
                    0.3, -0.8660254037844386}]]}},
                AspectRatio->1,
                Axes->{False, False},
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                Frame->{{True, True}, {True, True}},
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLines->{None, None},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None, "TransparentPolygonMesh" -> 
                  True, "AxesInFront" -> True},
                PlotRange->{{-2, 2}, {-2, 2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.02], 
                   Scaled[0.02]}, {
                   Scaled[0.02], 
                   Scaled[0.02]}},
                Ticks->{Automatic, Automatic}], 86->
               GraphicsBox[{{GraphicsComplexBox[CompressedData["
1:eJx1W3tYlNXWR0wzc5TPQ6Zz/PCSl8nwmkNkepaJR43SkKNiaqPl5VOpo4Xl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                   "], {{
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[0.3], EdgeForm[None], 
                    GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxNmgf811MXx7/3XqFSySYke6uMQlkZRaGQ7J6kkuyZmSciq8eKiIqUEslo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                    "]], PolygonBox[CompressedData["
1:eJwll3f4z1UcxT/3XqE0REO2SqIkKysys3mKIon8JERGWYmGjJQ9MiqjFA1l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                    "]]}]}, {}, {}, {}, {}}, 
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwl1FlQl1UYwOEPsMzurAiz0rDVtIUwRKVEDcgWQ9qXmUrgwkq4EHMpck3L
Fm2ztKy0XNujcqGaACOCECwhcdQ2y6W6q9TK8nnHix/PeQ8zzP9/vvOROa6y
pCIlSZIiP2akJcnTqUkym538Vgv1lAp1vv0iDmBPXsArOZCjeSFP4MXM0kXK
1iU60f6lvIqDeDVzeBJzeQ0H81o+q23Wz/A7jdFz+sheOr9Xhi4zX648FZtf
VJf1Ev6on/SS1tnrxd3qrQ3mV1iiV7XRfCr3aK9e03Z7y7lPr+tr8wrerGOs
j1V3nW7+VWfoE/NK/q7fNNc8SldopG6zV8A3eB3HxXdjKWtUZ30O7+QEpvNk
Zeg8cz03cKJKratYxlrewykcz/t0b3x+/WXvgGZoknk68+MZ6X7zTGaynzZZ
d7CBfytbjebZ3KkR8ez0hb0mzonvqDbzwxwZz1hN5lamMFGudQvncyrPis+q
yXEWcT7x7NVsvYWPqpv1ULZyAaezv560fogd/JAfxNnoCXM1a/S+Cszv8Vw9
qAf0rrbaf4dvx1nrcfM0fsO3+KbO1mPxzPWV9RCm8RGuZTvXsI2pXB3P2XoV
z9Q868360jqH/+n/+FvxTtlr4eH4vXaYmzkrzlWd5kb+o3/1eRTvEA8pS5vM
9XEOcResq1kVdy/uqA7GneVncZdZxz/1R7yz6muvT9xdTTKXx9mygRtZqbus
K3h3nHG8KyxnMcs4Ns6KRbyDhbw9zkCfWmfyePbQcbo17g/7xnsb75du0cfx
Wbg/7lPcI+XrJvNw3shlqrU+jXm6Ps7XfAN/0c9aqi32XmZXfD6tN5/CH/SC
2s2LuU3DtEjPx7uoIX43LO5cvHPmXZppPSvt6P/FI1x9pmE=
                    "]], LineBox[CompressedData["
1:eJwl0LkyQ2Ech+GPlLYYiogUYhkzCu6AVoJGkCaxpKCSRWfpiQQXYO8wQyeV
7R7o3EMKbsCTUTzz/v7nzJnJJFkoLRbbQgg5OiIhpJjlkOn2EIZJ23nt0m6e
7E991CXd1Ixu6bI+65c2tEzMHiDOhPuHSYruEtvsul/5tl9a3+meDukNt7y5
39mn4j7QHZ3SXy7sS8655ooEg1S8L+i4ztBv95FlhTHPejVKDxvuUz3jhAd3
k5pd55gqnax7fs+HPaoLuqZzuqrzOtL67XqnR5H///oPlQspiA==
                    "]], 
                    LineBox[{689, 912, 688, 858, 617, 857, 618, 859, 695, 919,
                     696, 920, 626, 752, 555, 871, 630, 870, 631, 872, 556, 
                    753, 921, 922, 862, 620, 860, 619, 861, 918, 917, 751, 
                    916, 690, 915, 914, 786, 616, 856, 687, 732, 731, 913, 
                    689}]}}], {}}, {
                  InsetBox["\<\"\[Mu] = \"\>", {-1.8, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["0.2`", {-1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {InsetBox[
                   SubscriptBox["C", "J"], {1.4, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["\<\"=\"\>", {1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["4.15`", {1.7, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {
                  {PointSize[0.05], PointBox[{-0.2, 0}]}, 
                  {PointSize[0.0125], PointBox[{0.8, 0}]}}, 
                 {PointSize[0.007], PointBox[{0.4463998339305619, 0}], 
                  PointBox[{1.2771956561278897`, 0}], 
                  PointBox[{-1.0806611991222994`, 0}], 
                  PointBox[
                   NCache[{0.3, Rational[1, 2] 3^Rational[1, 2]}, {0.3, 
                    0.8660254037844386}]], 
                  PointBox[
                   NCache[{0.3, Rational[-1, 2] 3^Rational[1, 2]}, {
                    0.3, -0.8660254037844386}]]}},
                AspectRatio->1,
                Axes->{False, False},
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                Frame->{{True, True}, {True, True}},
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLines->{None, None},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None, "TransparentPolygonMesh" -> 
                  True, "AxesInFront" -> True},
                PlotRange->{{-2, 2}, {-2, 2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.02], 
                   Scaled[0.02]}, {
                   Scaled[0.02], 
                   Scaled[0.02]}},
                Ticks->{Automatic, Automatic}], 87->
               GraphicsBox[{{GraphicsComplexBox[CompressedData["
1:eJx1W3l4jNcaT0PR1OAqeg0lUtKxqxrFxasdVEmZamttx+62otWiGE1RYbhu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                   "], {{
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[0.3], EdgeForm[None], 
                    GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxNmnf819MXx9/33qho2OmHEiU7WRlpKJRKlBKZ2Ssj/bIrCZVEoihpKTMZ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                    "]], PolygonBox[CompressedData["
1:eJwtl3nUjlUUxZ97blRSoSgkJM1RZilUiEaklEJmkiHRYEikyJg5Is2DlTSs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                    "]]}]}, {}, {}, {}, {}}, 
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwl1Gt013McwPFfzS05JyTroprIZUnJjG2ltDE2FUXUA06rB0mnmxJmumnJ
NdcuouuEVLJc2sY5uyRpq1TblGsRudQzl1C8PseD916fz/ds5//7/3+//84v
mjh0QoskSfL9mJGSJM+2TJLZbObnWqB0ey5P4Rw9Z97ENryMeezB69mTZ7IX
b+DlzGdvnsU+vJFX8CZeybN5FQuYwUK+oGbz8/xGN+tFveusLb/Vucq25yhL
g+1L4rrNi/mdvtfLet9ZKg+pgzbbX+UtWqYKe0ce1k9aqX3OVvBnrdIu+2re
rlPNp6mVzrP/qq760F7GozqiUvsAXaf+utPZQL7JQo5iAYviPfId7mY5xynV
3F4V5r3czCJO4ihO5mhW8R5O41jeq3FxvfrD2Z96RPfZS3ht3CtNtc9gN16g
LeZG1vHvuG+qs8/iV+of905bnG2LZ0WPqiGeDQ6Ie6qt9ga2ZAtlmj/lY5zO
7ro/rlfrNDCeAW0zf8Z5Otl8Dbfzmbh+XqqnzSVsYnl8ZrpET9kfZiM38m1d
rCftxdzLDVyvi/SE/SHu5pfcw8f1gHk+H+TVPImlfIu7uJY7mRL3Me6t+Q1e
qLnmHfrEnMGEffgx6/mvTsRnoS+cbefM+H012bfyHx2Pv1Gts178K75LqrHX
xvvUZHMxp/B1rdEx+2usZhlr+Lt+U7rSnHVVF02xj4nPgtWs5HjdFc8P7+Ym
DuEYDuJoDuZa5nEkczkiXlcfmdN4BlvrdN0Rz1u8JnO0X8NV5awzf4lnKD47
9dNt9r4cxuWqNHditm5VvX0of9QPWqqdzl6J72xcrz6I7w0P6KAW6T1n5zBL
L8V9si+M96XMeNbifqud/eu4L/Hcp/z/f/E/1YmlpA==
                    "]], LineBox[CompressedData["
1:eJwl0L0uQ3Ecx+E/nb1VSNAO9RIDl6AjZdPWRmkkTJyavN0Aqlo34H1AwshG
ewticxMd6gI8J4ZPnu/vnKEnzWxWClFXCKGknkQIq90hzPNUJ5pzZ7Rgr7GP
/Xq1v/jCPLe4zG0W+MZvvnNXI/aoxjTt7mgmfufe5w4P+Kkf+4MRD+Pf570e
1HS3dKSK+5h7nOWvru0bXelOt0orpcj7MqeY1bA9pBUVNenZIJMaUNnd4KXq
ena3VbMvdK6qerXh+VP8bfYEl7jOHEtc5DibfORZ4v///gNfNSoF
                    "]], 
                    LineBox[{688, 913, 687, 914, 855, 856, 854, 858, 857, 695,
                     921, 696, 922, 623, 753, 552, 870, 627, 869, 628, 871, 
                    553, 754, 923, 924, 861, 617, 859, 616, 860, 920, 919, 
                    752, 918, 689, 917, 916, 788, 615, 853, 686, 732, 731, 
                    915, 688}]}}], {}}, {
                  InsetBox["\<\"\[Mu] = \"\>", {-1.8, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["0.2`", {-1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {InsetBox[
                   SubscriptBox["C", "J"], {1.4, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["\<\"=\"\>", {1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["4.14`", {1.7, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {
                  {PointSize[0.05], PointBox[{-0.2, 0}]}, 
                  {PointSize[0.0125], PointBox[{0.8, 0}]}}, 
                 {PointSize[0.007], PointBox[{0.4463998339305619, 0}], 
                  PointBox[{1.2771956561278897`, 0}], 
                  PointBox[{-1.0806611991222994`, 0}], 
                  PointBox[
                   NCache[{0.3, Rational[1, 2] 3^Rational[1, 2]}, {0.3, 
                    0.8660254037844386}]], 
                  PointBox[
                   NCache[{0.3, Rational[-1, 2] 3^Rational[1, 2]}, {
                    0.3, -0.8660254037844386}]]}},
                AspectRatio->1,
                Axes->{False, False},
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                Frame->{{True, True}, {True, True}},
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLines->{None, None},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None, "TransparentPolygonMesh" -> 
                  True, "AxesInFront" -> True},
                PlotRange->{{-2, 2}, {-2, 2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.02], 
                   Scaled[0.02]}, {
                   Scaled[0.02], 
                   Scaled[0.02]}},
                Ticks->{Automatic, Automatic}], 88->
               GraphicsBox[{{GraphicsComplexBox[CompressedData["
1:eJx1W3tYlNXWVys/UzEyNZtT3g9OlEraWIm61CnqUOlkph7zTGJq6Ch18NZ4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                   "], {{
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[0.3], EdgeForm[None], 
                    GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxNmnnc11MWx7/3XkJFyRIVsoUWEcpeKSURSqYslZSEMlmLqBAqsrdIIgrJ
LkWWGOvQYOw1RrJvYxmNyTLmvH0+zyt/nOec713Pvffccz73/J6tB57Wc3iu
qqrRWlVVgndPVfVM8KeDpoc8LegvIf8rqb5O0LchfxO0R9D68R1dq7WD6lZq
w3eboG2DtgtaFu3eDWoX1Czo1yh7LujxoPis1guaGsK6wTcK2riSTHlDz8nY
20Wbn4M/FbR5pbk3CNrM9Xx/Em2eCnoyqJHr6wVtGlTbY20VtGFQg6Abot2W
wVsG7eBx6beN9dgkaOs/6LWdx2ro9W3i71oxzlvBDw/a3vXodWOUzwj6a8hN
PSdj7eh5GgftZN4kqFUlfdCxmcdAp9bujy47u57vF7wW+uzienRfJ+Z8O/gR
1nE9r383rwEd9/N8jNfOOqFLW+8F3y8HtQjaO+izGPNZ7CFod4+Bjvu4DXvY
1WPtGbSH6xlrf8/DOm5O0rV90AG2FfTa12OgU+dKczBGJ9fz3cX6MceBrud7
V6+bM+lufdFrVsx1U9Ar3ovO7pei7FXrdajnZj/esE49gkq0eT14x6CLQ943
6LCQv0vSCflzyoJ6BB3iORmrp+dB317m7M3MaHdw8KNsK52sUx/rzRh/qtSG
772S1sL3CyE/n6TvrUn7hm7veL5jg6YHTQyaFNQv2rQPOibkN4N6B/Vn/Cg7
KujIkI+3Lsz5Y5I8IOi9oBODTg8a6Hp0PMPlQ4KO87ys713PX1N3rOvnJo13
ctAxIR8d1DfkUz03Y5/iOfmeGPUdgwaH/BL3JuiEkN8OfnvQspAHBx8UdFLI
HwedHTQ+aKTHYuxR5sOCzvH81LWKfhsE/TPkMUHDg04Let/yBUH3Rf2s4FfT
L+ShQWdyTknjMN/64TRHBB8XdJH3ib35KWm+S4LqRZsNgkrQZdYPvS61Tnxf
WGkc+k9w/blB0/zNWQ6IMfsH9Qv5o+AfBnUNut7zMN5VQWOtz5VeG9/XeI6L
vJ5x/l47a61XYD8x1vygTyqt+yq3nez9YKwpnod1TDVHvxtsa5cH3ZWkz3VB
N3psxpjher5vsn7MMdP1fP8n+q4KWhr0uce4Jei3+H4o6MuQ7/RYjH2bdUKX
Kku+FXvz3nEP5rie73WiTa2gV7Aj16P7fOvEun/1ns4Omud50PEuc9o9mDTP
PUF3eAx0us86Mee91oXv15LsiXO43/XoeESSz+oQ9IDL0OtBc8b+Ougr67jY
7ah/PfouStJrk+D/sj6PWA/m+cZ6LAwanlS+qFLsIUY0DXrUbRmXmE88Ju42
jvb/dn3DkL8NviDodM4i+GNBTUL+wXr9N2hJpbj/n6AndCTVj0FPVsIEjaL9
99YR3EA8IvYTt4lxxMt2xhNgCeqJWxt73PXdFhxB/Ceug03ADcRUcMGzlWL9
85Uwy4aem351vLaNvQfgFzBNbY+9ufWoY11q8MKm1oP5Grkd4xJ/ibk1OIN5
wR3gmsberzttRw283/TZO8mnd/M8xFDiMRgBLNLCc1K2rXVq5nY1WGFH67GD
6xq5bAfrSj9i4Ytu38TtiJW7+/yJv62tE3G5BnfAW7r/rm63vfvt5rHbuG47
l7Xxvm7jsdGjreejnhhHTP1bJTyxVyX7b+/xwRQvVcIMrJ8Yurf1Ij7vZ532
dV0rl/ENFmnndYIr9ve62I921gPdO1uPNtaFuEkM7eC1oOuBbre0Uqze0/27
uK6dy7tYP+LzwdaDmEzsxv8Ti4gRYIJe7gNm6OG5mydhizc8H7ikBgvAwRXE
mXM8DnP3dDviNnGVcV/1vOwFGAds0ds6Ea+J5S8m4Ya/V2uwCGONT8I0YNb9
jG2Odh3jE79bJOFI8AW4o4/XyLjE6gGV4vU/KsVQyoi5xNkOxh6DKsV84jz9
iWND/jAHMpgBv4LP484Q58ENQ9kv44HhXtNAzwMuONXf4ITllWL9+iGvCP5n
63eK95I5iM/E2Q8q4RviLpgHTMS+gSnOsE7drS9zHpgU+8/yeCN9NuCIlZXi
NeMSY4mtYItR1uejStji/EpYANwwttJ6iKvEV/DBGO9hDXYZaf0Yj5hNzCd2
TfLcxGJibesoq5eEg8ApF3md9L/M7VYZL0z02BNcR6ydYP2JjWCCy60XMZnY
zHzEuOnVmtg/xXoR02owBZyYDo4AB1wb8qdug0772Ha6W2/iLDF+rPtdaV2n
uA69pnk+dJphPSZaF+rAEze6jv7E55keb5a//54Ugz/zXk+u1uCSme7ftJLP
wN+AAW6xbn2SsPKR1oPYfVu1BhPMs76U3Wqd5rodOmHLd1jf2113g8v4Jo4Q
pxpYj3nuU4MDiMtgHzDH3SF/UQkL1KxtvvVgbmL9PZ6Dfvdbr/tcN8dlfLeJ
8TY2pkKXhzwf8REMQOzdLQlbgCOI/4+53RtJ+ANcAq5Y6PGZEyzwqOcgzi/y
nI/WfCfFRdYJlljseVnzAo+/bhZ+IG5vAya0TsOSsMh3rgNXgAuIy+CBev5e
Ugk//OTyWpV8KPeD+/t4Um6DtX6ZdD+5m1sk4QbOZHlSnMLHE3OJ6cTQxUnv
beLkb5Xe9MSr/1WKtbT5NNo8k/T9cfAlSbhkx6Q+jEsMwPcTg4hX+HF8+PnR
ZnRS/KnMiUFbhpyT2s0JflvSu/QWbNtjZPt44gHre8ZrXMtxhtizc8h1k/wR
fh6/TkzBz+APT/c3eQPi0Lr2/fjp2nEua2X5+tpJ7z186lUhd/K49CGeEL9a
JrVj3PWS3p/42TpZ83MX8UX4SvxPnSQZn1k/y4eP8Bm9GvRhpbIPXP5FlP3N
/nftpPc9Pry+fSExGPve2Pd5Q/sA/NGuSdia+7NVUh2+6t7g9yS9P/7n+0Hf
Bi5Dvj/pHs6yXa7SUf0+FneC+4hdg42xe+ya+4Ntc0+4T9zThdHp4STsvnXw
zZLa0QfszX15xPa+wN/gZ+7Upr6X3L2RSZg7246wA2xgSdDqSndh26T7wF3g
3oDXuSvcD3BzPe/TLt6rHZJsGnvG3n+pdC+4l2B67h92jD1j/2OTbDTZ1sA2
2Da2SRn2Cb5jo7Dn3kl22cM2CMbA7t70Wfa2DdayTd3p8yGOXJaES7BNcgLr
OX5jU9ggcfVTnzdnvdy2Ncw2DD4AG1ybFDvr2+6I5dghtkM8xVe8Z1vHzt9x
2/E+h82TzuL64NfZV2IXGyXZAnvZwPvJWVF/j22Bs8afTkk6+xq/1tD+kbvF
+o61LfB2esT7t5P9QvKec+b4re2TYglnhS/jvLDxpvbV5ybZQS3Ps7XtDT+B
n8WWz0x612G/2Av51qdsy7wJsU3OrbnPGTyPX8MWfrXdNLHuLew78K872+dw
d1vaJ3Amrbz39X0WH3v/dvUevhzntazINtsmvRu5awdjR0m2zV7u7v0kbtGG
dxv17dymm/vT91vL3Bd8LRgdfM4bkPbEk38nYWLsc5+kNxvvtX8kxQbeb8us
Qy2X//6uC3l/9z3a43yfhK3fMycX95XHAKf/03VgZbANOA3MhR2De8GEXZIw
KDa5gr1MqsPvHmCbXxn8gyScusLlg3wnOrkNc3WwboxFW2Lj+56fnNupwQ8K
Oq8S72p5pXUAk3/kNqPtPw5JinFnJ+01+7za58T+Xx38lKQcGvt0qPeKspNd
zhuMNyHvQfAW7xzeKuRWD08q65nUpoPlXklvSMp6Wj7SMm0428PclzPp7TM9
NikXSR7yoiScVzMneI8823H+Rqasr+Wj3ZecZF9/804YaJnyXp6bMWl7nMsn
Bz8xKW/JO2iAZfD6IO/DENdRfrzbMC/neYLPdEJSHeXUD3T7fu6L7id5TMbj
bPv5fMmdDvFc6DI4rWk72OWc80k+66E+o4sr1fGNvvjkoS4H74EFiW+nJcn4
xq+TbJ136Vn0S7qntPlzUvwakfRNe2IkuBBMiH8d4fIfkrDRQZXGON3jUHaB
y4d7nIVugy9bbN92TlKcHpXkB2t5njPcZql9QVf7s/OSYtsYz7vUOpDrpx33
fpTHwR+PcZtJwS9PwkjY7EW2Ae49b23uPjZ4YZIfBStRDl66NOlNXlM23u2J
9WBxYghv7UkeHx88LinWYpsTbA/UT/RZ42uvSIphjHeJx8QfX5nkG7CdybaB
ju6Lz8FGrrY94C/BGdk+4Zqku09MI/aBYXjDkIsjtwYuJp8FNngzCXNTR3wi
Z0fbt5LwNDkv2lC+juunWwbzEyMbeizakgcC95Lr4b6DFbCvozwnv7dt4fFn
WAYbkh+hLf6Fvq1tn5R3c/0sy9Qzx/6ea3YSlsHesXtwyB1JeQruCHkkMDk+
B853R8tzXP66vynnPMEN7N/qoP8m5TvaeCx84QcuI3ex2nOBc+ZZB+4dZeix
zPeROrAPGJY3OG/Yu5Pe5LzHOUBy27/nuL1G9vCX4D+7zy9uD86B05/fBai7
x+PgS4lt2DUYnNw9uQTuCveEO/K5Ze4mZ/Oj95+1Ig/wmMxLPoCcBrmzs91m
tdf7o/env9e72vtCv5/c9yd/ozPxinwHMWuu+zLXKutJ+ffWv4fX+IvXzr3i
jYP98+ZOWW9r3gLkBdg7yiqX1816z5A3qef3EdiS/Elxnudnjz/e+/6rz4V3
fc6aZy3/RnSax88+p6Vey8RqDYYgdhNDwRxgiOU1cqW3yQNJOBTO982Vfn9A
5s3yaNK74uGQn0vKvTZ33/vcnncJeoFXr3H/q13Ou4VcxCKPA15dkLQeytE9
eV3Yy722mceS7jv38emkXHn9Spxv3thPupw3N3iCtzNvkyeSfAg+Ac73065/
0m2mug1vXuZhvhe835zfLfYf1PF+5/8EllgH3uvkkckhv+hvZH7vfsb7Q+6X
NrxfWDf7CGZvZL0bu3yR97byPsy2/fA7Fu/JXcCzWW8w1gxuBjOfE+XNisZs
HfVnFr1hzg5+VpEv/Nx3G/vhTczbmNwFdkCc7WbdP/N6DvM95A7W3ElwCXf2
C98F8Dnj8L4+LeY5LwsDzvSYYNTR2HVRmzEhn17kE8YEvyYL910Rcv0iP3lt
lC3PirmnRNkdRf6qZZQNL3prTWZ9RX7xquBXF8Wzy4NPKnpTjov22xa9288N
eUnWe/8C2mdhinEhX1gU4ycG379ovZdF/WtZsYl1fJ3W+PmvvT5+A+I9UBPX
wLX4D/Ks5FtH28Y+/oOtfmL5Q7cfbV8NPh5q/0MdGP5Al4Ozp9gmrvfdxx5m
+17jj2r+rwC5h33Udy6nP3MQC8CB4HtiNbgOn0BMh4Pv8Q97eG28g9bLyqnx
WxfyN15vW6+dtp08N3kp+tCW38F+891Bz2dtV829J5/47s21bqy9g3Vob/14
V4BD3rfOYNf2Lh9kW/3UYx4R57Z9lv532b/Msz95yDoMCvngIrzTMPjQrDwB
OfX6/j2eHPuGzrNjj8dl2SS2dnyWvR0dvEMRRqvv9vjtb7xHrJ88QW3nu9g/
ytm3k+LP4UWYfkWl/vQdW2T3q7x/9CFP8mr8uTnrXf5CyC9lvXF51y7Netti
49vZzidF2agifDwh5HWK3rfLg7+VhYsbhdy4KLfRPzj/wAUGOCnk5lnv7Lkh
316E1Z7OusPcX+7uBVn3d0TIrbJ8wJ0hP5OV++C3AH4vx7fwbq9j+QnvRbb/
oQ135dksv8CYZwYfVIQfh4XcrwhjnsgddV5vcfCbirDy48Q9679rlB2clbva
KeQrs3IPO4R8RVbeZfuiu8293jHkyVk5khYhd3HueGd8QFaua0Tw44veTmeF
PLjobYM/O997MqzIv6y0/dTzmRKTN3AcX8vlxfGePbnA5bXdfkO3R76Yc8iK
xWNto+Pcpr7ts13M2yMr1j1Cv6wz7Rt836J38u0h/ykrf8a51P3D/HV9LuwF
sZl4PTErlhBHauFfs94Q5Db47Zz8BvkW8lmc13zL4BPeNcvc9qlK7Xnj8PsJ
v6PcXAkLvGaZPCO/C/K7zstJv8PxziUPzW+O1PPNb3UDK/22hTzM9fw2yRua
/NHveRWP94LL37U+6ECej3zfMvsisAt7UoOByNUT86gjRoM/2JO77W/BKMRf
MALvDbAEWIB3AphkmsvBETNcDl7AD/F7BzGdPBoy/ul269PfZW+4zWfeL3BT
H6+nr9f9ktcOZ784673jjHpnvZmOCvnIord69+CDs3KitUOuU7TezYNvVuRr
FwW/PivX8lLIb2Tlwy4OeXzRG7Vv8JOzcoqLQ26UlS98LORbsvDHkfi0LLw0
PfihWfiqQbTZqOg834uyPlk5vyejbCvL/YN3KcrFgK/BFuAK4h++gd/uPrS/
GG3+imX8B9/YMP3Au+RgL43yS7LylytdRzljYfv8ftcx5jwm6213Vxb+wM+3
D75fEfbhftTyHXnFfo0x+G2RucDV7GVP7+fC4A2y8umcQx+fxb3sge/RMvYy
K096bpS/aZ98XshvZ+Vq98BHFtleR3xMVh52dJS9k5VL3Sf4tCw7XEE8yvot
Yt/gvbJsck/uelFO4/HgTbLy8ruFvInPfUbwz7MwySNRvmlW7rZZ8PZZcbZp
8P2y7lfdaLMlDjzmug0/mhV/vwo+y3Fqiyw9fn874/OKbHtVyDtlxcYmUbZj
Vh73geDvZ+XrHyzyy/jk+cHvKsq131/kx/Hh90bbA4py/VODP5SV/5hWFNeJ
6Quxw6J7vyDk6UW/E+DPOA/OYnbwW4tyGcSun7Li15tR9mJW/n1l8N2y88rY
e9Z75Dn2MsuPbRO8c9FvJ2DVn7Pw6l+y4iJjzgl+W9HvXb9E+byinHXDrLPk
HD8N/llWLv7b4N9l5YceDD6lKP/Cfs/1nvcMPifrzfF9Fn4Fu35J3Mj6X2nO
/GufO3fx/qz7WC/kDYry00dl+RF8CPHkRseUj4MfkpX3x0Zm2k6wzd2z7LMV
dzzrd50L8QHZv38Fb+P9Yc928b6xNzt7f1YHb5GVS8ZG2mXZSQL4FP3OzDn8
5rPAz91qX/dD8BuKficgvtW2f7sk+KVFObiuWbGcOM69bFl0N9G3dZHO3bJw
w5KQr+HOZeXW7gg+oSg/eEiRzWFvvYrsFVsdUGRn2BhvsjZF77IDs/AEWOIA
9qkoz9Uvyyey/8dm+SD8D/5y9yKfiU+aZ7/UNsr2KPqf+k25s0W/DzQP3jkr
V751yE2LcvxgwOezYsieIe9VlFu/MfiMot++8DdgQXzO0OCnFuVnwVBgQeIj
9g7WxObxE8QJfAX3GzzKHZ+d5VOwK+70kKJ7fUpWzCBenJ2F21aEfBxzZeWd
Twj5jKz88ayQby7KM16X5UM5o6lZ/ghfRNwgZhAv/pp1P7GHw7JiEvFoVBYO
W1nJvz5c5GPxqQ8U+dUTs+IiMbFb8BOy/0cj5Eez3hpgKPAxsXVBEY4EQ4L9
52fh/65RNiDrt4LDQh6S9ZvAtZxzUX62cVaMJD62zYqvxNaTg4/M+u0CX/5Q
kT//P8J55Xg=
                    "]], PolygonBox[CompressedData["
1:eJwll3f8j1UcxZ/7uaRFWgpZDZWQtGigkJEiTTP5EaEklFJCVLJDVCopKkXL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                    "]]}]}, {}, {}, {}, {}}, 
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwl1HdQ1nUcwPEf0LKy7ho21biyYWVSRASusAFWWmhTUk+huxbeJRUuFBRx
tcuGNrS0tMwmNEC9EzRCoIFg6669NLX+K+frc/7x9vX5fEWfx+f7e0wfP7Gw
NCVJkqF+mZmWJE+mJsm3ytEM+xPsyyt5BGfpKXMdj+MFvIrn82peyON5Ea9h
P+azP0/gxSxgBofxEp7ID/k0r1U382xVa5H9V12nZ/SRsx78Taco2365LtNw
+xJ1mRfzT72gdvuL3Ka/dJrqnS3ljVqmBvvp/FuFWq6tzl7lDq3QF/bXeIuO
NB+lo9XLvkv/aKXmOnud8/gv53OQBmugbnc2hG+xgBOYz2IOYy3v4L0s4n0c
w3pO4CSOZxmLuZZ3s5x3xZ/TPfEetDvuQI3mmfwhXjvuR2XOKnkmz9Imcwc3
cl/clTbFXfBH/RT3pU+dtbBaNZqjK/SzPlen329nWtwLN3M+H+LZelAP6G0N
dZ6lFnNHfGY6PO6UFXyc0/kYv9HXqrV/oPP0qH0at/J9vqdz9Yh9Krv4Lt/R
OXrYPoVb4jlnJxeq3LyAk5nNQ3mYvjKv4Zc8JO5MeebV7KO58VzoM/OlTGUm
m9nGFCbaHO+frZwVP68t9mbuV1V8rtroLIN74zujJntTfBd1v7mCk/im3tAe
+ypuiGePjfxf/8V3UunOzlDv+MztJfE5cAMbOFFjzaUcxzpezzvju8iS+O5x
DfNYFHfN0fG6Wm9O57E8Rt11m31AvC4H6nvdqnXxPrgznhlzjXJ1sz2HN/EV
rTX3jL9DI9VqH8UbtF0vxXPm7GV+pxH6xH4qf9cfel4fOzuJuXpWbfbn4t+n
THNW3JlOtv+iSnNV2sH/Bw8ACW2jdQ==
                    "]], LineBox[CompressedData["
1:eJwl0DsyQ2Ech+GPbIBEDIIZ11GwBYq4dEJ6cmmikUjpkhWQIGxA3ArM0FGR
LIHKOhRRes4o3nl+/5OZnEwmipVsuSeEsKW+GHtDSPNEx1p0T2rZ3macCb3Y
n3xmhiWuc4cbfOUX37inETulUc25u5pX2b3PXR7wQ9/2Oys8jN7PO92r7e7o
KPped41VLvBXLftaV7rVjcY1pqrPC5zlkobtIWW1qRnPBpnUgIruC16qqSf3
j87sc52qoX4VPH+Mfps9zTXmucIcVznFNh9Yj/3/33/gMSrC
                    "]], 
                    LineBox[{692, 917, 691, 918, 853, 854, 852, 856, 855, 698,
                     925, 699, 926, 626, 757, 553, 871, 630, 870, 631, 872, 
                    554, 758, 927, 928, 859, 619, 857, 618, 858, 924, 923, 
                    756, 922, 693, 921, 920, 791, 617, 851, 690, 735, 734, 
                    919, 692}]}}], {}}, {
                  InsetBox["\<\"\[Mu] = \"\>", {-1.8, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["0.2`", {-1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {InsetBox[
                   SubscriptBox["C", "J"], {1.4, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["\<\"=\"\>", {1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["4.13`", {1.7, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {
                  {PointSize[0.05], PointBox[{-0.2, 0}]}, 
                  {PointSize[0.0125], PointBox[{0.8, 0}]}}, 
                 {PointSize[0.007], PointBox[{0.4463998339305619, 0}], 
                  PointBox[{1.2771956561278897`, 0}], 
                  PointBox[{-1.0806611991222994`, 0}], 
                  PointBox[
                   NCache[{0.3, Rational[1, 2] 3^Rational[1, 2]}, {0.3, 
                    0.8660254037844386}]], 
                  PointBox[
                   NCache[{0.3, Rational[-1, 2] 3^Rational[1, 2]}, {
                    0.3, -0.8660254037844386}]]}},
                AspectRatio->1,
                Axes->{False, False},
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                Frame->{{True, True}, {True, True}},
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLines->{None, None},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None, "TransparentPolygonMesh" -> 
                  True, "AxesInFront" -> True},
                PlotRange->{{-2, 2}, {-2, 2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.02], 
                   Scaled[0.02]}, {
                   Scaled[0.02], 
                   Scaled[0.02]}},
                Ticks->{Automatic, Automatic}], 89->
               GraphicsBox[{{GraphicsComplexBox[CompressedData["
1:eJx1W3l4zNf6j91PTSlpMVwaVMfaWAYl9appLdXqVN1S1SklqFgqaommQVyj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                   "], {{
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[0.3], EdgeForm[None], 
                    GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxNm3n8l9MSx59zDqWSLZIWqSRLRAolbbJda9kKJWVJQpE9LZZQkiVSSUQh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                    "]], PolygonBox[CompressedData["
1:eJwll3cYz1UYxb/3XmW01BNpKCpKVmhJMirhicysqJBRZtlKZZORFUJIEaHs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                    "]]}]}, {}, {}, {}, {}}, 
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwl1HdUlmUYwOEX+K9sa9uENK0sG6dsGDJECiQjUAs0Kho2IQ/jZJ7SHCgu
KgXKdlmaLVOz4WhHpRimRYUMY7XzaEMrx/Uc//hx3ffDOR/v+73fR0JhcU5R
TBRFaX5UxUXR4tgo+lWZmm9/nkM4iifwEb1g/oLxTORoXsYxHMoEJvMaJvFa
pvBUDmMeU5nPNPblBr7IsTrRvEALtcRezX+4W0u10d6PezRAGfZMXaEC+6vh
Hsyv8D+9pi7769yr/3WmGpy9wRu1QpvtA7lPhXpTvzlbxf1arW77Wxyvk8wn
q7fOtscwVu+YH+XbfIxxWqSrlK2RusPvruZ65rOEeSwN7wHrWMT7eTcfYDHr
WcrpLOEMlrGBE1nJezlJ92mNeijR+fd8mDuVHZ6VpoVnygt4ob4z/8xveQRT
2cJq7tKf4Rmq1dk21oR7DPcb7kd/abt+8fs2HsPL2c7HWcGLwnWHe9BHynWe
rh/MnTyexynDPI/PcS6fDa8brk+f2z/TpXrGPoc/sY6f6hI9bZ/NH/kJP9bF
espeyS7uYDef1EzzE5wVPkvsxWPVYf6Q7ezJD5Rjfp+Dw7MN1x7u2zycRzON
bWxlrY4yN/MPtnChjjSnsJlNXBCekbbZk3k4k9jERj6kB81VnMr3wudHh2md
vna+lt/wUB4S3h/z+TxP56rCXh6um43cxCm6xzyZE8L7ygKWcxzLeF34e8zl
XczhnXxXW8NrM559dIput1/Jc4LhvnWbtjgbxIg1qlWWbnU2grdwpb4yn8Us
3aQO+828Qcv1pf0M/h6+o7pem5ydzn/D9epl1Ts7Lby2XlKnfVm4Lw0Pn02l
q7/97/Aeh+9I3MH/hQcAAx6tTQ==
                    "]], LineBox[CompressedData["
1:eJwl0DlOQmEYhtFfoJBl4CwOiaKh0DVgYlRsjAq1oDRaiKil0wbA2SXgjImU
2jmuQRrX4Eksnpz3u/dWN5ErThfaQggLSkRDWImEMMOaqsq4RzRrF9jJLjXt
Hz5zietc5AaX+cIWX7mjpD2gQaXd7ZxgmXvc5D7f9Wu/cYsHTPFeD/pwf+pQ
FfcRtznJOK91o7rudKthDWnXNyWOc0r9dp/yymnMs172qFsl9yWvdKEnd4xn
OtepTtShNe8a+rZTnOcq51hklqP84iOPo///+w9URy3e
                    "]], 
                    LineBox[{709, 935, 708, 936, 870, 871, 869, 873, 872, 715,
                     944, 716, 945, 643, 774, 568, 984, 719, 647, 815, 887, 
                    648, 985, 569, 775, 946, 947, 876, 636, 874, 635, 875, 
                    943, 942, 773, 939, 710, 938, 941, 940, 634, 868, 633, 
                    934, 707, 933, 706, 753, 752, 937, 709}]}}], {}}, {
                  InsetBox["\<\"\[Mu] = \"\>", {-1.8, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["0.2`", {-1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {InsetBox[
                   SubscriptBox["C", "J"], {1.4, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["\<\"=\"\>", {1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["4.12`", {1.7, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {
                  {PointSize[0.05], PointBox[{-0.2, 0}]}, 
                  {PointSize[0.0125], PointBox[{0.8, 0}]}}, 
                 {PointSize[0.007], PointBox[{0.4463998339305619, 0}], 
                  PointBox[{1.2771956561278897`, 0}], 
                  PointBox[{-1.0806611991222994`, 0}], 
                  PointBox[
                   NCache[{0.3, Rational[1, 2] 3^Rational[1, 2]}, {0.3, 
                    0.8660254037844386}]], 
                  PointBox[
                   NCache[{0.3, Rational[-1, 2] 3^Rational[1, 2]}, {
                    0.3, -0.8660254037844386}]]}},
                AspectRatio->1,
                Axes->{False, False},
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                Frame->{{True, True}, {True, True}},
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLines->{None, None},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None, "TransparentPolygonMesh" -> 
                  True, "AxesInFront" -> True},
                PlotRange->{{-2, 2}, {-2, 2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.02], 
                   Scaled[0.02]}, {
                   Scaled[0.02], 
                   Scaled[0.02]}},
                Ticks->{Automatic, Automatic}], 90->
               GraphicsBox[{{GraphicsComplexBox[CompressedData["
1:eJx1W3lY1NXXN61UcqxMzUZ+LqU0aq45pmYekzKjtNHXLbUxM9ym0FzSMcPl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                   "], {{
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[0.3], EdgeForm[None], 
                    GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxNmnn8z1UWxj/33mxRpAWlorRoTCK0izRopb1UkhaSVu3LoFJKkkJoo4Wi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                    "]], PolygonBox[CompressedData["
1:eJwtl3m8TlUUhs/eW6k0KUUzSUlRlBIZoxDFFQqRIWRWpHIbTYkGpEhFkczS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                    "]]}]}, {}, {}, {}, {}}, 
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwl1GWQFVQYgOFLiqQIUjOSAhKDdNeuLCHp7tIgIelI84sOpdSlEaRBke6S
RkqFgRl6F1hYOmZoaWZ4zvDj3ef7zt6te8/dQl37xfZNFYlEonyYkCYSWZw6
ErmrGI23L2QlNmMOTtIS80F+yipszspswarMz+r8mtUYyxoswFqMY03GszYL
8hCXsqVymn/Sz/rd/guf8Kn+0GF7If6vzxRt/1JRamtfqVvmFXymVbpsX812
eq5i+tfZWn6jF1qnK87Ws5M26bZ9I19qs1LsW9hNn5hzKbc+t7/WG23TFGdb
OZVvOY0N1UgN1NPZV9zFOPZnLAcwnofYk0PYg0PZi0fZh6P5PcewL49zIMdx
AAdrkDYpvao6P8kE3leT8NpomLPJLMMvdM58nWf5IWvxLKfygS7ohj2JmTiN
MzVDj/QwPNe66XPJzMLo8HX8lSNZTiM0XLvV1HmUkszX+DGzq555HBfwR87n
nfCa6ID9b1XUPPsPvMX93KcKmmsfy5vcyz0qr9/sY3g93HXe4ByNMs/m6HCf
mI0f6ap5F1OYlTu0U39pu8pqVrg7SjTXZWbW4Xle4nRd1Dl7bWZkTZ5hYrgv
4bE6ba/BDKzOUzwT3gMaEt4THMpt4X7pg3AfdSrcT55mOqZVJXNpllJJjbX3
C88/T/AYh6u3eRi/42G2DncnvBc5kK3C6xTuDHuzMXtxu46F7898zKs86mGv
H34mG+meuuuosxJ8pYRw7xSjb+312JUb9J+5OBuqsy7Zu7Cj1ugfe1E2UPvw
vNo7sI2W64i9cPgdtEzJ9j/D36E65tasyyJ8rInmRanf//97Bw0zqRc=
                    "]], LineBox[CompressedData["
1:eJwl0LkyQ2EcxuFPzmVYY00hGAX3IJMIFUKjlEiaxNJQ2soQgkuwRYcZShoi
LkEqN2E8M4rfPO//m1Od+GppvtgRQlhRZxTCWiyENI9V1Yx7VBk7z2726MX+
5jMXWeYCK1ziK9t8444G7SENa9Id4xQ3uMcK9/mpH7vJTR4wyYbu1XJ/6VBb
7iNuc5oRr3WjK93pVgmNaNc3eU4wpQG7X8vKadxbnH3qVcl9wUud68n9qzO7
rlPV1KWi90d92GOc4zpnWWCWSb7zgSfR///+AzrJLN8=
                    "]], 
                    LineBox[{707, 927, 706, 928, 863, 864, 862, 866, 865, 713,
                     936, 714, 937, 640, 768, 563, 976, 717, 644, 809, 880, 
                    645, 977, 564, 769, 938, 939, 869, 633, 867, 632, 868, 
                    935, 934, 767, 931, 708, 930, 933, 932, 631, 861, 630, 
                    926, 705, 925, 704, 749, 748, 929, 707}]}}], {}}, {
                  InsetBox["\<\"\[Mu] = \"\>", {-1.8, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["0.2`", {-1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {InsetBox[
                   SubscriptBox["C", "J"], {1.4, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["\<\"=\"\>", {1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["4.11`", {1.7, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {
                  {PointSize[0.05], PointBox[{-0.2, 0}]}, 
                  {PointSize[0.0125], PointBox[{0.8, 0}]}}, 
                 {PointSize[0.007], PointBox[{0.4463998339305619, 0}], 
                  PointBox[{1.2771956561278897`, 0}], 
                  PointBox[{-1.0806611991222994`, 0}], 
                  PointBox[
                   NCache[{0.3, Rational[1, 2] 3^Rational[1, 2]}, {0.3, 
                    0.8660254037844386}]], 
                  PointBox[
                   NCache[{0.3, Rational[-1, 2] 3^Rational[1, 2]}, {
                    0.3, -0.8660254037844386}]]}},
                AspectRatio->1,
                Axes->{False, False},
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                Frame->{{True, True}, {True, True}},
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLines->{None, None},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None, "TransparentPolygonMesh" -> 
                  True, "AxesInFront" -> True},
                PlotRange->{{-2, 2}, {-2, 2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.02], 
                   Scaled[0.02]}, {
                   Scaled[0.02], 
                   Scaled[0.02]}},
                Ticks->{Automatic, Automatic}], 91->
               GraphicsBox[{{GraphicsComplexBox[CompressedData["
1:eJx1W3lYlNUap1RyYUqJSud6STNt0lTyipbbm2JmhDoXTc1sVFyuMpZed4hw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                   "], {{
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[0.3], EdgeForm[None], 
                    GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxNmnf819MXx9/3XjRINESRlCgklFW0ZJORkVGSkZK9ZWRkZ6ZSFKkIlVJJ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                    "]], PolygonBox[CompressedData["
1:eJwtl3f4T1Ucx+85B6VdaD30JA1ZDUWKJOsXZW+VEpKZUTKyskcSLWVGyEwi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                    "]]}]}, {}, {}, {}, {}}, 
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwl1HlMl3UcwPFf+Eealkdl1pabWwdlGbOyIiEgskIOs1IBLbUsFQJsZdrW
iQYUVhJ20GFpp2dpWXl1W6lprXUBgkEBEda67+z1WX+8eX0+z2+DfZ/n+TFs
evn4sgMSiUSmH7W9EomnkxKJ75Wru+xP8gxO4GDerWfMO3gMz+JEnslJTOWx
HM1Cns0ipvE4nsNipnMyM3g8d/JZTtER5nt0r56zL+av/E0r9IE9mb9ruLLt
5+lcTbOv1XfmNfxDz6vD/gKn68U4o309/9RL6rRv4FWqN7/KOr7C+/gXl/B+
XagS+wUs5UZ9ZB7Bf7Vfm/WQa5vYwIQeVr4KlKdyn43j65zEGziR81jIHSzl
bSzh7byGH7OCVSxnNefwE17PWl4Xv09ztVG9le76Z6znj7oknoc+d60pzqdb
4oy8lVu1Rf3i3rrWzAf5k/aqx97KQziGrWzgz/pK++ztHBD3jG18hJU8Nc4T
Z9PbujTup740d/FwHqax5ju5nDVcFs82fre229/XKD1hr2YP3+O7Ol2P26v4
LbfxHZ2mpfY7+A1/YDcf0wLzo1zIHA7ioeo0v8UODuQbejOenV7TyHi+Pvs6
7o35fPaP95ItbIv3Ic6nPfZsHswsNrGFD8RnarRnsi8z+AWb4z3UTeY63szN
8X6pjw5So+ufMo0HMpUXK8V8imrM18b9YnJ87+I7qcr4TqnbvJOTeSOLOJ/F
cV52xZk5lEerwnwRU3gUj9QQ5cZzi78Z73e8s8qxl/Ef/R1njXcp7pNm28dw
Fl/Wh+aTWaCr412yz+QMrdNu+0nM1xVqt1/JqVqtXfYTmKeV8Uzsq3iZMs2X
M4sn8hctMj+V9P//v/8AegOtWQ==
                    "]], LineBox[CompressedData["
1:eJwl0DlOQlEUgOGLRDchieJQOBUOxEI3IQ7dw2EBEJyCQImlA70KTitwwkIt
pNZEE4clGBuW4Ecs/nzn3PeSl3eTa7l0NhZCiNQdDyHfEUKaxzrSnH1c8+Z1
9rBXTfMPn5lhiRHLXOYLf/nKiobMwxrRtL2TM9zhHgvc56da5g8WedD+Phu6
15f9W4cq2assc5ZdvNaNrnSnW41pVLveyTLV/kcNmge0qhVNOetnn5Latl/w
Uud6ssd4qjPVVVNCW5496t08ySVucoEbXOQE3/jAk/j/ff8BYSct2w==
                    "]], 
                    LineBox[{712, 936, 711, 937, 868, 869, 867, 871, 870, 720,
                     944, 721, 945, 646, 771, 568, 980, 724, 650, 814, 883, 
                    651, 981, 569, 772, 946, 722, 874, 640, 872, 639, 873, 
                    714, 943, 770, 940, 713, 939, 942, 941, 638, 866, 637, 
                    935, 710, 934, 709, 753, 752, 938, 712}]}}], {}}, {
                  InsetBox["\<\"\[Mu] = \"\>", {-1.8, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["0.2`", {-1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {InsetBox[
                   SubscriptBox["C", "J"], {1.4, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["\<\"=\"\>", {1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["4.1`", {1.7, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {
                  {PointSize[0.05], PointBox[{-0.2, 0}]}, 
                  {PointSize[0.0125], PointBox[{0.8, 0}]}}, 
                 {PointSize[0.007], PointBox[{0.4463998339305619, 0}], 
                  PointBox[{1.2771956561278897`, 0}], 
                  PointBox[{-1.0806611991222994`, 0}], 
                  PointBox[
                   NCache[{0.3, Rational[1, 2] 3^Rational[1, 2]}, {0.3, 
                    0.8660254037844386}]], 
                  PointBox[
                   NCache[{0.3, Rational[-1, 2] 3^Rational[1, 2]}, {
                    0.3, -0.8660254037844386}]]}},
                AspectRatio->1,
                Axes->{False, False},
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                Frame->{{True, True}, {True, True}},
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLines->{None, None},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None, "TransparentPolygonMesh" -> 
                  True, "AxesInFront" -> True},
                PlotRange->{{-2, 2}, {-2, 2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.02], 
                   Scaled[0.02]}, {
                   Scaled[0.02], 
                   Scaled[0.02]}},
                Ticks->{Automatic, Automatic}], 92->
               GraphicsBox[{{GraphicsComplexBox[CompressedData["
1:eJx1W3l8zFf3ThUtr7Fv71iKqk4Xoa1RVXW006JKDLWUMrULo63G1kmJ2Iam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                   "], {{
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[0.3], EdgeForm[None], 
                    GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxNmnn8l1MWx597r1KjskZlKbJnspTKllKWoYylUJYQCmEQ2VWWGFkikpRk
qSmikrKXtez7GpJlbDFj32fO+/f5fF8/f5zXOd+7nuc+557POef5rn/kSfud
mKuq6rJCVZXgDwWloMZB34bwTVDLoP8m9a8UND7k64MeC3lc8EbBVw9aEvI7
QWsHrRz0n2hbGNSk0tzYompq3iBojUpz2aul+5oFrRn0F++1ljlr3BhrTgh6
KuTmnse4Vp63ctDn6BW0MKiF57HuDfF7teCtg9pUktF5fXN0aet12X9Dc/bf
wP30beQ21u4UtEnQpib0WDtoY/fzTF+ib9ATQesGrRdtWwT9tZKMPltaJ3TZ
ypw92/9J363dho4drB+6bOv90GMb99PX0f21vpbWr7N13Sxo/6DdgnbnWcMI
VgpazJlm6bhD0J5Je3cLmpy0R/egrtYP3Scm6b1z0I5/er6dzBm3i/Xr4P3Q
o0tQT+vKc+xqzrn28v6s18PzGNcm9toevYL2qiTv4Ofo5HV7ex77fxv0jPX9
Puh56/9d0rp/D9rHe6DLC9Z176ADk3TaN2h5yN2DugV9FbRH0O5B+1lv9m+b
pNcBzP2TjgeZ80yjYszGSfv+FPSS93862hYn6X5Z8P5BP4d8aKU9eFcvBvUN
GhD0stsPYT7rBfUJ+YGg2UFzgn5M0uXwoCOtE7r0ifb9g/qFfHDwzYIODnlI
0BEe+4rXPgYdov+QoMNCbo5zCHoj2CCPQcfjvQ/zn4v+Z4MGhjws6Dj3n+r1
mDcw+o8MGhzy5cHbBx0d8usec0rQGZ6HXmean4AtJK15elC7pH35/a+guUH3
BL0ZdGLQeUG/xZhfseOgX5LWHhl0ifdg7Qu8Jzq+67UvCjrf65zEHjH32KCh
IV/qeWcFlbgvOeiF6LvSc4YHrR1trYKaBq0atErQS/jGLL0uD/okfn8ctG3Q
FdaX+VdbR/QaEzTCv6/y2iN81jVb6xzzLw4+NujuoFuDbgsa5+dE3+vN/xk0
sdJ+6DvJnLUnBI22bjeaM268510WdIM5427yvDHe8zrv+VboMz3ofd5L8GuD
Twma6rVY48RoPyHpWWu6ouPt5oxbMWvNW4Kmed4Ev+sJ1nG6Oc/0Sqw3J0mv
t4PPCvog5Bnu51nvTlpvpvUd5TOaZT3Y/y7vyTPNdhu6zzGfZjubZl1eizXn
J+1Tgn/o9ee6Hx0/8rrzgu7ze2LPFbJ04IxOTmqfH3S/+2dbR+4S9npa0t4P
Bi2pZOvnBjWO9k897y8hf1bJH4DfYCVX9xtjObi5PGhBJTx+vBL2g8dfBD0c
RFzwZdAjlfAbAk/BY/B/nDEVvAdjwXTwH8wHj9kDDG1e1WN/E+8BnoK7jd3P
b+KFJyrheA371/ScFv7NGi39G4xv5fFg/pOV8Je9W3kc8cINxt02lfCqvfcD
T8Ha1dzX2rq0dV8tDmjrvTfyb9YFUzf2Ppv6dwu3MQ6839T6rGfsb+c92B9c
JC5YVAmL13PbFlV9XNKmqo8J0BscAx92sk7g6dbWqYN/g0+dvSZ4DpZvb/3A
x22tb2f/RteOnr+x+ztaDzAUbAX3u3kvdO9qHcD9rtaNOeBnj6oe+3e0TuBp
d+/Rw7+JK3b2s9Wwv6d12s2/0XF3/14/Cfv/Vul5wFPw9WmP6WJde7lvA+vL
+qslYf8L1qm3xxED7G190AscBpfB/X2sD3uDvWAteL+/99vVbcQGGyZhf9+q
Hu/xyc8k4fpz1pU2/DU4f5B1aID/r+QnGoX870q+YXXjfw3nwViwFpw/1Dpt
buw+yn3g6jHeBwwHH8D5I60T8QCxQ1/rQf/hlbB9kPcAu1+thLP0gb/HeewQ
/36rEk6fjJ0kYfCx2IFxHLwE01+rhJvEAkOsE/qBsWAt+H+q9e6YhOuneQ/8
3LCqHvvPsB60gc1vuB09wU9wFUxib/ATHMXhvV0Jo8Hg860PmEwsMLxSXEBM
AJ6C7RdYv9+T8P9060r7SO+PL77Y+4OnYAf4D4b/07pe4nHEBJdah02SYr/+
lWIB4gAwtIZn06w7WAzmot9V/g1GjPW+rAtugRfvVcJP9OuSFAdcU+l5xnj+
SI8ZY73GeX4N49kfvcFbcLeG8eM9HyydVNXHEOOs30TPr8UQ/K49D/NPMA6z
L7EAccDNlTB9ivVnLTD31qoe+2+zfrTdYj2muu88713TfbrP7gaf31TrMcN9
c4zJ6PdqUnyw1OuCxTO9z93+TbxAfHCn9Zjlvhr2g8WXJMXxL1mn2R5Xiwnm
2H6G+X0RF8y1Pi2S4oOPvC53HawHE8Ff8JAYYF5Nn0p4zjj8xIPegz0fcB/x
wAPe9wtw0FjYLPjnXvezkB9NwtevK2F0w0qYDr6Dz6tl4T5tzTwGbH20UnyA
jo8k/a7TN6kGAH5+iu8K2jHo3KBzjG2/Vspb8DvfVPLX+OoR3L+k301i355J
uSd4As6BH5Oi7Vm3rRTyd+5bI+TfKvmgVYhnKs2lH1+Lf5+CrSXle/hy3hW+
/YdKOIDfx6/iX/HhrEfOg3+6OuZtFfSHz2VBpdhmF88Fy37xXPxuv6Rcjn3W
imdpluX7eO4fK/nbNb0esdqtId+SlGfgQ/Bl+Id1svqx8f9E/8tB74Q8OMnn
4m+/DvlF+7UVbEfzPJ5Y8FzbDe3Y9rRon5oUh9+W5C/wFcn74+Pu8J3grs4L
+d6k+PWu4DOT4ud7gi+rdJfm2haxw6bR3tAY1iPpHXexXX5qu8U2P/uTHYNx
822X2GdMq7O7L217ZybFoMSfv/t88PP3Rfsn3h+bXf6n9/OV39EFSbZC3k9N
A9sg7sKOvrUt8Q6/93vcO8kmsIc1smwKf4/tE4+ubJv7znbVJMZnnyPv/2fb
z/v27QfbLn+zLb3qZ6jD06T7MMB2gD2AV8QATX2GQ5LezUW2pf8F/4fPgIPC
TtgbHfDp13luA8cOKyad7Sded65tAZ8z0++EOOM+nwdn9YzfD/kD72hYUv7A
e3s9Kbfh3eMD8Cm8t92S7h73jvMjxuJcuRfELpwNtrCq7zj2y73lbPA/1AcX
2g7Xsi1yTtQX3rBtt7B9t0rKYbCTulphUm5BfZI+7GSdpDwEG9je7YwnX6Ad
f0Z9knENbb/YLf50B7cz9wH7MOL1V/w83PEWWW1beExdTB/yu0lxKfHde0mx
IDHqg0k+jb4NkuJX2vEFxIoHeAzt23kua9H3YVJMRbyzkddk3s/4GfdtmhRP
EEv8EPx729+PntPX7YzBtpcmxYv9LWOvxI4fmFN7+WtSPHes90LGVj9Kis9o
xy8S52G3yywfZTsm9jvJdr2VxwyvFGuNCL5Nkow9cy9bJ93NZdaD+YOSxjHm
N8v4vU5J8dXZlXwnsSKxGXEL7cQs1FIYd07I/wv+R1I81Nrvq52f5UPPP97j
WXOqxxJjbZcUS13jdZC5jzvVbKOSLSCTt5GnkHd1Me9umT139njwkD7yMrCS
tZ7yml0t7+K5m4e8a9IdW2y5p+2kjWVyIPIR6pDU/ZjXw/uCq/SRp+zvcYxh
3q5es85ObZPkSeRj5Ep7JcndQu6d9Lub23sl5Wx7uh25zr5sY9QsD0ryh+Qp
1CWpGfbxb3TZ1+20XZz0G5m2/TyePIG8ZaB5H8v9/Jtcpq/baSMXI2fraY4O
YDH9B3gubQdat0Otz2Fu7+fxJyXVpPCrdTVR3wvGkSMxj1rogKS6JffjcN+R
w5L6GDs66TfyIM8dXFvDMvfmCN+dq+BuJ/cgLxpqPtAyODDI92Kw+2p11KM9
hjt6TNI9PcpzB/veDfY9Yhx5DvsQDyBfWMnGh9jOeX5i9zEee5zHECfQPrkS
7vX3eYJFJ6X6eSd6DPwflol1iWuJTU5JksGpoUm/57v91KR45mS3I4NpQz3m
9KR4F799RtLvWkxM+xxz2sEv4gL8ewPPHeZ2/P1ZSViwyPeTu5my6vvD3X+2
xwAyfANgHPHteUn39Hz/XuQx57qdHOHSpHjg6dqdxF8l9RGPgpkXJsUi7EtM
vEfII5Nk5nG3LkrC2FGey5r4+lGWX3If8S13aLRtD39KHo5PfiOpZrdiyFcE
vzIpRsWWr0r1dfgr3E68OibJl+Mjxyb5VWztGtsb/oIa0JZe83LfF3D72qSY
g33JGcZ5//HWgbyB3+QObyblEtTpyCGo2a3nduRVK8URI30mzGE96mSMYx51
Ncbe6PHkDuiGjyIWIKbMbr8pKR4EA8ASag60TfJ4albUvPCL5A/kEd3NJ1uG
87ub26dYJo5hTbCpYWzYICvv5R5x34i9b7d8ocfeah1oo4/4jvo5mAQeEYOz
BjlzZ7eDTfBplslZidvJW2ck5ds3V8pnZyfF8Hcm3eHJvsv8Xuo7y2/if/aZ
6bnwuyy/7fYpfuecFbE0+7Af+UXjeNZGuV4XODEn65KHT/KYWV6HnIL2O0Ke
m/T7Drfze5nPcLrPgeeY5Wec4/HkI0tsr8TU5C33et8GkUzsmKU/9xID4P5S
P6GeQm5OjADG4/fwk8QcxCi/WsZnEl9Q3yFOIPcq/tZDW3E79aePfUe4u9xn
7vxXlrnXy60D/qE2n/ili3Xg3eLDiVGwTeoHv9uW6ENXdOZ+kmNyr6kXUdsa
7rambm+ZFbPW6r9w6qPEAE3c1sTffJHhTfz9l31+917YL2d1rc+sgetQ2EkD
t7f0Ou2s7x8+z3WzclrqXNTDqXfjYxdZXqdSDEU8TYx0f1KOd2+l2KmuPemb
PrWLVSr1M478htiZGJqYaL7nzvWY+V6H+jzfCajD44cWJNUvqIOwJvndw0n+
Z1WfD2tu53mPee7jltGBGgN13d7m1HmJQ6i7POHx1Nif8PM+6T7a+T/Ak352
bAk7IKdjbfZ40ne2se9R3TeCJHwh7lnsveBPWya+ocZ6pDk1XPLN5y3TP8R9
tPf2/F5+vw39TrlnDe2vqL+t6PdLbkGtHHwZUaleSk2Rmjnt1EUWxV1bLytv
5/7N8z3F95KnkbN9Yxk/vHrW7+z1yVWIIcG1773Xd5ZpJ9/juxXfhWpr0XZ+
7LtVkT2cGXxUVlx/SfCziuonV4f8bpZvmBj831l1h4uDP59VS5kYYycV4fG2
0XYGhYiQTws+v8hXL+e+FuXA5GDkYodH+5houysrFrgh5OZF+HJx8AlZccqN
wS8t2nds8OuK/MS1wX+yfxgf8vVFNYxxwfcqasdOF9pWiTl/9v4/WocBtq8v
U/09+9I2RvsXlvewP2JN8gX8Eb6oeVbtg/da830j7PfwaeRW+HXs4RbbRSPX
cJnL+JM9prHbsd1GHl/zg+Qh53hfciHsn3rW2X7Gz/2c1L2oZ51rO6Euybsn
Z+aZyW1/8vNz/pvYfrAdsIC573jMzz4f/AyxBfECnBzsKe/7me81z0oOiQ/v
ZHlb3/vPPWaC16nlbqzD2sQj+BfqosQj+BPilAVuX9E+tqV9cgvL7ey/W9mH
fw1eZdVIlsX7n+UaFvUxziGbr26Zc+E35sqdWN1nhe/lGwNnCF/VMvUX3jXv
i3OmHezCZo/LstsPQ74vq5awZsj8QYw4CPud6LvzasivZsX+Q0M+pShPuDf4
vKJ48ezgnbLeyYtZd5L3wn7oNNq+BH2ouYEV61rPk4MfWBTPYpOcD7kPfG3L
zSxzfm96PnNXNu6c52df1xj0UqzXIasWVXsH1HPAmBZ+F68HvyIrnjkbX1IU
I48AV4vi3x2CH5BVd+wScp+seuTl7F+U82yL7lnvbeuQx2XV57Ys8kf4oreD
X5UVm+HDrsnyY9vgB7JqdR1CHp9Vn+sacr8s/HqSvbLqi+cFH1KUTy4KeWZR
fM+9bO57je2t6WfkvJvbBrAt2hf7PNfy2R4VvGdR/YLck3bijtOCH1qUV09D
zsKsYUX+tO57W8iX+l2PZL3ivDTkvxfVHboFPyQLh+8MfkQWxh0S7UOz8vsX
Q34ma//NQ96sKD6q1a3Inant8Z8D6nvt3U4OAl/mMdS9lnoeMSyxLGc+yzL+
6h3fh3PMX7LM9yK+GxGXXmbbxW65Ny/bRxGLvuIx+GXqS+TgHSxTx9vS+qDj
+9aHWhw1P2p/1GEY+5Hn8q2N2ID4EAwHy3nX+BXiFfKnDT2XmiFx6Iv2pbwD
ZOIKYqN3vf5m3ruWP75vHRZWOsOG5kssr2N5be/BOtQ528Z72LBIn6U+I2J8
8hHyFu7OgNCnf5aeOzM+q348MHiPoprX6OCXF+XZt0T7QbbtgdhyUf1lpeDv
Z9WDjwn5jKy67LXBRxTVC5YHX5ZVJxibFRNwj64M+YssHccE/zIrp1gS/Uuz
6r+LQ74pq05wEH4s67tNa+KZItthDjVwcg1y1jfs78ECclT8/XQ/+1i/I9qJ
Jx/xePw/MSnr3Ov1Xrc82j6Lb5pDgu9fVGtrGbxVUbzZK/ieRRh+T1acga++
hDtRVPPGFzbz/UX3Adb/g6wz4nweApOLvlcdFrx9lg1MDfmRrPrE5JBvLqo7
LI62wUXfM9h/b+swE99VVAfZg7uZFTMvCD6tqD50cNY9547zbvFfvN9ZwWcX
1Re2jPZeWfd0evBvsmKV34LfVfTN4PSQby2q020c8h5ZZzsFrMmqI84IeXrR
fyd/ibZ/FX2H+BAbLPrmsX3wNlnfjTYK3r3oG8/8LMwD7/BJt9svPYjfzTqr
V/DfRd8rdgq+vm3m7iycxo92Dt466zvWLll2ho19xHpF31euCb5bUa13k2j/
W1busxp+sSin+Tjanir+BlOEGeBF22jfPcuWbgv+36yY5Ono3yArZngo5IeL
6i8Lgy8o+kb0a/RvY1/6SdYerN8xeO+s+sNGMXbrrO8wG6BL0TeBzszzmAuL
nodn6ZqVY99cyQb3ybLD3YKPKvr+smfIg2wb6D7F+j8bfG5RLYkzONLn0J3+
otzhnZAbFd0R3vlhfu87BC9FdY83uMdFvveR4O/ZV4wssvu672EER0UxfHue
qajGD1bfb7zGxzCfuY8WYXbdf3FoK6qZ3BN8TtH34QuKbAu7erwIs8HrFDwX
fdMiH+pUlBNhOy9n2c++WfEBscHxWfecO/55yHtnfWPsyfspqn+2C3nfom+Q
k0O+oqgu+TjvseibIjHLa1m+F/s6OsvGbuL8suqHh3MvsmLXU7P8Hb4ODJ+R
hePEcacXxXLclR2L7gu+/Fb7c85jp6wzwQan2g55J9tnvZd+RfeKO9Un5BOy
viecGPLwrPo0vvlN+2fuzXZFd+eo4E9l4Ti2sHOWPazBnS76ngY+HG2MwEZ6
ZNnJDPtZ/mtxAO826xsDMezcrDgWW+iSZQ9NQt41q4ZMLPZWVmwAPjT1/d0/
K84jxuMedPRdAE+WZOHDmVn4BDb9wHNn1Szxi3va/rfLipuJmb8P+busb6jk
f+R75GWzQ36u6Nvpk0XxH7HfpKwcG1siP+DOc98Zu2nW+HVDXqfo2yD+CWzD
R4EhD2TZGPbyWJbNPIyvK6pTc4e6Zd2jvlkx7oKQBwVfmPUd9KKsOI/4Aj99
R5avPi7azsr65sHa/W2T+BtiOHzOtyFfXZRvErcSQxA/XJgVlxOTg0sP2t9O
KMo9eF93FPl0/Pn/ASzwA9A=
                    "]], PolygonBox[CompressedData["
1:eJwtl3m0V1Mcxe85J0NIJGoRkVSGMsdrnpCluUcqNPCUSi96zZHmNEhlSkml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                    "]]}]}, {}, {}, {}, {}}, 
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwl1EOQXFEUgOHOxGZVsopdsa2JbduoGIvYtm0blYptLWLbNnbJdyuLf75z
3sxUT9/3ejK0712/V4xIJBLty6SYkciyqEjktSprgn2iCqmuPQmnaLn5PNOy
COuxMOuzKNOxOBuwGBuyBNOzFBuxJBuzNDPwAlewiZKap2qaVtqn8xM/a5Uu
2jPyi7KovL0Fy7El1+udeR2/aoOe2DeylbbovX0zv2mrntq3sZ1mmXdwBrdz
Jr9zNueosjrZK7Ezd+uKOTt/6bf2aK5r8zVPf+wLWEM1VV21VUurtc/3G7MP
G7FvOAueZHcOZjcOYQ9eZC+OZE+OYm9e5l721wD10yAN1H5FVMzPXA/3MpyT
aof7pRuu3eBUDQ3nz2E8qAOKpdKu3eaMcIa6ozf224zDcrzHWfygB3prv894
jOZDzuUI5gtnah7OEzquOvYK4XfNT5iYiVTJPJ5LOI6L+Uovdc5+VgW1yD6W
L3iGp1VAC+1j+JynwtkqvxbYR/MpP/IZ52tkuHccxYpMwIR6bD7GR4zPIzqq
wzqkvJod3qfum8szLsvyLu+FZyrM4fzsZRibpXiLt8Izr5she0nGZAnmYW7l
0uRwH8Pn1XyNMRilq+ZrLMq/KqRayulaDo029wlnz4zh8xc+mxpqPx3O03yK
zcNzxKbhOWKz8AzxeXgemIap1c1chzmZiimVQtVUNbym69XVRVXsXflTP7RT
z1zbxeRMpo7miszGamofngd7B0azLTfpsjkrq6q1HtnbhL9ba3XJnim8plbr
sX1NeD8qY27Gsswc7rsmm5dG/f8/+A+tcqdW
                    "]], LineBox[CompressedData["
1:eJwl0EsuQ2EYgOG/ugYSVRVxG7jFoDbBQMtMS2KotwlBhZnbDqruO6BuCeOa
UYtojGzAQOM5MXjyft9/Buc/Z3Ctki3HQgh5uuMhrHeFsKCn1Jizj5MxF7RX
E7ya2/qiOd3QZd3UvDb1S990jyHzMCPM2H9Js20/0C091A++ze+6o0fR+/WJ
Z1r2T46p2k90V2e1w525wS0P3DPGKPueF3Va5xkwp1hlhSln/Zqkj4r9Wm+4
iu5g/+HCfMk5Z/RQdv5IyzypS1rSrBZ1USei74vupfX4///+A/hyLuc=
                    "]], 
                    LineBox[{703, 933, 702, 934, 866, 867, 865, 869, 868, 711,
                     941, 712, 942, 639, 763, 562, 976, 715, 643, 808, 881, 
                    644, 977, 563, 764, 943, 713, 872, 633, 870, 632, 871, 
                    705, 940, 762, 937, 704, 936, 939, 938, 631, 864, 630, 
                    932, 701, 931, 700, 745, 744, 935, 703}]}}], {}}, {
                  InsetBox["\<\"\[Mu] = \"\>", {-1.8, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["0.2`", {-1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {InsetBox[
                   SubscriptBox["C", "J"], {1.4, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["\<\"=\"\>", {1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["4.09`", {1.7, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {
                  {PointSize[0.05], PointBox[{-0.2, 0}]}, 
                  {PointSize[0.0125], PointBox[{0.8, 0}]}}, 
                 {PointSize[0.007], PointBox[{0.4463998339305619, 0}], 
                  PointBox[{1.2771956561278897`, 0}], 
                  PointBox[{-1.0806611991222994`, 0}], 
                  PointBox[
                   NCache[{0.3, Rational[1, 2] 3^Rational[1, 2]}, {0.3, 
                    0.8660254037844386}]], 
                  PointBox[
                   NCache[{0.3, Rational[-1, 2] 3^Rational[1, 2]}, {
                    0.3, -0.8660254037844386}]]}},
                AspectRatio->1,
                Axes->{False, False},
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                Frame->{{True, True}, {True, True}},
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLines->{None, None},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None, "TransparentPolygonMesh" -> 
                  True, "AxesInFront" -> True},
                PlotRange->{{-2, 2}, {-2, 2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.02], 
                   Scaled[0.02]}, {
                   Scaled[0.02], 
                   Scaled[0.02]}},
                Ticks->{Automatic, Automatic}], 93->
               GraphicsBox[{{GraphicsComplexBox[CompressedData["
1:eJx1W3l4jNcaRwlVUYrQaYuqttP2Kg2jpHjLKIoyaGtpOvYiU/vW4MY+tirV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                   "], {{
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[0.3], EdgeForm[None], 
                    GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxNmnn811P2x9/33iwtQim0aJGkQvYsUUrWiOyUrJOEIUzIiMZWllREpaif
QpZCSJQMUYzsS5bxs+9L9pEx5/l9vb6P+uM8zvmce9/3nvd9n3te5577aXPC
mYeckauq6lmnqkrwx4NSUN2gDaKhcdCiUDQKHl2qBkHvx+9/BzUJWqeSfo2g
G+gXvFXQ+JDHBf0z5A+C/3/QhkH1g74N3aKgsSGvHbxxUBPPWS9oI8/D2E2t
q489lfrTb2O3NwyaEOPcGPRMyM2sWzfoB3RBTwdNCTo8dAODWleyk3nbelzm
b+f5NgzazBxbNnU7be2tY/42HoPnf4rxnwtaErS527Fl4/i9SfDOQVtWklmf
rcyxpYvHwpZtzJlza7fTtq112Li97WtvG+t7vbZzO207uB1bdjTvELST+RZB
P4dt3YJ2g1azcU/Px3jrZul3DermdmzvnWRr96DdrcPem5LeZ4+gSUnj9MC/
PB6296k0H+PtZVuxsbc5NvZyX9r2tq5r0P5Bu9ieFUHPef4WSfr9gg5w+25+
V75D86Afg16wPT8HvRTUN6hfkh0HBx1im3q7radt6WcdtrRKmgd/+iXkXkE9
g1rEWq0XtCT0K5OePSjoCNuF7UeaY+Pl+GTQLyFfGrxtUv+Xbcex9Avd/kGH
hnxr8KlBL4a8zN/pQN4pdP9KWtf+fhZ7zwrdg8EfC8ohfxx8Lu/FPEFHhfyK
5zkl6C+WGeOIaN8s6JiQjwp+ZNCAkN8MOiPo70FDgo4POgH/Stpbg4NOqyTT
9hL2Bp0Y8uue52x8JanveUFDV5v/ytB3DDo55L+tNt76ofsj+BtBw6xj/vPN
T7cdR3iNL7adZwYlAlzQljHGSM9fMyfzBJ0T8p9J+kuD3rVdlwVtGs+1DWoS
dKXnZs6cZd/lQVdZd0HQ2qFfK+iVGO+boK/ZJ8S+rDW7Juharx82bhz6jYJe
iz7XWTci6PqgS2zPcax90KCQx7idtrFu5522S7JlfFDdGO+K4DcE3VhJxvab
g0YFjQ6a6rGY5ya/A20T3X510C22FbsmWYf9k1d7jyluZ6zBYcOpSXbd4bF4
7o4kW6YFNciyaTrrHPo7wZKQ/8+2TgiaYZuw906PwZy3u522mW6faD873N/+
LvfFdoDsw2D3Bt2XNGeN7PmZ873QzwafQp5tHfPcbzuYZ451Mzz/lV6vN+K5
+5PW8gH35b0fNMf2jzzfw0FvRd+Hg2aFfHrSfI8EPeo5mHO+OePN8nuwxnM9
Hu/3aFL/ef62+CF+WSf0n1qPv+PT+MmXQQsr4ftXQU9Uwuw1o/1zz/lUJewH
X8FV8AucA//BfjAGvK+rZa3Bf/KCeh6LZ8AgcB5sb+ixwEYwEsx/uhIub+i8
gZyB8Zq4XwPPCaYxblO31beO3+s6Xr7sOZrZVnB+caU4D7a3roSvzN3Gv8kR
bjAeM19bt5EfNKu1rRJ+tvPcm7ofdrV3G/Nt7t8818G/wf9nK2FrsyTs71Qp
J+hg25gbDO1sm8BMsJNcaexq+dNW7od9XdyvNj/oYru29W9s3c6/a/F+B48B
Nnazrei2r1blATvaDnCyBi+T9NgPjoH9u9iObu4Hvu9ue+gLHoKLYH1324Md
YBM4S56wh23Gxp5uwxZwFmxd6nG62r5e7lebE+zlb9/O790yCe/3rYSr7Hv2
P7lAH9vaMAnvl9lu9GAuuHygbQD3+642H/JB/sbb295d/dz+tgNsPdh29fPv
WlzHjtZJ+cFhlTD5SD+/qfH96JBHJuE9+ccufp73IIfo57VYlozrlWIF8YM4
skbIn1WKGeQC5LXHeW7wj1gItp9gmw63biA+YEw/qRKuEjfAuQ5J+H1qJfwH
h8FjMB+5v58/zc+B50M8H3j9WiWcBetfrYTFzDnEz7xVCfvPwg+SsP9czwEO
g7vg21DPTb7T3+vL88NsK9h/vsd/p1IuclElnAc3wVRyhOWVsBjMvti21eYK
wzwfmAl2tnVeMKJSLjDSNoHvl3l9mJs4e7nHIPaDAWD8VZ5rmHX0A//BfPAU
bAf7wc5Ozm2wl7wAzB9tu8HSa/we1/k3No3xb+L49f69fRLej6v0PBgIFr5X
CXt5B3KA8dWq/ATMnGD7wNkbbO8E/x7lMeiHrZM8Lm1g4nTbBB5Ntk1T/Ls2
J5hk+6a6DWwH+2/zPLd7rFONmbwP+cA028Ne4rsfaztm+BlwFTy83/OAgXd6
7ln+Pck6cPd+Yyw2gO1g/z34SxJmv+9vP9Y2TPRzM/2e7LN7bets/67F9Qds
F7bM8Zxz3bY8CeM/CHkDQDIJ/2/22LXvM8fjkgvMtf3zk3Ad7Ibz+5FqVU7A
fid/f8xz1Yv2LyphNnn+fNu2tnXg6vqxtt2TziNg9BOVMPf70D0ZtCDk1lm5
Ae3fVMLuNYP+SR+PtwJsTcLvhUlnenCqofuDmz+GfqkxuEHw7yrN+13I3wZ1
DTo/aJgxkr3MXmXvfF8JA4j/YAtxnBh+c/R93rofKsVC4vhaSb/pd0vIk5PO
dcODX5g0FrGc+Eo8J9aDAz3sY+QOxPBfLeNvv1U6CxGTWsaaNM2Ka+sltRG/
rgm5c9DvITfL0hFLzvf78C6s2VNet/9YT7xq5OeIWe2yOPv+pKT4SGz8lfiZ
FL+mB5+WdBa5F/9NylF/S4p9xL3/VmonTs0M/YzkXDopFhAH1g75z0q/Z9n3
a/JV++ks+xaYgu/h6/gs/p/sv2DPQ/hqUj49176IHz4Suk+swwc/93h1Q1+S
fdb+TG76k7/FgfZTfDj5O/zi74JPfWu/4kyNL3Wy/35tH94jyW/wGXxkhf3k
70n+scJr9XrQ25V8nNy3jv3mB/sStvxo33jFPoE/HJZUI+jrb/+bfYPvxnc8
w36yMvhfK+0p8mxy7P2S3pN3fNV+gA+QX1FvqfFzyx293iwCa85a5rRqjVlD
9vz1SWuajf91HCvwgcb2E96Zd3/O34FcgW8xNCnXn++x6/q7sN+pxy3ydyFn
qqkrJO3hJfZlYs3jXhvyb77VO/Zp1gP/ZZ+87nflrP6GfQ7fG2tf2sD+VJPz
J+X41BKbpprjSrVR0tmA77uj9fgGZwX0xBt0Tax/3HGFPHunpOd5dpMsHblt
86RcvJP7I7cMeUFSbCSP/NCcHOw7P0P/TZJyTfLMj9yvlf1uHceZBe6zM+/u
dnKuNkm54GF+trXH+W/wP5JyQWTyQvxki6Q8jBysnfXkip/wrZLyts/YQ0m5
2ufWnew+7d3/S7eTp33mMckPTwy+VZKv4rvkIeRFxDPyEnRfeFzavrCeXJHn
tvSz1FL4fZb3QWc/O6JSn0uCD0ryS+LSV0k2be3vxPfiDES+QY5E/vKX4NsG
XViJb2P5G+uHV4pt5DzkNHXChpL1+2Ov5TGeq4vXcIekPGmc+yNjD3i0c1Kt
eGfb09LyLtaDUexVzkE7ed+yZ6f5PcgJiUM72d/wqV09DtgNboPv7O89/Czn
JvCMGIXf9UjaX/A9LbewT3ImAMc4D3AWuCR4n6QaIH60l32J/Lin9fBeljmD
ce7qYr530hkMn9rP/rav9d0r8d6WeZ78m7GZ8wCP2d/6AeYHWGYfXOS9gO5A
6zkbcA6h7ndwUs2ReiP8EOsPsh6ZsxXnMc5iR7mt5vzC/Em4AO+3mkyMJj7/
4n7o2RNHeF9wluAMM8j8KMsD/Jt3Otp6dPBj3Ic12cfrdkVSP/qwn471nmJ/
9PceqRk3ac6hlqkrjg4+0GOCy5wx/lFJd5z18OPdn711Ulp1VjrB/rzSe5g9
SD/GGWp+isfE5zgrguHEXPJs8ltwH/nWSvtgkPcCusHWE6dPS3rujKRxHrFu
sPXwIe7fz9+lr+fkGfKEC5LyPHK8s5NyU/ALzm8w6EH/Jl89x3r6ENvPTcIC
dEPdf4DX6hzbdqbnIt6fl5Svwv9meY0sGzpa5p5jmH30Qu8pfHa4dWtmyfuE
/Fe/C+/+rGPBFu5DrZ/nyd/B1Xnev+xZ4j9xiHM9sQg+0vJllslHX3IbeSm6
f7jP20k1oLVCvirpXI0Ps5+usO91tJ64DacfOSo+O9q+RLy8Lilmgs9XJ8Vp
+o5yf3B4TBAgSi7PvI1sA3l/bR0KTv2MmDEiKUeg73jbSRynnka96p2k+tr6
lfgEy99aT1/iEXFwa/fnLMHzE5NiI3sNftNqMm3kd9SUqDER28j3kXtUyvsn
W4ZzHujuvpMt/56EzdRKbkuqm7B/2XPX2q8+dftA96cP2A2/dTWZ57l/AQfA
g3O9B9nb5Nv1w0/qZZ17aZ/uPre7D/uUujd4Nt4xgTZype2sB7PgMy2T+9eM
V6lefY9l5rrT48DvSsr/4fy+zXuc/T/VceDupDMAY9zrPne7D/v6Do+Pnnzw
4qT8uGHMtU7WWZozA2dXzq2cr+cknU2Yg7P3FPefbTs5a6C/m72f9Ptu933A
45G/sl5gK+Px7D1+lmc4qzD3XOs5d2DDQ5V0D1mPjra57jMvKaeu2bNJMZL+
jEW+/aF/I8/zs4zJnTXxhXjCuYXzC/u9fiT4vbPWirPa2r7roeaDTN6yjX8j
E4eIQcQRai/UZajJ1D5DHvSz+xCviDHEGmLR80k15RaV6vDcx3O+AOPI08Ad
+BeWh/tZYhT5UR3XsAio5G1gCviSXPMCC+o4j1rfd5fkHt39G5naO/V/avPU
+xv7LqBNVu2gkZ9b3/ee2IvdxM5Wbuvk967nmhT1NOpr55kX27md7WZ94Nky
z/H8DfbPepafTar7r1epxs7cxGru4pd63cjNyPvJPXkv8nVidUvL5FxPJMUi
4hX/GVjsMbv6WfK6he5HvKR2wlqAUwv8G5nvg8w3Io4+lVQP4I6AOwbq/9RQ
GH9d86ct1/P6srasO7X3XR1fmbuRx3jG45AbUV8mV+pjmToz773EfTp4XViT
xW5r7r4v+FnyGc4JnBmo61LD5az6smVyM+ZkrRmD55b5Wdp4hlzvX27DliHW
Mw5jMNar9odNfK/A/m7oeML3rG/fYE9RB7nQvvSTvyPneM7z1D04eyJzrr8s
Frtr0R7H79k/5MJXhu7WLDzvZT17ipyc/cZeIx/mDNbWxLkMXAYrwABiPpjA
b850rSyjH+ZxdvNzjENefVvM+XlWzBgbfESRnT+GPKboLD0z5G+yah9jqCNl
1Xx2D/73orrYdSFfVKS/MfhNRbHk4uDXZ52ZJoT8H8eNqSEfUvSOk0P3cVZs
uzp0t2flWTOCX1c0783B52Xla5NDnlIUP24J/qfjD/iPH1PLWun35B3hK71W
zbNqYdw1gvWcr2rPVshdTbSRA1AjoVbCvrmk0nOXei+s8L4jNrGhaAdzGrpG
DKbVN7ZSl27gOEAf5OnWreP+2FY57uFn67jPVH/fKd5PP3jeG23nM47h1Og5
n5J3EWdP9h760T651P7JHuvpNaLW+JqfHe7Y8L1jwmLPxT7mTMx5ldyenI2z
bu2c3/hZzhfE9o7en1+6/9aWOeN38TjonvL3Wsv7CIyhJkn9H3mU4wp7kNoI
sbmV9yP3FJtl3VXgIzPtn+2sZ99dGfzsojPPzyHfnVVD4n15nnuDmv87OeZz
l8EdzIhKeSc1VXJX/lOBzFmGsdvlVXck8Gus38jzwje2/FXMPz+rTlNbS73I
Yzfx+C8Gf6go32UPjfH+eivkV7LOUtuGvE3R+uFvbW3PhraH2iy6Ta1n7LZ+
l6bWo6Ou2Nq43MiYWMe6NtY3ttzIa9/K67M8GnfLvh9LekfWkndrYTy9OPgJ
RWfmnYviC7Fll5CnZdUCdw15elbNb2jww4tqBJdhe9H54HL2QdHZ9XnWLCuP
HR383KJceELII4vOeO+FfFNWPrlTUUwhnnwQfGJWvkfcvSU79gYfUHReoQ7Y
zPvuheBXZMX/R4KflpUbsC+bO25A9D/bPtnC68N3osZa6zst/S2a+VnG58+L
+xfVX1oEPyfrvPAAMTILs7rx3lkxZ4+QB/i77RnywKy68l4hn5iF13uHfEoW
VrcMeVjWOePCkJ8oyuEvQF909u4UvHPRO/INXzdOkUeTr7NW1Cz5z0QtziMT
nsjlqGFxBny/0v0UeTQ66nrU9MiT0ZMzk99yx0SOOtvjE+s+qKSf5THedH9s
ec3xZLT3KvvsbbcNd9zjPEau0db2MC8xh3PRwEr/6yAnJh8mzyW+gNG19VPq
URu5D7Xa5Y5BxJ9Ffp5n2/u9NnM/9NR1WY/3vSbMSU7CGW2KbUCm9kUttZXn
/Mjz1v6mftvU47DeC+KbLCw6D3Oe4tyFPy/0+5LvHQfueS+MC3l8US3hxeB3
ZdX57mUP2jd6h75TVl1885DbF73TqaE7KSs/vDn4iuy7Fvy/qGYxCH8pqk+d
FvzSrDuHN7NyBb7JJaHfIyvHmZKV37C/JoX8Q9Z3vtPvUnPuC90x9m1yjXEe
B9whH8XXiD2N86q89G1jxDjLY+1Ty+1X/aLjwUV50/XBxxbVZRbEGNOK9leb
4G2L8r53g7+TVUNqFPKnWfX+j0P+LOsO4+rg5xXVs04Peb+ieut5IR9dVGtj
LU/yenLe4t6IOgxrz/5k/TuGfHCW/Q+E7v6i/1HeF/zZrFpLCnlO0V3FktDN
LqoRzg751yys3zh0fYvOAQeBA1nnghHB7y6qLd4VfFFW/XVx8FlFd0JLi2Ix
cbhj8C2K6vd3BL+zqFbSPyvWEGe6EpOzzmhfBH+u6P7m+aI4TgxnvQ/zmr8d
fb4tqqE/moV5YMKskG8oqnOx9k9lrX/rkFsV3Tk0D96s6O6ib7RfU3RXcnvw
GUXn+ZewNwu7Owffp+i+7UvGK7o3mhvyb1l5DrFwjuPh/lnflW/aB7/Ouss6
OStu0mfLkA/J2l8vBT+96P6sD7qi2t3TwRcX1aG6hf6IrDrJocR1fwvGGORx
+gUfknUWG1VkK3ayTsuz1qpX8HpFNZOritaadf6aNcy6AzsuK+4T89uH3L0o
J9075AZFdY/NQ+5ZdF/475DXKYqlr4b8eFHNKIM5WRi1Jd8x6+6LnIj1ZW3X
Dl636H7u3Kw9w/cCQ9YyjoC3Txpzdwy+Q9HdxRL8uejeb1FR3eFW9m8RHoPF
7LNnivZad96vaA3nBX+0qPa3WfB2RXdKuwU/Outu7cPg6xbtd+IHGEkM2S/k
hkW1FMb+xHv5sZDnF92BF75h0Z0f54+JRWeQa4vmYPya+OcYyL55Omvv9A/5
gqy7hcYhH5RV+63JKbKwkpixgX3sNt676F6X2DnY8RMb98mykz19v/c1Mfg+
x+Hvgx+ZdQfeISumE8957wOy3p1vu2/29w1566z7PXxhryx/YF272T+JE4fa
P4eEfmnWvehMfCqrRnoia5CFoeRQ72bhDr7ZM8s/nwl+b1H99w/8N+su5Rj2
d9b9DLj0ZBY24S89snyG3A3cQn88a5N1x0KesjArVyE3GV6UnxAv73HMnFS0
b9mz5EcPZeVIp4ZuWdYZ59qs3JS8FMz5KAt3HiyKrcTV6UW5EXNxXuT8yZmR
XI98iFyI+PGwY8jg4A9mna3YN+TiNXk436joPh5sIYcDX7bK2vPs9z2zMAZ8
6VX0LfmOPYr2Kvv0haI8mBx496K9zb4+J+RRWfctI7NwF8w9k7XPutdZGfz3
rDtv/PQ7++pjWT6BPxA/lhXFkP8Bm0sMEw==
                    "]], PolygonBox[CompressedData["
1:eJwtlwnUVlMUhu85pyRzhISwZCppztyg0EAlIqHSXxo0UlolpaQ5pJJQSlJS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                    "]]}]}, {}, {}, {}, {}}, 
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwl1GlQVQUYgOEbzZQtpi226EzaHyuztKbMFoxdIDIEKjW3TE1NgUKb1j8J
lOCWpkJRttiq2WIubTNpaZb7MqOpaYoBgi1aWqZZzzf9eHm+78Cce88593LZ
sJKC4lMSiUSaH9NOTSTeSkokflG+ptin6lYNsLfjc5qht+3v6F4l2weyFzsz
hYN4GwczlZcznUOYxqHM4BXcyHd5ny40z9Tzmm+fxSM8qgXaZL+Sf6qrsu0j
2Jsj+aEOmz/gX/pIzfZFfEBL9Lt9MY9pqVrsy/igas2fcDZrNEd/21/gi7pD
JfY8lvJzbTV34z86qS9U59jLekn/2ueyQIXqq7tUFNet5X4/iI9zIJ/gYK5h
CctZzAqWcjPHs4plrOYEbo3X5mNxLj2qJ+N8+lKnK9Xf7OIsHlK/eB76wbFd
cd16Oq6bE7ki3p/OUpZjP7I27nHM+s2+h62Zw/q4T3GPtT9ew17PNsxjQ9wX
VrBn3B9zOb/VavW3366fzE28gOfrTvNkvsFqzuPPOqgN9vW6Ra/bq9jCdVyr
m/WafRKbuYbf6Sa9aj+gRnMfPstXWMm5fCaeOc/leWo0f8MGtuVKrdLX+ko3
qi7ef1y/OZfnMJv7uC8+S9ob2XvzbGZyD3ezJp6HdtszeCbT2YM36Pr4fth3
6lfzDrbiGfo+jjOFpzGZ9+g687WabH4krp1d4rsU30FV2h+K98/tcd/4lIbE
Z4grtC1en53YUZeqzH53nJsd2F6XKD+embo7XhTnVh/7wzyh4/o0np9jn/Fi
XqTieP68hoUaqxz7OOZyDD/WFvPVLNAoNdlHc7je12Z7F/bVe/GM7Qs5TJnm
+5nFq/iHppvfTPr/f+B/VPGueg==
                    "]], LineBox[CompressedData["
1:eJwl0EsuQ2EYgOGfsgsGLWqASlSk6YA9SLQukWgZVyJ16UBbI2Yu3UAVxQ7c
ohKmzIpN1MgCPI3Bm+f7/nMG5/zR/OZ8oSeEsKqBSAjF3hCyPFddC/YpLZq3
GWVMb+YOX5ljmWusMM93/vCDhxozj2tCaXsfZ1nmMfd5wk/9mtus8JRJPqul
L/u3zlS113jAOfbzXg+605MeNamEjryzxRQzGjXHtaF1zTgb4bCGVLLf8FbX
erEHXqmpS11oUHuetbrfb57mCne5xB0uM8l291/YiPzf9x8U2i7W
                    "]], 
                    LineBox[{712, 941, 711, 942, 871, 872, 870, 874, 873, 719,
                     949, 720, 950, 649, 770, 571, 985, 723, 653, 816, 887, 
                    654, 986, 572, 771, 951, 721, 877, 643, 875, 642, 876, 
                    714, 948, 769, 945, 713, 944, 947, 946, 641, 869, 640, 
                    940, 710, 939, 709, 752, 751, 943, 712}]}}], {}}, {
                  InsetBox["\<\"\[Mu] = \"\>", {-1.8, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["0.2`", {-1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {InsetBox[
                   SubscriptBox["C", "J"], {1.4, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["\<\"=\"\>", {1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["4.08`", {1.7, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {
                  {PointSize[0.05], PointBox[{-0.2, 0}]}, 
                  {PointSize[0.0125], PointBox[{0.8, 0}]}}, 
                 {PointSize[0.007], PointBox[{0.4463998339305619, 0}], 
                  PointBox[{1.2771956561278897`, 0}], 
                  PointBox[{-1.0806611991222994`, 0}], 
                  PointBox[
                   NCache[{0.3, Rational[1, 2] 3^Rational[1, 2]}, {0.3, 
                    0.8660254037844386}]], 
                  PointBox[
                   NCache[{0.3, Rational[-1, 2] 3^Rational[1, 2]}, {
                    0.3, -0.8660254037844386}]]}},
                AspectRatio->1,
                Axes->{False, False},
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                Frame->{{True, True}, {True, True}},
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLines->{None, None},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None, "TransparentPolygonMesh" -> 
                  True, "AxesInFront" -> True},
                PlotRange->{{-2, 2}, {-2, 2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.02], 
                   Scaled[0.02]}, {
                   Scaled[0.02], 
                   Scaled[0.02]}},
                Ticks->{Automatic, Automatic}], 94->
               GraphicsBox[{{GraphicsComplexBox[CompressedData["
1:eJx1W2l4jFcbDkVVTZsS27SiomJaW4qU+vB87WhqqXxDW1R1FKWptKg9ughl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                   "], {{
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[0.3], EdgeForm[None], 
                    GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxNm3nc19MSx7/nnBCytgptStmyJXuLUEKoi2xXCiX7vpMlpEhZUoqKJEkl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                    "]], PolygonBox[CompressedData["
1:eJwtlwf4jlUYxt9zjvbQdKWktMuOhkJGVlT6R0Tmn5CtlJWVWdEgigaVSGRE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                    "]]}]}, {}, {}, {}, {}}, 
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwl1GlQVnUUwOFX1Da1RbMZ7Ys6k06pWJGWRKEiCqGZWjktlpK2qZBIZeak
4xK4oGnZorm2L1QubZYwUy6ZWmTNuAQJBcQyaba59MXnjB9+POfceR25/3tf
uubmj8prkUgkBvrxXMtE4p2kRKJZo7XEvlT9dZ/9Yi7X83rX/p7uV6p9HG/k
lbyJ45nGXN7MqziADzCdE1iq4+b3OZATeQlf0Aq9pBd13PW/9IF+sPfk30pW
pv0RDuaj3ByfNW/iP9qiRvvHnKTP4t/aP+W/+lxN9q3M1yrzF3yZK/WK/rO/
ytW6RdPs2SxkmX4yX8NTOq1yrXFtndbqf/t6jtBtulWjNDLuXaW6W8/43F2c
xXv4LaewiJNZzDxWcBoXs4AlLGS5yvSUZmi6ZuppfaUkZfjs4Thb/qF74+z0
s2uH4741J+6bc7ldX+scZbn2C1fxaMw6Zq/iecxhTZxTXNev+tNewwvivlkb
58L57BvnY57HPXG/Gmsfrt/M9byIF8Z5mUv4FhfxTS6OM2Q9m1jBG/SGeSEb
+T2/0/V63b6ADdzHveqn1+y/qy6eD4u5gc9yPYvi2bEt26nOvJu1bMNd+kY7
tUPXaU3cQ5yBeRjPj3eH1ayO90lHIns2z+VQVrGSK+OZqNI+hK2ZyRReG+9b
fDfsh+JZmA+yJVvpQFznILZgerxP6mNO1hLz40xjD3bXFVoQ3wGmshu7qotm
x3sSZ8jL2Vmd9GT8nWAKL2NHXarhcc/xe7o+Jv4v5dif4Emd0Jdqdm0bO7C9
CsxZvJp36jENsU/lUObxE/1o7sM74nsRz84+hQ9ro/bbe/F2fagG+0d8UIPM
DzGDveP91DLz20ln//6dATw+q28=
                    "]], LineBox[CompressedData["
1:eJwl0Lsug3Ecx+E/vQgG2ghDHYYOiEQkdQsNWpI6XYCyUdqq0VaHG1B1vAJF
omVjo65CR5uEpzE8+Xx/b97hbQfWc6mNrhBClp5ICNvdIcxplTMy7nHm7R3t
035e7C991mUta1YPdEVfta1vekjcHmaEGfcvSYruihb0SD/4tt+1pMea0Cca
tNyfnLDvPtWyzmrQOvfc8cgDY4yyxSbT3l1iyB5kjVWmPFskZkcp2Dd6yzVN
9w+X9hUX1Ohlz/NG59vsSc3ori5oXtM6oa3Ob9HzyP///QdfjzDi
                    "]], 
                    LineBox[{711, 942, 710, 943, 869, 870, 868, 872, 871, 717,
                     950, 718, 951, 651, 722, 1012, 721, 886, 655, 813, 887, 
                    656, 984, 574, 766, 952, 719, 875, 646, 873, 645, 874, 
                    713, 949, 765, 946, 712, 945, 948, 947, 644, 866, 643, 
                    867, 569, 983, 709, 748, 944, 711}]}}], {}}, {
                  InsetBox["\<\"\[Mu] = \"\>", {-1.8, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["0.2`", {-1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {InsetBox[
                   SubscriptBox["C", "J"], {1.4, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["\<\"=\"\>", {1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["4.07`", {1.7, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {
                  {PointSize[0.05], PointBox[{-0.2, 0}]}, 
                  {PointSize[0.0125], PointBox[{0.8, 0}]}}, 
                 {PointSize[0.007], PointBox[{0.4463998339305619, 0}], 
                  PointBox[{1.2771956561278897`, 0}], 
                  PointBox[{-1.0806611991222994`, 0}], 
                  PointBox[
                   NCache[{0.3, Rational[1, 2] 3^Rational[1, 2]}, {0.3, 
                    0.8660254037844386}]], 
                  PointBox[
                   NCache[{0.3, Rational[-1, 2] 3^Rational[1, 2]}, {
                    0.3, -0.8660254037844386}]]}},
                AspectRatio->1,
                Axes->{False, False},
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                Frame->{{True, True}, {True, True}},
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLines->{None, None},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None, "TransparentPolygonMesh" -> 
                  True, "AxesInFront" -> True},
                PlotRange->{{-2, 2}, {-2, 2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.02], 
                   Scaled[0.02]}, {
                   Scaled[0.02], 
                   Scaled[0.02]}},
                Ticks->{Automatic, Automatic}], 95->
               GraphicsBox[{{GraphicsComplexBox[CompressedData["
1:eJx1W3l8jNf6j9bFTTOtq6o6N1LUkraWVKXU9minRW13qoqqjq00DH6uUka1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                   "], {{
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[0.3], EdgeForm[None], 
                    GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxNmnf819MXx9/33swoStHQUBKF7EQllZ0tmSXZFPKTEb+S2VRSRAORzJKs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                    "]], PolygonBox[CompressedData["
1:eJwtlwm0llMUhr9zjllRaklWhsjQhMwNFEUpkpQkDTTQHKk0RyMVSsnMRWlU
RKVZadAkVBo0IUlUbqVo4Hm9rdVuvc/e3//f85+zz977K/po+9rtYpZlv2En
YSWBvdhJIcu+hO9G/5SybAo8DZ4F54cLwnvgluh++L5F/4UtQk/C14N4L2wt
vB5+Hf0D8Rno2dgA+DB8J/HN8Pvwu/BmeAs8Gt4GX4O+WgZfo+8gvgdeh95K
/BW4D9wcboE9AF+L/Ukswteh1xAfjq6oNcIzo9d+Cr7axN7Dnkbvw3c9sQfg
KnAluAxcEC4E3wWPgL/H/kE3xfex/hbx/ehF+L6AH4bvgevDN8CF4fPhuvAw
+Cq4NPwoVh7dCN+8E2dwK9wEno/ejU1A78OXG+yLyXuqvcyD7yv4ITihn8MW
oHfjW45eyTMb4E3w2/AWeB0ckj+r3zAULgkXhxthK/RZ7BdiGdyDeD24Kroa
dhu8AX4T3Y9HLkJfKIMv0pkpf+D16O3Ee8MN4LuD96Qq+gl85dA360zQx7Ez
0Zt4/jD6SWwZei82X3uNnUp8v/KPz5fArgjOIT37Dtwl+DP14dJwSbgT3B7d
DmuGvhzf88Q7aM/QDbDV8H74CHoNz1yBvhI7hP4Oq0D8KHY68fVwLWL3YnXQ
FfU30C9ExxrrN8I1k2PVlN/oq4hfgL4RXxWtB74Bfb3WgD4L39noMsox9FP4
bkFXUI6gz8aXH30tdge6Nb4lmb8jH9w++rsLYM3QtyXf3QVYIXQnfJWIFcbu
S85p5bJ89bQ2fEXQD+FrCJdNzsW5WBv4Na2J+FL4QfgSuGjwnj4LN4Fr6S5h
P2qv4LzoY8Tv19lE56LuZGN0heTcVs4v0lqxH9FHse3Et8OTgn1d4Trw7cF3
8i54GzwBPZF4DXR1rCz6XHyfqhbBLwbv0bfwAfgovAE+A31m8tqmY+WJH8PO
CD5z5Vbx5FxRjvXQd0V/9m9sn+479rvqB1YcnYudHOwrxvOXyuBiwbk+OzqX
lfOT0d8QH4JeiG8KeirWGz6g/VE9SD4L7XF/nm8F11Vtw0bDz8Ft0e11/7UW
eBW6KZ+pjG4RXYv+yLx3T8OVg/ewLXwz3FhnGVybK0Xflf9rNLwxulbkBN/1
karRme+8ftvA6M/qN2ptA1QjgteouzVYNTD4jnWEy8EtlVvwXHiO8inzM93Q
XZNrySNwF603WesZ1SbdMd0t1Sj1iteia796hmpbFfjl7ESNU62CczL3kHXw
Qng1/Gpwbdoa3ctUo1S7p8D5MtfwXPgzuAh8MLj2jtf5Zq7Bqq2q8artqrHa
+2XRtUJnsApeie1U+QzuVZuic1U9S7n7RnRtVA6rN82FV2TuUWuTe5B6z8jg
XC6tnps5p5U7JVQPM+fQVnhLdK8cG3x3qqsHZ75DpZRr0Xuvmqha97VqYOaa
1xf9OL6DmXv4I+ib8NVC3xdcu/vANYNr+Otav+4buoT2HP1Wcq3rrDNP7nnq
ddWDa9dw1fzgGvYqelTyZzvCQ9BDk2sf/7JPkmuKaonuhGrjS1iH4Bo5Ej0i
+e7pOxsm3wHlvtY4DB4L8+//z6g2PRP9W1SjWsDNZapN8C70jOjatlQ5nDwz
aFbQndFd+wBuF3zn1At7qn4G98T30AOTe6XOvD/6nuja0grfW+hn8R2Hd2D9
0O9Ex1pi76MHJefKr8SfV3/BNyvz31Rv7RW9l+qxTeFmyWtvwDMvE+ud3Ds3
KqejZyLNQkcyz06aWTSraIYqAneH7wiu+QvhBcmz12PBs9SoaK2ZSrPf29Fr
1wz4M1wTngFPhXfAv0avfVrwXamY3Kt0Z2rBg5Nr1Wx4l84i+qx3KaeJjYnW
mjl1duOie4/OcBL/7eSZ+cE5vyN6DfrbmlGmR5+hzk53VrW4VHTtU03WbFQD
+zfzjJSXZ/Mkr0W+6bqv0bOrerx+2wB8rYN/43L4M+VkcM58ot+qnhVcM3S2
y5JnL52xeveh6NlSPXxadE1RLVlM/GP04uhafxq+85J7tHqzZsSlxFon1/o+
wbX64uTZSjW7JfwLPDO4JsyLrhmqFavgOfCbyXdRM9Fo5W9yLFd3LnrG0Gyh
ntkheibTLKY7rdleM4VmCc34baNnFs0qmmE+V34l313NBKoVqrGqraoZBdDn
JPdizczvRue8cl17qtxWzihXlOO71b+ic1U95sPkNWutXYNnvzHJWjOgzmIF
vr7BZzJe9z15Nuym/dZZRM9yeka5Pi45ppzXbLIYGxQ8o0xAT0yebTXT1U8+
A+297rj2ulV0r9ae6+ynRp+lckC5+VH0rKUc/Sj5jupu9oSXEPs0+axVY/Vu
9GV0TO9IOcnvLHpX0TvIkuSZSLOQ1jgf/R3xHvDAYL0m+q7Lp9nl1ujZRDOM
avtTybO8any16B6h3qCe8Bs8OfndTD1Rvfmy5FlFPVrvJvOS/5beUVYRfyJ5
Vu6nPYyeETQb5PB8m+RnFNMMMDP5HU/vdv2DZ/vPk7Vm/M7R71x611LPqwyX
SX63Uw//RnuT/G7UPfPsJp+0Zrj/AP1X73I=
                    "]]}]}, {}, {}, {}, {}}, 
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwl1GlQlXUUwOELVLbvM9WXssnGLKjIDTENUDDCsignI1vEzIQErGybaioX
Csh2BaWg1RJKK9u1mbSUtNBqNIIEFVJaNLT9kz1n+vDzOef16r3v/75wenF5
YVlSIpHI8ceClERiaXIi8ZOuUI39MQ3Xtfaj+YSe1Gv21zVZGfbrOIIDOZLX
M5M38EKexdG8kaM4hU3qMy/jRSzmMXxKT+tZPaM+1/epWZvtg7hfqRpjv5k5
nM634rXmFfxdb6vX/g5v0Xvxb+3v8g+9H/dr/4C3qs78IReyVov0p30xl+hi
VdjHcRZX6VvzefxHt6nBvpr1fF7P6V97Iy/VZRqvyzVBTWrWJN3ndVfzfl7D
FpZyHks4Pz4nWzmLVaxgdbw3P4n31l26W3fqXt2jT5VQttd+H+fLX/RrnJ/a
XWuLe9eDce98iGu1Rgcpz7VtrOMe/aC99g4ewnxuj7OK6zHrN3sXD437Znec
C+dwcJyP+WFu0Bcqshdop7mHR/HIOC9zNV/ho3yZVXGG/JG93MRhesn8CHez
lV9pqF60V3IXv+RGDdEL8X+oJ74fzmcj57KB8+K74+E8Qt3mFu7kYVyn9fpc
n+kC1fu7HZH5EvaL54dd7IxnKs5SnfZxPJi5caZsZ218T+qwj2UKxzCd58cz
Fz8f9u/iuzBvZRKTtcXcxiweiJ+5eJ6U5lqqasy3M5NncoDOUKV9JjPYn6fp
VD1gL4oz5Ck8WSdpdvyuYDpP5Ak6XgVxz/E5XZ8Y76V8+x38W3/pI/3s2sc8
jseq3JzHc3lVfBaNtZcxl6VcqW/MabxSM7TLXsJpWq6v7WezUG9ot/1NTlWW
+SZm85x4PvW4+dXk/38H/gdbGqrA
                    "]], LineBox[CompressedData["
1:eJwl0Lsug3Ecx+E/vQYdlKGGOgwGbSQi0XsoSkJJXEC7Kdqq0Vb0ChxbrsCh
UWxslKvQ0SQhnsbw5PP9vXmTt2l8o5DJ94UQcgxEQtjsDyGjJxyTdU8xbxd1
UGM82Z/6qKta1RXd05w+a1dfdJ+EPcoYs+4f5ii7a1rSA33jy37Vih7qpLZ5
oON+54hdd12rmtZfbuxbrmlxxwTjFMgz471lRuw466wx7dkSw/YQJftSr2j2
vu/+5sJucM4ZUXY8b/NhpzSr27qgW7qoyd5v13s9jfz/33+XzDE9
                    "]], 
                    LineBox[{709, 941, 708, 942, 867, 868, 866, 870, 869, 715,
                     949, 716, 950, 649, 720, 1011, 719, 884, 653, 811, 885, 
                    654, 983, 572, 764, 951, 717, 873, 644, 871, 643, 872, 
                    711, 948, 763, 945, 710, 944, 947, 946, 642, 864, 641, 
                    865, 567, 982, 707, 746, 943, 709}]}}], {}}, {
                  InsetBox["\<\"\[Mu] = \"\>", {-1.8, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["0.2`", {-1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {InsetBox[
                   SubscriptBox["C", "J"], {1.4, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["\<\"=\"\>", {1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["4.06`", {1.7, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {
                  {PointSize[0.05], PointBox[{-0.2, 0}]}, 
                  {PointSize[0.0125], PointBox[{0.8, 0}]}}, 
                 {PointSize[0.007], PointBox[{0.4463998339305619, 0}], 
                  PointBox[{1.2771956561278897`, 0}], 
                  PointBox[{-1.0806611991222994`, 0}], 
                  PointBox[
                   NCache[{0.3, Rational[1, 2] 3^Rational[1, 2]}, {0.3, 
                    0.8660254037844386}]], 
                  PointBox[
                   NCache[{0.3, Rational[-1, 2] 3^Rational[1, 2]}, {
                    0.3, -0.8660254037844386}]]}},
                AspectRatio->1,
                Axes->{False, False},
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                Frame->{{True, True}, {True, True}},
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLines->{None, None},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None, "TransparentPolygonMesh" -> 
                  True, "AxesInFront" -> True},
                PlotRange->{{-2, 2}, {-2, 2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.02], 
                   Scaled[0.02]}, {
                   Scaled[0.02], 
                   Scaled[0.02]}},
                Ticks->{Automatic, Automatic}], 96->
               GraphicsBox[{{GraphicsComplexBox[CompressedData["
1:eJyFW3tYlNXWxyw/0+j4WV7O6NHUtFFPgiRkiC5rShM1EcsLyWSWHoLKjmmK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                   "], {{
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[0.3], EdgeForm[None], 
                    GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxNmwnYltP2xp+9t7GBEqWiRIQcyVTJECUcIpFwTGUek3mmQjJFlCGSUBpE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                    "]], PolygonBox[CompressedData["
1:eJwtl3f4j1UYxt9zjigNaVw0hKIh66pwEaEyEg2kZBQasn6Z8aMom7IrDSUj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                    "]]}]}, {}, {}, {}, {}}, 
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwl1Gt0z3UcwPH/NkK6UJxyTmKGpMsmUdmWbZI2ijww6yKNymXooh5wjkuW
S/c0l9TmlktK2bpR2Tk9iIwSW8u0UaQjFYWjJ4rX5/Tgvdfn832y/b+//2+p
xVOGT05KJBKZfhQlJxIXpSQSC/W61tjX6j71td/PW9iZt/EB3soH2Y+pzOIo
ZvIhrlejeR2zOZoXs0yLtESL9YfzP/WOPrN34XF1U659LHP4CN9Tk/ldntBG
1dnf56Oq1AH7Jv6lKn1v/5ATVG7+iMv4lt7U3/YKDtJdulOTnH2qanMP5nMy
2/IyDTf31Gml60tn1fxHZ7TKXqiRGqFpzor4FSfy2fh7OIclrOFTnM8n+bSm
xufSWWf/aqFm2F9jYdyzZtpn6TpdrxuU7Xw761mm2fF74neqUsnKdV4T98+j
2h/ZG9iMd/AbLuVvcaf60d7EC+Ke+F3cIeexV9yleW7ctaris9sHabf5EFvz
Qg0xv8LVfImr+DIHcy9/5WberJXmF3kkngc/UW+tsL/AX/hxPFPdpOX2w9pj
LuDzrOB8lnMB89kqnjO/5c9syRY6aD7En+I7olLzG3yOA9mcA7iLjVwS96Kd
9jymMIc7uI+L9IO+tvdnEm9nBtN1Y7xv8R1Vg7mO55Qw13Ibs/hfvG8aoR7O
rtEC8zPsw7R4b+I9VKl9UtwTr2ZHXaXp8T4zgx14pa7QE/a74zvE9myny+M5
xTPRtc7v1RQV2B/nKZ2Mu1d9PBe24aUqMQ+Mv5HD4vuuvPhOxd1pvP0DbTV3
51A9plr7OBZrgz63p/EeLY3nEHenh+2XxH1qjPkLduUx/a63tcVZp/hcejXe
mbinlP//z50HW6id+g==
                    "]], LineBox[CompressedData["
1:eJwl0LtKgnEcx+F/eQ8NOqRQQ2GCEIFdRAetpYOBF6CmnSwba7LDHVhXUGNH
DKKWCrSltugiWmzpeWn48Hx/Ly+vYKpUyZcHQghLGoqFUBsMYYZnaqvgTqtj
X7GuWXuDc+xwhU0uc5+rfGaFByzzkC96tKfYV0677hYbPGJP33aXezzmGC90
qXd3kyccj35Pp/YTp/mrV3263zjKEa2rqknPFpW0h7WmorKeLShhx9Ww7/Vh
3/FHN/py33Inet/ejr7HDAvc4jw3mecEH3jN89j/f/wHbD0vDg==
                    "]], 
                    LineBox[{706, 931, 705, 932, 867, 868, 866, 870, 869, 711,
                     939, 712, 940, 647, 719, 992, 718, 887, 650, 806, 888, 
                    651, 964, 567, 761, 941, 713, 873, 641, 871, 640, 872, 
                    708, 938, 760, 935, 707, 934, 937, 936, 639, 864, 638, 
                    865, 562, 962, 704, 743, 933, 706}]}}], {}}, {
                  InsetBox["\<\"\[Mu] = \"\>", {-1.8, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["0.2`", {-1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {InsetBox[
                   SubscriptBox["C", "J"], {1.4, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["\<\"=\"\>", {1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["4.05`", {1.7, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {
                  {PointSize[0.05], PointBox[{-0.2, 0}]}, 
                  {PointSize[0.0125], PointBox[{0.8, 0}]}}, 
                 {PointSize[0.007], PointBox[{0.4463998339305619, 0}], 
                  PointBox[{1.2771956561278897`, 0}], 
                  PointBox[{-1.0806611991222994`, 0}], 
                  PointBox[
                   NCache[{0.3, Rational[1, 2] 3^Rational[1, 2]}, {0.3, 
                    0.8660254037844386}]], 
                  PointBox[
                   NCache[{0.3, Rational[-1, 2] 3^Rational[1, 2]}, {
                    0.3, -0.8660254037844386}]]}},
                AspectRatio->1,
                Axes->{False, False},
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                Frame->{{True, True}, {True, True}},
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLines->{None, None},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None, "TransparentPolygonMesh" -> 
                  True, "AxesInFront" -> True},
                PlotRange->{{-2, 2}, {-2, 2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.02], 
                   Scaled[0.02]}, {
                   Scaled[0.02], 
                   Scaled[0.02]}},
                Ticks->{Automatic, Automatic}], 97->
               GraphicsBox[{{GraphicsComplexBox[CompressedData["
1:eJyFW3l4jFf7jsqHhsEX+1C7dqzRVEJRD6b1qbYMWlTbkdo1Pvs2qE+VoVRF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                   "], {{
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[0.3], EdgeForm[None], 
                    GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxNmgn4l1MWx997r5QiSdqmrCE7pUVI2TJDlmSyFJXGmiIihEjKktAiFZJo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                    "]], PolygonBox[CompressedData["
1:eJwtlwkUVlMUhd89N2VcFNGiRApFiEhFSaXBUBIlIZVKqaQUjRpoQEqiUJmS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                    "]]}]}, {}, {}, {}, {}}, 
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwl1Ht012McwPHfNnJJOXJOnEOHTUhpUxaxrQ2bhqSF5M6oTWrDX6i0rUJF
szFjlksX10prFCGdjnPcZ21Mu3RzV25H/3SjXp/TH6/ez+c5Z2ffvs/zXWpx
+fiypEQikeWfjJRE4igWUs0ryYnEYm7kPPNNOkxP1/P1Zh2ut2impuoFequO
0Nt0KT3WS/RCvV2P1qeo4Wlq+c3+Mp6xflV38jsDybJ3l16sd+sbbLF+XXfx
Jt+a39JJrGSreYX+wdt8Z16l99Bg/QL1PM9z/Gm/US/lMi7hXnvNfGx9tubr
VD1O+zDO+hz+IZ2N9tbpbv7lZfN4rqWIB+1dpxt0slbE82qllugnWqaP6jS9
j3JWssfeXqp5OM5IJ8Q7Ybp5BmdyVjwr2fY/01atYab1LB6hif/t5fFlnIH+
GO+QLnO7JuI9aIvW6U9sptv8vSbr5doa71Bn6+B4l9ZV2sxqJpp/jvPiHXOP
vqu9uNL6CX1J5+uLukCv0Dbdoet0KIus5+l2fV/f41wazY/rNl2raxgS5xt3
gE3WhfqYNuiceL/MZbT5SC3Qb7Rbj9AUOq1/0C6tp8L6Wa3UfE2Ku6Jfa0fc
27hjfBV3Rw+SyxfmNq2NZ+Fz8yj9jxxuiDtkb1B8E/EcdFq36H4OxO/gU3tZ
ui++I64nLb45HuB+Mu0N0FM5hSpzqQ7Xk/Uk+vNQ/Lxm6InajxPirpkL4xy1
iOOt+8Z7irOOZ7R3TdxNCsxl+jd/0URHnLn21mPJIzfupL2xTCE7/v/kUGpe
zvq4u3p1fBe0m0v0Tl7jQ3OajqEuzoGR3GE+Ri+i2PojPUN/4df4/vjA3ml6
FU9ap6cc/jt3CBPSn8A=
                    "]], LineBox[CompressedData["
1:eJwl0LtKwmEcx+G3vIGGHGwowjYVghDsEjqHSgdHNw90NivHWjpdQnUJNXSk
JcESyr226BJaau2Rhg/P9/dOf/7DxdXsSk8IoaC+SAhrvSFM8FxnyroTerKv
ua5Je4NTfOQi97jABpfYZJn7LPGAz2rZaf4oo233IWs84pu+7FfWecw4L3Wl
jnuHJxzhrk7tF47zt7v14W5ziIOqqqIxb3kN2DEVtKxRbzlF7X7V7Qe92/f8
1q0+3Xfd79acXeM8U5zlFqe5yRkm2eQNLyL///gPmgIt5A==
                    "]], 
                    LineBox[{932, 929, 701, 930, 862, 863, 861, 865, 864, 706,
                     938, 940, 939, 645, 713, 992, 712, 883, 647, 800, 884, 
                    648, 965, 566, 757, 941, 707, 868, 639, 866, 638, 867, 
                    703, 937, 756, 934, 702, 933, 936, 935, 637, 859, 636, 
                    860, 561, 963, 700, 738, 931, 932}]}}], {}}, {
                  InsetBox["\<\"\[Mu] = \"\>", {-1.8, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["0.2`", {-1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {InsetBox[
                   SubscriptBox["C", "J"], {1.4, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["\<\"=\"\>", {1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["4.04`", {1.7, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {
                  {PointSize[0.05], PointBox[{-0.2, 0}]}, 
                  {PointSize[0.0125], PointBox[{0.8, 0}]}}, 
                 {PointSize[0.007], PointBox[{0.4463998339305619, 0}], 
                  PointBox[{1.2771956561278897`, 0}], 
                  PointBox[{-1.0806611991222994`, 0}], 
                  PointBox[
                   NCache[{0.3, Rational[1, 2] 3^Rational[1, 2]}, {0.3, 
                    0.8660254037844386}]], 
                  PointBox[
                   NCache[{0.3, Rational[-1, 2] 3^Rational[1, 2]}, {
                    0.3, -0.8660254037844386}]]}},
                AspectRatio->1,
                Axes->{False, False},
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                Frame->{{True, True}, {True, True}},
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLines->{None, None},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None, "TransparentPolygonMesh" -> 
                  True, "AxesInFront" -> True},
                PlotRange->{{-2, 2}, {-2, 2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.02], 
                   Scaled[0.02]}, {
                   Scaled[0.02], 
                   Scaled[0.02]}},
                Ticks->{Automatic, Automatic}], 98->
               GraphicsBox[{{GraphicsComplexBox[CompressedData["
1:eJyFW3l4jNf3T2uptgZVSw2lKdVBK6qGWg8dVY1iLEHVbyyVUhE0QhulJWpo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                   "], {{
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[0.3], EdgeForm[None], 
                    GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxNmgnYl+MSxt/neZQUJbJUlIqk7LSQElmzRCJR9j0VCaFDC2UNoRCJZJeI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                    "]], PolygonBox[CompressedData["
1:eJwtlwfUl2MYxt/neSR7lxVFhaTCySrau4imiqRFRV9b0i4NbQ3tKLQjRaSd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                    "]]}]}, {}, {}, {}, {}}, 
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwl1FeQzmcUwOGPjS4YMSNm9BYkSlgE0btE2b0gWsgqiX6p95JEW72Llujd
jE60mHGhC6uXSbQoGW6UBM8ZF8/+znl3Zvf7l90SaYNSB2ZKJBL1fKmUlEhk
ZTrprMycSFTWTppNZ7DKfFiL6+faWatoF62qJTRZu2o1/VZ/46b5V62u3TS7
zuRr8yx9oKuZbV6j//CQ0hxztk57kNM8j/ksZAGPnK9nkXmDLtaeuplb5k36
mC1ctm/VH1hmXs4SfmEpT5yv0HrUpy59ne3guPkTbaD99UPNQ4q5PP9SiRPO
9upznsX129vSjjYMcZaih+KadIym6Vjtqce0n07Svjogfh87eOHsJekMjmel
HajNEPtQysbnpBxfOj+tZ+I+M8w8guHs5P+4Hs6Z5+hfXOCG/by+pTF/xn3X
v9lrvqS7dA+7yUQzZ2N0kY6O56PXuEpH7sbPZZ/vXdf9moVW5ik6lZ/jmdgn
a0u9pHf0d/2MZeaf9LYe1AN8Gs/P/qPejM+ot3QpE+P56iRtoRN0sY7V8Yyj
uf0DbaoX9YomaWYy4p7oZV3AyHj3dJQ20YQ2inumF3Vu3CvO2xvqG+pz1n4u
3u+YORPvmP5HXb6hgrPy8XcRz4zr5lP6mhmc5JSzOvqKmrSnlLOSDGIgyc6K
ahEKxzXae2lVLaQfUzDeFXuqVtYC+hH54+fYm2qF+D75zHnjemkc75Wzdgyg
YfxObaT99CnbuGLfrrk1V7yH8bnj3XTWlj58Ya9NLb63b+QPcxltE5+ZDHtv
/Y61HIlr1dbMMc+lBt3tObQmaeajWkrvcT/+pjnkrJh+xTRzxaT3//PeAb7h
oj0=
                    "]], LineBox[CompressedData["
1:eJwl0Lsug3Ecx+G/9goMOjAgYWolkkbCDbSOS6skRkOxoEcJI4viJtQlOFRM
BioOV1CLuAILq+efDp8831/e4X3b8c29wu5ACGFDg8kQ9hMh5NjWpYrutLr2
NSvK21XO84GrPGSRRyzxkVs8ZpknfNKbPcNfzarmPmWVrfhc3/Yr6zzjRHy3
bvTubvCck2zqwv7gHP/0rE93l2Mc1Y62lY3fpxF7WOta03T8HUrZQzqw79Wz
O/zRrb7cd2xq2W5whVNcYp0LrHGRGb7Eb+dVsv8f/wOhzi3w
                    "]], 
                    LineBox[{937, 934, 701, 935, 859, 860, 858, 862, 861, 706,
                     943, 945, 944, 645, 713, 994, 712, 880, 647, 801, 881, 
                    648, 972, 566, 757, 946, 707, 865, 639, 863, 638, 864, 
                    703, 942, 756, 939, 702, 938, 941, 940, 637, 856, 636, 
                    857, 561, 970, 700, 739, 936, 937}]}}], {}}, {
                  InsetBox["\<\"\[Mu] = \"\>", {-1.8, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["0.2`", {-1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {InsetBox[
                   SubscriptBox["C", "J"], {1.4, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["\<\"=\"\>", {1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["4.03`", {1.7, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {
                  {PointSize[0.05], PointBox[{-0.2, 0}]}, 
                  {PointSize[0.0125], PointBox[{0.8, 0}]}}, 
                 {PointSize[0.007], PointBox[{0.4463998339305619, 0}], 
                  PointBox[{1.2771956561278897`, 0}], 
                  PointBox[{-1.0806611991222994`, 0}], 
                  PointBox[
                   NCache[{0.3, Rational[1, 2] 3^Rational[1, 2]}, {0.3, 
                    0.8660254037844386}]], 
                  PointBox[
                   NCache[{0.3, Rational[-1, 2] 3^Rational[1, 2]}, {
                    0.3, -0.8660254037844386}]]}},
                AspectRatio->1,
                Axes->{False, False},
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                Frame->{{True, True}, {True, True}},
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLines->{None, None},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None, "TransparentPolygonMesh" -> 
                  True, "AxesInFront" -> True},
                PlotRange->{{-2, 2}, {-2, 2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.02], 
                   Scaled[0.02]}, {
                   Scaled[0.02], 
                   Scaled[0.02]}},
                Ticks->{Automatic, Automatic}], 99->
               GraphicsBox[{{GraphicsComplexBox[CompressedData["
1:eJyFW3lY1FX3x1TyVUez1GwyFCWcTM2fNkhGHg23LGlSE9MaxS1eR9MoF8zS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                   "], {{
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[0.3], EdgeForm[None], 
                    GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxNmgf819P3x9/3XiWV1UCSlMoeFZWRmYgyMjJCMsrIyAzRUMjOjiglK4qM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                    "]], PolygonBox[CompressedData["
1:eJwtlwnUT1UUxe9QaUIipQhpIIkiQiKUEg1UhkiTEJmHUkhlqNBAUWZFIUqG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                    "]]}]}, {}, {}, {}, {}}, 
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwl1Gt0z3UcwPH/NhXOUedUD9y1rMsiMswWJZdJqgcJNa1iZPXAhIrQxW1r
Myssra0LudY56ZwOFV0xl2prq7VxyJTk6IlKKqH0+pwevLw/n6+dnf/v8l9q
/rTRhUmJRGKwf9JSEolzyYnEYi3iZfNVOlb/odhcpZ9oR71Gx+nVeo9eq530
U63We/mX5+wlvGJO11w9T6n5Vl2ih/VVysyv6Q98T1d2OFul95Nkfp4XWM4y
jjhfzQrzG1qhD+g6Wsxr9UfW02zfoPlUxjXyIi+xkqPOqzSDvvRhsrO3qDGn
aj+doq30Au4wd+dY3AN2O3tXf+Y41fbh5DAsrpkRrI/Pwnhm+7lcfVLv0028
TT6TmMhD8Vl4hxN+7pd4Vky1L9LR9KfQPo0udKUbA5zX6e54HjxqnsF0NvO7
s4E0mEv1AF/wnf1z/YObabSX6UE+MNfpFn2f9/jLPoQn4hnp4/G89Bu+Zkz8
Tr5lq/9r1G16VnNYYF7Is/FM7PPj3ukz8Xz06Xheup99fGT/kCupsD+lTXpE
m+OdYG68Kzov7r/OifdGZ8X9jnvPUPsZbonPZm/QvznNV/E+OqvXcmaal+pj
Olj/5Ka4RnttvM98GddrH6SnuJF6+14tYU/8Xnu2niSLu0l1dgXF5l1xn801
+htF7KTWWab+SgZ30cFZewri3aS3s8v1Mi5ljj1Pe+olejHtmGkfqenaVtvQ
mkfs2Zqmd3KR+UKy4l2K++3sdgrinbM/rJnxjupPbIznY39TUzSZG+JzxfU5
G8Uketp7cX284/Y1cY3xzuptPEiTfUJ8L3idz+yd43Oz1FzOdfE9sie0B3nm
7fEd0EO0UMnHzjroCBaZu6f8/3fvP3rtoxk=
                    "]], LineBox[CompressedData["
1:eJwl0Lsug3Ecx+E/HRl00AFLB5pIiISpqg4brUPMTjG21YOVweE2XICkTmWR
lIQmEuEGVCLGLtyD543hk+f7e9/hbZrcrayXu0IIG9rrDmEmFsIdz7iknBa1
rLzOde/9Fg+4yUM29WpP8EeTenM/8UgD9o0aenYXeMxB3kbfVMtd5AmHWNKp
/c4p/upBn+5HJtivHW1r3LM19dlxfWnMvcJRrqrX7tG+3VA7+l3s6Erf7mvW
NG9XucAU51hhlmXOcoTTLDLNAi/0Ydejb2tYL+5LlpSJ/f/XfyocLPI=
                    "]], 
                    LineBox[{928, 925, 693, 926, 850, 851, 849, 853, 852, 697,
                     937, 939, 938, 637, 703, 992, 702, 872, 638, 791, 873, 
                    639, 969, 561, 747, 940, 698, 856, 631, 854, 630, 855, 
                    695, 933, 746, 930, 694, 929, 932, 931, 629, 847, 628, 
                    848, 555, 967, 692, 729, 927, 928}]}}], {}}, {
                  InsetBox["\<\"\[Mu] = \"\>", {-1.8, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["0.2`", {-1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {InsetBox[
                   SubscriptBox["C", "J"], {1.4, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["\<\"=\"\>", {1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["4.02`", {1.7, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {
                  {PointSize[0.05], PointBox[{-0.2, 0}]}, 
                  {PointSize[0.0125], PointBox[{0.8, 0}]}}, 
                 {PointSize[0.007], PointBox[{0.4463998339305619, 0}], 
                  PointBox[{1.2771956561278897`, 0}], 
                  PointBox[{-1.0806611991222994`, 0}], 
                  PointBox[
                   NCache[{0.3, Rational[1, 2] 3^Rational[1, 2]}, {0.3, 
                    0.8660254037844386}]], 
                  PointBox[
                   NCache[{0.3, Rational[-1, 2] 3^Rational[1, 2]}, {
                    0.3, -0.8660254037844386}]]}},
                AspectRatio->1,
                Axes->{False, False},
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                Frame->{{True, True}, {True, True}},
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLines->{None, None},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None, "TransparentPolygonMesh" -> 
                  True, "AxesInFront" -> True},
                PlotRange->{{-2, 2}, {-2, 2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.02], 
                   Scaled[0.02]}, {
                   Scaled[0.02], 
                   Scaled[0.02]}},
                Ticks->{Automatic, Automatic}], 100->
               GraphicsBox[{{GraphicsComplexBox[CompressedData["
1:eJyFW3l4zNf6T9EgJNpaO1XbbYnaU3FVyVviqtruUEtqGVujGFW11aRpqWWo
vTK0DdWMi5ZqgsY+vHYZlCTIkEQqTCIiIpmsM5a5t3PyOfN7Tp48P/+c5zPn
fM+7L+ecaDnps2Hh1Xx8fBKr+/j8PV6Ob93EZLvDHer1eEMX6uR2dRMe2IOv
S1x+1G+N0XFUYovABNxUrJf4rNhP4u6v7NHZtPmcfOiHYf5ZJbx48rRjwab7
EoM+MOgDgz4w6AODPjDoA0cIehJ3FvxI/MWEskUWo0OO4BcY/AKDX2DwCwx+
gcEvMPgFBr/A4BcY/ALPEaPEkEPlG1gdIQ8w5AGGPMCQBxjyAEMeYMgDDHmA
IQ8w5AG+IuShqvxGtYsqlzpCPmDIBwz5gCEfMOQDhnzAkA8Y8gFDPmDIV1Uc
qH6m2kmVSx0hHzDkA4Z8wJAPGPIBQz5gyAcM+YAhX1V5RY1zNY5UP1TtBn6B
wS8w+AUGv8DgFxj8ArcV/FJVeVDNS2rcq3Gj+hn4Bwb/wOAPGPwBg7+q8rKa
J9U8pMax6vfgDxj8AYM/YPAHDP6qqhNq3lbzoppX1DhUR/AHDPsDw/7A4B8Y
/AOD/6rqipq31byn5gk1rlS/Vf1A1bsqpzpCXmDICwx5gSFvVXVSrUNqHlfz
npon1DiEfMCQT7WTKgewOkI+YMgHDPmqqvtqXVXrkprH1byn5hXIBwz5VL9T
7aLKAayOkA8Y8lXVF6h1Va1Dat5W86Kah9S4V+NI9TPVLqoc6qjWfbVOqnVF
zdtqnlTzkhrnahyofqPqGfTVuqDmYTXvqXkEGPSB23jm7bzIw0cZ+3j+nbCk
evZxcXMxT5i/6Pm+gN/w/F4s6wvmz4t5wjxGfNdCYALGd+AjUuBKfN318JMq
54GR34HxHfAlz3hRroc8D8Tvkl8VQw9Yj30wDwx6yWJ/+Tsw7InfIQ/mgUFH
1tGKecgLDLup8/ge+gaf0Dewagd1nWoH7AsMvaQI/5D+B38B/8Dwb8iJEX6D
fVU/gt9jXu0zVXsjLkBftb8aN5iHfVT7Qy5g7At6iCvsr55DVfuq9Vi1H+ax
HnrDvFr/1N+BwTfsA76BIzx57y4bPettPOxI0mOrvpw6ePSQQZc9eSeL8Pt1
gXmkwIx5YIy9xPdyP+AGHr2cJdDLOB55we1+TEHid4mxDvx9IdbL34FBD/yC
P9CFXdW8AbvAzpgHxrwap8BV2RUY87c9OFfmPWD0ATcElnEKjPmqvgPe5f/C
crOllDt76D2QckNvVckFXCN8W5hD42LoH/xjHn6s6glxj/2Asd9Wz/rdMi9h
vio9AuP7Ux7/TyQ1j6pxhnUYpf4qvgPGd2reB0a8QU61LmBerQPAmK/KjsCJ
gk+pd/gzMPwaGHaFnQMFJmDQQ9/yZGLnZgb/Es4WcSTzOvwFfQTwDrEPgQ7i
Cf4DPsB3VXUVeQxxjhFxDgy60CvyFzDiF/SA4Z9YB/rAoI/vQA/fAcNe+B4Y
3zc65vFbuR5+DAw/Ax3kWfCBeqLGF/aF/KAL+YHhJ9ArMOoV7A/6i6eklcSa
8yRW/VSt0+BPjVf4IfhDfIE/YNgD64GhF9DDetADBv9YD/6B4X+zhf9JvSO/
Q05g6BUY9gJGPsR+ahwhPqBnxAcw4gProZ+q4gpxhO+wT1V0sC/WQx/AVfW5
0Cviy0fYUfpdVX4J/WE94gMYdqrKjrA71sNuwP9fn4r8hvXgH34IP1frkloX
gJHXgdW+CXaHXyFvA0Pfso5W9H/Iq+hHkFdhR+TbMvE7Id/KvqginyA+1HsV
2AX8QU6sV+9dYAeshx1QP+HvoI/voF/My3vECgy6wPIerwJDH5Ab+oDcoAN7
gz817mB/6B/z0JPscyvqDuSAnmEP6Bn2wPkFI+4fgIccHH9AqyviGL91gwLj
CivVfWB5T13RzyJOQBd6AF3oAXRwLgB9YNDfIuhLPWI/6FHdD/cR4HuA2Ef6
HfaBPrAP6Koj9gMf2E89V0H/6jlAjRfoAeNK8XslO4B/6EE9d6p6A5+YB5+q
/ZBXgNV7IOyL7yE39lH5gv7hB/BHxA/kBx3Mq3ULv2Mf/A5/wjziDPOoY5BL
3udX5EvM43vkB3yPfIDv5X27cm4CX9Ab5EOcgi7mkR8wD33B79S4hB5VvWId
7KDGBewBP4Y/gS70DIx8iHiVdUg5Z0AeYMgDvaEPVO+vZNxX1HP4OfSL/AEs
348q9A17ww/V+x9gxBO+g1zq/Q8w+hvoAXyq9z24BwDf6DOgX/UeHfxAn+AH
cYi+BRhywG6ws8qHjNeKc5B6boRfq/bAetRDyAF9Ig5BV9Uf6hL8HvqCfKj3
kB/8Yh70er89M89+4G6ld7etjY/VNzi991t3ti5caH7q4iGGVzS66o8rvROn
cp8Ca7tySa+v/5wmhsHlnDto+0JLvyKZL8d87hzvcHjfzzd8U62u6ZD3Pqw0
Mqyx4VF5pffMjXv9Npgj7/CwvWd7Bdbz9lGbht1oaGpzV2L53tN75acW423v
e6xuS1Nd1G3ZJ7Z/1vykZmU6h6SVj3JEuOS6nM6vzrZpr1V6RynorBnh0FyW
69X3uzF7v/I12XbL7zEPfrEO/KrvFAfC0ruGGi5IuZ9veP+i5mKK3Ceg0TtR
xtk2gn5gf+gPfEK/6t9dbPWLt2gi8gn2QB1Bn/7esk8N5hne942N695vaRhc
RLA31uG74XXrtTR86q3XA/a1Geb/ZinBn6Bn8BH/fFSEpV+plG9v4v5apu+9
9/um/BqtdEtcUp+FcwaG29a7pJwz0midcb+TNC8ZftOHZfK1nvceWZc4ecSb
nxfGtvyLerQonGPJdvJLYXa7dXM+n0iN32j0K+VaC5onaXIdckyZNGuFOa+E
+0wdc9E9Pp9LF1z+TXuxnN7OfKF2nDWTcyaZGhoeObnJmC5x2owU7nrrQRfd
kkx2Dh/yumHNDQ72yJdMA+q90zvUcJJrZTzPtS+7RtOrZX9nDDpM3/xa9JPe
x0mz7/9YJ27oHWoYacy2+5fy7m8TuwW6H9F+jx6y6ezYfUvMW8opYMeklw2D
L/PG4wt7Bl5w8f4jf+t5Hm/4cFy0vtYTdhzwYAIelpuzWR94kS4uyu4YesvF
E8I7X9CsvElfv2narA9z8fWBqxqbOhVyp/+0f2BfU8xLl2+dYkt8IOvD6FNf
rjHuz6XT2eZjwXPL2Leeo3Zc70L6eEpUmvvnYhmnPwr781pd53m29YWyXria
TP5D+3Uxx5w6leluXsg7x/iO8F9WTENqhC+xtC6UeWGn8DfupjsfZWxVRsM9
cZDLP/T0K7AOLOewE7U/9N+RxW89vnVB81Y5Gf+xq1rcxCw+62ebYtvrfd+Y
YQg+q+nh4k6TU6c5RifykIh5HUNfTZPjoHK/mqblqbzgK7/6hnFp3Ccgpb1u
sp1Hnunzo/7XSzw/5tA7oUfsHDtt0GD/rASu9rzHUe3WRJ415qSPqXEGn9x3
4GSw6SzPp+Ci2JYZXOQ5Z61kvytXm+vOpPG37h6THZq5lLPz+5GOPmn8w4wT
y42OP+mgGLmvh76L03cULDRbojl1xP4Ghk9z6dqQGTMtvn/ylOSg2/YRD6n9
q7/96V54mXUxUXv0hwsob1qDKH3gQonbT/FgSv28VyvdZBefnx3TLdRwnsD/
esE/Qb7uQj6qG9mrepx/FmmedG2ji7pAoH9A0KcVA7Q51t/yZN2A/rVC/wQ9
hoiRoJ8JQj8Efbj+9OiDHJa/69G6SufepiKf0p1fVncJ/cj7XrO326EFlqAy
Dp64s6apUy7BHwYJfyD40xbhT2Q+3K/Uesb7TgN/bif8mUpf39zIdMh7zujv
0X8ud1k8bYFFV0bw7xPCv6lpnybp9pKHdPPnu1HGV8qovJHhWezQm5w+tPUu
7QCXjL/vRPzRwA3tHlkfWvn0jQBnbJKLEI9rRfwR4u+8iD86GtNvldFxiZqE
hK4xJrsI8Rgh4lG+n/zKTw4HF5fL+vSDyHfcZWH4FzbtSfmetOpwfCfdmdPy
PQn5sETkQ86Y2mmNuec9eS5G/1Fvc+Entpec8nySHj9gh/5mMc/c9P4cS79c
2c9fb+ZTGDvxcaX790Xjdl3TRBTKuhAm8jtD31hXaky47R5fJOsE7DDIpq8d
t6aQd/+8eawjtazSO2lG798bG47nyHNY8MQGvQM75ch7hLpRnnrH7fXLcq36
tEr3sBeMi781Oi57666ohwx/xPq16Q9S3W7vOQB+37XZ3cGBjxMZ/on1/lkt
79sPeO8vrvR+baj/8Wx5f4H6dU3UZ0Y8YV5zfU3v0A+872fYD3zOiFy81hx5
V9ZxrFff13YJ+Qj8q+8Abwj+vX9nIfoRAr+yL6zIn4g/6FPt4+NFfyT5toj+
iGA/9R0zRdhP3oN0EPajuZ78VFzpHTxS+BPBX+BXMm6FvxDqi/pOflP4r+wL
U0R/Sahn6rv5dhFfUj/vif6T4P9Yj/hR72vqiPiR+ogW/S8hPtX3xXTRDxPi
FfM1xq38xnzdyUuXWBsbfr/JyM/dRX6W9XKAqJeE+jtB1F8ydl5VPS7TLvu8
bTOX7tU2y2aL6cJW/Ypynv9g6XZ9/yw2xqSd1xwt56829VtvjsykWj4D7tg3
Ohn9RYLoLxj7ucR+PF+b18f/XD6VphzuG9i8lCc9C29gKnPQFDFycttrlzS5
JRRS2mKoY3Q+R44eW9v0TydPHai/6+Y7jP4mQvQ3vPrfy6c6NKeoz4vWCItv
Csf3efSNeYuTRqaaJjiib/D63E7X3OOd9P7gt5PcC1P5lyMTevvveExhT0Yl
aS6elriHwIT+y0/0X1Kf84U+Cf1YrujHCPS7CvoE+v0FfQL9fwr6BHkmCHkI
/WAP0Q8S5O8m5Cf0jTXESNAXRvSbR0W/SdCvQ+hX2u+wsB/BfouF/WQ/e1X0
swR71hD2lHlqrO/cXdpmLvkeNPPJzw+tl1wyvyUE7DkQfN0l43zqlXFrjUEu
+R4zKGl5rDakTJ5zJz1u4Y6dWMZv1FxvND8tletQr3uJes2Dbox9FjuxXMYZ
+tbxvxz8VZ9zl1sPfHOtcZiXL/QvdtG/cPeyJeG2WS7eFHFsscV4iud377bU
6Lgq82egx55J5DPib3ue4+gJtFm/wiXP0eiv8rZ7+ivadOCTcNsiFy+YkvqK
yfaHzJP34jznL9rt6eeuy3sS8Ac9oZ9sKfpJsjwrDrd1dnFM488HB3ZKIvAn
+6WKfg8j9Le+NJY1Fy9L++wcob9tD06TciWuDn9NF5oh+Wgq8jBBn8g76H+/
Fv0vDVq9boMxuYxuvfy6v6nx/87tFfYB3eysiUP9N5by80Y/rTQOy5P7oz+p
MyZog/7Xvzgx+eRA/3NOTqw9d5gj+rY812zz5KtkLs9almHf6NUzzhfjPHFy
lOO7JJTH/u/8H/NZp7/swUdp9Wc5v2ifu/i7lfVOBDdIIZyDo2PcHzqO5vG2
gnybO66UO6+ekWPdnMdfxXzgE3eklNGfBYv+jBt9HDLR0aOEAyZebm3oUMCo
H8j7uJcw5rT4XT+1gHF+2i/OTwz5fRt75OepM3sZLNml8p2q/7sTP7U9LaF+
dV5rG9oyn4OmtyyyriqlHc2bXnFTHp/Pne9n+v7/3MNMi1pqblrOGSMbttUt
yeb58+83MnRwcs/sS0G66pncfe3IrfqEcg7xeyHDTfcY9skU9mH4z17hP7Jv
OSj8getZ4m+6KYXPTy/70vw0na/ODphlW+B918W5p/Ro7d36wNPy9zvCf/hJ
QdgRbbMkrp9iOK7xy+CcMYNXmy1n+NWj+XHBDbzvvajzt0ZMd1n1+/mt6/v3
BTe4zUGxB12xmd732oQ2Dxoajjtp7646/zAMTua3wmquMyY7Kb/avHtW/VXO
7Ve7lqnMSStec3/s0Jzh+rUfhDkcTtrycMN9+7xzjPiLF/HHjnaZAabG2ZKP
7i2HrzA/zeIhQ0/lWPV7uMfowr6B7iw+b1r0iU27izGfovXME+aHiHnCeXqn
OE9Lv48V8cb7PlnWO/DxfTpzKWKHVneZNR1WjfYPz5RxMPVUxG59TiZBD9uy
H37imJ1JrXruLLfqoxjzP4l5wnzQu555iq+V8F7oEe/fw60OSWxi+qKAdKP+
873REc/ArQSm8vfX79IGuOT6mJ0nwhx+Lir29HN7uDSgKM9ax0UOZ/PGBv9d
jPlIMU+YjxDzhHy5QORLgr8gH8Ffbgp/IdxHtBf3EYR8etdTH88R7I/vYd/p
wr4E+34t7EvwD7PwD4J/JAr/IOh/h9A/4XwbIM63hPhCfkM8dRXxRIinbiKe
CPGXIuKP4O/Vhb9LO2qEPxPO4zfFeZxW+h67Yx/hpOE/BCw090wj3Oe0E/c5
8p5llKhXhHwBv0K+CBH5gpAvfhL5wptXRP0k5LutIt8R8p1B5Du5r07UVwod
cXum5Xwe+b64ODTwqve9O0zUc5mvL4t8TcjXdpGvKXH3waH+4SncsX69OZYp
3vfv6aL+E/J5scjnhPy9V+Rv77lA9AfkO9Z0Jrg4mZKufHVGs837nv2x6BcI
+b2HyO+E+7Vu4n6NorZf36bNuE3R3+7ZpX3ulPd58eI+j3G+viPO1wz+gwT/
jPP1eXG+Zpyfm4rzM4O/G4I/Br2tgp58950l7gO55OrG/oGP71GTwphr7ube
//82RNxHMs7/6eL8z7CHn7CHPN8dFveTPGXuswk2n0fy/vzWkHV14kYVUNbQ
F/oFhnvv56Onx010uIp5kqePLJD36Q1+Snvd0KuEXoqeds/dqUDem/YX96sc
mVunX+B473s67jtQ//B+cbfrxbd1cwo48NL2poZH3veMBTkt1xuDnPLc/FLC
2+c0u733qHhP8Jv/8lqzZT8vvzCuZ+g79yj1s45PrfpTjPMozjl4Nxj9JCw+
2HRMxu3ZGce36wPP8daOZ8usD+95/36xzuKN+oRHZDZPmmpLTOBZB/oe0wzw
/n0j3nu2n/u+vsH/knw3edzXlel2n+QtT7Jb6ap7/44W/F6Z5+GXwK9F8Cv7
pJ2CHwI/ePfA/klif8L+OKdBP+gTJ5hf6xL6o5Njqn93UjMgXd6jrBHvCzRw
yeI79nnevzeAvuF3uG+cKu4bCfX9oKjvhPvEKeI+kVCva4t6TbAn/A7+lSn8
i3A/A7+BfMM7972s2e19/94k/I/gf/AbxEMDEQ/yXSikw7W5lilOwn0y+kX0
dytEf0d2Ov215fw9rtv2UL61jpPbpu1roQs9xhnt/+VrKnPxl4t+Los1H6Nu
NePrG565uLDDO8+toQXs7Pxb99ChJdxm6o75Fl0OJ4fXfNXgLKs49+RQs8gm
v2sDyjkuf+OLcUeKuFrouS1GPwd3C/5omXlPGRX7fvBv/3P3GfbZK+zDrSM6
NDA1vseBORtCQp1JjHz/scj33MnTV96nBu/5/ahPuCTXa8R6gr8uEf5KaT1W
PY8a9Rc3XN1/jCP6Js0quDggMG4/UULE09jMmwR+8gQ/hH7VT/SrBP6f9/Hw
T4j3uiLeKf3I4lpxLzt4afiHn9tOFhH0UyL0Q6vvRG8xtnJQj9X6F+OSiqS+
awl9y+9XiO853ffN08FniyhozPCP/Bs62OHhq4yn7g68Zy+5z5DnDSEPP681
aoPRcYH+JfoCidEn4PsJ4nvC/h3F/tSqfPgfWuN1+qD6u3/XWQa/IYJfhr6G
CH1J/ZeSR/8E+18R9if4T6rwH/ov+lCNxQ==
                   "], {{
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[0.3], EdgeForm[None], 
                    GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxNmgf8z+X6xj/P86GQ0lSSiJbMFiokGoqG+GtooKLM0ml3yujUSUNSiYZQ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                    "]], PolygonBox[CompressedData["
1:eJwtl3f0yGUYxd+hJAkhI0SkQiUtiUhlh0SIkJmQqFBECKWSvcookVKSlHG0
NE9DJVKdSp1SGQ0NpTQ+1/39cc+593m+4/2+77O+VXsNaX9DCiF8DQqB7xEl
cgh1YwjFwfXof8Gp8F6gKfw7UAx+FtgNH8n1d8FLgoHo/0BNeG/QIvka+c4G
p3BtOXQj3tUC3QS+CxSBnwn6w/8BNeA9wGXwb0FReB2wH34NaAWvAM7heT3Q
V8Lbg3bw6eArnl8PvRn/c+hP0RvQNdBdk9/dHLwBLw524j8EfoV3B23wVQR3
w0dzzxR4CfynwyvofcHXPI5+DHyG/gNUg3fBfxm+S8EseCdwMXwX/ruS90R7
oXfeB3+VezbrfejO8Ai2w/thm4h/OHoS/EhsveG9wDPwm7CV1X6C8+E1tafw
lqA7uh/6du5/IXlto7DdqbPLPrs7wRx0N9AS/i3X1JUPXAtvF81ngOnRtjVc
+yJ6Dfpj7Qf6ZfQ69Ar0jfBx2Mah7wB94Q+Dffi6oU/DXxNcrvPCVh1eFv9F
wXtWB94T21D4Gmy14bVAt+B7RuBfD37XuxQz+Opkr7UTtqrwzviboBuDofAu
2AYolkFH+GBsW7m2r/ZM+4NtNfxBbN+gh2SvvTBYhd6EXgn/CH9D7T+2t+B7
wYPoT9CF8M/WHsEbYNsTfI1idZ5yJjhm/4C/jX8rvDLYiH4UvRC+GPRMjmnF
cgfQHX6NYoz7B6EfwX8IVIf/gC3hy+DX4JhR7jbH/3xwDjeE/5KcK52xFcV/
CXoj/HMwFD0+mY9XzGafmc7q6ujc+QocEZ1DB5K/QWvvhb4KfiL3NEBfBCpp
7dg2B+fgJehKylnFtp6ZnCPKjabRsaecVC4qBqegn0Yvh7/IPZPRq9BL0ZvQ
f6J7Jz+rCmiNrxUYFhzzzeBNs9dWDT2Ja99Mzu3Jikn4SvwPwTdge1pniX4d
vQM9Bn0d+jb0aHAr+trsXLs5FuRi8rOUk6pdh/cwuoapVg1DT4iuWaP0rOza
oRo5SPEHxsDXY9vB9R+DbcHf0AhfY9ApOubLwEtrD+GlsJ0Prwc6wrtgm8a9
e0Fp9JfocYrd7Fpwr9YMPy+5dqhmj0HfDl4IrmnHwotn1/rC2OrDLwC9g98x
inv7oofDRyo+0MegvwiOoQnJNVq1WbYb4U8o5uD9tV+KpezYHaxnoHugh0Tn
eGPFFvoM+P3cUxh+VHbuRdW47JqlWqU9bYK+OLu2aY/aK7fxfxD8zkFqZthq
4+sT/S7VDNUKvbMV/BV9P7yk9hR+XHasnYtNzbAROBh8JoqVo5PXophRbJZI
vlcxOkP5Dv5U7VDOwftkx8pa9IWql+A1eDO9A19F9ZfgnqXacmryt6vGtMuu
KYdrSXRtWYCeFV1jlAvFks9KOXE2fEB2rK7Dtk69BvwVXCNfS455xfrf4Mzk
nqheqB7yJXot+C04x7W251RvoteoXtwG3TO6J69Ingk0C/ysmqFYz461l4Lv
fUA5F/yMY9Xfkt+tmvQA/vngx+BvKoXvXfBvwQxSGv4O+Cd4z+bCt4D/gmvo
VO0Pejdch7JIa0XPVS+LnlUWZnPNLC+pVyb3qrXRvauWrgnuYXrXRGz3Rb9T
vewWbJ8E97R79G1gWvQ3zdZZgLfhM6N799Tkb1cPX4H+Ojm3F6EX6myza7nW
vAg9LXvt6hGKxdbJtU0xeRJ6AXpqdA+bgr47F+Q6+nn4U8m9aFV079iQCt4V
XctWJ/di1TTNYouxzYueyZaptuqMor9Rvahycm9QT1qCfhw9P/qeR1R7s3ux
7pmc3XPVa7VG9c6bkmuneugryT1NvUwxuAX/MvQNyg/tN/qe5FlnZ3Suqier
FytnF6ueoLtGzxzqHb+DStE9pK1yLztXVRN1dieoZkWfoWrhnuRaqZpYXXsF
cizo+arH6BHRNa0qfDtI0TPK8uQ1a606Y/mqJce6rlHv/Tu5t6gH98vOeeW6
nvlb8gyp2VFr3gf/AZSJ7on3Ju+Bvl01uCK8PHg5+Bt+wv8jKAsvB9riuyK7
FqjGHZ8942q21czXET4zufY0RF8Br5DdC/RMzZ6aiTQLaQZ9NrkmqxYr50+G
d8qeNfcHn32H7NqpGKgML5Ncu+pHr61DMtca1fu1Br1bM4By8crs2V85qdpx
Hbb3gmvINviHoH9wDVBuz06ePZXjJ8G3qt5G3zNHvTp51pJNtaI8+D64Zuhf
4uTsWUL/FJrNf07eO83omi2rZM8mmjGXaL+yc1c97snkGVGzoWaorviuzp4F
NTOqth+fPLurxr+vb0meXbUGzbpFsv9dNPMWyu6B6n3qaaPFsR0I/kdQLlye
/W+jnNiU3GPVW3VNn+QZTLOXckCxuzR51lMMH0yegTT7VI3uVTpDnZ161sDs
nqBeMDZ6ltE/gGZ/zTSnJdcQ1Q7VwNrJNVK1UTNmFfWO5GfrjK7HNzb5WZpZ
6ifXbNVqxfT/tDy/kA==
                    "]]}]}, {}, {}, {}, {}}, 
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwl1FdsV2UYwOE/lCF7lDKKNXqhCBZlIyO2BZQ9LEQQFKHIhqJAoUjVUimg
IuNKBG9kCDJklKosJyrLQAIJe2+ZCZCgVzxvuHj6+96vI+f8z3f6TM6k7Nwy
iUSioy9PJCUSl8omEpP0PWZZV9JOepn3rYt0vVbRKtpZK2sXrapVdYN+oq9y
hcnmKcy2rqav6VWmWrfRPP1Li5lmPUf38Dc12GRvnnbnOvnmGczkA/ba+5QC
64/4kB7m+Ryw/lz38QW7zQu0D0VxnXwc90oh++3P1nrUpy797C1mi3VtTdNs
vckt2pPMPzSg1Pe/0kMcZI65MU14nnReYDEZZPJKfM5k8SXd4x7oRi96soSj
/t6xeEa8Yc7VDJ5loHkQZShLEs/Z36Eb4vnxpvUQBvMNJ+014ed4Rvobm+Pz
Mm/S0zSNfXOe/s4q629ZzkpWcNZ+M4ZZ5+s7Ol1/4key+IPtrPa9bbpGL2or
JlhPZFw8D/N4balj45nqmHiucZ3sYq35OypQYB6tO+Iz1506k5FxPnSUttB3
49zocB1BDs3NF3gp7s38g57nHFvj+dkrjXPJW9ZDeZsXzWdI51dzSZznOCP8
Es9XT9E4rte8Md4DvmdnnAM9QSMyKW+vXLx38X6x13qdZutY7auvx1nka47b
W6rL4qyx2nyEwzzN//zHQ0bQ2c+k6QPuc4+h8Wztp+pd7nCbATxlP0U7xP3Q
nxJ7deKdoti6IU/SIK7NXqou1D91kd7gX1Li96hl3S7uhVrm5Hif6G3+LM6d
dU19mZ5xXuLsa1fmxmdnrqZtmW5dnRpcM9eMd0U3xr7ujuugkHX2Kmtrcq0r
Jj3+X/cIL4yYEA==
                    "]], LineBox[CompressedData["
1:eJwl0DsvQ2EYwPFX+x2QNFGnik2LVU0uu0td2i7C4lIfo7t7JBzBgFkifICS
CJt+DwYGgt9Jh1/+z3Pe5bxvtLI9U+8IIVRZTIWQS4dwrA0tUGSIEYbZIXY+
qas6oWt6zp050jf6uLdf6Tq/nNhPuTbP6ob+EZvPuDHP6aYGnWfL/KB5bXHB
k/1Sf/hm2j5F1jzOJ188+9ajo5rREh+8U+OIR2eH+so+L/YDrTJgruigdmu/
Lid30yXNa5f2almzyT/rLs3krXSMTm7te7pAlG6/9T8fwCzV
                    "]], 
                    LineBox[{908, 904, 906, 905, 823, 824, 822, 826, 825, 672,
                     915, 917, 916, 614, 678, 974, 677, 845, 615, 765, 846, 
                    616, 952, 546, 722, 918, 673, 829, 610, 827, 609, 828, 
                    670, 912, 721, 910, 668, 909, 669, 911, 608, 820, 607, 
                    821, 540, 950, 667, 704, 907, 908}]}}], {}}, {
                  InsetBox["\<\"\[Mu] = \"\>", {-1.8, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["0.2`", {-1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {InsetBox[
                   SubscriptBox["C", "J"], {1.4, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["\<\"=\"\>", {1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["4.01`", {1.7, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {
                  {PointSize[0.05], PointBox[{-0.2, 0}]}, 
                  {PointSize[0.0125], PointBox[{0.8, 0}]}}, 
                 {PointSize[0.007], PointBox[{0.4463998339305619, 0}], 
                  PointBox[{1.2771956561278897`, 0}], 
                  PointBox[{-1.0806611991222994`, 0}], 
                  PointBox[
                   NCache[{0.3, Rational[1, 2] 3^Rational[1, 2]}, {0.3, 
                    0.8660254037844386}]], 
                  PointBox[
                   NCache[{0.3, Rational[-1, 2] 3^Rational[1, 2]}, {
                    0.3, -0.8660254037844386}]]}},
                AspectRatio->1,
                Axes->{False, False},
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                Frame->{{True, True}, {True, True}},
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLines->{None, None},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None, "TransparentPolygonMesh" -> 
                  True, "AxesInFront" -> True},
                PlotRange->{{-2, 2}, {-2, 2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.02], 
                   Scaled[0.02]}, {
                   Scaled[0.02], 
                   Scaled[0.02]}},
                Ticks->{Automatic, Automatic}], 101->
               GraphicsBox[{{GraphicsComplexBox[CompressedData["
1:eJyFW3tY1EX3pzQia42nMJXMC6mtl8rM1fTFjomaqdWKpOZbm2kqupblBVzS
8opKmZarGZm6ZN5S8I7h1lHEC4qGhKxKoMByERFh5bYbuj/b4TP7POOP5/Wf
eT6c+c6c+zkzs3aYMCN00oM+Pj5/NvHx+XdMO9C5ldl2jZ9/vF9HQ4iTuz12
+rpdlylxXVKzldGOJImtAhNwGzFf4hSxnsSvPLHLYNOXc0bi+lBNYTUvmjj1
iM5cLDH2B8b+wNgfGPsDY39g7A8cJfaTuIfgR+LI8bULrNEOOYJfYPALDH6B
wS8w+AUGv8DgFxj8AoNfYPALPEuM1Bjf6gj+gcE/MPgHBv/A4B8Y/AODf2Dw
Dwz+gcF/Y36h6l2VQx0hDzDkAYY8wJAHGPIAQx5gyAMMeYAhD/B5IQ815ueq
H6l2UeVSR8gHDPmAIR8w5AOGfMCQDxjyAUM+YMjXWN5Q41iNE9XvVLuBX2Dw
Cwx+gcEvMPgFBr/AXQS/1FieU/OOGtdqnKh+Bv6BwT8w+AMGf8Dgr7G8q+ZB
Nc+ocav6PfgDBn/A4A8Y/AGDv8bqgJqX1byn5hE1DtUR/AHD/sCwPzD4Bwb/
wOC/sbqh5mU1z6l5Qo0r1W9VP1D1rsqpjpAXGPICQ15gyNtYHVTrjJq31byn
5gk1DiEfMORT7aTKAayOkA8Y8gFDvsbqpFp31Lyt5jk1j0AeYMij+plqB5Vv
YHWEPI3VdbVOqnVGzctq3lPzjBrXapyofqTqXeVbHcGvWvfUOqHmYTXvqXlG
jVvVr1U/AAa/6v5q3lfzrJrX1DwBjP2Bn/PQ7bzAw0ct+3j+/WG94lnHxe0E
nUA/4/m+gjt6/l4l6wfoJwWdQMeI79oLTOo6OZ79SiUdGPEPjH3A9zyB75Mj
3zP/iqQDI98D4zvgs57xjJwP+a+Lv0v5VAy9YT7WAR0Y+2WI9eXfgWF//B3y
gA6MfWRdbaBDXmDYWaXje+j/otCvxOAb9gAdfgkMOuardlbXUe0GPoChxyzh
fzI+IDf4Q9xiXWDMU+MY/oN9VL9FnIGu9q2qvyAOoX/Vf9Q4BR32Vf0HcQyM
dbEf4hjrq+dW1T/U+q7aH3TMh55BV8+dqn9ADuhfrVfqOsA7NA8ss1hruIeH
7+sc5cnD+Rztods49LcLt1KNdfS8Z71cqv2wR1uT5l5enpxdHW8pozQPP4WE
eZkC82iBGXTgf8T3HCO+Z6wH/Ivgh8APvusv9pf8AAd45E0h8Jv7+7xTbvct
6in+LjHmQb5IMV/+HRj7QV7oRyv4IfAHDHmgD8gPPuFnah6En8DvQAcGXc07
wI35GTDoiDM1rzfmR8Cgwz5FQo9SLuixMb6Bm06KG+sIdDHsAf5AR9yoekDe
wXrAWG+jZ/5OmUdBb0xPwPj+mCfe0knN+2pcYx5GqZ+G74DxnVqngBHfkFOt
Y6CrdQsY9HTBh9Qr/BcYfgyMOFL9GBj+C/vC/2FfrIN9G6vTyGuIS4yIS2D4
H+RGfgJG/GA/YPgP5mF/YOyP77AfvgOGPvE9ML5/6ojHr+R8+Bkw/AD7II+C
D9QX1f+xLuTHvpAfGP4EvQKjfsF+2B95B1j1I7WOgz81nuBH4A/+D/6AYQ/M
B4ZesB/mYz9g8I/54B8Y/jdT+J/UO/Ix5ASGXoFhL2DkK6wHf0ddQD6HnpHv
QG+sD5bng4b4UtdprE9T6wjkB26sT4YeEU8+wm7SzxrzQ+gL8xEPwLBLY3aD
nTEfdgL+X30u8hHmg3/4HfxarRNqngZGngVW+ybYGX6EPAoMfcu+p6FPQv2D
3eEnGNHPyr6mIV/A/9V7GdgB/EAuzFfvbaB3zIfeUb/gz9gf30GfoMt7yAaM
fYHlPWADlvflil7gt5BfvXeAf0NfiBvwBX+APGocwj9gH9ChV9kHN9QhyA07
wF6oW+AT5x2MuA8BfuvQBwf1htu8udmqEdqEyvvqNLC8F2/oXxFHWAfnAqwP
jPU3iPXl+Qv3G9h3mJhH6rkJ8kCfWFcdsR72wXrquQn6g37/V11APkW8Ip8C
q34Iv1H1D71AXuhF7dPUPg/7Ib7Vc6yqd+gBdOhBtS/yErB6b4V18T30inVU
OeD38BPIg3iEfhBvoCMeQQcfoKt1EH/HPvg7/BF07AM67Ai55ftDQz4GHd8j
H+F75B98L98HlHMT+IJeIT/iHPuCDvlBhx5VvSK+YQc1rmAPrAO9ASOfIn5B
R9+n3pfJc3RDPYc/Q37kB2D5HtWgD9gDfqTeHwEjXvAd+FTvj4ARD5ALdNgN
dNm3456gYT/Ij/0QJ8jvwOATeoUd1HspGU8NdUPenzVg1DfoD/qAn2NdVX7U
DfgV5AX/qEuQD/yAjv2aW76+6v4gX55DL0+se8x07v/5vcDUNUssbbz6Sgqc
85amfx3nLkmKje55W+avNk2O9Am5XH3f+3L3YckmS7D3nvp8yue9tS+W80sx
C9/W/OK9z1q31DbOcaXuvvfNnUuzIm3+19hxOGShpd773lm36PY3luB8iTF+
MaJlVbwlR8Z5jweqm5t258g+L/mZd5IDh2VzTkHkj8Zwl5y3vd3TN+xz/rrv
XSUs9mJMdM80OV99z1v+4rXMwDN75Pegg1/5LtnAr/qO0e2Tmte0Caek3FOu
RTpSb2TJdYL+6fWcYY2NoB/YH/qT7z0N+se6sI/6u4UVp94PDul7m2Bv2AXz
KrIrthnHeuvtq9f7f2zzryH4C/SIfcIGzI6y9q6R/I8aPv1EYIz3vj9m/TuH
dLNdUq/pWWtjjSUuKd8XrfsGa2+5pD7N5U2DDItdUs7HnnlvVXSck8a/uiLP
TXlcM+qGnznSyQVnDKfdX16lrEO6V7V/Onl0dFWgYXE551da9+jvVvOubhHD
tFcdcgz/O+5n4+lq8k393hoYU87zrJMz3Ql1pB13LlF/N49jct7McF918s+D
W8YZt2exPazrasvXeTxuxJ+X3Zsu8vgZm1da6jOo5Pkdd9bYmE+umbjNuP0v
Cr88d7HFepjeats13FZRR4/+5bs5uuc1Grbj8c+tuffOMdU/JOgGlZNr0kMf
23oUUbi/3534b+to2gPBQzSFadzsO/tB3QEXH2z9rz4NnDspPznQdQ8382AC
nswHFlqsqfTJP5tupJ518cDK4mbmMZcowm9RWerwe348YU1Pw7OVHJrUq2nC
wireV9b/KdPK67JuxWm7LLBsKKXJsXW9QqbW8s7koYutvSvJL7A0TLO2Ssbx
SuEfnHUiZ4ojqlLm+6pe5Ud1s6s4NmfELXuLe3U+8tsJjqgqGtq+YrWlTSW3
oq0WY0mNPLcHV4yfahtQx5s7JQ7WrirkHq8dsNtb1NLgiM1X7dXXecmpRZuM
bevolUzXXv2wQp745Oid+o3e943xe4dftXdy8fjFC++k/prODz95+j/aF7Pl
mNGndUrgsCvs6F//jiM2m6uS97+unWHntut+a2q2neW/P99dYr9o54D62d9G
zzzNk6fU3LIfTOdMT/7J5TDHsHamj1O4+6bSEI0ul4vXDN2tM6/iKPfsftpb
2TxC86+fm6jdzz8+ZB6TzWP/e9TH3PI8RYiRV19wzLRGuLj5KNfSaMdG7mLJ
dMZ/WEqxHQou23XnuNUy/7r4D29Q1Y0OfbUJadyn5chWZr7XN63+6aLbHSlx
zNceTPVvb19gCXNx5sTaLoYmJwn81/zj4Z8gn4+QjyrmH+lmaFJIy28HL7VY
TxH2nyf2pzf6hn5oSy+TdQP2WC/sQdBj7ROekaCfFKEfgj6mCX3QxYP/9hVr
7ju37hP5lBbseXSOdYj3vaZkStpca+da3no8/WFzy1KC/fsL+xP8aZ3wJ3nu
PynqA8Gf3xL+TGGb3im3Wyrleeqbzk/3184o5bAfPlsTHVpL8O8Jwr/pYtjv
fbVjymjeU/6F9rwaWtKvfpe+7SU+GvhwC1N/l4w/XxF/NH5KbYb7y1T+SH/6
oC7FRYjHKyL+CPE3TcQfjc96uHuIKY0+atnNGX/MRYjHmSIeZf90aPG7PUMK
62R9+kbkQ1l3MkU+5JCfY4NMK/cx3i/l70hEfuSyN9+O1xsSCXTky/UiX3L8
0OXO1Bv58hyM/sN38MD6+Aec8ryRXjb+qC6lih0bDs+y+pbK/ujQzsRe2hdv
yX4FcX/qq98eSfiwUtaRKlEfGPbAvNI/cutSh9+WdQZ20i7ud1I3u5JH5CW+
5zhTe9+7q58nPkvYL9Jq1WXW3Pfe1fS1j3frc72/y4oQ9ZH1xwf+YNyefd89
q3+fO0WpxnNSfz1E/WT4L+Y/vci2V284IesU4mTL28vCHYEXGP6M+dOmhXc1
HPfeX/Q7mm5wxBbJ+wvUwzdEPWfEH+jNJo39zqL3vpdhPfDp9+SpsZpJ3r4V
89X3NEdvj3wE/tV7eLPgX/YFvUX/QuAX85BvEa/Qp9q3fyL6Kcl3e9FPEeyp
vnP6CHvKe436AR77ST85LvyJ4C/wK/hLR+EvhPqjvrunCf/1/t5B9KeEeqe+
q+8T8Sf1cUj0rwT/x3zEj3rf8qCIH0J84n0X8QiMfBcv8h0HrX5mp/4PJz+e
OG+O1fcyI19vFfla1t+mov7S9qea9w1pXUj2R76vj79QR+aP7zQ3P1zEvQOa
vqWZX8cVOyKK7UsLeejRCZ0MP9bxp2u53D4pjxZ9Gb0qOsbJ6C+mi/6CsV6J
WI8D2p9PdSeUU8ofXZZbAmp4XOvKDqabDjKIkZf+/GZVal41b7zeIk4/rJzR
v/QQ/Qu3vdjiZGBXJ8cPyP2v5pdrjH7nSdHvcPWGxNWW4GNU0y2vubllFt99
+uLN1K+ctIR6+ZvHXOTuC2f/ZBzqpCxH++363Cs8ur5JQeqvt+gJ38IxmsJk
iase8mBCP2YW/RhBnz5Cn4T+bJjozwj7l4j9CfvPFvsT9j8p9ifIs1XIQ5B/
nZCf0DduFyNBXxjRb+aKfpOg36NCv9J+PYX9CPYbJOwn+1mH6GcJ9vxC2FPm
ndA9Kf21j7vk+02SplOA6XeXzFfTVkyaaT3pknHr5x/1TXSQS/ZhZZd9Hand
auU59p3n+gSa3qzlox0js90J3rh6bEHqJ7Ye1eQ3f0wvw7MVnJxveDlkZJ2M
o3DbtAHaVXW0ZUOXINO5fD4xassFN3n5Qv/iEP0LL0o3XnB/4OLgPfOeNWmS
2bU+/7WQ1ukyHxYURBzWb7xAEZ48eIL7Tf0j1z7HJe+50F+1DfX0V/RK7eJJ
tk9dvGLBxgCzbZ/MeyPE+Yumb07sG/JbprynA3/QE/rJUNFPkmFufJDhWRd3
fXDMgBBnOoE/zEe/hxH62xG9aEW0I03aZ/z4uok2fbaUK+Z7h0VvyPX+HmTO
E59Zo7MJ+kReQf/bQ/S/ZI+s72zYX0s7+4XY7e8UE+yDewH024NEvy3XR38y
wmd1L0OTazx96kNPmXY72bDppc8t03N4xOnjV+15Tn7ek78yOHY8/Whc7tUz
zhdXXhj1hqbTEVr/8pAOhnv9htWd+7Tp/Sxy3FmywHLv3Lu8/yfFqd1ucte4
Ps3NkTU8N2leW8PiMt6cOPJp0+4aRj82VvRjHH7pXJjmF+/vp4aeiF1uyazm
EbXbHPGflfOqgih/84vVvOyaX1ZgUAVbzac2GpfXyTreLio00lpfy4N6fx+i
PV7E336as8gS4OSmjqvjNLo8/m6ye47Vei8vJoWutGgLGPrbJ/THsG8/YV/Z
J3wq7MWzOn3a3Dwmi7tm7turC8hh3xlPtDOt9L6TRtz09zcbC/lw/var7reT
5d9jhX3Z3GJis4QHLnDU3hnTrZ1z2fDZlB+iHcfl+QL6LRL2Z98jj+w0avdx
ruvMYE2nHO5clNbCdM77/pnUecJs61Ynlex+bodxewbPfumWK/6Yk4ae2z9Q
U3iee7evnGUtupcXCvun6MzJ7Puae5Y110l3PfnuJCM+Toj4YP3e50I1nYok
H2u3xp4NbFbEHbd1ecYQspsHec71RdxmS2K+XbedQd+11UMn0Lf87KETzrtb
xHlX5pNTIh64+c2zSyz1xfRKnnmfzpzGk3xnndSF5Uk/bRbca4rjSh6Bv4A3
ngp3jMujsBjHnVTjagYd8Q36Rys8dJow3JjvZu/v1T6aV3FKN6+CrvXatsIS
fJCBtwhMA0uujHW4vO+3pUMe8TPXOumP+S9s1hsS+Njwr13xTicNXPP6mcAz
Wxn0IYJOoJ/5zkMn5LO2Ip8R/AX5Av4SK/yFcF+wS9wXEPLdWJHvCPbH97Bv
irAvwb7XhH0J/nFJ+AfBP7oK/yDoP1Don3D+zBLnT0J8If8gnuorPfFEiKcS
EU+E+AsW8Ufw92nC3wn+fF74M+G8/Lg4L9Ov9k6kfd1Jf/sn1cU/kE24b2kv
7lsI9WSDqCeEfIF8h3wxSOQLQr5YLPIFrftT/7tuQQ1NKo2aYNOWEc4P8Eu8
Ex/wnE9vEO5/7p723P8Q6l1TUe/kuaNE1EtCvuss8h0h320Q+U7uM1LUU/ra
GvOhbU8Z7Tx8yapL8b5PvyXqt8zP4SI/E/LzUJGfyefs+4X2g1kcNLzTN9Gh
3vfqQ6LeE/L3OpG/qd6TV45wZzrzQsh17/v0ZNEPEPK5WeRzCm5ZkOvmDNo4
f+QwzVrve3RT0S8Q8n25yPeE+7UMcb9GQf2+O+tOyKG75dmzrA6nvO8bI+77
GOfrFHG+ZsjTWcjDOF+Hi/M1g/+ugn/GeTpcnKcZ/MYJfhn7P3jLs7981/UX
94Nccr75NuOlAunXuL8cKO4vGfcBC8R9AMNe8cJe8vw2Vtxnctn+R9sajnvf
edtout1NHV5BWv+fXgl513tf/03ciXnWoireua/VxcCdFfJ+fW5Ol8Haq973
8E+/m9nR8KxTnmP3pO/zM3/vvSfFe0BU3BeDtQkHufuBkTNtPQpo0O+GjqaV
xxjnQ5zDcO/fY+SxklSjVcZ1X3Eu5AE75h/Q5xbId6SghxZGWdJv0qFoQ318
5WlO33Ui0vKe9/d/eG9pnb23vSHkrHzXmF9afFhvOMarX77TX3vL+7tt8Puq
4JfAb2fBr+xzcE4FP3i3wPofiPUJ6+O8C/2gz3uwjaef567lEft1AX/Le444
8T5AZSkbr9kned//oW/5/zEa7gvzxX0hof4HivpPuA9sI+4DCfUc92HXTr8d
Z1xew+V/z+0e0rfMe08i3jcoaMTyOGN4jdQj7kNl39jgR8sOH3zCtPIGwT/k
/29o8K+Owr8I9zG4F4O+hoaPK7av9b53xwj/I/gf3sMRDytFPMh3olxd6GFd
mJNwv4z+sfu2GZ/Z9hTwnr814TYfJwcMfq21uU8Ftxm6f5RmcDWvP/NnhHVI
CTf7vk1r081aHv3Rjk6GWSV0c+KKitQmdZzx0Mb2pt23ubMnv1cy9FUj9MXI
1x+LfM0vtHo9y72plorSOlam/lrMsG8/YV9esLJvrrtdAec0/zUjsFkGo56U
iXrCd6deOaILK6ZLm4d8Fe04K+efF/MJ/r5e+DsF93zsSOC0qxyxOLWlafcl
cq893MGk2U9xL/XuGeK8ROAnV/BDkCdIyEPrlhVNdvg6+NWXE/8MPHSboJ9W
Qj/0nw5z/RJaOuh62tDPbCdvS33uEvqkkUvfKEs1JvG8bXeTA0tdVF28poPh
eBLteHOUr/lefsb6A8X6DPpuQed1mcvbm367TWXaw4n6Zg4ePX1ua9Nvtfzi
nGWR1txihnxLhHwcPnpZki7gNLnejV5gPZkhcanAhO+fE98T1i8R61OAu7DE
fjCTkvlfv/uSId9NIR9Df/uE/qQ9koQ9CP7iK/yF/g9qRXTh
                   "], {{
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[0.3], EdgeForm[None], 
                    GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxNmgn4l9MSx99z3jbhWkr2lEglkYQsKYVKihQSIVvZiy6htFmKbEWJikqU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                    "]], PolygonBox[CompressedData["
1:eJwllwcUl1MYxu99L6KtkJCUlBXZtEuhrAoVhTSUQkmKJElDpbLaIUk6ciKJ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                    "]]}]}, {}, {}, {}, {}}, 
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwl1Ht0znUcwPFnm9Q2103SOZ3TwYhcKmTICUvSlktGLpU0qhUjl2xF2SpC
CAt/UOhCk5nNKk0LbXMpnTqnzim60P1e58Q59F+vz/HHy/vz/T7P8fye5/f9
rWPBnHGzkxKJxGD/XJqSSPyQnEjM1jmUmi/TYfojj5rnUmZ+mhxSrW/RZ2kw
P6NpOlx/Yp55PkvN6Xqr/swC8436mDbpMhaan9OjHKEFlfZW6Eh+pcT6cRbx
BMfsrWSx+Sme5Hbr1Zwwr9LjrKHR+gUdxW/8zgBa8RFt2Os963Us5VRbt9X2
eqf+wZ8MJIOP6UCt1zfrp3xCmXUnOtORLmTF9TCAgWRzE4PiM8mJ3zJ+7/id
4jeknC/8f1/GfWGMdZHeTFZcZ1wXCZJIjs+yX6dVcc+4yzyRCcyzHkJXJllP
JoVm1Nj7UKv1a67lfesFepjXzTt4hdd4lW/t92KquVjv1YX6LvsZygccYKfX
6vQN/V77MtM8i4fj/lk/on20MO6lPqiL9SG9Ia5D67VCL4lzYH6PQ+br9YE4
Fzo9zonO0Ou0QEv0Pr2fafS2/o6eHLR+R89wmrfiPtp7O84oU8z3cDc9rL+h
O/XWtTqffXEt1t30K66J7229V+cyzjyefLZzyt5L+jJb2MbWePbs74lza67U
PC2MZ0Bz43yziZP2NuhGXqTC+nM+42r+4wLn4/sz2Huu0nOc5d+4X3EW7F+p
//A3f5HPFfbb6aD4feL6qbGXGc8WpfE6l5PBGHuZulabdF2cH0ZTZd06zhdL
zG3iuYo97rD3fHxnc0vNJjfOjXWejmA5b1qnaX+KzS3i/fwSz7Deprs1XRto
jM9il71U7UeRuXnKxb91/wPCNpeb
                    "]], LineBox[CompressedData["
1:eJwl0Lsug3Ecx+F/9RpQpVUM6nAHdegFYJA6VScsaLgHu82hWksTDNgkDTdA
E2Gr62DQgaDPG8Mnz/fXd3jfdGhjf3EvFkIoaaUrhP54COc8YFZjGtWExnWo
uucz3OQ0t3ihhp1hS8O6d19zWz+quM90Y89xh7+q2jXd2vPc5Z8W7DIfOMI3
XarpvuK3vpR3zyodfY8+1daz31KcZJJT+tC7StF79RR9E191qhd3hesatIvM
sJdprnGAq0yxh31cYoIFHuvRPmJO3bpzn3BZyfj/f90BYUUtEQ==
                    "]], 
                    LineBox[{903, 899, 901, 900, 816, 817, 815, 819, 818, 674,
                     910, 912, 911, 613, 680, 974, 679, 838, 614, 764, 839, 
                    615, 951, 545, 722, 913, 675, 822, 609, 820, 608, 821, 
                    672, 907, 721, 905, 670, 904, 671, 906, 607, 813, 606, 
                    814, 539, 949, 669, 704, 902, 903}]}}], {}}, {
                  InsetBox["\<\"\[Mu] = \"\>", {-1.8, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["0.2`", {-1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {InsetBox[
                   SubscriptBox["C", "J"], {1.4, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["\<\"=\"\>", {1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["4.`", {1.7, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {
                  {PointSize[0.05], PointBox[{-0.2, 0}]}, 
                  {PointSize[0.0125], PointBox[{0.8, 0}]}}, 
                 {PointSize[0.007], PointBox[{0.4463998339305619, 0}], 
                  PointBox[{1.2771956561278897`, 0}], 
                  PointBox[{-1.0806611991222994`, 0}], 
                  PointBox[
                   NCache[{0.3, Rational[1, 2] 3^Rational[1, 2]}, {0.3, 
                    0.8660254037844386}]], 
                  PointBox[
                   NCache[{0.3, Rational[-1, 2] 3^Rational[1, 2]}, {
                    0.3, -0.8660254037844386}]]}},
                AspectRatio->1,
                Axes->{False, False},
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                Frame->{{True, True}, {True, True}},
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLines->{None, None},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None, "TransparentPolygonMesh" -> 
                  True, "AxesInFront" -> True},
                PlotRange->{{-2, 2}, {-2, 2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.02], 
                   Scaled[0.02]}, {
                   Scaled[0.02], 
                   Scaled[0.02]}},
                Ticks->{Automatic, Automatic}], 102->
               GraphicsBox[{{GraphicsComplexBox[CompressedData["
1:eJyFW3l4jFf7jqX5VMS+jlSF0LFrarRV9SCoqmrks6ShU0upmqKfPbEvHZp+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                   "], {{
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[0.3], EdgeForm[None], 
                    GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxNmgnYl2MWxt/neUVKi8qSJVtKSZQ1RYiSLUtjGUtSlqS+SckWZV+TQoVs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                    "]], PolygonBox[CompressedData["
1:eJwtlwm0V1MYxc9QIqJCg4qKUlKEniEpQ3OapHgNKj0NUpkaFEKTNMhcGcJr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                    "]]}]}, {}, {}, {}, {}}, 
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwl1FeQjmcYgOEfoxOWqAdmzOgtRLQocaB3qyyihQTRQ9SwWpRVE+1A2xOd
1VuQ6NEJxgwzekkk0ctMYkYm1zMOLvfzvH7L++23SvYZljw0UyKRqOOXXFkS
iUeZE4lvdRTfm3NrM/2T0eYxTDfn0eb6F2PN45hhzqst9G/Gm79jpvkDbamP
mWD+VCfqaZ1FqjlNz3KGguxyNkfb8JTJ9no6Rc/pXKbGv5NptLUv4DfzfD3P
D/xq/1E78IznNKAQFynCXp9ZrJ3jz7OEU86WagoveMlnFOUyV0hnps+tinvo
VU3T0pShFOUoG1+funGHuD8NqM8yGtOERvG8acpybvh65TlkHqHHaUwFkp11
ICvZ2BV31p16K76PdLF3JYXR9iZUpJv9c7KTg73OLugevctHHLOP1RNkmLew
kc1s4r7zj+lt/oJejLf/ws80jWfPYbb6vUO6Tf/Q2nwTd2IYU+3DtZYO1Sk6
WCfrEK2pg3SSfq2pOlBr6ACdqP10gvbXT/SreP+0j35JX6rbf6daPEv7QX3I
A/bH99TZAR1Hd3NPelDVfo8qHLX/pGPYxxF7Zb1DpbivfbeOoqO5M53YwG1n
a3Qtq1nPOkY638E58/Z453WIttTWtCKdm85WxvvGCjLs17lGKRrxH+/iOcT7
6jMl9S3/8k88j3innJfQN7zmFcWdFaO4uWHcM96fuGOc6yVmmItQlEJxL2eF
daGe1EXxPOLe7LEXjveK6eaCfEgBkp3NY3ecaX3axbtmb6+tmB3PxJ6kdZlk
zkd+ntiT4tnozvia8ffHzyzT2B6f0zqMNOfM8v7/t/8BAXac8g==
                    "]], LineBox[CompressedData["
1:eJwl0L0uw1EYwOGjf3ehVW0jGopboC7Ax4bWR6d2abkNu1AfSRFJa8Aqojsd
RGLiPmog4Tkx/PK87znJGU6u1lprjoQQKrFUCONJCB0ecEYlTWtOszrUtftF
1rnABrt6NE/yQ1N6st+yqVR8Vxe6sy+zxYSXutK9fYV7HOWq9s19Fvmpngb2
Gwb+collFeKsb/3o1Vme88yyrC8Ntatzvbg747tO9GY/5Y7y5m0WmGGOW8yy
ygmmmeYGx7jOYz2bj+I/xXM92NvcVCb5/+s/5GwqtQ==
                    "]], 
                    LineBox[{911, 907, 909, 908, 819, 820, 818, 822, 821, 678,
                     918, 920, 919, 618, 684, 978, 683, 841, 619, 769, 842, 
                    620, 956, 550, 727, 921, 679, 825, 614, 823, 613, 824, 
                    676, 915, 726, 913, 674, 912, 675, 914, 612, 816, 611, 
                    817, 544, 954, 673, 707, 910, 911}]}}], {}}, {
                  InsetBox["\<\"\[Mu] = \"\>", {-1.8, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["0.2`", {-1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {InsetBox[
                   SubscriptBox["C", "J"], {1.4, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["\<\"=\"\>", {1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["3.99`", {1.7, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {
                  {PointSize[0.05], PointBox[{-0.2, 0}]}, 
                  {PointSize[0.0125], PointBox[{0.8, 0}]}}, 
                 {PointSize[0.007], PointBox[{0.4463998339305619, 0}], 
                  PointBox[{1.2771956561278897`, 0}], 
                  PointBox[{-1.0806611991222994`, 0}], 
                  PointBox[
                   NCache[{0.3, Rational[1, 2] 3^Rational[1, 2]}, {0.3, 
                    0.8660254037844386}]], 
                  PointBox[
                   NCache[{0.3, Rational[-1, 2] 3^Rational[1, 2]}, {
                    0.3, -0.8660254037844386}]]}},
                AspectRatio->1,
                Axes->{False, False},
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                Frame->{{True, True}, {True, True}},
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLines->{None, None},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None, "TransparentPolygonMesh" -> 
                  True, "AxesInFront" -> True},
                PlotRange->{{-2, 2}, {-2, 2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.02], 
                   Scaled[0.02]}, {
                   Scaled[0.02], 
                   Scaled[0.02]}},
                Ticks->{Automatic, Automatic}], 103->
               GraphicsBox[{{GraphicsComplexBox[CompressedData["
1:eJyFWnl4jFf7DkoVU6EaOlxoLJ1WLQ2DanjUqKp1qJaig2rUZ6g2NG00LUqn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                   "], {{
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[0.3], EdgeForm[None], 
                    GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxNmgf4l2MXx5/7fkoKoSERKkULyeg1SklJRkNmJUpGRkaUMtpGshKZlUgh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                    "]], PolygonBox[CompressedData["
1:eJwtlwf011MYxu99bxpWGZF2JDrZI0pDlBWiJO2hRDRRCWUUoihESUOkIiWz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                    "]]}]}, {}, {}, {}, {}}, 
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwl1FeMlFUYgOFhaVIXvDAhoYhIFwQRkIQqSO8gvegCUoRdeu+9akJRbui9
w9L7rkqRYCChSpGiNEmABO6ozxcunn2/c3Zmdv5/zmzxlLS2qVkSiUSN+JE1
kfgnKZEYqIOYYM6iX+stUs1pTDQnaX29zWDzECaZs2oDvcNQ8zAmm7PpN3qX
4eYvdIRm6BRGmqfqb2SSh+32pmtj/mO09Zc6Rn/XGYw1j2ccTaxnc8Y8S/9g
DhnWc7UF97hPNfJxkmR2ecwCbc0pfor3Yu9nbcMDHlKdAvwZf4elTPK4X3Wy
no3r0SIUpTAfU4z5VIlriOunGlVZSC1qU5O61GERF7xecQ6a++sRavMJzew1
56X5FdvivVtv1Uv8GO/dOjWuKz5TrUMJ2lq347X5DTs5bb1Dr1Kao9aDo6w3
b2AN61jLNfvl6GTuTMf4vK33s4+6HOMAG/1uM5u4aV2J/uYB9I3Pz7qffq4/
6FjtrWO0j1bUXjpav9dRmqIV9DsdqT10hPbUz7S7Dtcu2o2ulLe+Qdl4b9Z7
45xynd38ZW+PDqG9uQPfUsb6b0rFZ2CdrmlxbjhsXVKv8CmHrLfH9yjOnLkV
LVnNZXvLdQXLWMXKuA/2t8R5jPukDbWP1o/vTXyn4oxx0d4S/YXFrLc+zzkK
U5MXPI/7EOfVYwrpM57yJO5HnCn7H+lj/udRnGt7yXxo/iquI84J6fYKxvlg
ojkf+ckT12Yvr87TzDjjcVZpGWcqHqcnmGDORW4+iHNrbyY7zHm1Kk05bt0s
rp9pbI3naRVGmbOTg3+tc2qjOPfxuvFc6jE+7mX8Ha0c3wPz26T3/9/eAdqA
l2w=
                    "]], LineBox[CompressedData["
1:eJwl0L0uA1AYgOGjvQIU1Ubq3y1UxexnbP0uUgZM3INdgiKoSDCoWYRdDY2J
62DQhGDynHR48n7fOckZzsDadnGrLYSwwkIihFQyhFPd0SGGGWSUEXa5cD+u
Zc3rql5yb+7TV3I82G90nR9O4tvUzGc6xTS/9qpO6rne6oxu6B+z5k191H59
44pn+7V+88WEvUA2znzSpOEso2PaowU+eGeZY+rujvSFSqz9UJfImBc1q12a
1t44x/foJuW8Q+e0XUu6z5N5L/4XndzZD3Q+7snWn/8DoOEsIw==
                    "]], 
                    LineBox[{903, 899, 901, 900, 811, 812, 810, 814, 813, 671,
                     910, 912, 911, 610, 677, 972, 676, 833, 611, 759, 834, 
                    612, 950, 542, 718, 913, 672, 817, 606, 815, 605, 816, 
                    669, 907, 717, 905, 667, 904, 668, 906, 604, 808, 603, 
                    809, 536, 948, 666, 699, 902, 903}]}}], {}}, {
                  InsetBox["\<\"\[Mu] = \"\>", {-1.8, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["0.2`", {-1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {InsetBox[
                   SubscriptBox["C", "J"], {1.4, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["\<\"=\"\>", {1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["3.98`", {1.7, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {
                  {PointSize[0.05], PointBox[{-0.2, 0}]}, 
                  {PointSize[0.0125], PointBox[{0.8, 0}]}}, 
                 {PointSize[0.007], PointBox[{0.4463998339305619, 0}], 
                  PointBox[{1.2771956561278897`, 0}], 
                  PointBox[{-1.0806611991222994`, 0}], 
                  PointBox[
                   NCache[{0.3, Rational[1, 2] 3^Rational[1, 2]}, {0.3, 
                    0.8660254037844386}]], 
                  PointBox[
                   NCache[{0.3, Rational[-1, 2] 3^Rational[1, 2]}, {
                    0.3, -0.8660254037844386}]]}},
                AspectRatio->1,
                Axes->{False, False},
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                Frame->{{True, True}, {True, True}},
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLines->{None, None},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None, "TransparentPolygonMesh" -> 
                  True, "AxesInFront" -> True},
                PlotRange->{{-2, 2}, {-2, 2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.02], 
                   Scaled[0.02]}, {
                   Scaled[0.02], 
                   Scaled[0.02]}},
                Ticks->{Automatic, Automatic}], 104->
               GraphicsBox[{{GraphicsComplexBox[CompressedData["
1:eJyFWnlYlFX7hjIzdMxcE/1My2xyDxtNK59iygzRJi2VstFUyBzBJVOHzPi0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                   "], {{
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[0.3], EdgeForm[None], 
                    GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxNmgn4V9P2xs/ex5SMJZEMqZREUkgyZLiSkBJSkemWMYmKpETRhEJkLBUp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                    "]], PolygonBox[CompressedData["
1:eJwtlwf0z1UYxu99r0hCkiQNCqVNVlNLyqjIrhQVySwjhUSKkoRIokF7SVGU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                    "]]}]}, {}, {}, {}, {}}, 
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwl1FeQjgcUBuB/d3FhxgwSLbpglcloi0WUiBJW76y62moreomScKddiU6i
95FE2YQw2oxE7z3MYCbuokQN4jnj4tn3nPN/++9Xzrfls8Z2yUlKJBJN/XiW
nEhcpG9KIlFR9pNj5XPSuER/swF8rX5BXS4z0GwQ49QvqccVsswGM179ivpc
ZYhZJTlU7pYTGKaeKPeyh3fOaavZJHUDrjFaX1mOkblyMjlxPnGuNNR/w3H1
dPkrM9ivnymbcJ0bVCEpPiOFHY75Vn7BAb7jd7M5sjk3ucVt8nCQQ8xjouMm
x7lyWD9FFqIwBfmYj5hLKlXiOqhGVeZRi9rUJI06zOeE7ysS90TdR+6iBkVp
apYp/+ERazhitlr+Gc+QL+PZxDXIgbImxWihb8lj9RPWcVS/Vp7mE3L1Q+RP
8bl6PT/EMfzIWfNStFZ/RSuG6beyhdr8zDY2+GwTG7mgr0DvuCZ6MkbfS5aX
PeRo2U2Okt1lOdlVjpSd5QjZRZaVnWS27CCHy46yjGwn29OGDNpS2vw8JWM/
9JtjDznHRk7EecrBrFavYRUb9GdYGc9KrpBPY8dZzz59CXmK4rHHcY/kAJqp
+8duyeUs46T+e7mExXFf9UtlX7mKw+qVsqHsEe+ObEA6i/jDbGH8vlwgl8be
c4yCfMZD/o77Q3XHFJAPuM89MmK3zPPLu9zhr9hvsxTyqauyM/Yo0ixvvBdM
UCeRzP9xjSTUs+L9kbPjnYodZXscJ39jXPw/4J26MW/5nGmxJ/Fd3vvUeIfi
eP1U2YjXvOG/+Dtxv8mOPYhnHnsSu8F28/TYP/Vb3/WLug45bDZ7Y/apOlP9
b/KH/3vvAQFLnnM=
                    "]], LineBox[CompressedData["
1:eJwl0Lsug2EYwPGXBnVqI0QdJqvjBRSTYzdd1GJwAazMWnRCu+AiRJgxCNfB
UAmh1+D3xPDL/3m+vnnz9ZvaOyjvd6SUdlnvTCmbSemIQwqMMcoE41SpMceW
87Na1kvuzEP6yjD39ivd5odz+wXXcV6LLPJrb+i8NvVGl7SibZbNO/qgI/oW
53m2N/WbLxbiDvLxXrT45MWznE5qv87wwTsl6jz57Szu5CT+g/1UN8mZNzSv
vTqggzHHffSR9bxbV7VLV7TKo/lYp+nhNr6frsWe+f/mfzUOJ5s=
                    "]], 
                    LineBox[{894, 890, 892, 891, 799, 800, 798, 802, 801, 655,
                     902, 904, 903, 595, 661, 966, 660, 821, 596, 747, 822, 
                    597, 945, 530, 706, 905, 656, 805, 591, 803, 590, 804, 
                    654, 898, 705, 896, 652, 895, 653, 897, 589, 796, 588, 
                    797, 524, 943, 651, 686, 893, 894}]}}], {}}, {
                  InsetBox["\<\"\[Mu] = \"\>", {-1.8, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["0.2`", {-1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {InsetBox[
                   SubscriptBox["C", "J"], {1.4, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["\<\"=\"\>", {1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["3.9699999999999998`", {1.7, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {
                  {PointSize[0.05], PointBox[{-0.2, 0}]}, 
                  {PointSize[0.0125], PointBox[{0.8, 0}]}}, 
                 {PointSize[0.007], PointBox[{0.4463998339305619, 0}], 
                  PointBox[{1.2771956561278897`, 0}], 
                  PointBox[{-1.0806611991222994`, 0}], 
                  PointBox[
                   NCache[{0.3, Rational[1, 2] 3^Rational[1, 2]}, {0.3, 
                    0.8660254037844386}]], 
                  PointBox[
                   NCache[{0.3, Rational[-1, 2] 3^Rational[1, 2]}, {
                    0.3, -0.8660254037844386}]]}},
                AspectRatio->1,
                Axes->{False, False},
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                Frame->{{True, True}, {True, True}},
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLines->{None, None},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None, "TransparentPolygonMesh" -> 
                  True, "AxesInFront" -> True},
                PlotRange->{{-2, 2}, {-2, 2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.02], 
                   Scaled[0.02]}, {
                   Scaled[0.02], 
                   Scaled[0.02]}},
                Ticks->{Automatic, Automatic}], 105->
               GraphicsBox[{{GraphicsComplexBox[CompressedData["
1:eJx1Wnl4zFf3t5cw0VdVYngVRUO10rRpFXV4R+lL6VBqedOx1BJGq401Smkx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                   "], {{
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[0.3], EdgeForm[None], 
                    GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxNmgn4l1MWx997r6xlJyEKZSnKMpaSKSktlsiSKInsS4nsSqUp2bcUSdGi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                    "]], PolygonBox[CompressedData["
1:eJwtlwf0z1UYxu/3vUaFQoNUEjlJgzSUIlFpEP1DQlZJkf4i/wrJbKBllNIk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                    "]]}]}, {}, {}, {}, {}}, 
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwl1FlQVXUcwPErbpmgD84047jglnsu5IyDYgmWZu64lKkpKmqKgCSC0AKl
LU+SPtmipSIugYE1WmpaLuOkjriWlZqW5Uz1om9my+c3PXz4/v7/e+bee+45
h67zC7LzmyQSiaz40zSR+CEpkVioAzRXV2kTHaE/ssi8mBJzkj6mV1lifoFS
c1N9XK+x1LyM1eY8bUZzrlsv14Garwe1jAJzuRbqSD1EC/ZYv6RZ/MQq60Fa
oof1ZUrNZfFZjLJ+jTPmSj3C63xtvUbHcIOb/EyreI1k9jrmDX2ao7wZtfeW
juMXbvErKRznBFW84rgKXuWkdaV2pBMdSKUzb8e5xznEb00ag1nHMIaTHr87
GVRx1vt15oA5R/eRTmqcj735eo+/qOYbe9v0fFzT+O7WS+K84hrqMLoyPq6d
3udvdnLK3g69RA8OW+fpfmritXhvtlPNt/Z7MtE8iQnkW38S144v+JyP7dfH
Z+hudvG9dX9y4hx4nnnMpZ/9ObpSZ+mLOlv76nNapM/qCp2pffQZLdTpWqAz
tLdO1WlMJpsp9LJ/hYfjHrGui/uS7+K70mivVpexxbyVj+K7W1/mw7hWuln/
ifudXXxp3V0v0i3uY+uaeH54ypyrY3UTH3DB+l19j43xu1q/rwv0HF04GJ8f
vwcjzVlksoFGe+vj/fQd3ayn4zrSnqHc5Q5DvP4oD5n/5A9+Z1p8jv12cQy3
+Y229trQ1pzGZ3HP8Gns67F4/szJpNCasfbW0hDrODaeqzh36u09qF9RHs91
rBkdz6E+qRVx75hb6uB4ruL4eK70CVqYH4jXo/F7UxT3R9wLFMc9Q4P9TOri
/048O2RQTK29ZvoIC8z/Jv3/P/A/xEGaMw==
                    "]], LineBox[CompressedData["
1:eJwl0L0uQ2EYwPFXewPaojQ6FHUDorqXbr5qYSlxAdwDk/paqoqF3oMIMxEJ
7oOBpYKtvzcdfvk/z3tOzjk5he3d2s5ACKHOSiKETDKEffaYYJICRaZocEiJ
dffP6oZecGfO6Rvj3Nuvtc4vTfsZN+aWVpjnz36uZW1rRxd0U/+pmrf0QfP6
ziUv9iv9oUvZPseoucQX37w6y+q0DsVv5pMP1jjlybUTfeYovsN+rDXGzKua
07Rm4zvisxhhmJTzlC7poC5qg0fzgc7Ec27j/9Nl0sn+P+8BjOgqyQ==
                    "]], 
                    LineBox[{904, 900, 902, 901, 810, 811, 809, 813, 812, 662,
                     908, 910, 909, 602, 669, 975, 668, 830, 603, 758, 831, 
                    604, 952, 539, 714, 663, 968, 664, 753, 752, 599, 661, 
                    967, 660, 713, 658, 966, 659, 598, 807, 597, 808, 533, 
                    950, 657, 694, 903, 904}]}}], {}}, {
                  InsetBox["\<\"\[Mu] = \"\>", {-1.8, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["0.2`", {-1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {InsetBox[
                   SubscriptBox["C", "J"], {1.4, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["\<\"=\"\>", {1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["3.96`", {1.7, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {
                  {PointSize[0.05], PointBox[{-0.2, 0}]}, 
                  {PointSize[0.0125], PointBox[{0.8, 0}]}}, 
                 {PointSize[0.007], PointBox[{0.4463998339305619, 0}], 
                  PointBox[{1.2771956561278897`, 0}], 
                  PointBox[{-1.0806611991222994`, 0}], 
                  PointBox[
                   NCache[{0.3, Rational[1, 2] 3^Rational[1, 2]}, {0.3, 
                    0.8660254037844386}]], 
                  PointBox[
                   NCache[{0.3, Rational[-1, 2] 3^Rational[1, 2]}, {
                    0.3, -0.8660254037844386}]]}},
                AspectRatio->1,
                Axes->{False, False},
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                Frame->{{True, True}, {True, True}},
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLines->{None, None},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None, "TransparentPolygonMesh" -> 
                  True, "AxesInFront" -> True},
                PlotRange->{{-2, 2}, {-2, 2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.02], 
                   Scaled[0.02]}, {
                   Scaled[0.02], 
                   Scaled[0.02]}},
                Ticks->{Automatic, Automatic}], 106->
               GraphicsBox[{{GraphicsComplexBox[CompressedData["
1:eJyFW3l8zFfXT61pCJ42VFNCpTyj2kpTE8urDp1WN2KqaqsOilY7lqe2mqBF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                   "], {{
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[0.3], EdgeForm[None], 
                    GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxNmgnYl9PWxp+9H8OXiERRhibSiE5lyNAgoiMJJVRvI6LBkMiURMqUoRBS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                    "]], PolygonBox[CompressedData["
1:eJwtlwf0T3UYxu/3/dKSlU1EpKVSSrScpFBCZITISIj+CNFQhJQyIlulrFBO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                    "]]}]}, {}, {}, {}, {}}, 
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwl1FewTXcUwOF9XVFD9ARBRGeUiSAhenkQvXfRRblXSZAE0S4vypPee+9l
9D4Io8wQ3VOUEBKJGV4E3xoPn99a/2PmnLPPvrtk3/R2aSlJktT3T7/UJPkh
U5Lsojx97aP1A62lfzDQPIgfzVn0K73PYPP3jDFn1a/1AUPMQxlrHqbZyM5D
+3CtoGl6WMeRbv5JR2htPUIKG+2/6DeMZ5M9kx6Lz0cBe0Hy08A+mXPmSXqc
KRy1T9WGPOJPHsf34CTZ2eb/ZGgTTjE93sPZDG3KE/7iKTko7LUiPDP/TWXy
cIb8cS29NlfP8xsZ9ppxPakR1ymuITO56PVLdKWBvYtWi/eIz2xvxGvz/3zB
pzR31kvf8Ja18d7O1ujvfEcre39tqf20OsVpbR+giaaw0XxWN+hNPudw/K7a
TlNpSxtWxOd3XpJD5i1xD8RvzFAOcoD1Xtupa3Qda7lnLxefzdyHnvSO70FZ
5z10lHbTkdpdy8R10RHaWdO1i5bWTpqmHXS4dtRSeoe77GC1s+16m1XxG+hK
zcwQc3vdqhd0mw5imXk5S9lsv8US85e6OO4/Bsa9GN/X/JneoER8d/v6+Bvi
2/ie2kIXsZDr9nk6P+6PuDb2BXEd9BrF2G9fHdeBxuamNGEOV53N1mU6Kz6n
XuEyBanKK15SJ/6WKGB+wX/8G/cF5Z3n1So855+4r5wV5UNzJfbRjO3Ocupp
xpk/5hMK0djZNLbG37juZQ+N2OIsq55gTDwLyEd9e16tp7+yOe4xrcgEjtgn
al1ym/PwUfxm9qOMiudT3CPxPIpnF7ud/8wG81vPtJxax55Dc8V3Iol7lv5x
/6e+f+69Ax5sk9U=
                    "]], LineBox[CompressedData["
1:eJwl0DsvQ2EYwPGXztg0IS5Vl6Cuc7tSqksbEwY+ALP7pkWp21IWfAIJwcgg
Iia+DV38Tgy//J/nnJM3eU9iZa2w2hBCWGa2MYTuWAgbrDPEMIOMkGKPEhkK
vk9rUWvcm1v1izYe7de6wA8n9lNuzGc6xTS/9nOd0Au91awuap0Z85I+abt+
c8mb/UqfmefBHtdPytF5TDLKOGPs8u79lm6zSdW+o3k95tV8FJ3PIR/2is7R
b87pgLZor/aRIEkPzZ53alY7ojvqPi/msqZo4s5+EN2Prtj///8DDMgrOA==

                    "]], 
                    LineBox[{900, 896, 898, 897, 737, 738, 734, 736, 735, 662,
                     905, 907, 906, 596, 669, 970, 668, 830, 598, 760, 831, 
                    599, 949, 536, 716, 663, 964, 664, 757, 756, 593, 660, 
                    963, 659, 712, 657, 962, 658, 592, 819, 591, 820, 530, 
                    945, 656, 695, 899, 900}]}}], {}}, {
                  InsetBox["\<\"\[Mu] = \"\>", {-1.8, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["0.2`", {-1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {InsetBox[
                   SubscriptBox["C", "J"], {1.4, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["\<\"=\"\>", {1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["3.95`", {1.7, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {
                  {PointSize[0.05], PointBox[{-0.2, 0}]}, 
                  {PointSize[0.0125], PointBox[{0.8, 0}]}}, 
                 {PointSize[0.007], PointBox[{0.4463998339305619, 0}], 
                  PointBox[{1.2771956561278897`, 0}], 
                  PointBox[{-1.0806611991222994`, 0}], 
                  PointBox[
                   NCache[{0.3, Rational[1, 2] 3^Rational[1, 2]}, {0.3, 
                    0.8660254037844386}]], 
                  PointBox[
                   NCache[{0.3, Rational[-1, 2] 3^Rational[1, 2]}, {
                    0.3, -0.8660254037844386}]]}},
                AspectRatio->1,
                Axes->{False, False},
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                Frame->{{True, True}, {True, True}},
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLines->{None, None},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None, "TransparentPolygonMesh" -> 
                  True, "AxesInFront" -> True},
                PlotRange->{{-2, 2}, {-2, 2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.02], 
                   Scaled[0.02]}, {
                   Scaled[0.02], 
                   Scaled[0.02]}},
                Ticks->{Automatic, Automatic}], 107->
               GraphicsBox[{{GraphicsComplexBox[CompressedData["
1:eJyFWnl408XWLstlKYZFLXAjiyhoQHYISgUOGC5qQcytKAIaQKUiQUFAMAXZ
jVxkEwMoIBBFrVBaVApSQg9LW2gVTDdCAdtSUmhZ2hK6JBXN15vpO7nP8PT5
+s88b8/8Zs5+zsykyxuzIqc1DAkJSWoUEvLf8Yn7Tpe49dncq1V4V5PBx97E
0LVWT6LEDoEJuIOYL/HyN985ordd48xDX0Rqiir5twOPtbe5CiTG+sBYHxjr
A2N94GSxnsTRYj+JF0ypXuqweuT41P2xJpexVGLwBwz+gMEfMPgDBn/A4A8Y
/AGDP+C+gh+J54qR6uNbHcE/MPgHBv/A4B8Y/AODf2DwDwz+gcE/MPgHhh1U
Pat8A6sj5AGGPMCQBxjyAEMeYMgDDHmAIQ8w5AE+K+Sh+vxa9SPVLqpc6gj5
gCEfMOQDhnzAkA8Y8gFDPmDIBwz5gBHHapyqcaH6mWonYPALDH6BwS8w+AUG
v8Dgt748peYVNY7VuFD9CvwBY39g7A/cXexP9eVJNa+peUSNS9WvwQ8w+AEG
P8Dgp748reZVNY+peUGNK3UEf8CwJzDsCQz+gcF/fXlezatqnlLjXI0L1e9U
O6t6VuVSR8gHDPmAIR8w5Kuvbql1Qs27at5S41yNI8gHDPlUu6hyAKsj5AOG
fMCQr746p9YNNe+qeUrNA5AHGPKofqXaQeUbWB0hT311Wa1zap1Q86qat9Q8
osaxGheqH6l6V/lWR7VuqXlezaNqXlPzihqnql+rfoD11byo5iVgrA9cGKBf
4KWBdas5U2ACfjww3y3pfwTo17lr4P8Vsm6C3lnMl9/niPmE+emB+eXye9gb
OFXQ5fyHxUjqd+ADdGDEO7AqxyKBSZULegAdGPOAfw2M6aTOLxH/l/pTcUjg
L8kB/YAOedX52AfzgTEfGPzhO9gXdIygw5/xf/APDL9Q6apfqBh8yjpcR8f3
oMN+8AvYDxh+rdIhN/xAtbu6jvodsOoHqh3r4xsY8ad+j7qP79XzmRo/at0F
Heur8YP5sB/0qMYR5ASGPtV4QNxCDrVPVv0feQb2VeMBdKyn9qOqf6t1Ro0H
NY+p34MPzAcGv2ocAIM/YOhD7WdUP1D7CTWvQQ7oX63Hqr/CLup3ahzAf1Q7
qf4HPYFP1Z9B7xsYS/gHTYNP7I4qOeL/0YG6VsjWwPcuPh5Yz0kYIw9nlKWZ
vRJXT+3byaKp5TPqYmWc/aYc8f9eAfny5HdDBeZXBGbQgVeL7/lP8T3rBF8E
PrE+6BjxHfYF/lZ8J+XGPuDjwYDek0mV1ylGBt/AC8Q86i++47yji075/WUS
g451QQeGftV5wKpeIDf0AHmAIT/0ouoBcqvfAUMPkBNxhrgARj5DHQMdGHTE
G+jAoCN/Y0T/Bzz24OQEo+kOXxV6k3zBPvXxpfKt8gWMOANGHwe8PXT9GF38
bdoRWG9PvXIAy/xcF2fAyC+IT9QRYMQp+Fb7AtDVvgEYdOgH/gI9Ii9Cv8DQ
L+SEXzee9vWrHm0Ntz0SkFti+Ccw/Bd+Okdg6bdYf5dYX8YH/BTzsI6aF6Bv
1A/Mh/2Bocf6+jTkSayLEesAIx9D78i3wNmBPFzE0BMw4h3zsD8w9oe9QAcG
HfoGP/A7lT98B/6AkTewDjDWgT9CL8DQL/IB5EMeAYafYH3UFeyPugIMfhEf
4BcY+oNfASPvgh9g8KPWHzVfwg+hN8QD+AaGXoDhr/BTjMifWFfNj2rfDz1A
byEiXmRdAIae6tMj+MV88Av8//Xt0CvmQ2/AUj91eQz8Ib7RdwFjf2D0WcBY
Hxh5Dxj1SD2Xoa6pdQB5A3aBfdX7WLXeqvdMsAvsp85X76GgR8yHHrE/5iF/
wH/kvWgdlveSdRj9H/wJ8su+pK7/A13Ni5AbWM376D/lObBOz8DQM+JMrUPA
8l5czJN+jHwMvUMf0CP2xzrYHxj7Y13YG3UX9o4Q9pb9vDpiPvIR5uN7jOAP
/KvnRrUuYl3Q1XXVcyP6cmDYUdUv+gFg6A/r4f9YDxjrQV/gD3yDP+gB+oXf
wv9gN/g99AK/Bx3xDbp6LkJ8g47/Yx/8H3kLdOwDOuIJfgZ5EU8q/6CDf9DR
FyI/qH0j9KJi2BPrQC5gxD/0Djr8G3UMfQzsDXsi3wBDDtgL+oEd1fsYYNQ7
xJd6DwS9AsN+kAP6QJ0Hxj5qXybfc+v2h/xqfIMOjDwEfWB/0JFfkA+A4a+w
O/QBvwNfqvzYD36E/bAe6pp6Lwn+QA+bs2K+y1lwz/3MxlanN1p/Ct6LPPTm
xTGabj4p57l3p2f5ySfvZ+6+5k3UZ1ezT7PhvLvylsx7u0PP9zHF3/uufHfP
X6vs24P3N0mZ25P0ybXntk1XFjqiKu95z40dY3rCkHuTf4r96HXPxGpW75k3
90654E64yTFdmqy0zwzWiQPOn5rZtgTfE0cMeO+mO6FQYowFa6Y9ZDLkyTje
OMIwSPdiHrcTcss43fXn1UdMjYJ9AeT/6ceD3xhNZ2Tfs7/d+y/o+mTI+fe8
87T+77z/SP5gb/CnvnMlBvhLkvHxZuN9X5l1aQT+1N9BdD46ualt/AWph4i/
01rYXME6Xz7g01ij6TxBX+AL+pXvP3X2wL6wp/q7gUHHB8x17fcQ7A+7YF7n
OWFDDRkegr9BT9DrXc/b+e6wGpknysPjYozraiS/t+eOnubaUCPlbPJ8u9Ga
bjU0v2CBJ+3GOR7eOCrKVe7juNf+7GPa5pFj7M+7JnhW+7jnjjdYPy6HEw7e
etRy5jL/1eqVBvFdznHbHsM2WB/xUfSuQ4MNh7O5dFTzZrZqH696yP+WR3uS
I/cnD9W1quFzxuPFaeZYatsgY5k91sfzRs6c69qQSdqcsFRtDx/lP/rk+y5n
Fr1Y+oFTG3GSO3V52exIzaP3juT3N3zppa1a9wxHk3wKfclZkbalkmKee+gb
48FblBw54qi2Rym1f/VKg/iMSgp5tlk3S6/L3HpU2lfm9j6a+cDLp/TZBbR4
WMafcSN8FNWp+8eOx5y8M33qUN2zNZzcee0iR5NN/Lq1/TbzjhoesPD8M7o+
p6h4TvJJbXQN214/M8UTXcSD7rs53zHIy0mW4lX2mCJ6casv1PaCl2sCer9O
G/1b3O5u1dz1dP9Cf345L+6c/bNxWAXPPvvAaf30Wuy5MNjwbQXfHeE8rq+4
w57FnYYb/nmbe27ocEpfUU6rrx39whpZwfPn3f3IMaiCHu44KdZ8vpyXZJwt
cn9QJfvcxFxO1FdU81bvvGJ3pZtf/XOhyZNeRZuv98nyTy7heWNnXXGfqaa2
hVmDDT+4ZV/eR/gzP/5ESj/DYJ/Mn9+/9eD1tL0X5fjukJO/6B/M5fGDI6e6
nJf41OsPfmH9yc0zGgwZpSn6jZcn1FSkLSni6LDhUzzpKZzYODbRaNrFc56e
stv49yU+3mrucW36pzT9pbZvupwXeeKtiefc+t/pQzHydyedTW3trtPXWzx2
o+ksJzYv/NS69QYtqnp7lXXjGfaXnFrhKC2neeF6u1m3QO73mtiPwM8YwQ9F
T7d3spxx0+Tnvz2st52mfN2sbG1ohszz2G+l2I8m7/qlg2nFrXvOObtEvqGy
7174ymwKvldA3xuFvgl62iJGgvxvCPkpe9DdRvH23bL+tTcsLE9r4SX3mN1L
HKOuUMfiQ3ZzXhW3Tv5+gsdaQrDfOmE/WvrK3nBDnwp+xN/8HY+zXOaBdSI/
06zmRSHxU6vkObzroZ2dLUMr6ETzFwv9v5cT/C9a+B8Nefj2XMfVEu6x+VKc
sWU1wV/XCX+lzX+MKXOH3ZZ9JPy9v/B3Wc+9oj5RYpOG7S1ri+V5EfG0TcQT
/f5VtlFTlMoDq1dMc82uIcTXBBFf1HJM2zY2l412T00dottZQ4g3t4g3cvT6
4a/PXbX+crMqz/1yjTxXPHqqoq8hPvg7kQqR32RdqBT5Teb9UJHfZJ/hzDw2
WpPi444Zwxc4mhTLvhLyqO8j5w5d1huKqmTdDRf5WebtR0U+ZugPfYLn12O+
tF+DeR16nf/x+uGG3HLuFzVmt3l65T3vlGHrWq50pJZLvnaXl7r88VcZ9kb8
j3xs/4eOQdX33OPbo2bm+l1Fst+YKOoVP9b94kL7fX/cc6/VpuyzfWadU+ov
ZGCgnjH8F/PJcOJxk+GUrDOIi69nXUvWD8xkxBv61YU1T1ek3SiSGHVvmai3
jPgDfdidfQNMK4LvM+jfxoW/N0wX/wPXDMhebzUF32uSNV37me5clnUN36vv
N5cGB76X56qGQl6CPOp7zkYhj/R3m+hHCPLI99G6/Am/gn6BoSen6IekXMtF
PyT9bLuwL8Ge6jvgl8KewT5Q9G+EegA/hT+p73hthD8R/BF+C3+cI/yRllwc
FmsuDr5/zrj/zibzqlusvptminiQfrdO9LeEeALfJ8L2jDAMLmD19wCdRfwG
zwUiHmlZm/U7zDHneaXvfL47x8fIV71FvmLky/YiX/LOlCOfW3XVPHJncqjN
XMzI/x+J/C/rDcb0YVMGmOILuGf2uX6GPrV1b9c7ekN3F5nmPXJIH1LDeZ/0
zPHTebq+rV+mv8zH6BeWi36B9xsHRNvv3uKW41+b4kmsZPQbHUS/wasWb8jQ
7vHQGjFyVIX9X7ptlTz506SRmqO3GP3KftGv8PT3hlocV6so5oXjpCsr5vJb
LcrSLnrZOCd9n7lZAV9sG53l1/u41/ZQp//xi3w+sfkes+4EFYevfsiy9hyj
XyoT/RJ/8Y/xJe4PsunarlGfWj1HOHrc8c/MxWW0O+rC/TbXSa5YsypFG13b
TwfqXxJvCNQZHx3InxRm0aTL7/eK7wnfW8X3hO/nie8J328W3xP6w46iPyT0
h6WiPyTwnyv4J8j7nJCXIG9HIS/BvkOEfQn62iX0RdDveKFfQp+6R4wEe2CE
/UKF/aQ/6IQ/yP53iOh/pT8uFf5I8JeJwl8I/nJV+Ivs+4e0DJxHZH+Oe9je
o7vuNa+6TDOadqpMMycQ8HcCB98JnOYM/+QaeQ8f6fssxljbjyLvTD785kH9
zNr6VpYQbuge/N0L+oXHRL/Av13qe7/tyf/5fUtdf5Aq+gN2Lxq42n6zgpLu
rNxpTCrjlwuH/R13Ofj7FfQrN0W/wgVhnkmecC/Z/vnUBE23QraNCd9hPu+V
cb3jojVVe91LB28ObWtZm8urzA9M8FwIvp/hXBF5/96FDmsK/720V5Sr9f/I
WXc+iOo6rp/B8gP16FT4gq6sXOoP/eCBQYF+kLA+9KLb12eCJ93HsXsODdT1
+V3mq8gFo1taNGeDv8fYm9XGorkk68hN1/A0vz9P7jNka85qa/9LBPmQp56J
PNDOcthLc+K6sFb7B0FfuC9Bv91S9NsE+6AOod8vFf0+hZiHOrUz7vBYnvm2
J/E2wV6Yj/6/g+j/g/cv/Qs+cowKznvGE9HZ8m7wHrFpQckK+yKv5Gt2L22s
cYeX3m8yN1U/LoNnWvTJ2vAant2o4SxX6wR+o0+PbWZbDdu7vjRWF3+MPA3a
3Ez7tEb2By3Eeny5TUeNrd01Nq5Zv9GaWc04Xz0ozlf8zIfxN9xdrvDTKb26
mQ575T3bPLE/d3jFO91zIZhPi5PyvGmjr9DG6Sl7jWe9/GOT2f/WrL1K7jZR
5WntvNKvc4W8vFzkI47YF9kovkElQ3+RQn9Sz6OEPnje40sG6l4so7694q+5
p1Xywwte2GUNLaee0XzB366SM9/5fKW9g1fKOfGtH7qZ5np5duhzYbYFhXz4
WvcBhlleHnb0+6bxawsZ58894vzJ8Iflwh84889eEz3hPv7w3QtvuZwXGOfb
leJ8y/DPdOGfsg9bI/yR20/qF2/MO8fO5vMiPVv/4C+s4bNc5cF3v8L9TTta
Eop4RvmKB2wLTsr/3xX+y+ZH/s7SRmSwa8kKrelkHkcPOZGjjXDyxtWt7ca8
PMZ5urc4T/NqGtjaNj6FS54ovB13OU/G4Rjh/5z+zugZHu1+7rU+cZM55g95
fh/778D5XeI8Ea+c90pYd9OKq3Kd1NQRkz0Tr3K7nDN7zbofuefXT7a0LbjK
m8M6ZGnT7Qz6xewAnUDvJOikG5q/yerJkXE5Z2XPnqaT2bQ798MVdscv/NAH
lfuNeTkUteHcHId1K4M+XdAJ9PnrA3SZD2aLfMDm6B47zcZiim3bqoPpypna
vPR7M9snwffGD7e1+cq81EeNqj7zx3U5JOkH04d3s2g+Y9BPVQboBHpqWoBO
uP+YIe4/CPlvoMh/BPvK3/3V2XeMsC+Bv3WCP8L52CTOx1RY0L00bVJt/X3u
P5fcCb8S7l9mivsXQj7+TuRjgr8jLuHv04W/E/x9kPB3gj+dEv5E8Kflwp8I
/tFR+AfhvP+qOO8T6sUaUS9oT0xMS9uTtefb7T3+YdtyQ75HNJ2zcoJnawmh
Hh0U9YgQvz1F/BLiVyfil3BfYhX3JYT8NEbkJ0K+wX0P8s06kW8I9zejxf0N
If8UiPwj68NiUY9l/pwu8icNDH93kqboGA/ndyM0HwffX8eKek3IryaRX2n/
3Q3vuYwJVNXp0W3mL4LvrZNEPSfk31KRfynjyfaX/UsyKDklL0Lzrxp5ngi5
E7jf4z29k6vTbmTJ99SXFkd8ZB9yiZuFRBS4N/kY/TfufXBPvX14/jDdLB/j
fP6UOJ8z5Bkp5GGcz2PE+ZzBf43gn3E+XyTO5wx+Twt+uYWnUbFbnyPfazNX
HvnIfvcGn+1wO107o4pxvsC5Bu+5sYPe22TtH7znGpf3TrwxqYrX/LWvt8EX
fN8Nadi6efzx2xy3r+B91+w7jPMLzj14j2j17dTephV3uO9T3/c3HA6+9/oC
felVeY+Ad5emgXx1nEd2Tcn3UyY9daOxxdHklLxPqBL3xxz1UthSR5Ms+Y6E
d51tvyTcb1n7K+/5MeGY3pYtz33NXrOd1FcUUk7Hcfn+JSfk+RV0vDs01qae
0tuOyThdHOhLU7na23C8ZtoVuV9VSrfl9kXB32VDHpx/IU9JIL8eJ/ADOvg5
JPiR/cIUsR9hP7yLYD/5u/06faLvxX3hs+K+kFDPjol6Rk0PhD5t8GXJ92vU
n1xRf+jnlC0PWDRHJB33pdHivpRQ/0eJ+i/fNbzi/YNOPz+wheVMmXwPh7+l
C3+T9yZG4U8Ef1LfyxPF+wmhn3lS9DPy/h/vBIi3xiLegr/jFO85NLvnoS3m
VbV95BNFUa6Y2vOjJmKGy3GNt/ySu9EaU80NuxXuNBdfo5HJ3+4zJlXzZ+P7
l6Q9cZP6WmND4pdV8YE1HRvEj6jirwP3izf4esyy+2yzqvmV0i9f90RcY+TT
zSKfcsz4fk3ip17hXt9sfcSyNpNXjTsWZ+x0jeKq4lib/hujXhwQ9ULO7yjm
E/xdK/yd/nHOclQbWkpd0kc0s7nSCP3NdNHfUOMlOfPt7nwe5tyY5X88lw43
nzvL5TxAG87uTtHOyCXwO1bwS4jXPSJeCfL2FPLST1NTJmhybtMUzeYT+pV3
pP42CP1R8mCdUzv/DmnXjX/bk3qbrxq2nNFer+AjyyIeMxwu43Ffvv+5NbKa
+v9uMbtaX2PwN1bwx3d1h0rTWqTRSMOOrdZnshjykZCPd5/9ptC/s5wKX700
0GA5JPF3AhO+Hyi+J+zXQ+xH4OdnwY/kt63gV8r3lpCPoa9dQl/SXhuEvQj2
3yrsT/Cfz4X/0P8BiErewA==
                   "], {{
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[0.3], EdgeForm[None], 
                    GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxNmgn4l1MWx9973+yUJEuDJNJmjzYqJUUobUK0SKGFJIUQlSWZSJSSrZWo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                    "]], PolygonBox[CompressedData["
1:eJwtl3f8z1UYxe8gCtmbQmZGIRmNVzJCMitbJUoKEdGSysoeJZWsioZERER7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                    "]]}]}, {}, {}, {}, {}}, 
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwl1FmUj3UYB/B3/EOWpqkkSxJJhUNZx0RjcFMJTSqNLE32bZjs2a5ypeyU
yTBqIpGjZVA4J+fgHFpQ3Mi+c05uMMZYPs/p4vP/Ps/zvuf/br/3bZJfkDs+
LUmSzn6GpJJkfJUk+Y5mDNIPpgrt9Mf4UD2UAnVKtpf/Mkw9nAnqB2QHeZwR
6pFMVI+SP8gfKeRzfbnj/qS+LWvqa1GDTma1ZaX5SjlJn8lkivR3zMvUCY/o
HyWDLvppbFdPlVuZzib9DNmVU5zmDGmxb5wzxfaZLbvxC3PYbDZX5nCWc5yn
KnVte4IL6os8T0128RAltn0qd/Nb/F/cFzrGfSMzrpNP2GP7Xt4mW99PtqJO
nI8+h+vqG7SmHq+a5cmblPMlZWZF8g/e5/V4hvI1OUi2oQG99ENkJXdYyzaz
EnmQp2IdxLOWfeQ92Vu+wRJe1Ddig7o01kU8a4bTz+wt0sjlTVbQ1rbGbFRv
kEc5wjMMNBsnB8ixce6yqcyTY2R/OVq+J5vId+WouF+xvuQ78mn5N//wLcvN
1svDLFO/JJfKhGHqvvIbuVOuk/ksUi9mIV/rD/GZekE8S+Zz1+wDvorj6J+U
f9Ew1jEV3IprYk2sQfusln+yih364rhWfqc+681WxnXQXd2THsxjv9mBuB5K
9Y/LfWTQkmv8R5ZtnUlXt+AqV3jOrHm8W+oXuMylWAdm9ammbh7HjXUVx41z
5FcK9XXimDxGttmsuA51Sn7PJl6J9RffilhHfBzb9DPlSU7wMg/H/fPuPque
QkF8G+K7Eece743Mkumx5uz3s3pMrIl4/vF9inXCRvOP+EJ9y37V4r3SV5UP
Up0K8y3xrNT5qf+/b/cBYIGUqA==
                    "]], LineBox[CompressedData["
1:eJwl0DsvQ2EYwPGXDhh1YHBtEXdqZqQtA9GlNfIBGNw3d9Wa6IBJQsLKYJGI
wcLHwQfwe2P45f8855ycvOekVtYKq3UhhGVy9SF0JkLYYJ1BhhhghGH22GeK
ec9P6oJecGdu1k9aeLBfaZFvyvYzrs0VnSHLj72qo3quN5rTkv6SNy/po7bq
F5e82Gv6xCL39qR+cGDOMBHfyzhj7PLu/pZus0nZvqNzesqz+UTfOOLVfqyz
9Jrz2qdNmtYeukjRTaPr7fH7tE2n43niOeO/034auLUfapaOxP///wN6qiki

                    "]], 
                    LineBox[{894, 890, 892, 891, 731, 527, 729, 728, 730, 655,
                     899, 901, 900, 592, 662, 956, 661, 829, 594, 753, 830, 
                    595, 933, 531, 709, 656, 949, 657, 750, 749, 589, 653, 
                    948, 652, 705, 650, 947, 651, 588, 818, 587, 819, 524, 
                    929, 649, 688, 893, 894}]}}], {}}, {
                  InsetBox["\<\"\[Mu] = \"\>", {-1.8, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["0.2`", {-1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {InsetBox[
                   SubscriptBox["C", "J"], {1.4, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["\<\"=\"\>", {1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["3.94`", {1.7, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {
                  {PointSize[0.05], PointBox[{-0.2, 0}]}, 
                  {PointSize[0.0125], PointBox[{0.8, 0}]}}, 
                 {PointSize[0.007], PointBox[{0.4463998339305619, 0}], 
                  PointBox[{1.2771956561278897`, 0}], 
                  PointBox[{-1.0806611991222994`, 0}], 
                  PointBox[
                   NCache[{0.3, Rational[1, 2] 3^Rational[1, 2]}, {0.3, 
                    0.8660254037844386}]], 
                  PointBox[
                   NCache[{0.3, Rational[-1, 2] 3^Rational[1, 2]}, {
                    0.3, -0.8660254037844386}]]}},
                AspectRatio->1,
                Axes->{False, False},
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                Frame->{{True, True}, {True, True}},
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLines->{None, None},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None, "TransparentPolygonMesh" -> 
                  True, "AxesInFront" -> True},
                PlotRange->{{-2, 2}, {-2, 2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.02], 
                   Scaled[0.02]}, {
                   Scaled[0.02], 
                   Scaled[0.02]}},
                Ticks->{Automatic, Automatic}], 108->
               GraphicsBox[{{GraphicsComplexBox[CompressedData["
1:eJyFWnlc1FXXx6UydZ5KUXP0SROXiRTRR8xMPSVmSqSTD26Yo6FSOW65Y77u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                   "], {{
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[0.3], EdgeForm[None], 
                    GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxNmgnYl9PWxp+9H2OhUMbQoEGDlDIkpCRRIpXIVMZSGSopSZ0kSUmDJFJK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                    "]], PolygonBox[CompressedData["
1:eJwtl3f0j2UYxp9Byi7hR2SUJLM4EUeysmdUtoyE8qPMELIjo0VS2jvRQWnr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                    "]]}]}, {}, {}, {}, {}}, 
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwl1FlQlmUUB/APKNqotEwzsXFpymJzQ0NKy0rbESoQsBAkkDKwRWkb7bJF
K03JFjWBqJhpAdKaZmqmnLFst5tK22yZ0ZuCsmLP35kufvzPOe8LvO/zPN83
saqhqD4pkUjk+3FTSiJxR3Ii8RLp3KC/kV51Bl+zWF9KvbqPTL6hzKycBnU/
WXzLErObqeAWXjN7nZU8qe/2f99Q/xUPoU/iP30Oyeoj5hvlPfqprOIp/d/m
nepeeZx+pjpV5spbZQ1VVLOMLvNauZwTmKU/Xs6W97JZ3edv7VQPyi36+9X5
7OIB2s0elBfxPT/wI0PuT3PtZH7SH2RCPD/vcCzPufaofI93adRnkMkFZJPF
Gt53/QMWkasvkOeQxqx4Zn5X/8G5jGCuWbHspoen6TBrkntj3yiPvTUrk+dx
Gi3652OfmBd7JS+Rj/Awn+pH82Kso7w81l5Wcpn6sXgvpujPoFW9Q1ZRE3vB
VWZX8q96oVzAE/He+jG0qdvkV+xjHEVmK2IN5O2yUJ4lC+Rt8jpZJ6+XY+W1
sbfyalkrr5Fnyi/4Mp6fx81a5eesV58v18l/ZDVXqJvl27JFLuUFuvTb5Wds
5S39NlnBpXGu5Xw5Sn7C6RyJM82flMb+0+meZ+XHbIlzpX9GlvARI2k22xzv
z4XqQpknH2Ite/QfxmeA7XHm5O44y0zmMIfis+JaDqnqSfzGr4w3SydFPZFf
+DnOkNmpDDvLZ+sv5hT93FiPeGfqYu05iTn6E2WevC/Om3rA77arX4lnp8ms
3+xN9eqY6xvldxxgOsfE+rtnfKy3ujKejWn6/fHZUc+Qm+L8uK9DfRcv6++O
5E426HtcH1RnM8AwQ7EH5q/KYveUpPz/PXcUErmawA==
                    "]], LineBox[CompressedData["
1:eJwl0DsvQ2EYwPG3OjFo3LWSVl3nGotQbQdicvkArGjZkFRbddkwWCQkzAwG
ixgsfBp8Bn4nhl/+z3Pek5OTN7tZXanEQggbLLSF0BsPYZstMgyTZoQs+xww
xaL3c7qkF9ya2/WDTu7t17rKF037MSe0yDPNt7NTHdczPWeGNfsPs+Z1fdCE
fnLJs/1Kn1jmzt6h7xyaJ5hkNPo2Y+zx5ryiVXai/7Hvallb0fei/9RXGrzY
m1oiZS7qkMZ0UJP0MUA/wfNundcundMjHs01zfDr0m/sdXOBnvj//f8BVisn
Tg==
                    "]], 
                    LineBox[{886, 882, 884, 883, 726, 519, 724, 723, 725, 651,
                     891, 893, 892, 587, 658, 949, 657, 819, 589, 746, 820, 
                    590, 926, 523, 704, 652, 943, 653, 743, 742, 584, 649, 
                    942, 648, 700, 646, 941, 647, 583, 808, 582, 809, 516, 
                    922, 645, 683, 885, 886}]}}], {}}, {
                  InsetBox["\<\"\[Mu] = \"\>", {-1.8, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["0.2`", {-1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {InsetBox[
                   SubscriptBox["C", "J"], {1.4, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["\<\"=\"\>", {1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["3.9299999999999997`", {1.7, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {
                  {PointSize[0.05], PointBox[{-0.2, 0}]}, 
                  {PointSize[0.0125], PointBox[{0.8, 0}]}}, 
                 {PointSize[0.007], PointBox[{0.4463998339305619, 0}], 
                  PointBox[{1.2771956561278897`, 0}], 
                  PointBox[{-1.0806611991222994`, 0}], 
                  PointBox[
                   NCache[{0.3, Rational[1, 2] 3^Rational[1, 2]}, {0.3, 
                    0.8660254037844386}]], 
                  PointBox[
                   NCache[{0.3, Rational[-1, 2] 3^Rational[1, 2]}, {
                    0.3, -0.8660254037844386}]]}},
                AspectRatio->1,
                Axes->{False, False},
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                Frame->{{True, True}, {True, True}},
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLines->{None, None},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None, "TransparentPolygonMesh" -> 
                  True, "AxesInFront" -> True},
                PlotRange->{{-2, 2}, {-2, 2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.02], 
                   Scaled[0.02]}, {
                   Scaled[0.02], 
                   Scaled[0.02]}},
                Ticks->{Automatic, Automatic}], 109->
               GraphicsBox[{{GraphicsComplexBox[CompressedData["
1:eJx1W3tY1MXXxzQlctG8ZZuhadlWlpatpqVH2+o1Kt3MK9qqlWlualmiy88U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                   "], {{
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[0.3], EdgeForm[None], 
                    GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxNmgn8l1P2x597n5G1kGRNm61dSlnSQilFEgmRskSUJaJSJEkbKWtZStLC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                    "]], PolygonBox[CompressedData["
1:eJwtl3cYkFMYxb/7XqU9tIyUppJRoVRGRWjQlKaW6KFhtEloyB5J05aUyCh7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                    "]]}]}, {}, {}, {}, {}}, 
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwl1FlQlmUUB/APPs19ptRcyqls0hQwlZRKM620VDQVi1gFaTGzsFzCLnOh
0sxWNzDIpbSkhUit1KkZZ3Sm3NIWbzQtrWbqIhLNjfqd6eLH/5zzfMv7Pu/z
0bNsZk55SiKRyPLnvmQi8WhqIvEuVzNOP55z6r4cZZI+h2nq86RxjMlm9/OY
+gLp/MQDZrnk8SD1Zp8wnRf1f/neBvXfcRH6FP7V9yNVfdp8sSzX38RMluib
zLeoz8oW+gHqpBwoi2Qx+RRSwDbzKbKEy8jUt5Q3yzm8HPfpsz5XX5Sv6p9R
b+cLKthgNk/eynFO8DOXvL6Ntbb8oj/JNXH9fMlXPE+59cq4B7lLPiX70Jcb
SSeNCnZbb8cKdbb8iOtpT2ZcN42xb9zA5QwxmyRP08QbbDZ7Xe5jfzwP3o5n
JXvRkWr9KpnL0HhO8nY5n+f4Vt+Zt9RF8g55RhYwTL2QBfTWd2KNeq0spCT2
nbvM7uQf9Qg5nBfi/vVdqFW/I4/wI1eRbfaIHCMflmNldzlaPiTvkWXyXtlN
jpJT5d2yVI6UXeX3/BDPL56D2Xr5HZWx73KRPCuLWUeN/kp5mPzYLz40q5WH
Yh9o0NfIvLhfPtBXy4OsjjOur4rfBSup06+QB3iTev1ymcNerqDK7DU5nkHq
cXKwfDbOHV/rv+GV+Ex9B7mHVvTkT/6I3461DFqqr+N3fos9jf0jqb6WXzlF
B7P2NDvHPfS3xdnTD5E72UFp7C2tuSW+U2bJuXE96gveWxfnLa6ZZWbnzT5T
z2K9frZ8P+6NpXEWrG+N30Hsu/5p+R79eSnOmPVP1U+wVv+k3MgmHmcGGVyk
mUs0es/HcoLXT0z+/z/tP1SjmKE=
                    "]], LineBox[CompressedData["
1:eJwl0Lsuw2EYwOGvuuiidW5SRTGzOYS2OhBTiTtQx6mCCW3ZMRAGLkAHA3cg
kRi4GVwBzxfDk9/79t/8D1+htr9eT4QQNih1hNCdDGGTGkPkyTHCMAccMsWS
/0/qsl5wa+7UD7q4t19rlS9O7Kc0aTDNDN+utXRcz/ScWVbtP8yZ1/RB0/rJ
JU/2K31mhTt7St85ivdjglHGKLDHm+vbusNWfJ59Vyvx+bTNLX2lwUt8Z11k
0FzWrCa0XwfooY9egt/TuhDPQefjt/NoPtY8vw79Jp6HuUgm+X/+f0iUJfs=

                    "]], 
                    LineBox[{877, 873, 875, 874, 733, 518, 731, 730, 732, 648,
                     884, 886, 885, 583, 655, 945, 654, 816, 585, 750, 817, 
                    586, 918, 522, 710, 649, 938, 650, 747, 746, 580, 645, 
                    937, 644, 707, 642, 936, 643, 579, 805, 578, 806, 516, 
                    915, 641, 686, 876, 877}]}}], {}}, {
                  InsetBox["\<\"\[Mu] = \"\>", {-1.8, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["0.2`", {-1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {InsetBox[
                   SubscriptBox["C", "J"], {1.4, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["\<\"=\"\>", {1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["3.92`", {1.7, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {
                  {PointSize[0.05], PointBox[{-0.2, 0}]}, 
                  {PointSize[0.0125], PointBox[{0.8, 0}]}}, 
                 {PointSize[0.007], PointBox[{0.4463998339305619, 0}], 
                  PointBox[{1.2771956561278897`, 0}], 
                  PointBox[{-1.0806611991222994`, 0}], 
                  PointBox[
                   NCache[{0.3, Rational[1, 2] 3^Rational[1, 2]}, {0.3, 
                    0.8660254037844386}]], 
                  PointBox[
                   NCache[{0.3, Rational[-1, 2] 3^Rational[1, 2]}, {
                    0.3, -0.8660254037844386}]]}},
                AspectRatio->1,
                Axes->{False, False},
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                Frame->{{True, True}, {True, True}},
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLines->{None, None},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None, "TransparentPolygonMesh" -> 
                  True, "AxesInFront" -> True},
                PlotRange->{{-2, 2}, {-2, 2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.02], 
                   Scaled[0.02]}, {
                   Scaled[0.02], 
                   Scaled[0.02]}},
                Ticks->{Automatic, Automatic}], 110->
               GraphicsBox[{{GraphicsComplexBox[CompressedData["
1:eJx1Wnl4zFf3j6VKGEsbqiO10xGtktd08cNRaaui1bEU9eqgraUdGi8VHUtb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                   "], {{
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[0.3], EdgeForm[None], 
                    GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxVmgn4l2P2xt/neW1llyhJJWklFSoVLVIqZUnZUokSRYgiS9psLSilSFHD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                    "]], PolygonBox[CompressedData["
1:eJwtl3f4z1Ucxe+wFRllREZGJWRlZFOaFEUoZGdEkhZSIaNFS7tQSkU0nkpL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                    "]]}]}, {}, {}, {}, {}}, 
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwl1GmUjXUcB/BnxlJZQiKHNKaGjHKQJaTs0dhnpsXOUA3O4WRJqJwOWcdO
NfY1S+Fl5yRrCm/sO+eUaWyzIaOhSePzP1585vv7fe+9M/c+z/9OfNqY5NEx
URQ18qNzqSj6IDaKlvM0ney35G2O0sXelb7mO8RxjHd0SfQz/00djtNN152e
9GCDbiP9+dSe5W9uMmfLInmff3iRB1zVT/S8IeaXGMpn9mv6zeYbcrJ9uLku
J+hl700yfdiqS5HF8j/+pR4f87k+x+/4wZwvp9pHmLfzIyNZpBslX+EkpzhN
geeXyMjjZ+RZnuGuvpKuMhfsF3k2fC59nO6BXCX/1P1B9fCedAm6umSHz00N
SvT1dYnctOdQk1I01nWWueTxNd/ppss97KUr83RdZC3KMNs+J9wzmpib8hqf
cED3BM3D/ZLNwv2TS1lpXiKfpyxz7MtkT/rQm1a6lhSYX5ctmMAL9qfIMGfK
IxymIh1178n28l3ZQVaQ7WSqfEumyLayvHwz3FvZWrbhDcrZf+dQuAaM130r
f2OcubYcK/PD+eAb5tqflAfDOWUxK3SL5K8sYL19oUxifvhe2OfJ/eH1rLNn
yLfDdSXTPkvuYwZr7TPlbn6hNLN008LnpYG5XThb4dyRzs/2XXwV7qk9kj9R
7Cw8J7O4QrzH6lCkr2a/zKVwBnVVKNRXtZ/nXDgzutjwfdZXtr9KjL2h3MkO
UsM94P/w3nhIIul8qc8LZ9u8hvp8ocvVbTN/yEL7R3I1LzMlnFuPbzGnhWtq
HyZXkcAk+3WPf28eFK6xfXC4D+G8MYCB4bNyl3sU8pfXrA/X3fPfj338f+sR
yhaYhg==
                    "]], LineBox[CompressedData["
1:eJwl0Dsvg2EYgOG3rfMpEYc6LVhRp4XEgl9gQMuiTKpf0RWRSthr6CbxD0gM
/CGMdCZxvTFcuZ+n35vv0MliZStJhRAOWEiH0J4JYYdtBhligCzDFDlkmhXn
p3RVL6iZf9zs1Zzi1l7Tdd45tpcoc8IMs3y4luioVvSUOTbsn+TMm3qnaX3j
kob9Sh9Z48b+6/kv5iPzOBOMMBbvzz7Prue1wC5V+54u6zn35jN9iu/DQ3wn
XaLXvKh92vSsbu2hgy46+fZ7q+aca4nfomXq8bu1ny9nru2JeZ62zP///wck
0SUa
                    "]], 
                    LineBox[{865, 861, 863, 862, 717, 504, 715, 714, 716, 633,
                     869, 871, 870, 571, 640, 927, 639, 806, 574, 739, 807, 
                    575, 900, 510, 694, 572, 693, 634, 918, 635, 734, 733, 
                    568, 632, 917, 631, 691, 567, 690, 629, 916, 630, 566, 
                    797, 565, 798, 501, 897, 628, 672, 864, 865}]}}], {}}, {
                  InsetBox["\<\"\[Mu] = \"\>", {-1.8, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["0.2`", {-1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {InsetBox[
                   SubscriptBox["C", "J"], {1.4, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["\<\"=\"\>", {1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["3.91`", {1.7, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {
                  {PointSize[0.05], PointBox[{-0.2, 0}]}, 
                  {PointSize[0.0125], PointBox[{0.8, 0}]}}, 
                 {PointSize[0.007], PointBox[{0.4463998339305619, 0}], 
                  PointBox[{1.2771956561278897`, 0}], 
                  PointBox[{-1.0806611991222994`, 0}], 
                  PointBox[
                   NCache[{0.3, Rational[1, 2] 3^Rational[1, 2]}, {0.3, 
                    0.8660254037844386}]], 
                  PointBox[
                   NCache[{0.3, Rational[-1, 2] 3^Rational[1, 2]}, {
                    0.3, -0.8660254037844386}]]}},
                AspectRatio->1,
                Axes->{False, False},
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                Frame->{{True, True}, {True, True}},
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLines->{None, None},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None, "TransparentPolygonMesh" -> 
                  True, "AxesInFront" -> True},
                PlotRange->{{-2, 2}, {-2, 2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.02], 
                   Scaled[0.02]}, {
                   Scaled[0.02], 
                   Scaled[0.02]}},
                Ticks->{Automatic, Automatic}], 111->
               GraphicsBox[{{GraphicsComplexBox[CompressedData["
1:eJx1Wnl8zFf3tjWWmlS9ahmaoqRjK9WMWtoeNbU0qEEUKUNrKUbLa0k7qL2j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                   "], {{
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[0.3], EdgeForm[None], 
                    GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxNmgn411P2x++9H7vKksk2KFJZUkQqSqWQFEpZopKyFBUyRUhCKkQjW7Jm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                    "]], PolygonBox[CompressedData["
1:eJwtl3m0TmUYxc9532uKkjljXUOEpMxTmSNCVzJFLkKmmyGVDKUQpULTakZF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                    "]]}]}, {}, {}, {}, {}}, 
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwl1FVsVFEUBdChxd2Da3ES3N3d3aG480WCu0NxtwR3+CTBXX5wJ7i7u60b
Plb32WfedGbe3DZ37NCWQ+JFIpFCflSLjkTaRkUiK0hGVf2dfM85aug1aWf+
QHbOU8uuNu3NH8nBBerYJZd15Xq5gQ700e94vY3me/Kb/M5XctGN+a7pKjeT
m+70tbvv+i3mh7K/3tOcl14M0B/ZbzM/kYP0vuZ89GOw/tR+h/mFHKYPMO9i
JwOZajdIFuIil7jMS9f/koW5wlVS884+ueek4IZ+k7ThPthns8vO3fA5Sc8X
+7x2MeG96o/JyE/7AnYFeR7eX3hN/toXC/fd/IrX4T0yx26KPMThcK8ZH74H
mYl4jNRnhftPAybo9WVmohilz5MNacJEvbHMQjSj9cWyKSdIyDi75rKkfCtL
yOL0JpuegLHm5fIsZ0hKZbsqVKS1XkkmkRVkK1lOtpTlZWJZVraQpWQZSpNI
P8VploXv3G6pPElPc1YZK9/IZixhjB5fHqcRi5hnt1AeC+csXKcvkPWYG+hx
8iizWazPCeecmcTpM+QRpoXfqU+XBzlAhBF2k2XVcJbCZw9nR3akA/v0/eGe
M1z/5XveG/4GZAb5gPvk9FgOPtmn029zi1R2KXlvn0a/zrVwXvgTzop9SlmE
3xRlD7vD5wzngJ/mgvygAP0ZGs6f56YwryU/Q+ye2W0392aK3keuIYaB+mOP
bzX3YLIeK1eTh376A49vMndmkt5FrmQVHekUPiuf+MJn7nrOOlnd9W2i/v9/
+gcga5YY
                    "]], 
                    LineBox[{851, 847, 849, 848, 718, 501, 716, 715, 717, 634,
                     854, 856, 855, 568, 641, 915, 640, 805, 571, 739, 806, 
                    572, 885, 506, 695, 569, 694, 635, 907, 636, 734, 733, 
                    566, 633, 906, 632, 692, 565, 691, 630, 905, 631, 564, 
                    794, 563, 795, 498, 882, 629, 672, 850, 851}], 
                    LineBox[CompressedData["
1:eJwl0DszQ0EYBuBNDolQEIlbJ1oSoTGjEaVLFIbKJeglQmaSBoWCQuUf+AnM
KPhBaNBSyHjOKJ553293Z8/sKRw1NuuJEEKNhWQI55xFIXxbfNZ/Zdt8pS/x
yo55l332mGaGN3s1OSYP5CFFKuZ3Svqy7Miue1/0C27Nl/KeRVrmH/tP+rY+
zgQj8d2MssGj/TW5ziotc1XOx2/gRj+VD5xwZ27KOfr1shyQX77VJzP0kibF
p/WELDkX4rfIOtf6sRzkw5mmuaHPktR7iFghyzBD5MmxRYEpJqP///4HaOgk
Wg==
                    "]]}}], {}}, {
                  InsetBox["\<\"\[Mu] = \"\>", {-1.8, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["0.2`", {-1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {InsetBox[
                   SubscriptBox["C", "J"], {1.4, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["\<\"=\"\>", {1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["3.9`", {1.7, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {
                  {PointSize[0.05], PointBox[{-0.2, 0}]}, 
                  {PointSize[0.0125], PointBox[{0.8, 0}]}}, 
                 {PointSize[0.007], PointBox[{0.4463998339305619, 0}], 
                  PointBox[{1.2771956561278897`, 0}], 
                  PointBox[{-1.0806611991222994`, 0}], 
                  PointBox[
                   NCache[{0.3, Rational[1, 2] 3^Rational[1, 2]}, {0.3, 
                    0.8660254037844386}]], 
                  PointBox[
                   NCache[{0.3, Rational[-1, 2] 3^Rational[1, 2]}, {
                    0.3, -0.8660254037844386}]]}},
                AspectRatio->1,
                Axes->{False, False},
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                Frame->{{True, True}, {True, True}},
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLines->{None, None},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None, "TransparentPolygonMesh" -> 
                  True, "AxesInFront" -> True},
                PlotRange->{{-2, 2}, {-2, 2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.02], 
                   Scaled[0.02]}, {
                   Scaled[0.02], 
                   Scaled[0.02]}},
                Ticks->{Automatic, Automatic}], 112->
               GraphicsBox[{{GraphicsComplexBox[CompressedData["
1:eJyFWnl4zFf3j7WtGlFLVaop5dUhtuaVamM5GFutQ/u2KjrUEstY+lpKNFVV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                   "], {{
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[0.3], EdgeForm[None], 
                    GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxNmgncl2PWx6/rumXLFImQtCBla0GlzZolUbIXqaQSIaSylLWyJVuiJGZe
MpZhsi8vioyoLDNmXmNfxstrDAaD8TLn+/x+/8//+Xye8znnvu7rvq5zX/c5
53fO+T/tR5829NSSUlpSpRR/ab+c0n8F/3XQbUFxmdYJuieEu4N2Crov6N6g
LkH3B/0uqFvQRkH/E3NvD/pNUJOgZkGvxPiaoN8Erc5ab8Ogjbz2ukEtzNcL
2th8/aCW5k2D/hDPvhB0R1DLoLdi7M6gu4J+FbRZ0A5BbYK2CtrRvG1Q66Dm
3nfLRvu3MW/huS28f1tz9m9nvklQe/NNgzb3vrzjPUGtgrYJ2tYy+nQ0Z+52
5lsEdTJHr87m6LW9eRvfb2a9W8X7vhv8t0E7WT/0GhnjffluQV2sXweejfH3
g98bdGPI8/hOId+QpWP3oF0a6burOfruZo6+h2Tp2iPoiCxdewYdlaVrr6Dd
rTdn39ucs+9jjr59zXcO6meOvo8H7R802GPt/A57BnWznns10ndvc/T9OGip
9X3QeuwTtK9ldJmfpceAoANDPiCoq/fsa10OMO8f9PugPYIGBh1kGV0GmaPL
YbHG0CxdLgv+iPe83zrzzH9nrTsE/bLWG8qzjdY+LsaPDTqYM82ae3TQM557
TNCwRs+Nizljg44I+XCvgV7PsVbQyUHDPZf77WPu98GXBT3r9U4Ieilr3TFB
J3oPnhtrfiz6842DRgVdGfOfDH5k0GiPo+cp3ndE0IqY8zxnEvRs1nOnBU0J
eX7wRUGnez3WWJC1/xlBZzbSZXmML+ObBa0MejFoSdBZvo+OD8b10qD+Qc9l
vfe0oHN8Buh1rvnEoPPMTw16OOY/FLRn0GSvNy7ofN9H5zPj3hlZ+r5oHWcE
XWhd0eUic9a42PzsoEvMpwRdaj41aKY5es5qpO9sc/S9zBx9LzdHr5eCVgZN
D3o56IKgK/gultHrKnP0mmN+se/Xzvhqj6HjNdYPva6zTuhyvTm6rA5aZV3W
eL8bgm70fuxzrdfg+UVZ4/OSvvkc7znXe7Lfzb5m/wXmrPG6170l6LYsnRYG
VSG/5jVvarTeq0GvWN/fxpyFYANnmTXv1iS7wQawzyYh/9F7gm9g29pJeAYG
gXN3G9PAoXuNaeAQ+AamgUPg2x1JeLQkCefAALCNWA3mrTHOEbdZG3wBb2o4
x3UN51qkOs5x3YBtXr+GDcTfGjZ09n7gCLjCnlv4urmf2SLVca51quPclqmO
c21SHee4BlfB0k1SHefaJeENMnh3XxLObZ2Eb+DFNqmOc9umOs51THWc4/ru
JJxuleqY2tZ67OB3A8uI0318D7zY0XN39jW6dPH1vZbBO/ANbOtmncCI7qmO
bbukOrZxDa7tZt3AtR7WFVzr6XNGJ3CkV6pj2+6pjm29Ux3buN4qnv0sCQ9q
+QfPodOeSbhQw7M9Ux3PuF5qGd22jHU+SXVMA1vANbBsX+9bw9G+JvBsv1TH
M64fsAyuPZyEbQdaD7BjYKpjG9dg2iDrA0728/lenoVzjyXh2mCv/1ASZh3g
tcCdoV7rcF+Db4d7j15ZOAd+tAv+dRLW9cjCyEOTsAmMAqueSMIZ9ng6CTe4
Xp6ER2DP4+iVhVHPJ+HWyKQ9mD/KeoBrNSwd5vXB0uHWlTHwpYZDxHZi5h+S
8HVC0PSs+LXYexNbwJsXjVdgzDLjH1gC7oIvx6Y6vp5oncAWsIa4BRZO8v3J
3ru/8QlsWmq8AlceMsZOsa7oSHxf4TV55+eNi1OtH/gyLdVxkWv0A1vAGLDu
fOuzdcg/pjruXZCEfexzoa9r+HdhquMf1zX847qGf1zX8O/SVMe/mamOf7NS
Hf9mpzr+cb3SMvrVsJy5HUPP/0/Cwxr+Xem9wYg53nuur9n7Gl+z97W+rmHe
damOnVdZp+s8b5XnXOb3Zx/wF7y7wdc8A37NS3Vsu9nrzfe9uR4DnzoDOFm4
erXHmAf2LfC+4NtC67FjFhaCk2DcIs/HJm/18+DbYu9xdhbm/SnkP2XhHVhE
PnaL9SHOE/OJ7RvG+BtJ8970+AZBLWL8L6kRziVhziNZOAqGPgp2ZOEiWAZW
gl9/trxWbX5WXbluFnay3kdJeTMx6e0kvEGfDWLOT/7+7T1OnN8sxt9JwqEn
szjxHlwBX8CiTWL8r75+LwknePaDpBqIePxhUnwkNu4S8z/1dessnYiVD2Rx
YtugrOfRtYvXpI5YLwvb2B88IY4Tw4nbxG+wY9eY80VSvCR+gw/E8/+zfEjQ
iKzrR/mWjrXM/dTPEWP/12vy7D88l5z81ay4R1zpHfJXSbGzbda8WqyEkws9
EeN3BT0V8t+TarBaTEcGR9aP+3/z+7Ae8ZfY+11SrCHOTIg5/0yqLf5lTuz+
Jin2EffGWiaOdYj53ybFU557JikOD7VM/G+aFd/Rt1/Wfuw9KSsWE4eJS8Qn
Yua/LROjptteGmKF8WBk0OtZexILOdfLjKMXJMUPniXG4Of4+LZZuS9j+DY+
ir9n+ys+TzzAP/HNTln5KGO/CvkXr4Xtky/iC81ivGQ9gw/hU+SK+Dp+i882
j/trZ13fbt/lPj6JbxIy8FtiAHFmMb6flR+v5diAb2+c5cP475CsOhnb3DTL
x/Cvn/3uvBc+hE9hw5tn+Qz+go2/n2TnxIO3/Cx+hX/hv/gDfoFPzYxnD7b/
YDfYDzkNNks+gy+0ybJjbBh/w76xbfyM5xpykyz/xDfxj888f3ZWjlXzEzi+
MybLjrFhfAVfI2e4IsaPb+QDcPwFX/kyKUfAT7DvWt1NToIdXp2Vo9TsG46t
js+yb2wbm8KesVVsFFvFL6hH8Ad8AdunBsf+8ZsfknAaP/s8ydewXzAXe8Z+
iXvY3nZZ3+kK29MvtjFsEGNgfPssu8Qmrwt+rXGCbws+YtvYHLa30LbDfexn
myz/YQ621iTX7RE7XOyzfMLnic2uk2W32AuxD5u5Pst2mzjuEt+xDeyOOLLU
54Rvc1bUs8T3ld6zuW0ePNnQWAV20E/Eh8AKcAi/IdYS37FBfK6ZfYraitqN
ugrbpz94p20Hm8N+6J9h39j2e0k9Mmyc3Li1Yz22Sf6NzeIr9N3Angbbz/U6
aDNjDzaITT7iM97B50ys6uC4wxmTV73ob8K5z/B3JtZc7u+5nb8p9kXvZpnt
DjvENrGFjv62xEjiO3aN7+9o/985q6YlVoD3yJwN/Vvu0evFXjo7lmFTxC/s
qmvWGTJn36xrZGoBemf4Y/esupheMWeNDOYPyLrH+P2Wwf3fZ+FoLb+HD/U4
eT/1yDPBn8712gCOP+6eVTMc5TnI+PiXvsd436zc+/ik/BCZ3PaUrHuM3+d3
QbflHh+ZlLuSZ5O30lPaI2h8yHtl5dvI3EMmn6V3xL2Tkq7Jw8ltT/Oz+Pg+
WePMOT3rGpn7/T3noqzz5WwvyTo7dBvocybeghv7Z+VU/fwNOP8VXhMc7Opx
8hHsD1wjHl6atRb3z8rqZxFzBmfVvdS6cK7BhUMtM068pg7cK/jRWfUwcbuT
n6FeZox71MnEbGI+ODDIz9LPpH6mrua5I7Pknh470nsx9zDP397rdraeQ6wb
GHJ4ll7DvC/6jAo+OqtfAFaDu8RI8GR4Fg5Q11F/HmF+nOWDfY2+n3hd1jwh
a939/O7HWGfqa3oT1Pifex5zsMcxtkni5IlZsXKk1xlgPUd6PvgDHj3qdzrM
74VO1KLoO9wy+AKGnJyFP9jsRNstOHNqFp58b/vDrvjG1HLUcWDaSVm4RN94
vNfEdibZfqgFpmblDD/YVlgDe5mclU/N9zzyDuYiL/I+Z3rO+b5GnuY1mXNu
Vq1CfYL/XWw7Z/w8zyHvoYahfpmRJS+2fIGf5TzGWf/zs55n/BzLi7zGDI8T
5y60f7HnJd6XGE+Ogs3iZwfZp4jfs7Kwgucu8rM3eQ/OgPyc/IN4Dx6AJR3s
c5fb737hoUr2Rx/j5awcAL7KMvGJfsHxHmcedTz9B2RyDHJzet9LPHel57+R
VcvRW6THQN4/KimfedW2scD7suZC78sYtRe/w9GnpEfxmte4JXQeXIS39A3+
mNU7uC1pr7XN37D8uudgP8zjmrz6Od9jfLX1BH8ujPM4rCh3eC/4C0Xfp0eM
DyrKa9d4/dV+p9f8LrX3n+g5r1gH3oFr+p3kvuTA88zJiRtyoaRamjqaOv1W
j9NDo74i/+/ja/ppv87KucFuekpXZdVHjN3mcXB4TlaOiH9cY5unDiJf/Ke/
0RrryZ6LrNtV1oN6AnygjwMuwB+23NxnR+92T8+Z4u94S1Z/G841ueIkf2/q
oVUex8Z4P96L+HOz33eA57xse2CMe9RDvCv9M3Jj6nh+Z6UPXaux6ffyra71
99otvt27RTnGDiH/nBVDFsRYz0o53EFF35j594d8RhFuXxL8mkp50Gu2Rb71
TjG2f1H8YGy5x/8efL2i3KGP74HvEPZLrOsazx5YFBteDN63Uv6xT/B9K/l2
p+DbVeqLrI3tVYq7X8T8PSrV96ND/qyonukfY6OKsLRfyAuL8pn92auSz28f
fMdK8e6A4CuK4sBeIa9VCWeqoud59gWfLXXZRTF2dFG+DI6Q35D37GV74PuT
D9M3oWeC/z5iuyI+PGb75Ns97u9HDkV/dojnUOcTN+iL8x238fd91Dow9pS/
LzUYz9IDmOfxG+yL+OSz3oN9R3gu+4F9Ux0L6O0RGxrq7SzM4jvy3bB54gtz
7/RZoAN2hkwvCmxa4bk9vT7v8pjfkfd92mc12PGK+RO87/OWm8bZblAJa8mP
r7TO1D3UR8SMsXH/7awc/4SQ38yqG04K+b2s+mBmyPxzBJh/SvCbivzlp+Df
F+Uxp8acsUV5yt+Cb1KUs42O8T9nxdWzQz6vCGOnhTy7KO+eGvLFRXXAOSFf
VVRDfBC0VtF3uTv4ROtwRsz5Kiv3PzPkr7N6HG9iR0X5wAHBu1TC14Ehd6+E
oznkXSph6ydx/e+i3GZWjJ1WVD9/FuPrFOXkl8b4SUX10CUhjymq5yaG/FFW
fd4WPyuKSwdV8o2G3wqCTymq+XqH3KcSDh8aYy2L7PnG4K2LaqlecX/3Sth7
XvBriurPXUPuVgnXr4ux64vqzzEx9tesuvDTGNuyqK93YowfU1SrjQ/5uCKc
HhfyO1m14+yQz3Qsmh98u6L6b03w1UU1yfmcld+rV/COleL92yEPKLKfDjH2
lyJ/fSb43KI6bE6Mjy/KK08JeWRRD6UJ/19TKQc9LfinWfvuHfLJRbnHNsF/
Lso7J8T4+1nnQ+0wN6se6RT3m1XKfTcOvlGl3KjWr+Tb8XslNRgxh/qM3zLJ
f8Bd6kBqQuow5tPb5PeFB70+cWep5S5+ljoPfp/XaeiLeq/+nk+d1MPjrH23
9yIl6upnWe9264duxJh5jj/Ur/QvKo/d6PHfOR7RX+rmWNbdzz7pGEVMpwdB
L6G7372bib3W9xnyjugLnoPr9DrgYD/9j0Pj5c4qwnfiLXkGvY6WjlPEqItj
zrFF/Y+5+FZR7wZMu7QI1yaH/G1WD+BafKKh6A47Drl/Ub2yX/DOlfY9MvhR
lb7x9OC9i3okZ4V8blGOv2/wp4r6CxfE+N5F/Q/w5E7H0kdjrI+fJWcEA4j/
NfzgXcihkNc2FvBeDf3JpPclB7nD95oaR5Y4fnbxd+V1yDXoc53g+HyX51Cz
MI7v8HsTz5K/7eRn6UWsH/qvVymnvqzojDifd7P8Fp8dVhyjQ968yIfx3w+z
/AqfIn7gJ/jIiOLYHfJbWbGAOPB5jG9VVA+3KoodxA18cR374+IY37Sob5or
xUFs+8hibEjKkRtiepKvj6zk7xuGPKISrgwl162UIw4OvlMRZh0S8pBKWH16
Ucwl3hLXwRhi+4SimEu8PbEo5hJvhxfZHPZ2dlFsJa4St4gjxJCPs3AIDDqh
KEYTn7Hl+2zPxNRljqvvB29R1IMghg2rFMeODt6+ku9jj8fYJjeIOcMr5ajk
ccRQ4ucP4F5WLf9dUd5DzsPZXO14eGXIVxT1nIjTxztWf8B5F/U+wJOvizEl
q29LrUxe+XRRbvkJWFTUE/ky+FdFfYc2RRjAmmDvEcZfcOZDY80/ivI8cryP
g39U9H+ODwX/V1Ye/U3IHYp6IaUoxw0xXRF8ZlHvDZy8x1h5b1FuSl4KDj9Q
hMV882n+7t+yflGdDw7caSwYEGt2LOpLkkf8WJRLvBX8u6w8oV3MOafInyZx
3ll9QXKQgZXyEPCqVIq7xwbfulLPaXqMH1epPrkcXC3qQV5UdI3cLuSVRT34
WUXvyTuSw36RlcduHmNbVOpBgIfgPX5N7tyiUv78Y1buQt7SPPiGlfogxMWH
HRt/ysJ1bA8ddyvS8/Xg6xf9ZtU6xrsW9e2Wc5ZF9Qh8kuU3gjct+l3oJWy5
6Le7zeLZVpXqsKFFNSf15hGV3gH9we05RdjdJsa2qtRDWRVj6xb9Rtcyxjap
1Df5IStXI08jphKXiavfZMVlYnK3ojyM796jKO4T8/cpitHE56OKcn3y/CuL
/AFfmFGEH5xPl6LcbnnIT+JHRX39Z4vytsUxPq4otyCvmFxkE9gDGPJOEY5g
O+Sa2M8eRXgD1nyflWuSZ/4HI3kfUA==
                    "]], PolygonBox[CompressedData["
1:eJwtl3fYj1Ucxp9zntfeyc54FVllJil7RdmR7SIyK64yipQVKRQaV1mlrWiR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                    "]]}]}, {}, {}, {}, {}}, 
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwl1EWMFFEUBdCaGYIGd4cF7u7uDoM7DO4bgru7W4I7G1iQ4M4GhwSCu7sn
uJ0fFof77quq7unuH/ImDIsfGhNFUVH/lI+LoqaxUbSEWMrp9+UDTlFRr0Qz
80PScZrKdlVobn5Ees5Q1S5OVpNr5FpakKBf937rzDflc/mCZ2SkLfPd00Zu
IBPt6GV3y/0bzXdkH72jOQud6Kvftd9svi/7613N2ejGAP2B/VbzYzlY72He
zjaq6z3lG3LxmtzhfRni2hPPfDLn4SznSBz+dvu/MnLPeXmBpOF17FPbpeGy
foXkvLfPYJeRq/o1UvDZPqddrvA59dvhc/LFfoTdOHMF8pkryvxyguwq98n9
VGGCXlmm5JtnR+lTw+9BDSbq1WUqvrs+Wp9lrkkdJum1ZWp+uD5Gn2+uyxF+
2423q28uJO/JgrJA+P5Iq/9yzzjzYvNJThBDGbuylKKxXlpGsqRsJIvLhrKE
/Os1iskGemFZlCL8sT9md5xF9LBbKI/SPXzf4fcOZ0HWYwFj9Z+eO2yuxbzA
bq48xOxw7vU54bwyk7n6DHmQaSzWp8tKTGGOPlkeCN9p+Fv0SXIve/jq/Uba
jQ+fO5wlc+lwfuSYcM5lVrKRiSxkDuee3a7Hy9a0Yri+i5289brJ5CUuEut6
DK/sk+irKMAwu5d2O8Jva/4gP4bnwxnkXTgP9gnyFTl5SY7wPTLItUeeT2Re
SXYG2j2022LuzFS9i1xBVvqF8+D6JnP78D3pHeRyMtNbv+36+vD5mBw+o1zK
MlrSigw85ilPuOGZ1eH8u79J7P//q/4BDbyS6g==
                    "]], 
                    LineBox[{843, 839, 841, 840, 710, 494, 708, 707, 709, 625,
                     846, 848, 847, 557, 633, 911, 632, 795, 560, 724, 796, 
                    561, 883, 498, 689, 558, 688, 626, 904, 627, 721, 720, 
                    555, 624, 903, 623, 684, 554, 683, 621, 902, 622, 553, 
                    781, 552, 782, 491, 880, 620, 665, 842, 843}], 
                    LineBox[CompressedData["
1:eJwl0LkuRFEcB+DDNcbW4AnuLCqJZugtozKNwjYSycQ2JCPEUmgppvEA3mA0
Ct4FD4CWmLET343iy+/3P+fmnJMbV3Zma20hhBWG20M4YDcK4cnild6U++Zj
vcANc+Z5FlkgJsOtvSXZJ8tymSyj5jty+lhyh2w591o/pG4+kueMsGd+tn+p
l/Te5Ey66KGbaS7sT8opJtg2F+WQ3OJUr8oGG5yZN2Wen+Q9/PLori/5zTuf
fPBgvSkzvBCzxolzVmWKe9/UzOt6lhZvvDJuvYMUEWk6mWGAQfqj///+B8t+
LMc=
                    "]]}}], {}}, {
                  InsetBox["\<\"\[Mu] = \"\>", {-1.8, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["0.2`", {-1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {InsetBox[
                   SubscriptBox["C", "J"], {1.4, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["\<\"=\"\>", {1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["3.8899999999999997`", {1.7, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {
                  {PointSize[0.05], PointBox[{-0.2, 0}]}, 
                  {PointSize[0.0125], PointBox[{0.8, 0}]}}, 
                 {PointSize[0.007], PointBox[{0.4463998339305619, 0}], 
                  PointBox[{1.2771956561278897`, 0}], 
                  PointBox[{-1.0806611991222994`, 0}], 
                  PointBox[
                   NCache[{0.3, Rational[1, 2] 3^Rational[1, 2]}, {0.3, 
                    0.8660254037844386}]], 
                  PointBox[
                   NCache[{0.3, Rational[-1, 2] 3^Rational[1, 2]}, {
                    0.3, -0.8660254037844386}]]}},
                AspectRatio->1,
                Axes->{False, False},
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                Frame->{{True, True}, {True, True}},
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLines->{None, None},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None, "TransparentPolygonMesh" -> 
                  True, "AxesInFront" -> True},
                PlotRange->{{-2, 2}, {-2, 2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.02], 
                   Scaled[0.02]}, {
                   Scaled[0.02], 
                   Scaled[0.02]}},
                Ticks->{Automatic, Automatic}], 113->
               GraphicsBox[{{GraphicsComplexBox[CompressedData["
1:eJyFWnl4zOf2D0oVU6W2DLUvYymKsSZO2qCq6FBFNZ1blCJ+dUvQsa9Tqq1t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                   "], {{
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[0.3], EdgeForm[None], 
                    GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxNmgncl2PWx6/rumXLFImQtCBla0GlzZolUbIXqaQSIaSylLWyJVuiJGZe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                    "]], PolygonBox[CompressedData["
1:eJwtl3fYj1Ucxp9zntfeyc54FVllJil7RdmR7SIyK64yipQVKRQaV1mlrWiR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                    "]]}]}, {}, {}, {}, {}}, 
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwl1EWMFFEUBdCaGYIGd4cF7u7uDoM7DO4bgru7W4I7G1iQ4M4GhwSCu7sn
uJ0fFof77quq7unuH/ImDIsfGhNFUVH/lI+LoqaxUbSEWMrp9+UDTlFRr0Qz
80PScZrKdlVobn5Ees5Q1S5OVpNr5FpakKBf937rzDflc/mCZ2SkLfPd00Zu
IBPt6GV3y/0bzXdkH72jOQud6Kvftd9svi/7613N2ejGAP2B/VbzYzlY72He
zjaq6z3lG3LxmtzhfRni2hPPfDLn4SznSBz+dvu/MnLPeXmBpOF17FPbpeGy
foXkvLfPYJeRq/o1UvDZPqddrvA59dvhc/LFfoTdOHMF8pkryvxyguwq98n9
VGGCXlmm5JtnR+lTw+9BDSbq1WUqvrs+Wp9lrkkdJum1ZWp+uD5Gn2+uyxF+
2423q28uJO/JgrJA+P5Iq/9yzzjzYvNJThBDGbuylKKxXlpGsqRsJIvLhrKE
/Os1iskGemFZlCL8sT9md5xF9LBbKI/SPXzf4fcOZ0HWYwFj9Z+eO2yuxbzA
bq48xOxw7vU54bwyk7n6DHmQaSzWp8tKTGGOPlkeCN9p+Fv0SXIve/jq/Uba
jQ+fO5wlc+lwfuSYcM5lVrKRiSxkDuee3a7Hy9a0Yri+i5289brJ5CUuEut6
DK/sk+irKMAwu5d2O8Jva/4gP4bnwxnkXTgP9gnyFTl5SY7wPTLItUeeT2Re
SXYG2j2022LuzFS9i1xBVvqF8+D6JnP78D3pHeRyMtNbv+36+vD5mBw+o1zK
MlrSigw85ilPuOGZ1eH8u79J7P//q/4BDbyS6g==
                    "]], 
                    LineBox[{843, 839, 841, 840, 710, 494, 708, 707, 709, 625,
                     846, 848, 847, 557, 633, 911, 632, 795, 560, 724, 796, 
                    561, 883, 498, 689, 558, 688, 626, 904, 627, 721, 720, 
                    555, 624, 903, 623, 684, 554, 683, 621, 902, 622, 553, 
                    781, 552, 782, 491, 880, 620, 665, 842, 843}], 
                    LineBox[CompressedData["
1:eJwl0LkuRFEcB+DDNcbW4AnuLCqJZugtozKNwjYSycQ2JCPEUmgppvEA3mA0
Ct4FD4CWmLET343iy+/3P+fmnJMbV3Zma20hhBWG20M4YDcK4cnild6U++Zj
vcANc+Z5FlkgJsOtvSXZJ8tymSyj5jty+lhyh2w591o/pG4+kueMsGd+tn+p
l/Te5Ey66KGbaS7sT8opJtg2F+WQ3OJUr8oGG5yZN2Wen+Q9/PLori/5zTuf
fPBgvSkzvBCzxolzVmWKe9/UzOt6lhZvvDJuvYMUEWk6mWGAQfqj///+B8t+
LMc=
                    "]]}}], {}}, {
                  InsetBox["\<\"\[Mu] = \"\>", {-1.8, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["0.2`", {-1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {InsetBox[
                   SubscriptBox["C", "J"], {1.4, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["\<\"=\"\>", {1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["3.88`", {1.7, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {
                  {PointSize[0.05], PointBox[{-0.2, 0}]}, 
                  {PointSize[0.0125], PointBox[{0.8, 0}]}}, 
                 {PointSize[0.007], PointBox[{0.4463998339305619, 0}], 
                  PointBox[{1.2771956561278897`, 0}], 
                  PointBox[{-1.0806611991222994`, 0}], 
                  PointBox[
                   NCache[{0.3, Rational[1, 2] 3^Rational[1, 2]}, {0.3, 
                    0.8660254037844386}]], 
                  PointBox[
                   NCache[{0.3, Rational[-1, 2] 3^Rational[1, 2]}, {
                    0.3, -0.8660254037844386}]]}},
                AspectRatio->1,
                Axes->{False, False},
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                Frame->{{True, True}, {True, True}},
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLines->{None, None},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None, "TransparentPolygonMesh" -> 
                  True, "AxesInFront" -> True},
                PlotRange->{{-2, 2}, {-2, 2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.02], 
                   Scaled[0.02]}, {
                   Scaled[0.02], 
                   Scaled[0.02]}},
                Ticks->{Automatic, Automatic}], 114->
               GraphicsBox[{{GraphicsComplexBox[CompressedData["
1:eJyFWnt4zNfWTlGfpibUQRia0qApQqRGUSwMqm4Np61QnaLki8atLmVUq26p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                   "], {{
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[0.3], EdgeForm[None], 
                    GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxNmQn8l1P2x++9D00SjRZrtkQLQolEVJSyFBFSk6wRKdmyp52iUnYjZkg0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                    "]], PolygonBox[CompressedData["
1:eJwtlwm4T1UUxe89R8YIFRkykwgv8WQs6ok8Q2TI0DMkylTIUIZIczRJSWmk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                    "]]}]}, {}, {}, {}, {}}, 
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwl1EVslFEUBtBpgaApDsUp7sXd3d3dPcAGKe7u7raBBQnubHBIILCgFIq7
Lkhw57ywOP3uve/9099m4gaO7TgmKhKJxPuTHB2JnKViikgkWlaSzeU9snCO
ymZVaKGuKu/LB5ynmj6FrC7Xyw20ZKA+0edvVCfJJ/Ipj8lOe5bZ005uJgcd
GGR2x/4t6mQ5RN9ZHUsXhurvmW8L5yCH67urc9ODEfqH5jvUO+lNDbNesqbc
JWvJ2rxU5+cFBejLaPMnjn+vLsgFLpI67DP/Ln9wicuk5Y15Wsel45r+Oul5
bx5jlpEb+ptk4IN5TrNYbukTuc1H8/Fmk8J9Deekrh7OI5w/PTmo/2zfRHVN
9Rpi+GI2yWx6uD7qMkNfR2bkq/UE/Rx1PRowU19fZuKb9cn6heqGHOeX2XSz
xurC4bnIQjKO/mTW/7RnmnqJ+gyniRBvVp4ylKMsf+0tLZtaLymbyFLyj3lx
WYIiFKMov81Phfstp+oXq09yIjwrfT/60Jsks0YsYor+u2OOqo+xgKVm8+UR
5rJaP0/WZjZL9LPk4XDfWKWfGd4dprFYP1UeYjIr9VPkAfbzyf+bYJYQvkPk
UlcM76WcIDvKrGQjE1nC/aMD+6y3k+1pyzj9Xvbw1uemk1e5Ep5JuOe8Mk8T
zoPijAnvs9nu8OzVb+W7sC+8n7ymTrhf8jn5eEZeejLK2mPHp1KvIA8jzR6Z
bVd3ZY6+m1wero9h4bfA+tZwfeE+6jvJZeRksP6u9U3qNswK1xeeBSlpRWuy
8pBsPArfBcesletoxoDwPTGLUlcInxn9/3frH59nlP0=
                    "]], 
                    LineBox[{840, 836, 838, 837, 704, 491, 702, 701, 703, 621,
                     843, 845, 844, 557, 629, 911, 628, 789, 560, 718, 790, 
                    561, 882, 495, 683, 558, 682, 622, 904, 623, 715, 714, 
                    555, 620, 903, 619, 678, 554, 677, 617, 902, 618, 553, 
                    775, 552, 776, 488, 879, 616, 657, 839, 840}], 
                    LineBox[CompressedData["
1:eJwl0LsyQ1EUgOGdHNKEJ3CZiYTKjAatWyWlW6SKxK1yjRkvQKFJkVeIRhHv
gjdAmyAEDfGdUXzzr7VP5pzMzlSOVg4TIYQSk8kQTjiOQmg5bJrftGo/N09z
x6p9jQ3WGWKYe88KOqibWmSEGfsDo+ZZPdOO996aT7myV7XOVPwf7G3Pb8x5
cz8pkvQRscS15wu6p/O6r4s6obtcmne0QYWafVvH+SLHN8++1dVPOnzwzpPz
to7RIsMWF95T0hSPfnNgL5uzvMR3xitzzn+1xw8Je2CZgfieSEf/9/4HWk4u
iQ==
                    "]]}}], {}}, {
                  InsetBox["\<\"\[Mu] = \"\>", {-1.8, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["0.2`", {-1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {InsetBox[
                   SubscriptBox["C", "J"], {1.4, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["\<\"=\"\>", {1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["3.87`", {1.7, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {
                  {PointSize[0.05], PointBox[{-0.2, 0}]}, 
                  {PointSize[0.0125], PointBox[{0.8, 0}]}}, 
                 {PointSize[0.007], PointBox[{0.4463998339305619, 0}], 
                  PointBox[{1.2771956561278897`, 0}], 
                  PointBox[{-1.0806611991222994`, 0}], 
                  PointBox[
                   NCache[{0.3, Rational[1, 2] 3^Rational[1, 2]}, {0.3, 
                    0.8660254037844386}]], 
                  PointBox[
                   NCache[{0.3, Rational[-1, 2] 3^Rational[1, 2]}, {
                    0.3, -0.8660254037844386}]]}},
                AspectRatio->1,
                Axes->{False, False},
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                Frame->{{True, True}, {True, True}},
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLines->{None, None},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None, "TransparentPolygonMesh" -> 
                  True, "AxesInFront" -> True},
                PlotRange->{{-2, 2}, {-2, 2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.02], 
                   Scaled[0.02]}, {
                   Scaled[0.02], 
                   Scaled[0.02]}},
                Ticks->{Automatic, Automatic}], 115->
               GraphicsBox[{{GraphicsComplexBox[CompressedData["
1:eJyFW3l8zFfXD2opnVIPxdCIVhi7YhTFKVHV0Jgqqqqp/WmNraRhUm1tjbVo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                   "], {{
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[0.3], EdgeForm[None], 
                    GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxNmgn411P2x++9H2tkUFkTlaWSJaJSJFIkRUWLqGxFSIisZau0kmXKkgxp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                    "]], PolygonBox[CompressedData["
1:eJwtlwn0TlUUxd89jxQKmVWGFNFAgykaKENkDpkypEJKtJqLIinNpTSXNM+p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                    "]]}]}, {}, {}, {}, {}}, 
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwl1EVsVGEYBdChuAYLrsXdneK0uLu7OwE2UJziUCTB3RaQkODOBtcEAgvc
3SUk6PnD4vR+3533ZjJ/X1uw3+h2o5JEIpEyfjyNikTOUCtpJJJW1pYxPDPn
4ix17HWpTz2e615wjgb2dLKhXCvX0Zbh9vvef735oXwj3/KavHRmpWs6yY3k
owsjdI9cv8n8RI6ydzcXoAej7U/1W8zP5Vh7b3M0fRhnf6Hfbt5BPxrp+srG
cqeMlXF8NBflA8UYyHj9K/d/NxfnIpe4zDt9Mq8n54r9Kpn4rM+iy8oN+02y
8E2fQ5eTW/bbZOWHPlpX23yHu9zjp36yfpq5Xvj8cOayhBxAf/bb/7gu3tzQ
vIps/NVN1c0K35c45thjZXYiTLPPk01oRoK9qcxBEqbbF8vmHCM5s3UtZWn5
WJaSJRkavpc9GbPMifI0p0hNdV0NqlCNqqTSV5atZUXZSlaSKWV5WYEylKMs
KfQnScpM+1J5guMMtg9hEAPDM6NrwRJm2KPkEY6yiBW6hfIw81ltXxCeCeay
3J4gD4XvHM7VPic83+GzWWafIQ9wMJwVU3S/nfs+8y/5UD7gPjHEk+iaKeGZ
l/nIRR5y04O9XusuJ8pucpLcw26+eM/M8jrXSBnOhA/6jOHvh7JM0L3X7Qq/
W/PX8OzxKbxHeD7pz4LwHMkLnKcI73np3gyyUHjGKcw2ttIznJf7eoUzpCBj
wv8H92w2d2WevVs4Q/IzMjwrXt9g7hDO194xnCHpaUd7cofPJg+vwtm5Z7Vc
QxuGue+eLo25pvlJ1P//V/8A31GUhg==
                    "]], 
                    LineBox[{851, 847, 849, 848, 708, 500, 706, 705, 707, 627,
                     855, 857, 856, 566, 636, 919, 635, 799, 569, 725, 800, 
                    801, 570, 571, 567, 687, 628, 911, 629, 722, 721, 564, 
                    626, 910, 625, 683, 563, 624, 887, 497, 786, 562, 784, 
                    561, 785, 496, 886, 623, 662, 850, 851}], 
                    LineBox[CompressedData["
1:eJwl0L0ug1EYwPHTvgstOtFZWqQ+wiIx6eyrg7S2Uh18q8VADb0BEpNeA4OE
q8ElYFbq8/fG8Mv/ec57cpp0uH602kiEEGpkohBmkiH067QOaIkVbuxLeqiL
2tBlndIDLsz7es0uV/Y9nSRhjkjy6sd+nQXzl/7wzYvzdx2nQ4Ftzt3b0gzP
7hzbd8wTfPBJlwXnvaTooY80ZYbIMsisuycx85v37uJ3tGlvmed5oGpfp8YG
OfI8+rYZv6V1HWGUJ/uYFvVMu968N59yaW9qm7n4zN7x/dZcMa9F///9H7aW
K+I=
                    "]]}}], {}}, {
                  InsetBox["\<\"\[Mu] = \"\>", {-1.8, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["0.2`", {-1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {InsetBox[
                   SubscriptBox["C", "J"], {1.4, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["\<\"=\"\>", {1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["3.86`", {1.7, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {
                  {PointSize[0.05], PointBox[{-0.2, 0}]}, 
                  {PointSize[0.0125], PointBox[{0.8, 0}]}}, 
                 {PointSize[0.007], PointBox[{0.4463998339305619, 0}], 
                  PointBox[{1.2771956561278897`, 0}], 
                  PointBox[{-1.0806611991222994`, 0}], 
                  PointBox[
                   NCache[{0.3, Rational[1, 2] 3^Rational[1, 2]}, {0.3, 
                    0.8660254037844386}]], 
                  PointBox[
                   NCache[{0.3, Rational[-1, 2] 3^Rational[1, 2]}, {
                    0.3, -0.8660254037844386}]]}},
                AspectRatio->1,
                Axes->{False, False},
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                Frame->{{True, True}, {True, True}},
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLines->{None, None},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None, "TransparentPolygonMesh" -> 
                  True, "AxesInFront" -> True},
                PlotRange->{{-2, 2}, {-2, 2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.02], 
                   Scaled[0.02]}, {
                   Scaled[0.02], 
                   Scaled[0.02]}},
                Ticks->{Automatic, Automatic}], 116->
               GraphicsBox[{{GraphicsComplexBox[CompressedData["
1:eJyFW3l4zNfej621dCp1VSoltcbQFvUabVV9Q1xvxTZ1i1ruWKqxjK22GEWV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                   "], {{
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[0.3], EdgeForm[None], 
                    GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxNmgn411MWxu+932ylsrSQTIkWpSRlK0lUJFuWUNJmKy32LKlEKXsbLcg2
xr7OyGAQUyTrjMZOIbsZjG1mMOfT+/6fPM//dM+937uce++55z3n/Npm2Nj+
Y0pK6Y0qpfhLk3NKk4JuDL5JUL2g+kELo21UULOgW6K+nr+9HvV/0D8oBb0S
xU1BdwZ/R9DWQa2DDom2o4JuD/4PQVsFbRr1DYI2DKqi/vcob6NPUN2gLYK2
NM9amwdtFFQ7aDOPo74ya55NgrayvPBbJ61B3+39ralpE39rHtQgqGHQ+uwl
yjuC3gp+RdBdwW/j742CmlkOxvzOc1N/PkvelkGtfiN7W6+HLO1cMu6Z6P90
0M1BO7iNudv43JG1teeg3t7fkfeDGLOa8wrq4DZk3NFli6AeWXPtEtQ7a/+7
Bu2XJdNuQXtYJtZ/O+j+oC6mVl6/82/2tLv3w5iuHodcD8ec3YK6Bt0T9Z2C
9gp6wGP2CVoT3zohV1A3j0P2nkE7e529k/pQfzyof9DRQft6HuRtGfP09beL
g98zyj7IH/xLQfcF/2LWOgcEPRt8d/bN2QS/3W/W2M57OzRLpt5BF2btrVdQ
P8uLXIclrcuch7vk+yVZc6PfhwR/cNCBwZ8R5UOWfd/g98na621RTg96OEn2
Dr63Y7wn1pkVNI25g86Ovo9EeSRnFPyIKE8Lujz4y4IeDf4vPqfhQU9mzUW/
o4IfEHRE8Jdmvb9hQcd7vYFBm0T751E+EbQs+KVBtwbdy10GtQv6W9CrQTfw
vrPmGBf0VNCxQaOCTvB8g4KmBo0POifodMvCmme634lBD8Y8DwR1DDrD3/n2
RNT/gq4Eneu5Twk6z+Vo9JR7RveDznfbmKAJLseyz/g2NEvOST4zZJns8gzP
h/yDuXe3IeNFQWdx9kHPeOzEoCn+zreL/X2874q9Ii/vD/vBG7yGewq6Imip
5bjUbZO95hUumfsy9+HbjKS9safp3j/1K90XGa9yiSyzrS/0fZa79ByXWC7G
P+c15gTN9D0h+9Weg/rsLPnm+j7RR/T9WsvK+pNsv7G589yGLM8HLbcs18T3
F3wGx2eNvz7ou6AVnn9elq4vDFpgOZDrxKx5b2DPwZ8cND8JN8AT7P4dxiLs
/3yvz3gwCvwBI25NwrH1g74PetHrgFG/D6rDnEl4BsaAYeAM2AamgStgCWtg
4zfz3XLHYAH2d3OvhS0Hu8CJO5MwrHGSrIwDa1bb3jfweth2cII1sPdN3Bcs
2NprNnOdMc1db2gZqINjTT2+nudg3seS3ilvHhx73raPb9j1Vh4DLrSxHLS1
9Hxt/Y21sfPtvHZ715t4XGvL0cHfanCI+t3meQusjc3t5DU6u76p99rU63fx
NzBrF6/RIst2gyvgWhevC5btajmRF4zYzbLu4TpyYGex712NF8gEHoFRO1km
bHyPJAzsaRna14yzrD3dr06MfTcJ38CcF41JYMe+XhtM6eWxzAtWgBlgVm/P
e28SdnS3rIwFK8GsPpa7xm9gf2BIv7QOj3ifx/g+unrdB5OwiHn7ul//tA63
qLfKwtFDk7AIDDs4+DOzcOtPSTh2uOVuk+XDDUjCk4Ge68kkbMKG1o32VUmY
90jwi7Owq79lBJ8WJ+kj8oFdYNLQJDuCHqDL4Ndw92cdMAFsABMez7K3rIft
BhuWGqPAgHuMUWAAGEYfbPvTSVg1MgnnmBOcetV4Bl4sScKKYf6OnQcPwBj4
E70PZAHP7jN2neU6mAJOdMnC6VOT8A0cO9vjznA/5MYm12AGNnpaWodz53qu
SUm4wzgwYrLlmuJ6DZ7RD6wDK9hLDRaCF8h3kccgx8Wus850r02/Ga6Pdp3v
f3X7BMuKjDXYPtVzNYx1/5mEb9zPKPdFJrDm0rQO5y73GOz0VZ5jpuvMPct1
ZJrt+hYx5zdJ2FWDeeDNMvdBZjBrjtcDfxZ6LGuCO9d4zDzXm2Th0Aueb76/
gUcLLMPlHjfX8i1wv8n+xlpgHNh2XZJNxv438llf6fU/zMIgdPyPYBMYEHyO
8uUk7Hkn+NeMWxOyMA+sAvdusGx13bee5wHbwLUfkjCM77Xw1ZKwBwy93vt9
N6sNG/+q5dw46E/RfksWFr6WhG3IPyfa5vpMr83aJ3t8AXubFRNNsZ3AZr2V
5PdjT2tn1fHDX8ZeZfFvJtk7bN1Y3mgWPtD2fpK9ej2pDbz4iXNJssesgV3B
Nq42fxBny1kk+cbvJdlj+uxuHizo4jmw59NizalZvnfbKD9KskkfJ9kFbMIH
bsNG/ZmzCfpzUl8wFfvVPto+df2h4Bdl+eHYJewhNqdelnzUrwz+iqyYZk1S
iX07wetiW/6TZE+ZY7ssObDlmwb/SZL9+izJ18c+Dsyai/obWd9H+Swf9Hki
I3YNmzYkyw5iAyclvVdsy7/M805567wr3lSDLD+StvnBv5T0Bv4b9FWSbZiZ
VWIf/hf0tcfzNp7znD8H/TvpXTbO8hF5t+gy+o+vtVbXsvzCbz12jtfjHfDu
eIu817m+/1W+a94O/hy+XM+sOJY7R8fJJ6DPxPIrk/wxdJwYHx1bL0vv6XN1
8Fdl+ftfJpWcD++GN8X7Klnvh7ezYZa+trB+oav4B+gdvgG697bfAu9i4ywd
RebuWe+Bt8C7eSPJDzkNn8RjZvvMsGOnZ+Hrap89dzPDuoWOHelz/9rj0F/0
9SjrB3qCvh2dpeuDrCPoGHp+TrTXtz6hR+jb2rgoS+fQt82zzmWi7/4r6wa6
80+3N8rSJ+4dvSauRLd5J+gierh79NnANoR7/sb9udvvfL/o2ve+/+XWn4W+
hx98F9zzTz575P2PZT4v5v7F49Hf//ls0LufPR/ffrFujY7+ybYXO4pdRjd5
N18k+QTcOfmpGp1Cb9AZbPCvSfYdn7+W7Sw6RS6pRtfQFfRkA+vhXd7Tlln7
WmX9QDeeTLIdj/je6ttucPfoALqPHuGDomsHZdlcbCx3SzzP2fPWN7Vd4E7A
6aU+b+6JM0d/N7IdRnd4n7N9n9w3d8qdb+Z3wdsEj7m3P1om7HDTrHiQo0SX
t83SZzCPdmIg8oG/y8oxEk8RuxE3kVdsHlQrqWzmPowh1qMv4+DJU15nDKqJ
Byjx36831rS0raXE9yTf2NRj6YPvu7/nIa7Y1vK28Hx3o5tZ/u6jLnlH22f5
wQPcBx6feVCUOwQdF/wuWf4fvt+9bh+S5LPhR+KLHRfljlnvAl8L3xV/jbYO
br/ffU5KGoOfie8G4U/if5En2TnLni/hnrP8zqtc4j+SY9kp6OSksqPnxFck
P3KBxyLzcJ8lZ0ustlvWW73L/K4+K85pD/PEJ8RU3V12M0/f3Tx2T7d3TP7u
PmvtYpb92zsrriPeo6SODWd/nSw/bT3dTkxCLESerY3HEA/2dPveLvd1n17m
+f6O6/DEmH28LvEV8SSx5P5Z/G5uo06ciV3v63bG9XZ7X/eh/f2gA7LsKzEU
OUHyby2tn8RklAdmvVniQGJF4jfaDnL74R5/hNv7WW8PdDtngA/FuRPP9s+a
h9iS+xzsO93e++Sc0NkjrLfMSyzHOgPN1/g/R2ZhCHMelhXHHp5V7+2+R7k/
5dHmP7d+n+i7G2L9PNRjmWec9Y84hfdxrN8IeHVMFlbgVwy1ftKnnd/XcOvt
2jgtyhHuc2qWT4kdwx8/IctfPSnLD8aHpqSOTzzPdXxj+h6f1/nK8Pga+Bz4
3/QdmcUvSsovnZKFF5SjzX9h+ZDtbt8N94I9Y0xtzzfS8vw1K28+xvPRp5bb
x/q90P98r0vbOLfjdxOn4xeDFWfldb4mMfdgfyeexz4/5Do8WIGfwfsbn9Uf
/4GYnTq+LrjIuvNdTrAMYMWpPueJbqcv8dS5WfiNX4o/AXbx/QKP/TEJI/HB
fvF4xoIP5BPjb21McaH1hHKK93iR+V7uQ50zwJcnn0KupKvHkAPBLtHezeVU
6y25jhlZ/j9t09y+PMrnsvIgj2XZfXITd7ntEPeZ7rVu85zwM9zOm7oxaS/g
3vueY5j1eVaW38T3yd5vDVaRh6G80nyNHQdHHvc3sIycCXl/MAg5LzMPNtP/
NJdXeyxxKrHx2pxvFr/Wf/bYof7ON/xtZETWC/xG4fHtV3g8Y1f6LhvXvBW/
lxcCYF8q0iVyNW9m5QOIjfj9gLwMMe7f/RY+cB2/nffzmtvJedKHfOerHouc
5EjJx5IjYl5iHuKdj7Ji7JVuY11sDrlccrj13QeeePmppH70WZW1BvOTx8Nf
x1cnX/peVs6UO3zffXgz9LnP50BcAcYRfxCH3OSxtHM+r3jsMO/vA++fNVm7
5vsqz8+31d77avfnfG52ex3P807NuWX9/spesbf4BOBlPe+fvVPnPvAZ6HuT
zwF/inx68RuEx+eivN3tC7JiP3xUSur45sQk5Epm2h7iw9Vyn3nuP89jF1hO
5KnJq79uGZp6LdbnPfGueJvkwcjf4R8Rf8Nj0/jNlHzFxtaxJ3yPb3qPI70v
fhvAbySvcYvPqoHPsaHtAGvxfm+2fMjG71+sd5zH3eyxi92ODM2932bWD3Ir
5FXw+9/1ve8VDuzelfDm9TjIH7P8gh7RtnkR1vQKvkERFuwbfO9K2LBHlN0q
4dLM+H5TJX+c3Au6hW+GrVpu+d+zDMhCO7ljYn/60dbS+6X/Jabn3GdQzL+w
6H13jXU2K8LNA4P/d5EfvkVRHX7L4A+udNd7Bb9VpTjg1eD7VfLTd0feIj05
IPhvinTpb/HPQZXOb/8o/1VkA1+Jsm8lXWhcNIb+rHN70VpHBt+4ku/zrt9m
Y+99hXl8zhd8PtzdM74/8sPLfKdPu31j68LTeV3e7mm3k+MlB0283M7jGQtW
g83g7w/0reT73eo+6OoNftv4NmPdf4zfN+/8FcuLnNgNfHbWGuE1qeOzfZJl
j7BFL5vvaxtF/T73+Tjrt4d+bu/r97LMb4Y638n943OjG3t63SVe61nrA7rU
xe2dvQfkxZ/pbNmQc1jse3gln4MzJ44iFkAG4it81CHxfVAl/6NTlGuK4o/5
wU8ritdXRvmPovwfNgEbjQ3/NKiRdaNz9P+4yLZ9VaSvK7wn9t4j+EOjbddK
vuDk4HsW2ZDvo9y+6H2jj8daJznDT3xut0XbH4pi+Jkxx5FFOYPDg/+5KHb5
PqhWpRjh1GjrX8kP+zZoq6K9PxjlQ0X+UcMo+1Tyea7lnIpyFb9GeXpRfDwr
2o8uyklcwFvLygcNZP2ivMDZ0f5FVu5hcNG7Qv6bo7y2KI7/2HtBT66J9jM8
f/dKdgQbckWUC4ryDefx7rL8sHOCH1WUzzg/+LFFuYrxwX+ZlQtZFm3zi+L+
idE+vih+mh785UU+7z5RblMprrgsyquLckN1g9+oUpx0eZRzi3IMa3x3yLxP
JVuJnVwPG1Mpzvu2yKZgT74rsh3Yja+L7EVTz7HGOtDJ8xK/71fJnmJLZ0d5
fFGecQ5tRTmk4VG2sW7MjXb+AxR4/kOUn2XldX4Mvl0Rhuwc5X+L4t4W1nli
5XOxdVn5Hmxh9yJ7CNbio5xjbMLfoF6TU8Bnw9fG58b/Xptjtp1Z7Hb8cHw0
/LxLTYwlF0FMRH6hndse85z0x7cjF80e+J2APS5y+1DbKH4nG2Lcow9YDC7g
7x7s/je4Tyu/a3zVMR6PbcAvW+Q5H/WYIba9/K6ALQUjwWKwg7skBwQ+kwfA
nmJL73A7fTgL9g/OjnGfrj6fxT6TCWBKVu6qnfeCXMh+t+U/IO6hd5FcraL/
dpXi1Eui3KAoNzYt+MuKYlYwdlYRzn4S5adF+b9fotylKEcxIPpcUJSrm4ju
FMUgi6L93KLcQI8om1WKmd8O/q2i89si2hpVygW0sZzowlSwtCjn96FtIHeB
rSR309HEb43kbTqYJyfU2vdFbHKP9YHz7xBz7lgprn7A85A/6eg6OSTsLOsR
p3RyO31utBzIQP6JPFTNmvdbhua80aJ8AL4/vw+Ru90y2odWyivw5hb53TWJ
cliRf4VdB/tjyFrfp2cl/2fr4LsVYQc2dSfbVc74uErnfGvw2xX9/lAv2jap
lHPBRxhiP+Fh7qQoxr0+yjMrxZ/4Nc/bt7k7yh2Kcvn4YntW8sfuDP4OHA/e
RJSHVdLPo6PsWpSffSDK+4vyuPUr+QH4AKcHf1ql3DNYNNp4BO6NrHSf4OFg
Y+IIbHMlG3B8lL2KdHvbKEdVuotjo3y5KGb/KMqTKt3JycxXOY8XZUufOeN2
9thTonyqKI47qQhLwJFxUZ5aKVYfUwlTwdPW2LmiuPzrLDwAC04psnHYtx2L
8APsaF+EE2DEV1lYAo60KJIP2Qp7KopnL8a2F+Wn3+OtFOVTV2HXi36Lm8f5
FeW2dy3yD/ANwMZSCR/ZUx3vq3YlbAaX1w9+w0o5PjCnjnEHGzDFdqBFtG1b
KbfFuf6adbbErBcWxa0rivB7UZK+bGKdeRMsKvpd7klwvii+Xh7lc0X5j01j
7s0q5f42qOSz4q9i2HKlXCc+Reciv2JBtM0o+n3lsyg3NJ5eF+2zi3L29aNc
WhSbXx/t84zFtYvkQIafst4PbwffZ1KR/7Mw+l9ZlL9fgs0ryuNzJ79k3cuH
YHfR75lfsn5RDrt1jG1TOR8XbY8X/Q4BZn5v3Pw86j8Vxb7g5InGSnR5uvW5
bRGO0j6uyHZjt1m/mXXjmiKfBn/m4CIbjX3er8g+YhvXC75jpd+QLi7SJ3Rp
/SI7jg3n/PBLOENsbRPb2zOLfCz0p16RP4QvVLfIL8En2bjId8FvwWY3rGS3
22NjinL8DSqdNec8oMhfxFecUIQN4EIf9LrSb27tomxbKR82kLOs9DveI9Hn
qEq/5cwpum/uGl3YoZI+nF3kO+I3Ti3ym/GZjynyHfEb8SXx+fD3Rhf5Mfgw
5xe9Jd7RpUV6xpwjivwhbPI5RbgFZvUrwrwlSb4eeoaOfZfl8+HvnVzkP+E7
XVWkW+jV/wHf5ncY
                    "]], PolygonBox[CompressedData["
1:eJwtlwfUl2MYxp/3fttLGoqTtlJaRIVEaZdSWgolSZIiioq2mVRSOBGZHSGk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                    "]]}]}, {}, {}, {}, {}}, 
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwl1FdwlGUUBuBNGGcQVHp1EJDekSIgvUYgICSAoPSO9N654oYSOpEW6qig
9CIzDMygUpUbROkXMHBB770/Z7h48p73ZP/N7rf/pmTfkWkjkhKJRGU/7icn
Eidpky2RKCTbygfyIf+SqheW7eQj+ZhTtNeLyG/kJtmbDuY+8jd+5abnfy4r
8oxKDGKNxw2UW6jMYCba3fL4reY7crI+1FyVYUzR79pvN9+X0/SR5uqMYnq8
bvtd5t2MoaPdaJkm98h02YnX5lq8ojbjmRHvz/XJso5+mjOcjddun8c+L+f0
83zGa/vP7UpxSb9MCZIoZ1eeK+arlOSDeL12qfIa17lBdmbZZ8QZ8qW5o6wj
hzOMP/SczDGny58ozUfMtVsoO/Eti/Qusgwfk6Fnyq58x2K9myzLJ8zTV8rv
OUYeFtr1lPXi3GUP6prHMoZy+s/xWTJOXx3nKE/IAqSYv6YFrWhJfvtmsjmN
aUoT8tk3lI34igbUj/O2/4fcLNCz5N8cj888Ptu4BxjBHbvurGK+nkse4Sgr
WG23XB7mRzboy2RnlpKlL5GH4vxYry+Oeyf+djyvPl/+yV9xZsy2yyEP8iG3
uRX3fXxf4rNipcfMjvtcpsgKshIVGcR+uwPMDHqy3Mcb91ZxeZELcaZxfjy3
L6Y3IJ/eUO7l93gveoIk3sR9xFvGxnu2Gyf/5z9q8pKHnu9T+QUvqMFOdjCc
zDjfOA+qMVW/55pt5iFxdvoPch1VmKTf9vvN5v4s0QfItRSlL/0oz5M4D57G
98A1v8iN9GKC667bFTS3jr+Z/P5/1Tv1Xpcq
                    "]], 
                    LineBox[{864, 860, 862, 861, 720, 511, 718, 717, 719, 642,
                     868, 870, 869, 581, 649, 929, 648, 813, 585, 738, 814, 
                    815, 586, 587, 582, 643, 899, 512, 735, 734, 733, 579, 
                    801, 508, 898, 641, 578, 640, 897, 507, 800, 577, 798, 
                    576, 799, 506, 896, 639, 675, 863, 864}], 
                    LineBox[CompressedData["
1:eJwl0LkuRGEYgOGfMxi7yoytYNCPJbEkplGoTKKwFmI0loTOMmOpGIULQKVw
EURirgZXgHaeP4on7/ednHP+kzNcOl45agghbDOUhFBoDGFAF3RQt9jkzb6u
l7qmV7qh83rBo7mir5zzbC/rHF3mHrr5c1iHdtJKO238up7SJhJmPHfKg/kk
fgs/7rm2n5lnaTanaWGVDFl66aePHcYYZ5RFz91E8Rz9iO+har/XZT7Zs4/o
vuaZ4Mt+oDk91Emm+LZPa1Hv4vdojVue7FV9YSles6f0nZJ5N/n/73XDbyMM

                    "]]}}], {}}, {
                  InsetBox["\<\"\[Mu] = \"\>", {-1.8, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["0.2`", {-1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {InsetBox[
                   SubscriptBox["C", "J"], {1.4, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["\<\"=\"\>", {1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["3.8499999999999996`", {1.7, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {
                  {PointSize[0.05], PointBox[{-0.2, 0}]}, 
                  {PointSize[0.0125], PointBox[{0.8, 0}]}}, 
                 {PointSize[0.007], PointBox[{0.4463998339305619, 0}], 
                  PointBox[{1.2771956561278897`, 0}], 
                  PointBox[{-1.0806611991222994`, 0}], 
                  PointBox[
                   NCache[{0.3, Rational[1, 2] 3^Rational[1, 2]}, {0.3, 
                    0.8660254037844386}]], 
                  PointBox[
                   NCache[{0.3, Rational[-1, 2] 3^Rational[1, 2]}, {
                    0.3, -0.8660254037844386}]]}},
                AspectRatio->1,
                Axes->{False, False},
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                Frame->{{True, True}, {True, True}},
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLines->{None, None},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None, "TransparentPolygonMesh" -> 
                  True, "AxesInFront" -> True},
                PlotRange->{{-2, 2}, {-2, 2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.02], 
                   Scaled[0.02]}, {
                   Scaled[0.02], 
                   Scaled[0.02]}},
                Ticks->{Automatic, Automatic}], 117->
               GraphicsBox[{{GraphicsComplexBox[CompressedData["
1:eJyFW3l4zFfbtlVVpVUtZb4UUY2UqK2xtHhUUE2Lkdpfxq5h+uFVLVOx1DK8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                   "], {{
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[0.3], EdgeForm[None], 
                    GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxNmQncl1MWx++9j1FkibJroUWIskZSoQU1oWmKpEWWipS1BVkSUqiUVkMi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                    "]], PolygonBox[CompressedData["
1:eJw1lwf0j1Ucxt/3+9ojIXHIyl4hMhOlv8osssmIbIpQKiNFe4jTMtppaYik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                    "]]}]}, {}, {}, {}, {}}, 
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwl1FeQjWcYB/CDaNFLGG3G6jUJg+i9rW7VkCCIFnb1esONtrrVy+i9JmYM
M0mQENyQSnIRw4xORO/l94yL3/7f/3POd+Z873m/TRqYlpKaKZFIVPPnXuZE
4hxtsyQShWSy/F/e5zzt9MKyvXwgH/IrHfSPZEe5VX5BJ+sv5Xa2cd3nP5UV
eEJFBrHW+wbKnexiMOPNbnj/butbcqI+1Loyw5ik3zbfa31XTtG/sa7KSKbq
/5kfsD5IKp3NRsku8lvZVabw0voTXvApY5gW9x2bImvqf/Anf/HIPJ95fi7o
FynOc/PSZkn8q1+iJK/Ny5tV4LJ+hVJk4mOzZHkt9ocbfMBM8zmxn9Sy7iRr
yxEM5wc9O7Otu8iNlCYHc8zmx/3RnYV6N5lETubqS2QPerFI7ynL8CHp+gp5
ipPkYYFZH/mZvCs/p471aNIoq29iTeyfvlqOlWdlAVpZt6Y5LWkR+2feVDaj
EU1oTD7zBrIhdalPPfKanyE38/VV8jS/MEpPZWScA+6Y9WYl8/Rc8id+Znl8
T7Nl8gRLY//0DJnCYlbri+TxuHc26AvjDMXnsUpPlz9yLPaUWWbZ5Pdk5Xac
XW7GcxOvx/fxnpmySuxDPAOyMpUYzBGzo0xnhv7G2TkcZ1OWkP/wN4W8VpDH
5sXid4l9jv2Sh/iObnG9fMsrasRZJI2M+O3k7/wW5zDOL/d8XlFZjWdUZz/7
GB57FWdQro97YHLstWv2WH/NEn2IXEclJug3vb7DekDsrf6VXEsR+tGfcjyi
PI/jeXDNZrmFvoxz3VWzgtZt4tnO/P5/1Tvs6Zhn
                    "]], 
                    LineBox[{637, 574, 636, 894, 503, 798, 573, 796, 572, 797,
                     502, 893, 635, 671, 861, 571, 859, 858, 860, 718, 507, 
                    716, 715, 717, 638, 865, 866, 926, 577, 867, 578, 645, 
                    927, 644, 811, 582, 736, 812, 813, 583, 584, 579, 639, 
                    896, 508, 733, 732, 731, 575, 799, 504, 895, 637}], 
                    LineBox[CompressedData["
1:eJwl0MsuA2EYgOG/M6hjV1pVCXHYaxVJrbqx0pWow0ZF4rAiQZ1iQ0ncAFYS
N6GRcDe4AFwAT2Px5P2+ycz8mRnd3F/cS4QQagzFIcxFIQxqSXO6xipN+7Ke
aVXPdUVn9ZR784k+U+fRfqwz9JpT9PHjsG7tIUkXnXy7HmlMgqLnDrkzH2iW
L/dc2I/M07SZO2hniTQZ+skywDrjTDBG2XOXXJl/ve/VHHFtv9UF3tmyD+u2
TpLnw76jI7qrBab4tBe1ojetb9C31hk82Bv6xDwNe9AXauaN+P+//wF6mCLx

                    "]]}}], {}}, {
                  InsetBox["\<\"\[Mu] = \"\>", {-1.8, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["0.2`", {-1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {InsetBox[
                   SubscriptBox["C", "J"], {1.4, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["\<\"=\"\>", {1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["3.84`", {1.7, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {
                  {PointSize[0.05], PointBox[{-0.2, 0}]}, 
                  {PointSize[0.0125], PointBox[{0.8, 0}]}}, 
                 {PointSize[0.007], PointBox[{0.4463998339305619, 0}], 
                  PointBox[{1.2771956561278897`, 0}], 
                  PointBox[{-1.0806611991222994`, 0}], 
                  PointBox[
                   NCache[{0.3, Rational[1, 2] 3^Rational[1, 2]}, {0.3, 
                    0.8660254037844386}]], 
                  PointBox[
                   NCache[{0.3, Rational[-1, 2] 3^Rational[1, 2]}, {
                    0.3, -0.8660254037844386}]]}},
                AspectRatio->1,
                Axes->{False, False},
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                Frame->{{True, True}, {True, True}},
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLines->{None, None},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None, "TransparentPolygonMesh" -> 
                  True, "AxesInFront" -> True},
                PlotRange->{{-2, 2}, {-2, 2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.02], 
                   Scaled[0.02]}, {
                   Scaled[0.02], 
                   Scaled[0.02]}},
                Ticks->{Automatic, Automatic}], 118->
               GraphicsBox[{{GraphicsComplexBox[CompressedData["
1:eJyFWnl4zMf/R1UdDarORcnXlaKkfqIo3onU8XWu1FXVLYpi01IlrKJKuzSV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                   "], {{
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[0.3], EdgeForm[None], 
                    GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxNmgn411P2x++9H/tSUra0IkmiKESSJVHJkhBGyV7JFqVNRCo7KW1axq5i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                    "]], PolygonBox[CompressedData["
1:eJwtl3nUVmMUxe89T7OkJClaqZAm0lwaRFFUNM+zBmkyFBYiylgtZGxAGogs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                    "]]}]}, {}, {}, {}, {}}, 
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwl1EdwVXUUB+CXgNRxRnrvw1AGTCB0As5IQOlNEKQl9Jqg9KI7F4xSRHpX
UGZoUqTDAljQey8bygKG3hFp3xkWX37nnNz7Xu65/0ml/jldspMSiUQtP14n
JxLn6Z4rkaggv5X/yzdcoIe+ouwp38p3XOQ7fSXZS26QQ+itHio38g8PfX6y
WZo6SdaT2axUj5Kb2UIOE8weuf5f9RM5Sf+DugFjmKx/ar5N/VxO1Y9XN4p7
+VH/wnyneheT6GM2UfaVu2U/mUke0vWfyGZyKj+pX7m/oPxCf4WrXOOteWnz
DPV1blCNXNQwr8lt9R1qkpfPzVK4q77HfT4l3ewb+Tiek6d8xi/ms2PffKnu
KVvEnhjJIX0Rpqt7yTXUpigzzObF/uMZmaPvG38DxZipXywz6c9cfZZMoTiz
9CvkKU5Sit/NBsmWsRc5kAz1mHgvpOrXsoqx+pVynDwny9E1npNOdKEzZc07
yI60pT3tKGPeWrahFV/zFaXNz1KS2fo/5RlOM1r/PTlk89JsAH/wm76EPM4J
lgezZfIYS1itXxpnhEUs0y+UR5nP3/oFcc5jXyzVz5GHORL74VezwvIghXgR
Z5NndIu9xne5ZqZMkx1kqqxLHYaw3+wA0/hZn0/uIzfVucXN2Gnsj3fOYtV4
L5SJfcm97CFLn58C5KW5WT45WS6UU+RlLtE0viP25vOqqBvHedY3kTvYHu+V
BWbjYl80ZIr+mXu2xjuIXcV7iH1Rn4n6x36/ST2CeXF+5V9UZhjDqcN76pJw
zQP3rFOvZzDjze6blY9dqv9L/vi/6gOTtpXr
                    "]], LineBox[CompressedData["
1:eJwl0LsyQ0EcwOGVVCQSt7g0CDp0lBKXVqWQRnUK4zITT0ASDHFptLQKXgJF
eAu8AWldCt+O4pvff3fO7pxzisneWrUjhLDBYSqERx6oc5sOoaHLDJlHGObH
gYIO0scA/Xzb79YcWRadO+DavK9TfHmmZl0zL5E399JDwhjjjDJBkU1mmGWa
VefOOTF3aoscZ9ZXus4HW/F53dYFSnxa78T7dFfL8T1px/fRSrxb8/rMC5c0
7WX0njsuOLXXpfM6x5v5lXcmrY/0Ro91hSd+fX89/f+v/wCiUCdp
                    "]], 
                    LineBox[{736, 583, 804, 868, 867, 550, 511, 929, 930, 928,
                     553, 517, 822, 524, 824, 591, 823, 592, 654, 933, 653, 
                    825, 593, 746, 826, 827, 594, 595, 589, 648, 900, 518, 
                    743, 742, 741, 587, 808, 514, 899, 647, 586, 646, 898, 
                    513, 807, 585, 805, 584, 806, 512, 897, 645, 869, 
                    736}]}}], {}}, {
                  InsetBox["\<\"\[Mu] = \"\>", {-1.8, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["0.2`", {-1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {InsetBox[
                   SubscriptBox["C", "J"], {1.4, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["\<\"=\"\>", {1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["3.83`", {1.7, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {
                  {PointSize[0.05], PointBox[{-0.2, 0}]}, 
                  {PointSize[0.0125], PointBox[{0.8, 0}]}}, 
                 {PointSize[0.007], PointBox[{0.4463998339305619, 0}], 
                  PointBox[{1.2771956561278897`, 0}], 
                  PointBox[{-1.0806611991222994`, 0}], 
                  PointBox[
                   NCache[{0.3, Rational[1, 2] 3^Rational[1, 2]}, {0.3, 
                    0.8660254037844386}]], 
                  PointBox[
                   NCache[{0.3, Rational[-1, 2] 3^Rational[1, 2]}, {
                    0.3, -0.8660254037844386}]]}},
                AspectRatio->1,
                Axes->{False, False},
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                Frame->{{True, True}, {True, True}},
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLines->{None, None},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None, "TransparentPolygonMesh" -> 
                  True, "AxesInFront" -> True},
                PlotRange->{{-2, 2}, {-2, 2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.02], 
                   Scaled[0.02]}, {
                   Scaled[0.02], 
                   Scaled[0.02]}},
                Ticks->{Automatic, Automatic}], 119->
               GraphicsBox[{{GraphicsComplexBox[CompressedData["
1:eJx1WnlY1NX6R/R6TR1tU3MytOXimGvIqHHJVxtTK000UlObzC1zXMosG+Ln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                   "], {{
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[0.3], EdgeForm[None], 
                    GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxNmgncl1MWx597n8EkIjIUbUxDm0ZEQoooJGoipEVRKFHK0iJF0iJTUokx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                    "]], PolygonBox[CompressedData["
1:eJwtlwnwT1Ucxd/9PluSIqSUSGQNiYqyZEmyRCIpZV9LZSsTKbQvpIXSQguV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                    "]]}]}, {}, {}, {}, {}}, 
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwl1Fd0zncYB/BXEom2dqnGIcRsrYuiqL33illUI61ZgutaQYLYzrGCDuvO
HrXpDRd1cKHaatVM7O04x43j8xwXn3yf53n/7z/5P7/3TWbO9KzcUolEorEf
/yUlEsfolZxIVJS95TX5P8fpo68k+8rr8gYn6KevLPvLIjmUAephcjObuOP+
d2Qmt6nDKNa57mv5M78wmh/Mil3/q/qunKYfq67Ht+Tq75lvUz+QM/Q56oZ8
x0z9Q/Md6s8YrB8vB8rv5SC5U2bJ+3EP7tGEh0ximdcmy2ac5gy/89x9k73W
XH2Wc1TjtXkV86r8oT9POm/MM8xqcUF/kUu8NW9i1ll9mT+ZyyqzObK57C6/
kC1pQTa7zZKZo+4l18YOSYn3my2Ic4szoUDfV9agNPP0i+OcYhcs0g+QNUlj
vn6ZPMRBPiTfLEu2kldjl3wZ+4xdkqFfH383E/STmMhRfXm6q3vQhW50pZx5
p3h22tORDpQ1byvb0ZqvaMNH5kf4gIX6lfI3Dsd561fIHDmOf+J8Wc4CfRl5
gFTy9EvlfvaxhCKzwvhsxz5Yoy+Qe+N3sVGfL3vGflitz5N76BE7ZbZZktxF
Kf7mL67QhVmsdM2Psq5sK2vLOmQymnSq8wmfUi2+F6TFM5BCKqUZykv3eMUz
XsTnkiHmT+RTHtGUx3EuLI1zkac4SeP4bsV18bmVn1NMI0powHayKYzdxm6o
z/T43njfVvWY2KP+m9hNPB9T9SVe36L+iZFMMbtl9rF6OIv1I2QtbsY+uMVt
12yIvcfzMNl1N80qxBmo/016/3/qHSXhjbk=
                    "]], LineBox[CompressedData["
1:eJwl0MkuQ3EUB+DTdqWGnY1hIdElLTtrnkBiIy2JJdUWCTU9AptKPIIWT4EX
UM9h2Jjaot+NxZffOSf/6d6pjepyJRURRarpiCZXbHOZiajIOUKdJsWrDb9m
f3T5oceL+Yf85J08W5zZsylHebZmV19WF/iiwzcr5lkGGWCYIVaZYJJxFqzd
p67uOO86eYs81p+qF3mkqB+TJTnDLG39WnKOXJd5Cjwl3ymX5IkMecNtcg9H
Zj13XKgbHHBo1jXLyWnuze54YERfk+dyR87T4s36vcz/v+4DKz0voQ==
                    "]], 
                    LineBox[{709, 564, 783, 855, 854, 534, 498, 916, 917, 915,
                     536, 503, 806, 509, 808, 572, 807, 573, 634, 920, 633, 
                    809, 574, 717, 810, 811, 575, 576, 570, 629, 887, 504, 
                    714, 713, 712, 568, 787, 501, 886, 628, 567, 627, 885, 
                    500, 786, 566, 784, 565, 785, 499, 884, 626, 856, 
                    709}]}}], {}}, {
                  InsetBox["\<\"\[Mu] = \"\>", {-1.8, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["0.2`", {-1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {InsetBox[
                   SubscriptBox["C", "J"], {1.4, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["\<\"=\"\>", {1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["3.8200000000000003`", {1.7, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {
                  {PointSize[0.05], PointBox[{-0.2, 0}]}, 
                  {PointSize[0.0125], PointBox[{0.8, 0}]}}, 
                 {PointSize[0.007], PointBox[{0.4463998339305619, 0}], 
                  PointBox[{1.2771956561278897`, 0}], 
                  PointBox[{-1.0806611991222994`, 0}], 
                  PointBox[
                   NCache[{0.3, Rational[1, 2] 3^Rational[1, 2]}, {0.3, 
                    0.8660254037844386}]], 
                  PointBox[
                   NCache[{0.3, Rational[-1, 2] 3^Rational[1, 2]}, {
                    0.3, -0.8660254037844386}]]}},
                AspectRatio->1,
                Axes->{False, False},
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                Frame->{{True, True}, {True, True}},
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLines->{None, None},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None, "TransparentPolygonMesh" -> 
                  True, "AxesInFront" -> True},
                PlotRange->{{-2, 2}, {-2, 2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.02], 
                   Scaled[0.02]}, {
                   Scaled[0.02], 
                   Scaled[0.02]}},
                Ticks->{Automatic, Automatic}], 120->
               GraphicsBox[{{GraphicsComplexBox[CompressedData["
1:eJx1W3l8zNfaD1eVkFpK6bxu7DHVWhomtNSDWFPLlFRV3Umb2ip1bbVMuWqd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                   "], {{
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[0.3], EdgeForm[None], 
                    GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxdmgn4l2P2xt/neakMLRLKFgpFElKaFiVJISmSNChKi0SNaCOkkopWstaI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                    "]], PolygonBox[CompressedData["
1:eJwtlwm0T1UYxc85FwmZqagMhUfKIlI84XlIQl6D8mR4L1lmrQaVSipWZV4N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                    "]]}]}, {}, {}, {}, {}}, 
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwl1FeQj2cUB+C/XSUuDLt6izpmzOi9t0W0BKv3tXrMJDPJKLt6X2QSnUji
ColeotzggsGF3q2yaggSxk1mEMtzxsWzv3POV+b/vt/3bbXMb9O/KZBIJOr4
0z45keiZlEgsoxDt9FfkVfbRSV9Ypslr8jr76awvIrvIVbIXXdVfyjWs5o77
35NlyaMc6fzkvL5yPRvoxzizu87/WX1PTtAPVFdgEBP1981/UT+UX+uHqisz
jMn6R+a/qT+nh364/EJ2pxub9D3lY/kXj6jOE0axyLEMWZODHOIwz9w3X9bm
CEc5xkvz4q4pwXH9CYrx2ry8WUP1SU5xmv/Ma5m3VJ/hLFNZajZF1pVtZR1Z
n3oMYYvZO9dOV3dQ/xh7yP9mWWbZ6o7xTJijT5MpvHc8Wz8nnlPsBXP1XWUq
HxyfqV+g3skOCjDbrIdsLC/L7jRS58gMWUquiN/NaP0YMtmrL0ibWEesk9a0
Itm8uWxBE5rRlCTz3exhSTwHs8VyFyPVJeUIeUk2lA3iubIonnu8A1xUd2Mh
s/QJuZ1865uhn6/exh+x/ng3zebFux1rZbl+lvydGazSz5TtyYpvQz9dbo3v
g2nB7K37b1a/kRfkec7Riu/Jcc538Y7KRvEuy0pUpH/sI6VJiXWSSnrsSewX
H+J5xHriu+Kl/hUv+Jd/4rszfyaf85Qa/B17Fvvh2Eh5gD+pFt8Oj/3eorIK
96nKAyrxK4NZEO+e/IGKTNI/cN1GdX/m6wfE3lGe8fo8x9eq19GHsWa5Zp+p
v2KevrcszQ3KcJNbzrklb5PLXe5Eb75SdnBdx+RP/6s+Ag4RkPg=
                    "]], LineBox[CompressedData["
1:eJwl0MsywmEYwOFP5ZAFrWSVsaBiYWHJNbTIoIWNymGhmiEugZUZd+DQTeAK
cB/RkgrlMOMxLZ75fe87X99/ptliLV8dCiFssRsJIcMlZS6iIexomm9++eHF
D/r6xQc9Pnm2f9M2r8xR5NQ72zpO050Dc8l5ng7vdMnZDzNCjDFGWSPJNFMs
uVvh0LntvZv/7+uxue68wgPr5knd0DQZHs2bmtCCZlngybyoq3qiPe81nJep
Ubfr2k04n1PlyK5jN6Mp7uxuuSdu3tMz3ddrrmi5X4kO/us/tAQwEQ==
                    "]], 
                    LineBox[{699, 554, 778, 848, 847, 523, 490, 909, 910, 908,
                     524, 495, 800, 501, 802, 564, 801, 565, 625, 913, 624, 
                    803, 566, 708, 804, 805, 567, 568, 560, 620, 881, 496, 
                    705, 704, 703, 558, 782, 493, 880, 619, 557, 618, 879, 
                    492, 781, 556, 779, 555, 780, 491, 878, 617, 849, 
                    699}]}}], {}}, {
                  InsetBox["\<\"\[Mu] = \"\>", {-1.8, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["0.2`", {-1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {InsetBox[
                   SubscriptBox["C", "J"], {1.4, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["\<\"=\"\>", {1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["3.81`", {1.7, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {
                  {PointSize[0.05], PointBox[{-0.2, 0}]}, 
                  {PointSize[0.0125], PointBox[{0.8, 0}]}}, 
                 {PointSize[0.007], PointBox[{0.4463998339305619, 0}], 
                  PointBox[{1.2771956561278897`, 0}], 
                  PointBox[{-1.0806611991222994`, 0}], 
                  PointBox[
                   NCache[{0.3, Rational[1, 2] 3^Rational[1, 2]}, {0.3, 
                    0.8660254037844386}]], 
                  PointBox[
                   NCache[{0.3, Rational[-1, 2] 3^Rational[1, 2]}, {
                    0.3, -0.8660254037844386}]]}},
                AspectRatio->1,
                Axes->{False, False},
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                Frame->{{True, True}, {True, True}},
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLines->{None, None},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None, "TransparentPolygonMesh" -> 
                  True, "AxesInFront" -> True},
                PlotRange->{{-2, 2}, {-2, 2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.02], 
                   Scaled[0.02]}, {
                   Scaled[0.02], 
                   Scaled[0.02]}},
                Ticks->{Automatic, Automatic}], 121->
               GraphicsBox[{{GraphicsComplexBox[CompressedData["
1:eJx1W3t4zEf3V9StlvJQbFP3S6jbixCKg/0JjUu3SouyREnJanlQsWiFsk21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                   "], {{
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[0.3], EdgeForm[None], 
                    GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxVmgn8l1P2x597H0mpJJU1pSxRMWUpiopKpWyZNlqFRBuFyNJMUinJWApj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                    "]], PolygonBox[CompressedData["
1:eJwtlwnQl2MUxZ/3vi3aUyqRlEpJm4oWCq20TPVNe1LalCKUENlSGDRlTcaS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                    "]]}]}, {}, {}, {}, {}}, 
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwl1EeUTmcYB/AvHIxORFmw0BMlyiijjjrqaAkRJdqGQ8yM3uvRe10JoodI
FmGBQxbRRTdqlGjn2DhHN/rvORa/+T/Pc+/95r7ffe9XfnBGj5FfJBKJ6v40
zJ1ItMyVSMzknb6B/oT6JDtorH9v3kSe0v/LbzTVfzBvJhfqW9Fc3VouZhHZ
jl+ShbhIYdox23lpchntGafvIFewnCuuG2DWWV2UdAbqr5qvUl+Xg/Xd1F/S
nSH6G+Zr1CVoq+8R9yXbxH2xVp8mr8sbXKMU/9GTSY71kmXYzR/8yf8+97ks
x1/sYS8PzfO4pqJ6H/s5wCPzIuZV1Ac5xN88Ni9r/q36Hw4zgmlmw2VFWVdW
kJWpxPf8YvbMtZnq+uo5zOW5WZZZproBjRirT5H5eOH4KP3YeI7xzGhCEvNi
vfHcHZ8oN/Pa+WP0LdTV5XGZSjX1dNlbFpDzmcGP+r70Ybv+revrxT1Sh+RY
D2/Ma8na1Ij1U5Mc862u2xbfAT+YTZVb6KXOH89FHpPfyK+ZHP9fTon9RhV1
M1lVvvJ5m9Qv5Wj9BPWvbIw9Fms2Gy8bMibWoB8tN5AV36l+lKxHBtP1I+V6
kvk55mZPff469ROZVx7lCLUYxlTnDI29KavGHpbFKUbXWFd8j+QliXyk89q5
OfHceBXriPfD/L58EPuQe9yN98j8trzDTUpzi++YGPtG/s4ursY7Ffs8Xnr5
FdmU5DLFWU0XJsQ9ytkUY5D+mutWqjsyXt9JzqIIP+kvO75EvZQ29DO7YPaR
1NhPnDYvyE5a6tvK/vKic86qz3GGC5znkvkCmeKcRrk//059AtIzkYk=
                    "]], LineBox[CompressedData["
1:eJwl0skyXGEYBuCjm1VYiZkWSqqMVVyGUIq2MMUQszZdACvFNltDbiIssLDA
fRjKHDPZJTE8f2Xx1Pt9b53+65y/umxwNjmTFkXRd77GoqiYZbpZjEdRjyzi
id88c+QHD/KRW+6541B/Ka+4oIBO5pzTIdM48MywvctcyC9uuKZR/1f+4w+v
vNCizySLD1TohkiZr523Zn6Q0/aUuZ5dWu3psk2WkGDPnpQZsl2W8ol9e5ls
kDPy0Xk/zJWMMKW71cXDvTDMpO5GlyOz+cilPVfeyXxZ5bk8WS3HWDKPhruR
NXIn3IO5iFpzHZ8ZZEJ35Zxt8xablJOuP9ePy2/hvRkI59vPwjuGbwr3Hb5P
xuSpflT225vlhkwQmZv4Qsx+4rkF87r5J2/0Mq/rk6uscOy5kfj//8w7saVE
pQ==
                    "]]}}], {}}, {
                  InsetBox["\<\"\[Mu] = \"\>", {-1.8, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["0.2`", {-1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {InsetBox[
                   SubscriptBox["C", "J"], {1.4, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["\<\"=\"\>", {1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["3.8`", {1.7, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {
                  {PointSize[0.05], PointBox[{-0.2, 0}]}, 
                  {PointSize[0.0125], PointBox[{0.8, 0}]}}, 
                 {PointSize[0.007], PointBox[{0.4463998339305619, 0}], 
                  PointBox[{1.2771956561278897`, 0}], 
                  PointBox[{-1.0806611991222994`, 0}], 
                  PointBox[
                   NCache[{0.3, Rational[1, 2] 3^Rational[1, 2]}, {0.3, 
                    0.8660254037844386}]], 
                  PointBox[
                   NCache[{0.3, Rational[-1, 2] 3^Rational[1, 2]}, {
                    0.3, -0.8660254037844386}]]}},
                AspectRatio->1,
                Axes->{False, False},
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                Frame->{{True, True}, {True, True}},
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLines->{None, None},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None, "TransparentPolygonMesh" -> 
                  True, "AxesInFront" -> True},
                PlotRange->{{-2, 2}, {-2, 2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.02], 
                   Scaled[0.02]}, {
                   Scaled[0.02], 
                   Scaled[0.02]}},
                Ticks->{Automatic, Automatic}], 122->
               GraphicsBox[{{GraphicsComplexBox[CompressedData["
1:eJx1Wnt4zEf3D0E1rHrdbUlR0q0iim1FcVJJtXXdKhGp31JKSdrKS11WXSpY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                   "], {{
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[0.3], EdgeForm[None], 
                    GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxNmgfUVsURhnf3xoIVAbsoiIgSUBEFRQyIVCVSLGBUEOxALERQaVYUFRFR
7AVFwI6AWDFArLHFkhg1KkZjNMZuYosl8/C+3/n+c/45M7v33t25e2fmnZnv
bznypMEnlpTSgiql+Etb5JRuCH590DVBMUxrBt0Uwo1BOeg/MX4m6NqgrWL8
bPAbg44P+big60J+OPhDQVXQg0FrxNwGQRsmyazZ2HytoI3M1w5qYt4o6J54
dnrQRUH/jfHzQXOCbglaN2iToE0trxfUFp2Cmgf90nxr3qvB/luaN/a9jb1/
c/MmfgbeNGgb82ZB3wb9KWhu0Gbec/2gE7J0aRW0XQO9Wptz7/bmmwe1MUev
HczRa0fzrXx9fes9OtYfFTQv5HbWD71uD9o7qA/nGte3Db5LUIckGX12baBX
R3P0ap2l026cVZZOuwe1z9KpU9DjWTp1Dnoq63z3CNrTZ80ZdzFHr73M2wct
jPtbBrUIWhDjna3rryyj5wHWvW/QpXHfDO4P+eWgO6zvkzH326A7Qx6TtX8P
dM3SY1/0ydKjZ9BJWXr0CpoV8mVBXUPu1uBs+jbQpZ8513fk3YO6h/xa0D3e
6/qY+13QwpDHBu8dvH/Q3db/10nPdPB5/zHJh36R5E/4EnbfKOu5wUGL/NyB
QQdZ5jwONh8QtA+6BA3kfYKvCn5/0Gkhjw9aHPK4rPUOD7rP6x0R9PusdYcF
DfcerH2k+SFB3we9G7Q0aELcf0bQAyGfHnxo8GOD5oZ8S9B6QZP5FtwbNDFJ
PjFodsxfkaXDJll7jgl6Jmvv2n3Dvf9J5iOCFsQ984MaB90edFtQE2w96Nag
DYIeCTom7v1d0KlJMrqNMz8uaLz58ZyP+QmcK2eO//Atgk8JejjkPwRfGTQt
66z72hYmWVd0nB10cdD0oClBJwedEnSm+digs8zR7ewGOp5jjo7nmqPj1bHf
VVk6LvNZTg06v8G5XmCOLtPMJwddaI4uF5mfaR3PtC7TzdGlY+yza9B+fu4k
v8Pvgx4NOg894/py7z8ga++ZQZdZD/afZc7+l5uz/xXm7H+J9+S9r411zsua
Wxm0ImhG0Iecu9d+zOteFXRw1rpXB30U9LjX/jjoCX+HGV6bs3w07l8W1MyY
BI7kBt+ecwajwCWwBIy6KQlTbk7CKDDjOGMUcfwhYxUxF18FI4i9NaxiXMOq
xqmOVYzBpyZeH7yak4QZtyZh1cbeDywAG9hvM4/Zb3OPiX/ET2I78XB+Uiyt
YdWWqY5VW6U6VjVPdaxiPNcymAVunGBsYG/ifyu/2xYN9gYLWqc6Pm2f6vjU
JtXxaQfv3dbjGta29d7tPK5h7RapjoXsvWYWVoEBuwX/a1KcrWFVh1THKsbg
VEc/D07tZt3Aqd2tGzjVybqBU52tGzqBEXukOlbtmepYxbiF8YJzRiewAGwA
K7p5jE7dPb7DMroRs4mrxNxtfR/PgUf7ei/wqKf3Aot6eW+w6bYkLGE/4k+f
VMckxmBRP+8LBoJ/+yRhETi0f8h3JWFKbz9/gPXi+QEe7+oYx1rrZOHQoJDv
TcIOngdPe/iswC5wCz8g7yPXw/bfTsKfIUn4A/YcFvKSpNjPWuDOEamOa8R8
8KCGPYyXWgaDHkrCnKOT8Od0x3rwhtgODt1iHCC+3+qYja+vNO4Q56/MwqEH
sbcsHBqdhEFjrEMtXhMra/GaMdhDbASP5ht/iJO3OcYQ65cZh1gD/U71GjUc
YlzDoXF+T3AE7OvveI+eU4yjZ/gacX6C753kMbpM9hg9pnhcw54pqY6jJ6Z6
3nBQqmMP70YcJaYSW8Gcc63fNVk49EjIPwa9l+pYBA5MTXUcOj/VceiCVMeh
aamOQxemOg5dlOo4dLH1uMRj9Jrh8aOW0QkMAnsu9R7gAxhE7sN7DUh1HD0n
1bHncu8x22MwZ7b3ui4Lh1aEfGDwD5KwB6AAh8AfcAf8qeHbLO99UBYOgT1f
BT2V6jkcHEx4OskvqJ/WsgwmEOfBF2L881m+tEaqYyd7XGgb/k2SHU+zDRPD
5yTF7U+SsIr1vg56LglL7s3ixPIXkmI9929juUXQp0nYA+7cGfffEdSc/YIO
Na68lJSXE3taZY2pJ141J5YQd4l3xLrPgl7x+ImsfJyY+5ekGET82T/Ln/Hl
SSFPdK5FXCHGE7uGxdzaWeNT8LOsvPr1pHhELPpVzL2RlCO/aU48uSvr7Mh7
d8nSlRz870m5L3HnraT4Qmw50jJ+3ZOYnBW/7jcntvwpK/7g0+8kxQ9i2Rte
m1j6t6QYR3w7y36DP7fJqlU4p38k+RC+Q16FfWOvnwe97/EPSbkX1/Gr5b4f
P1iR5Bc/J+VMzGGL2OxM281jnvuXZWwXu3/ctvVl0L89xg+e8PWpoeeTnsN+
sefs7/a6z3yC9ScukTeRM5HPYGvYHnY4J6kGx96+SbI/ZOyOurhFkk29mISl
2BF2hY0NzaqLqImwIWype5Id/TnJlsBD7AlbOiLu367BN4Zjk9gNOQO21Dmr
TsO+8D9yPnyQ/HDjLDtcEXy58eBef0u+45Ex7pZlX9gOHBvrkWVD2A82ssp2
ssT2gW30y7I57A37ooYa4fN7z2f4k21iqr/9+/6mfPN/ep5v+4G/79Gx5lEN
YtOH/tbHZH3Xj/zcT372fdsKa/JtP/b35Vt94u+FbX7m88buPrcu2NcXSTbH
uqyPzYD5X9lGnvA17IdY8rVt4Xl/+2b+/t82+P7f2QY4v+99NpzH/3wmnMeP
Pif2w1bBp+Hxjh3s89g2xskZgG+NjcWrc/ysWEs/qmTF3l9k5fD0r4i5yOTU
m2VfS+pHIWN7FzgW1nJQODnbWlm56c6+B7llki2v5fmbg8/Jyp/uM8eW1s3K
qwb5HmRyM+IW70QMQV/0x+96o2OWXc21fGjIG2blOcjkEsjgQ5+sa8zPswx2
bJR1Ptgea6znNffLusb8AssjQ26aldsgc6bI5BTU3Vw7KslvmlnmGjI5D3kO
66MXPkaMID5MtG+RY52Ylafim/j65ln4h19umfXM1j7/lj57ZHJncIpr83zP
NpbBK3J08nPyZuSu5i0tw7e1TJwgbhB7Vtc0WbXD9lnybp5j3NHzbSyDS9Qk
xBhyd3Ji8mHycHpD1NFtLXdPimFtLVOHUJ+wZ7sseXfPtfO+1CfULdzb3et2
89xOvn9ny8TDP3vcyXaEjxAL0YOcnnx+gOWB5h0t9/P63Mt67b1Op6z3oj45
IKs/Qm9kj6xr+/oeYitxdXXNlHUeXbLknp7r4vu7Wu7pe/byPH6wt32B+Eq8
xSfQj9wO3Q+2fIj5PpbhPSxTd4DfxGMwvJflQ7JyuKv9rTpZZ/yjr32EWoB4
Tax+174xwnZOvgJG8P7k6ORg4Dvy6Z77teVV9lv8ixyVfBUMH5glz/QcY/LY
wZZn+p5Bnv/A15gHs9EfbB+Z5ef4+N3BL87qWYBfm1p/Yhg4Shybb9/ALx7L
6rcyPiwrz5vveeSdknK8w7PwmNwJfMVXwM9htnnyLmLxG44nI6wPfKRlcAmc
quXS4BZz5MxgFZgBFh2bhSHkwvRZiM1Lgi/Oql3nmJN7LMrKa2t9Cjj9APLW
UZ5bZJmcFj7a8h+DP53rtfEY2wA4sLq/43uIS/QF4MSpOx1PqM+xcfJQ5F6e
O9n2fL3lXr7nFM+z9vFen2+ILZKPnZpVn2Pz1DXnZmE+c1wj112ahR+1+hlO
XkF+O95zSy2DKfDTLD+Qlb/W6mQ4sZkc9gzPcQ/yEM9NsEycJl5TF99gmbgN
n+T554I/m1WjkgsMycoXl/i9evmeKX4WfmZWno+/4D/kxmdbPt0+xZi8mfM4
x74wwDJ+RH7AnuSh5MHUctRx5K7IV3qOMXnO+Zav9D2MyYPAE/C7ZRKGI69h
HdGVfajd+B2LnJFagpqCWEFP+EKfPz0l6hxi5pOWsR/4k7Yf5Mc9j5/hb/jg
jn5+B9vbk74HO6U/BaZwxvQm6AHQp3rKzy30OvjsM/4WY3z/c5Y7h9H1Lvou
4Ct1JjGB/iXyGp57wfNT/Czni51Q8xxt/qLlyd4LfZ6Pte8sylmGWw/6J5fG
XJ+i81vmZ+mJjA99BhTlnrwv/oYfPm25c6qPefcVSbX5JebX+TtiX9fbxvjW
13oe37jC3+XyrN5ZV9vtDbY9YiUxs5H9lHXwNX5DZH6dpN7sJVl1DD1bxtTc
D/msOD/6IvRHqNGw16ttz7Xae2PzRZaf8nvxjs3iDK4qyoOv8lqsc5rH9F7o
UdGrAnPO9Tz38E68GzXQCX5f7nnQz9TOYLbnOXe+3zGOl+i0iW0ZO6an0Ca+
y+BKPrh98E5FmN865B0qYdsuwZ8t8p2dQm5fKZa3C/7LSr2TiXH9/Er1x1jv
Te9r15j7X1bcI0/EJrgOtlKDNbONLLONvWideb5bPLtPJb/ZK/iMony+Ucjb
FeUUbYI/XFS3fRDjdSvVq5+FvE2leqxH8EOKcO8nr8U6ewTfs1L86hC8Y6UY
3T341UX+hY13qWTnnYI/V5yf8772rya2FewE/KWWAFvotdHrpGYklhOvic+1
2gB5lO2E77O+/ZO++3jfP85297xtb/Xvb1kxnW+90jZP33ix/aLWvxhi/oBl
nmE81L75qM98rJ/tbf8ijo+1fbA+tkZ9zLvg4+iDPxA3yDvIP8CN5ZbJQ2rj
YT6D5Z4f53enJlrsvdB5pW3yMPvaw16/8l6czYZx/o0r5Yj4K2eOL7dI+l2E
/tahcf2lrPjzcvCfs/C3R3yrtpVyrB+CdquUEy6K+Xezegq9imwdOz8s+CtZ
NcrEkEcW9RT2Cz6rKFYMw9ayaty9Q36hqKacFPJRRXnTNcGHFeXpq+Lax0V5
/vLgK4p6BhvjR0U9houCn1CUz3YIvmMR/jSNezaqlPNeEPzsojzxvJCHe/23
MMwiXNuM9yqqef4RfEhRnfpOjP9TVEdMiGcPK+oBvB58w6IYia/3tL8fHHzj
olxxIX5WFH82Df5mUQ12eKzz16xe5Hsxt3lRj+fvwVcV1V7bc2aVcv09Qp5T
VPPfFvzcopr+iLg+sKh/sHsln8QfTw4+oaifMTbk84r6Avj9I/b94TH/RlYf
4pyQlxTVar8JvqV1HhnzRxTVZJ+wRlFt99/gXxTVYJvFPZtXqiGOjbnWRRhx
JO9ahOkt4/pjRfXwCOJfUW+jVciPF8W2ycG7Fed1wTsXYdB9wZcW9dVy3P9z
UT3WCn0r1UXUttS6zU3kuOS31OL83kDNzW8Q1O0jHSvIC7ETzpr8YCdj3T32
k418P72AZl7nKGPBXfa76b5/HT97t2X2ne+9eO52PzvKus2zL1/mGNLO/tje
cWmW57t6TE7Nb5czs+wKzrjmx5f62Tt8Dqzf1Puiy6F+R+p78hbwnZyH3gm/
RdH/AcOnW39yOOaJ+dQU9F/IvcfEeX+R1Y9+AnsvwtKnietFsW1U3DO6qLab
GvJpRf2qU0PuWtQzA/cmFWHfPsG7F/XPRsf8SUU1ZX+wtFKdtGfMXVyUOzSP
ua0r1aL0Tvgdi/7J6TE31D5Lj4fftOjzgEP0tnjXWo20vzEFub/f9Sa/7zp+
X65v4PWp0Rr7m9Ljmeb1yW+p6eZaF+bmef4Wz9d6UPO8HvZbVbLhs4piE3Fp
WcgfZfVS1w+5b1Gdd0Xwy4v+V4szGOdzIKb2d1z9MfhPRb2M+4twHUwnxlxW
FGeGxj7rFtWQGxTFL2JX0+CDi2zms+B9KvU32oc8qii3/bIoFhOH8cux9s0b
g3+ZVeNgFzcU2cZN6JuVIxGrDq4Ur8hzwRuwpl8RZqzuX4c8oJK/DAq+bSV/
Ic9iLdYhfgysZNfc28L3/yHmD6jkr2sUPc+z+/MelXrStxdhGPjF+yW/Y+Oi
WMz5vOnYRFwiru/v8xlUhFtg1mtZMZd4+2nMf17Ut+oXc00q9WCIo4sdS9/O
iqHET+LiMY6NYON1Rfj4dfBvi/pJnNM5ju0/EO+L+grfFOEQGDSFb1WUw68d
fHpR3/lb7K+oBpxblF/iXzcH71L0O8kWRXgD1twd/O2ieu6tIixsGfOvBn+j
6LeKD7Gloj4HmLDQuNAz9OxVqffxL+y2qD/YoiheE6vPIkcu6k+TL3xXlDOA
G18ZO77KsiHsZ3Lc/9ui3wCwqTU9D54fVxSrr+V6Vk/iwpCnFf0ut7Iof30H
f6/0PfgWxwX/d1bvnLyma6Xc5ses3DTY6lx7QVG+vXPMTS3qtRAMNik6E3Lb
fSthxPHBP87KNz4JXhXlikcX5THkME2K8BVs3b0obuIXnzo+EhtHFOVJ2MCL
Ib9U1Nv9Ogu/wW6+5zdZ35Sz2bTS+fD9v8+ygV2LYjFxeIO4vn6lntPxRe/P
uz/E9aKe+mvYXdH/mZI38T68C+/3TtE7kpetV5SbfZeVQ5A/fJ4Vo4nPbYty
MvKxvYviO7G9XVF+Rm7GP8JOts7kU8Ro4vNfQn61qH9N7vBhVv5AnnJH0V7E
qiGV4tXhRbkXedeaxIei3uoBRXUyNfL4IrwBa8ClU3wmW8XczkV9wDOK7BKb
bBTygZX6bsTdZpViL7knOSL54XtZuRG+/ErMv1z0/7z/B4vv63Y=
                    "]], PolygonBox[CompressedData["
1:eJwtl3nUllMUxe89T5JIkpSEJkVIKEOjr4E0SaWSKcoYJSSsSCLDkmFFoULm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                    "]]}]}, {}, {}, {}, {}}, 
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwl1DWMVVEQBuAHJLi7FECBL+7u7ou79Czu7hDcqXB3EqAAEqDA3d2dhgR3
+CYU3/4zc++5+949Z7fowMHJKakSiUSSH9XTJBLNUicSs/itr6a/oL7ITmrp
/5jXlgv1i2hOD/1V88Xqm/KmvMUN7nA7evN7Mit3yUZrplvbSi6lDSP1beVy
lsV66/qYdVDnoCN99XfNV6ofyAH6TurcrKIzo826yDw0UneV9WVDGrBa31g+
kU95TH6exfdhrGs9ZSH2so/9cd3v+y6LcICDHOK1eSZrSqgPc4SjvDPPbV5a
fYzjnOC9eWHzSuqTnGIok8yGyOKymiwmS8ZzSWat2WdrB6trqufFO2OyfoRc
H/tEXUaY1ZHp+GLNEP04dT0a0oD0zI/1THV9ktzMD/cP1zdVV5DnZRPKq2fK
7jKT7CbPyXKybLxnMuq/Wz9MPUO9g+38MqtiVpWKVI7vz0/zra5vi/NAF7Np
ckvspTqD7CTPyiRZhinq2XJq7COl1I1kafnN8zapv8qh+omx92xkfJxvswmy
duwzU/Rj5AZGMVM/WtZgHZ88J8VsuLo6wxik/2i+Rv1BppVnOE1lUpjonkEy
n0yKsxifXeaVrePck43sZCYrWWjBb/f9iX2I98ZPmpm/jTPFK97EuYt9iX3i
pbogzynAi9gfxrjWXe5hN494GOIPPz4P9+Nz8oBcJNPfuvvumaueQ076md0z
W6FuF+9L3z72guz01t92fYk6Cy3oaXbN7C911HW5ZJ6ZXXEe9S1lL3ndPVfU
V7nMda5xw3xB7Emc+zT//1f9A9azlYY=
                    "]], LineBox[CompressedData["
1:eJwl0ksvnGEYBuBvZpx32DgzDNFFqUR/g0hQbJ3HsUZqj1XTVRM/gPInWGDB
gv4O2tCGGIdx3nG9sbhyP/cz77yZ78sk04uD32JRFK0yHo+ietYY5UciisZk
HU+88MwfX3iQj+S4544T+6y84pIahllyz5CMcexMWh8x13LNLTd02UfEeNUT
Mk43ZZRTSqvP5pg1X7pvI9whM/qiuZND+vQ8+UU2kORI75f5ckA20sRvPSU/
ywWZc9+m+SPzfLW7skuYf4YefoNd1q5KVlDJuV4tr+W8zDjXxj49ei8L4d3I
dnkQ3oO5jk/mDj6EZ2PG7sI9e+ZddmihxP6//bSc0ZuZZkr/Z18sU3pheDZZ
JM/sC8Lz6vnhXYTzrJgnZZxTZ77r2+Yt8swTclmm5S/W+evcZOL9//IGHJlA
8w==
                    "]]}}], {}}, {
                  InsetBox["\<\"\[Mu] = \"\>", {-1.8, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["0.2`", {-1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {InsetBox[
                   SubscriptBox["C", "J"], {1.4, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["\<\"=\"\>", {1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["3.79`", {1.7, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {
                  {PointSize[0.05], PointBox[{-0.2, 0}]}, 
                  {PointSize[0.0125], PointBox[{0.8, 0}]}}, 
                 {PointSize[0.007], PointBox[{0.4463998339305619, 0}], 
                  PointBox[{1.2771956561278897`, 0}], 
                  PointBox[{-1.0806611991222994`, 0}], 
                  PointBox[
                   NCache[{0.3, Rational[1, 2] 3^Rational[1, 2]}, {0.3, 
                    0.8660254037844386}]], 
                  PointBox[
                   NCache[{0.3, Rational[-1, 2] 3^Rational[1, 2]}, {
                    0.3, -0.8660254037844386}]]}},
                AspectRatio->1,
                Axes->{False, False},
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                Frame->{{True, True}, {True, True}},
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLines->{None, None},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None, "TransparentPolygonMesh" -> 
                  True, "AxesInFront" -> True},
                PlotRange->{{-2, 2}, {-2, 2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.02], 
                   Scaled[0.02]}, {
                   Scaled[0.02], 
                   Scaled[0.02]}},
                Ticks->{Automatic, Automatic}], 123->
               GraphicsBox[{{GraphicsComplexBox[CompressedData["
1:eJx1Wnl4zNf6j3BRNbZap2prMajd2Op6ETQ/tUxtDWVolZLRSy1l8LtVy9RW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                   "], {{
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[0.3], EdgeForm[None], 
                    GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxNmgn8l1P2x597H0uItBlpRRQTocWSaBNFUraoqGyhhWRoUyS0GK22QWQn
e4OytsgSDckSDWNrxs6MZWzjf97/z+f7+vZ6dTrn3uc+997n3nM/n3PP97fj
kJF9R+SiKJ4qiyL+FX9IRXFj6BtCbg/7tpDfwv4m5IWQ60MaRN2LoW8KGRn2
iJC/hP1s6E1DbxNyXUgUi81Ctg+pGbJ1yLKoXBryO2OFbOVndUJqhGwRMiue
nxCSQr6N8qqQ+SG3uP12Idu6781DahUal3Jt19FXA4/JfHb1PKhr5Pdp2zvk
sJAeIY1dx1z+HmOvD3kj5LsovxKyIKShx+P9Hdw35VHR7lzWK+zmniPf18Jj
0ralNX3sZs1cdrdm/F38HnM9J6mfnUP+6OdNQlpZNw25OtrMC2kW9t4hO7n9
PtbMpY01fe+ctBZtmUPS/NrRf9L82oe8mDS/fUNeTprffiH7e67M5QBr5tLB
eo+Qv0b7piFNQs4PGR1yR9SfF3qv0AeFHFzIZr5l0pwpd3Idc18V9ReE3EM5
aeyuzC9p7G4hY5LGPgR/C/vakAO9nx091p+S5t4l5C7XH+r9rszlbyF3e53e
CLnP7W+JdyeE3O/1xi/qhoyPuu6hjwg50v0xZgvWNuk7Frq+V8jmSW37hjzo
uqMZN+n9Y0KOdV/440FR3zHkKOaBH7KuIReHPSnkobAnJvU3IGRB2JeFPBL2
lKT+Tgo5eaO+B1kfF/JDyHshi0IujfaTQx4N+5LQ/UKfznqEfVfIliH3sg8h
NUOeD1kZMifkBs590hzqJY05LGRN0tjDQ0Z67MEhF4WcE3IuaxxtFoZsE/Jc
yIqQOiHLQ07DX0JG+Bt4f3SheuZ2vvUZ7K/10JCe8W6PkLPCvjX09JDFYU/w
PBh7WtK8xrKPHoNnF7iPM0PGee48A/PAOfBkouc+KmReyPSQGeyL58scL7Fm
jpOtmeP8GPempHGe8PhTQi6zzZiXWzOvK6yZ+1Rr1m+a9USPj57keUzyXK60
Zi5/tmYuT4U8yZ6HXBVzedrjH5E09syQWZ4H48/x2NPc9yh/51zXMf7p8W6f
pDGfDXnGY852H7z/cchS973Mz64JOTZpjGtD/hWywuv6fCH+2STk5kLcAu7D
S/AKWA8vwUVg/YaQ5Z4XXAUPwD0PcHZDtjVHwTk1vbfjvO60Bctrua/aLrPf
dVyGh7DhplsL8VB9z4P34AB4AowAH+Cu+bZ5j/rGbgf+N/B7DV1mvEYu13bb
Rp4rPFDhSTR8sLX74BkcBS9VuOD2QjhMW/Ae3AcbwIWBfmdXP6twUouiykkt
PQbvwR9w2jnG6ApX7VZUeQgO2CQJx1sXageG71VUeWjvospDlOGrVp5zY/dB
v3BTG88NbmrrucJN7TxP+Ghfz4F34IX9iion7V9UOYlyE3MEawIXwUMdPT+w
/yDPr5PLd9tmnvAP/NG5EAd18VhwUFePBQd181jwzyEeGz66sxBPwKftvbaM
DVfADXBFD48Lz8Arh4d9byG+6O528EIvv9fb5RpJvNKH+YdeW4i39kpqQ78P
FOKII/ydPdwH78MFcAM8c6z7beA1Zs3fLcQ5x4c8XAjj6QvOOtrzgYvgof7u
C6w+qajyDeVFtuGdxwvxzKmFOOcSYz0cA57DPXeZZ8D0e8wz4PJKcw34fKO5
57Gw6ydxz9mFeGdYUeU+8Hu4xx/pMnyDDR8tNDbAC/ebf8D3FeYh8I75gefg
XoV7KFe4h3IP43qFO8BPcBX+gW/GeOzxfs74E1zm2y5wX8zjIj9jHhNdZh6T
XK5wzMVFlWMoj/WYcAo8M9l9/hTyfiHOOc/v0dfNSZy0JOxHQj8c0jBVuYdv
AA/B2BpFlXumFlXuqfDCDJcr3DOjqHIP5SdtMyd4B765ymPACTM95myXGWOO
y4wx12XGmOcynDPPY52RxENwz6+F+AaegV+ucT/ww7Xu56gkzoBvwHA4ZbOi
yrXMZaW/nbsR2AsHgcdvJXET730d8pzfp+5G17NexAzwxbvR/k3zwb9DXirE
H48mabCW+xB3J3D95UJ4Xi/ks0J8A9d8WogLmUtTt2nm9ZxpLod3uDttGfaO
oVcXinnBVHANTPs85FWXX0qKr8GmNYVwB8x5q1D8yhl/3X2AQ+8UOs+c5T2T
ntHu7UIYAT68WQh3wJwOSX0R866zBjsWRf3cpDh2cOjNUjXmRoO346JubFLs
Pcjjcmb/WyiOIYZZl4QnnFHii4/sS38vhA1g1tRoc4XjwCvt75y3p5PwDczp
HHYnlzlHnJUxHgPfxW85W6wx5wtfxtfw7V8KxT3UzfI8mMMXIR/4/X+4T97F
F5e57Se28VF8Gh/FP/HrFa7Dt/Ax4pnjk2Ij4iJ8k9i04mvcx/E3fOol+wm+
x90ZX/pPId+qZ995xf7D3uIn8NIuSXehir/gJ50K+chr9pM77Sv4ySDiAvvB
VyH/9DcstN/gM22T7lTs7RBihI18At3L/vK2/eeUeH5gkr8cnORz+Bu+iW/h
Vwv8HF9iz9Z7H/GdtfYf/OU9+wxr/7739LAkHoKDfvbeTPHefmgbX8aHBnj/
PvD+nh3vnpWq+PKx93FY0vdXMGXDRvvJmoA7RyfFuPO8P596j1jvz73e+PUX
HvPZkC8L+dkGry/9gTFf2y/AqG/sC/2TciXgDJjxb/vCKu99Pe//dxvt//f2
Adb4B68Z6/Sj14q1+cnrxxr84nXYNCnmI97Dh3/1eoChxN/wBrmj/xXCzw+9
1qwtjkwcTq4JPMUG97ZLekZ9Toq58WfiZ2xi6ceT4kxitx2S2tFmtrmLZ8vc
D2dkltuAh+QkmiXlB2Z7/juG/VDoBx1DPJkUU+GHWyTFWMRXd9omNtsqKV6p
3JOxiQW6Jj2j/m7bJ/BtSfEMNu2w4fxuSc+ov9f2iWHXSopR8FviBGzigkOT
nlF/n+0hYddOimGwaYdN7MDdh2enFCoT24zyt9zh7+TeXTfpLFzhNRjmNSGu
4r7A8zruB7zZPlXxZgevfyOvP+tJLEH5Ntc3tg0egBXgzYCkuJyYHN3U+1K6
H+4QHfyM+oFJ73C3ITblnsAdgbsJeTf4sXkSfoFdnQrF1sTVPWz3tG5hG2xr
mdSW/pr7XTAJjFro5y3cBvzbI1XjeO4kxMqtkuz2rqPczm1buX73pPtM5Q6D
vas1z7jnMCdid+a7b+j9UvWOwd2De8dJSWvBOrRJqqdNu6RyV9eDueAtvMrd
AFzs7f7JKXFX4Q6zv/W+fhcfP8B+Dr6Cw+A073BPoI9jbYPJ+/vdbp5ze9s8
P8ht0Afb5k4B11Ywu6vPy2lJ56FyXg7xWcAHu9sP3/MZGGyfPMx+S66H+JvY
G37HvtB1PW0fbpu2xJzEn/B5ryR7pusoE5f2tj3TbY50PTFCF8//I7ejTd+k
ePTqsI9JKl/tenAfzIfXiUfh/+OSbHgBrILXwas+fnee29KO2AAM65eEY1e6
HXHviUkxH/VoyvPtL23sA9T1d/0LSflZzlLyu+Dq7T6Te7gNPrZnoRjy5KT4
gHgPvuccw+eD7VfEePA65wbMO9X7iD7NNvM93WsCn2FfaX2G68+0zXP0UNd/
6WfUw7fw79JCnAMfU0c8DwfDk3Ds8CQeJmYn71PhGezSeqTtx5JicXIc3IHA
FPCHe/1Y+/NjrgdnFifxUCWPgOZuzTv0Qc6DfPdoP6c9dmvXnW+7c6HcAnt0
YVKugTrGZGzyCKtdT76jg+d0gOtfSXqf57xPjLbaYzPuLZ4//ZALBd/B9idC
L0nKNdxhTUx1UVIO4nC3meB30TwjDn8qiSMrd340MRLx/CTXPWUb3kRfbPuZ
pJi7cudHw5/E75NdRxvs4113qe3XQr+alMN60Jo7/uVJuS3wAU35Ea/hOO9d
PX87+QH0VNtr8eWk+/lr7od4kriHOu4BM5Lu8GPcfrrXEGwBa7hH/Nk2OAOH
wCVtjUU8W2Js4Z5WyQnQL/eRma4HW4iVfhMc/P95J3bhjMKHxCs72l/Yd7iA
fV9tH1jjb2FuL7sNPoN+2e139zPyZtz7VtlnWFdyOsf4u+mHnMnr7ne4+1nt
Pskd0Z64nRzLGu8F7dd6DtzL3knCZ+6+5Ebres6r3A/5Q+qbek3Wei+4B3PH
5h6NfjsJG5fa5vkK97/css7+Q6zLnWe+/WrdRnOgvp795DX70Ku22fdK+RjP
51Z/yxW2F3t/yDsT38KPC+xv5KXIR8EvZ7qMPcA254KYj1wWz693P8TG3IG5
C8N35C3JjYLD/M4y1+8y5wWeJ77N2b7fZxObcwo+gVNgEPdVckDcX4mpwKvW
3rdX3c95rieW5rfON70++Ot8+/YF7qfy+8XN7pO6+ba5Z/PtfOujnkN9193o
deA75vgbb/C+sqfcQ9Z73A4Bxsdl8efeYbctxdn7hO6exeH7h71fKbxfHnXf
JN1Fp4U9p9Q9gxgXnyDXRd4VXycGaxPPB5c6p+/YZ5bbj1bYT+rYpg8OIncJ
eOPAeO+gUnx8eOgFWZz7vyjvXuquWJ85Z8dEoV/OutceEvU3Ze31Nlll7H7x
39VZd/sbQ3ctda/rGHqrLN7vGfYRpbj/iajrVgonjg+7S6l3OzN+Fm4s9ZxZ
W77jOX9XXdt1fIbe8jkCv8HzvvYlcH+868DxPsZhcBm8ftr28UW1TPy2yuvM
ucanFtvfqHvR9cRMT/vdSe6f8Ue7Pf5I/nyJ/Xm8bfIMxCzEJcQkA20Tr+zm
PW7ps7UyVc/fSp+d+T7/de2Hz9sXWYelXqsl/nbGXek2vLu514J1+N3ry10V
Yf34PYd7JPjMOWvm89vUmt9jOMtzY49mZsWM+On0LF+9jP3Nuve/H21rZcUk
h8Z/72fdic8M+72ku37NqDu4VNzYIuzPsu5XfUIflZUzmBG6d1Y+Y1S0PTXr
rn9J6EOzcKx11L+Z5Rd9Q7cvFeNOC312dg4odL1S95DpoUdl5VZmhT0y6z60
MvTzWbmZHqH/koUfrDeYAr6PjPYbknIPX4b+KYsfz476fyTls74KnUrdjz4L
e9ssvrs79AiPtUc8fyPrTvsuOJEVB54eepesGHYEZzyLB84J+59JuZBhYQ/I
urMOD/vjpFzq5LCnZuU22rPepe4/o0MPz7ojdg39x1L3kB6lziTn8bCofzAr
V3IWbbJyYzM5l1l3r8dDz87KkXQqhSNgyJTQc7JyQ5zjfsaBy8MelJUfei/r
zHPeJ4Q+MItr5oc+Icsfvg79Zdb9uTnjZ+V0do5+mpe6r2QwI+ue2RLMzMqD
/Bz6v1kxy59Ct8vilHNCt86KDb4NvVtWTLk09DJ/I9j2ivGN303INZAf4L7P
/b+hhXh6J593YkS4Dn6CJ8h732LOgC84z5zzJsap+91nJeYjxqvtschxNHX7
PX2uF/nM1nN7YhL0Q363vu16xpnrjC1LXMa+3vXkHNCU+d5rfJabGROIm4mZ
ace7xObwOTkvsP1cfzt5D97jffzzYa8P9ewr7X8rqrE4sff3of9QKtdJrojf
wIba5rcx7lOvxSBrsvKUs6PtZVl5ux3D7mA/6QwXZa35+Kgfl3Xnbhn2bqXu
2G9F3dtZHN406hqXuq/357yUusO9E8/XZa3fxKhLWfnTi8K+KOtefn3oMVn3
+/U++3A653+98ZC7IXmxLY2/fBfxAN99p799S38jebIart/cdXf727e1b5DT
IgdGLowcGXkD8miVNbvX/fOM3/nIjS10+yHuZ6HthvEtjUrlO67Kwmuw+umw
v8jC+H5R16RULmRG6POy7sH1Qw8q5asnhW5Vqs8TQ59QKp/dN/RXWb5aM+xa
7mdLuL5Uvok+9nQ/4NzJpfx9TOifk/PgYW9TKldUht60VI5pbbQfWGo96mXN
gzkQH21WKkb6JAkfwcZzszAdPB+d9T18C3t7n/cX3AXrwd5vk3ANTBuWxRNw
BPHUA1kx1V5ZfAAXrA79U1JOf6csLAaHT87COPDthSxfx8+fDfuZrLxyryxe
hBO3yMJKcBLMgwvBvdezYi/irv5ZXAKPwBu7mjuuC31t1m9oO4c+JevcwVGX
mqd+z+Ik+OiXsH/LyvcR3w3MivHuyto/9u62sG/NyrN3DD02654BN95rfuTM
XeBzB6aeb1z9F3if9beT8Hz3Ulx/RdhXlcq1g9NUgtWNwz4xK4cBh5xeikfg
jSXmjsVZMQHxQLMsboPXPkriPPju17DrZsVd8N4tWW2GZHEzvPxJ2Buycru/
ZvkZPrZF6Bqlcj9bZ8WaqVB8+lhWjDqP85KVdxkbz39JwoEcddtl3bWnZOEU
GPVX1jUrt4PvbGr/aRD61FL5HeKUi7NiFXjsxyQuaxh1Q0vldz4K+8Osv1fd
LIvLPyi0lpdnrSfYNsn4RjzVKCumIu74IMtnmtA2615yf9a8mfPuWfwH98Ht
S819nN1+Pr+cxR+S1urzrNgF36sT9ftk5WV3CLtBqTwZXDrUfX4f+rusHFuX
LCxmnkdH22NK5d1+iLofs/Lmq0K/lPW7RIt4fnBWzvSALD6ACzYpFUsRR4HH
7Ad7QTyyIuv8HpKF45xxyAocB8Ov5IyUyrtdmIU7YM6nSXEkMeQXSbERcVGN
aLMoK3exPeuXlavbtxSGgp/47Kwsv30odM+s329/S+Ik+OieqPs6KfdFjAOH
wV/gR7NSGPJI1h3vw7B7lzqTnMcj2YdSdwLmsrnnU2btJfvYJ56fkZU7/z+R
OiCR
                    "]], PolygonBox[CompressedData["
1:eJwtl3cUlmMYxt/nfltKVpqikkQa2sOoNFU0pKiIhrasBhER6ajkHGQmp4Ws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                    "]]}]}, {}, {}, {}, {}}, 
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwl1DWMFgEQBtCfw50Kd7cCd3eXw93doSa4u0Nwp8LdJQEKIAEK3N0dQgO8
CcW7b2Z2N7c7u/kL9R+TPDpFIpEo60+DlIlE16REYiWZqa9/IB9ygkb6LLKx
3CA30o1h+oeu36R+Kl/IlzznNa94Zj7SeT3VBThFc30LWtGSLWa9aK3uLbex
lReuHW3WT12I/ozRvzTfoX4jx+sHqouyk0HMNhssi9FePUS2ke1oyy59svwo
P/GBknyOZ2KOY8NlGc5xngtx3P9L41g59UUucZkf5jnMq6qvcJVr/DYvaF5D
fZ0b3OSPeWnzBupb3GYyC8wmyQqyiSwvK1ExdsAes9RMVTeXa5nOQv00uY8W
sUdmxn5lDtIwTT8n9hA7oR05WRfXx24dXyAHyEMyAzXVnWUN2UmuYDl5GGp2
X1aX1WLH5NanZ4Z6mTzOMTJR16wetahDbTKaH+EoSxlstkQejveoziUHynuy
I1XVi+Ie5GLZgcrqZFlFppMHSRt70c+XbTnAXJaZzZMt4xthkX6W3B/3HPeg
nymbsZdUTDGbKptGHe9Jn1LuJons3OUODeObcfyv9ztRTtTXim9XXVMWlt3p
Rh7ykjP2Fs9KFzLEXkhL+nim2D0/Xf+Lb/G98T2e37wjX9Wl+UKpeDdMMH/n
Ps6qz3Ca97zjrXk2WZw3lIgZReL9M861r52zRr067puxZq/Mtqv7MEvfV66i
IKP0zx3frM5Hd4abPTLLqm6ibhq9Oi8nY8/6HnKEfOy8J+r8POYZT3livj52
G/tJ+v9b9Q97vZHZ
                    "]], LineBox[CompressedData["
1:eJwl0kkv3HEYwPH/mLpZaiw3FbEnGEs1HGyJvoEeGok1rraWMUPJuFsSrt6B
7V1wwIFD61UU0Qpj9/nH4ZPv8zx+tlA+Nv1tKhIEwTo/soIgzjZTbEaDYFob
iZqz+cClT4hoFi8+FuirXrjf6wMZ6plgxcfHtYC/3iTsk+YGHnnmie/uedx6
k6s55NPPJ8oopd3beRbMD97uhT8DaXta+/jNkL1Ih7WeBv7YR7RYR7WROOf2
Jv2qyxrRfTr5xaLbk+9VaN4Kv3d4d3t0q9IKKrmzV+uzLumid12cMmAfZMlc
o916Rq25jh5zLx2kwt/RLePrnJiPOeILJe437ilN2tuYI2n/716sn+2F2qpF
+s89pi3h30GbNcGaeVZjXHuzYT80H/DR/FNXdUZ32eHKu7no+//LGyWEQSA=

                    "]]}}], {}}, {
                  InsetBox["\<\"\[Mu] = \"\>", {-1.8, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["0.2`", {-1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {InsetBox[
                   SubscriptBox["C", "J"], {1.4, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["\<\"=\"\>", {1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["3.7800000000000002`", {1.7, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {
                  {PointSize[0.05], PointBox[{-0.2, 0}]}, 
                  {PointSize[0.0125], PointBox[{0.8, 0}]}}, 
                 {PointSize[0.007], PointBox[{0.4463998339305619, 0}], 
                  PointBox[{1.2771956561278897`, 0}], 
                  PointBox[{-1.0806611991222994`, 0}], 
                  PointBox[
                   NCache[{0.3, Rational[1, 2] 3^Rational[1, 2]}, {0.3, 
                    0.8660254037844386}]], 
                  PointBox[
                   NCache[{0.3, Rational[-1, 2] 3^Rational[1, 2]}, {
                    0.3, -0.8660254037844386}]]}},
                AspectRatio->1,
                Axes->{False, False},
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                Frame->{{True, True}, {True, True}},
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLines->{None, None},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None, "TransparentPolygonMesh" -> 
                  True, "AxesInFront" -> True},
                PlotRange->{{-2, 2}, {-2, 2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.02], 
                   Scaled[0.02]}, {
                   Scaled[0.02], 
                   Scaled[0.02]}},
                Ticks->{Automatic, Automatic}], 124->
               GraphicsBox[{{GraphicsComplexBox[CompressedData["
1:eJx1W3l4zFf3j7UaQooWY9+nai1Dq+Go8Wrt86o1ZdDah/KklGjaWtKhqb3T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                   "], {{
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[0.3], EdgeForm[None], 
                    GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxNmgn4l1MWx9973yRNiRYqtIpsE1HIljZKJGWpaLO2pymNyJakVSiaSIrG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                    "]], PolygonBox[CompressedData["
1:eJwtl3cYz1UYxb/f96LiycouKw2yRxGRURJlPxnZIxmlpVApFe142lJaRDuR
hvZAS1MaFIqQjEgppc/p/P44z++c+97v+N373vc935rDxvc8P7Is+w4UAZvz
LHuLgQPwhuBY+A5wBONVQTP4pWA1sZPQ7eCfg0Pgp4FW8I9BUXhb0BBeOmVZ
Y3hT0AhdFn08/ARQG60X+JT7VUMXIVYf/UTmsarwweAD+HZwLXwmc+Yw9yV0
H/Q49Hj0bPTZ6HlgmzhjQ+AXE78IPpexuugcfRy6LhiJnoCeAH9Mz0AfE+Yf
gVvhI4iPIj4a3K21AA8R2wjWwquA++HvgYrMbYp+Bv4FmASfwth0rn0B3Qvd
Gt0T3Rt0R7dAnwnvBjqhrwdrmLsHXAK/gvi1xJ5Df4/+Hv4AvAy/NYidwNhC
9CrwCLxyeC30jvfAq4FH4ZtAF+b3Db9rH65/E/4G+Dfznh8J3wgqEKuJHgHv
wTUD0YPA0+gTwaLMObAG/kP4XbQG6+A/gcPQc9Bfw0/i+u7ot9F10KOVI/Ba
jN0HnwUWZB4rytyDQD1iT6IbELtQOQZvwthF8MnEr9S7MHYceh84Gn0MqESs
CmgBf5b4eGKT0JPRT6GfQbcM78US0JRY+zDvxJwO8GaMdYZ3UU6jO4OlxH8D
AZ9OfCaxieir0dehb0a/iJ6o/EG3QS9Gr0AvB4FOuie8K3id2O/gHPjO8Nka
rByEDwAriP0K+sO7c7/+xIqjf0Svgy/PvMYPa/35XYb+BexC7wbVGZuPvgte
XDkPfwf0hN+pPVIuMngQvE1yLt7NWEfx8NytYBj8FsZmKdfQ89Gb4B/Cd4A2
6HrEOzB2CjhLZyV8dvQOG8G94dwrD+bCNzD2fuYzug1+GddMVC1RTdH5COd6
f7CT8TLJtaMDuhKx18Bf8NK6Fj6D+Gx4H8b26t7hte6hPeP3cuJXa+1Vz+B/
wb+Gn8zvVcw9PnmvR4IcPQ19G3wSc/bzOxV9I78D0dcQfz6cC9eBpfBXwL3a
G7AwfA9duwtMg58a5v/XWPgN3O927jdDe6h3BWvhP4NFyqfw3N2gArxY+N5b
lDPhPdbe1tA7hWuSapFypia8d/JZnZe5VswJ76Vqxk+FHFNuqSY8qFoG3lVu
6x0LOaVc0tgo7lUePYbxseBMeDmwOXMO11OtBp/AH898lmeDlZnP9Ojk/6B3
H8f1C8I5pVzaCYaKh7ly6sfcOabcUs1XrXkKfJu55gwK9wT1AuXQ6eE11Nrp
jPbheXvCazME7A3XHNWaI8Ef8D/DvBnzZ8JfBHvh68EZ8MWqsfBXwQ3hM6uz
qj26KVyjVZs1Z3p4z7RXqtnvwZeFa7962Evwl8P3vkf/UWcjXKvVI3R216PL
Fs7wUN6/DHo4vETuWlwLVMxdkwcTL601zNxzP4V/Br7J3AO+0VrpP2Y+8xvC
NVm1WM8oqbXNHRwKNmvtwrVePeA07l8inAu6h3q/erR6szzAFvhRoAq8Mtiq
XAnzBswfE67JqsXKgb91VkHnzDX6X/g/4bWvjT4kuear1tdH94MfnMyHgRLw
4uofxBsozrWHKwcLNXCTal24t2uNtJfKWeWq9jTBQ34jc88fF/YA6v3K2T2F
Z+jeescD+uPJ76Zr9KzXwf7MzzyH2Gr0G5nPxEj0knDtPFc9Dl6SsYaFNVbt
bwKa5+4BFZJrkmqRxo5I7lnqVSeip4Q9lbyUcl7eST1QvU8eqiG6UXJuKAfK
wQ9Lro3yVFWTPZq8WSvtSXINU+3qyO8qYm3DvFTu2n2yalTuGn5FuKarliun
Vmo/mdNOvQJUg1dPvrf2pG5yzVat1pzG6Cbg0Nw5fLp6aXKt5ifrwdyWkB8y
r2F7vTs4K3cNbQdvm3xWNPa/Vwr3KnmmXaB8snc8RWum/AnX0q6MdUN3Te6V
fdHNNTe5V6unzwh7LnktvYN6iTyRvJB6ivb6jORrtee99Pzk3JYHUi+Wx5S3
VE/+Muwh5B30n+XluoXfRZ6uNrpO8tr14x6Twx65baEH/Z67J6kXtQbFkmuY
apc8kLz0APTw3J56IPxyxkbkHhuU/AzdW2Olkj2PvI5y8ILwmddZl4dS77k5
XNvUgyonnzmdNXmm+sk9Ub1QOSHve0s4t+WBWyXXdNVyebo7VJvAebk9xZhk
z/d25jF58zWFvZdHn6C1S871rzJ7c3kEeQN5dHmrjmFvL48l7zE83MvkQdSL
r0Q/n7kny1vvy9375bG3hT2VvJRq1NHEayWvrTxZc9X+5GfrHvLW8gzyCvLY
8goXh72lPIO84/bc3kQeUt8K+kbSt5G+GeQ95Pnk9eRB9G0ijyBvoG+UB8Lf
EPp2UM+Ut5ga9oryGPKyuwq5LE8rL3ReuJfKE8lbqhiPzewxy8K/Cp9djf0H
qxSeZA==
                    "]]}]}, {}, {}, {}, {}}, 
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwl1DWMFVEUBuDH4tbgzuIUQIO7Lu7u7rJ4QgHB3Z0CdyrcPQEKIAEK3N0d
QgEJfCcU3/7nnJnZNzP3vles/+j2qWkSiUQ5f1LSJhKdkhKJ1WShkf6uvMcp
muizyqZyk9xMZ0bo77t+i/qxfCqf8YQXPI/aPNV53dQFOUNLfSva0JptZt1p
q+4hd7A9/pdrx5j1VhemD2P1z813qV/JCfp+6mR2059FZgNkMTqqB8p2sgPt
2aPvJN/J97ylJB8YzBfK8JmypDLJ+R99XjpZXn+Bi1ziu3le84rqy1zhKr/M
k82rqK9xnRv8Np9mPlldh3LqurK8nCory4aykqwa18fzsM8siTnqxnI9M1mm
nyEPxFrRnAVmzWRO0jJXP0+2oDWtyMUGFjPQ8UVykDwiM8a9xTuTteO9yVWs
JC/Dze7IWrImw8ijz8B89Qp5khNkpkE8Uzwn9alHJvNjHGc5Q82WyaMMUeeO
9ZC3Y/2ooV4i18ilsV+oFvtIVpfp5WHSMU+/MPYah+KeYn+bLYh9HO8jPlM/
Rx5kVjyffrZMYT9pmG02Pb4TTIvz9Am5l7/WMYe8xU3qUcHxP+bT5ZS4v9iH
sY6yuJwoe8iCFCIfBcgf35F4J2SOZyEjGejCD9f95GvsN77R2XyI/ERpPlIq
1pCJjr1xH+fV5zjLG14H8+xxP7ykBK8oSl/Gu/alc9ap11KEcWYvzHaqe7JQ
3yvWgkKM1j91fKs6P10YafbALJu6mbp5/F6o83E69qK+qxwlHzrvoboAD3jM
o2C+UTZ2Tsek/79V/wDhqZBq
                    "]], LineBox[CompressedData["
1:eJwl0r1Ok2EYBuC3dFOwrQKbGoP81BqgiAN/AxwCkyGi0klABYW0CIIJzGBS
JuQMFDgIHJQBB+UkUCI/0QpF0esLw5X7fp4+bdovvZEb638WCyEUeVoRwm3e
McpyPIQnMkNMj1PBd2/4Zxf0P/KMv3yz/y2PKZFmmEV3j+VbVlhl123efkS/
xQmnlLlnX8lPNxflBaoY4BrXuUq72zyz+rHbdb2Dtej7mOft5/RevvDQnJSP
ZAutfDUPyZTMySxt7JjvyD65IM983obeyUvm7E7sEnqBN+Yp2SDrqeMmv9w0
yrJ8LafddLHNffMgM/oD2USaz9EzkRm69R7uMskru5LP2tI/8ZE2au2P7Gfk
hDnLC6bNh/Y10e81X5bVXOHAPhU9C/ukbJbPWdLH5SX23RTNH/TNaKcnGIue
g/zh9ff6nizEz/9D/wEiNUZc
                    "]]}}], {}}, {
                  InsetBox["\<\"\[Mu] = \"\>", {-1.8, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["0.2`", {-1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {InsetBox[
                   SubscriptBox["C", "J"], {1.4, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["\<\"=\"\>", {1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["3.77`", {1.7, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {
                  {PointSize[0.05], PointBox[{-0.2, 0}]}, 
                  {PointSize[0.0125], PointBox[{0.8, 0}]}}, 
                 {PointSize[0.007], PointBox[{0.4463998339305619, 0}], 
                  PointBox[{1.2771956561278897`, 0}], 
                  PointBox[{-1.0806611991222994`, 0}], 
                  PointBox[
                   NCache[{0.3, Rational[1, 2] 3^Rational[1, 2]}, {0.3, 
                    0.8660254037844386}]], 
                  PointBox[
                   NCache[{0.3, Rational[-1, 2] 3^Rational[1, 2]}, {
                    0.3, -0.8660254037844386}]]}},
                AspectRatio->1,
                Axes->{False, False},
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                Frame->{{True, True}, {True, True}},
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLines->{None, None},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None, "TransparentPolygonMesh" -> 
                  True, "AxesInFront" -> True},
                PlotRange->{{-2, 2}, {-2, 2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.02], 
                   Scaled[0.02]}, {
                   Scaled[0.02], 
                   Scaled[0.02]}},
                Ticks->{Automatic, Automatic}], 125->
               GraphicsBox[{{GraphicsComplexBox[CompressedData["
1:eJyFW3l4jFf7jl1DJFWlUqVodaq1NtMPv7QPBiVKhyq+fAylFLHVPkQtJTSW
FlNaVDOWVhNNNHaGhyJMYklJDCkRySQkyDJZZgZf59M5uc9c13Hl+vnnve6c
9z3nWe5nOeeMlmOmDR5X3c/Pb1MNP79/nq6j/muiHEe5XWC31ww6N1sEJuCl
Yyce05ru8pVD3w8OyC3nC/vbvGSyZUn8Vv3z+XZtmsSYDxjzATcT70t8Rswn
8XyxnsRdGu4x2PSFPHe0c7ElyiHlAYY8wJAHGPIAQx5gyAMMeYAhD3BHIY/E
eEJO9Ql5gSEvMOQFhrzAkBcY8gJDXmDICwx5gWcKeSWGnVW7qnIDq0/oAwx9
gKEPMPQBhj7A0AcY+gBDH2DoUxVPVZ6oflD1UJ/QBxj6AEMfYOgDDH2AoQ8w
9AGGPsCXhD5UVdypvFd5pfoF8gFDPmDIBwz5gCEfMOSrKg+ocajyXOUJ5gfG
/FXlFTWu1bhReYf5gTF/VXlKzRNqHKo8Vp+wLzDsCwz7AkM+YMhXVd5U85aa
F9S4Unmp8gB2BoZdVD2A1Sf0A4Z+wNAPGPpVVQfUPKzmOTVPqHGm8hr6AUM/
1S+qHsDqE/oBQ7+q6oaal9W8puYFNQ4hPzDkV3mk2l2VE1h9Qv6q6oaad9W8
peYJNa7VOFR5r/JEtasqJ+RR86Sal9Q8osa9GmcqL4Ehjzrfm6JfkvMB53tx
Mi/2fufkFIEJ+JYXF/Br3nXLONuLM+T7kB/4ihiX36eL7wnfJ3vlLZbPJPEk
YPARGN9BjlcFJhW/4X3apRyqnNAT72Ec+gJHivefsYuf998JC/TDOOQHxvd4
X7Ur3gfG+6rdsQ7kBcYT7+OJv8s6UYlhnxZiHskLYIyrfgJW/aQ+wXNg1S+Y
BxjxAVyV3VW7AEMvdRz7AcQX7Ih4AUa8AKu8g3ywA/TCOPTFd9BDjXOVj2qf
Br3hL9UOalypdU+1E8bxPubFOLBqF8yn2lntE1U+qfVDjWOVF2o+VvVU11X9
i3wFeTGedzzynMdTxAMPjjqgN5Sy89OOzY0BT/Os1w+5tNX/mw81CSXyecr7
fSoNPvJnkTXCRakC81CBGePAMeI7+cwU6xHWw7wYx/ppYn3eFVBthdlSQfO9
+mdLPENg+R3mgT5hYn7CesCQF/KreQYY8QAegs8yn1T2McgDGAfGOPTp6J0v
v8p5gH8V+jH0BW/AT/AHcoIXwLDDNu/7sTJPYR5g8AT5BePAGEdc4TtgNY4w
DoxxyIVxYIxXZTdg8AB2ifL6ySb5NldgyTfwAu9jfuSXx8IfDH+oeRT5Bxh8
e8+b1zIlVuVQ46Czd94zMk+pdRNxjHnxRP6HHSE3MOyB9dS6DIz5YW+MA2Mc
PMH6kL/xMe/fJcZ7kA/zwP7QV+UJMPIU/AP5kWeAwT98Dyz3u+P/Ko83P5Dv
g++qvI2EPKTmJciPvAj7AsO+eF/tC6Av5m8n7CYx9MP3kBcYfMO84Bsw+IV1
gLEOeI114DeMw0/AyD8awXdZV9W+D3L8f3kXciF/qn2Q2idBTnwPfwODR2rf
h3qF9aE3vpd5srKOIs6hJ+Ic/AGWclTyH/yQ56SVdgOfMS7PgSrXhz+xPjDm
V/eVsA/kU/0Ce0FejCPPwN6IA2DkaWC1j1H1AN9hL+RB2Af9B+IE/Qkw6na0
4PUz+xrkb2D4CTwFzzGu1hnYEXrjfXkeVsk/xD/6I3wPjPdR//E+/IA8ifoJ
jHwCu+F95Ae8D4z3Ef/qPkOe61Ri6Ac9YD/5XaX9gGE/8BLvg1fwG3gE/4FH
8B8w/Ie8BL+q+w/oCT+jfwJ/5H6kkj/gK/iHeIYdwU/ED+TGE3kH61fFQ8gJ
+wDDzlXpAQw9oBf+Dv5AP2DIBT7ifawvz6UrMd6Hf1Ue4O/gAeSFfyAvsLR7
pb/AN/AZ8+EJvgDD3+CHuo9BvUB+gF/hR6yP+irvbyr1gj+xHvZ/0j6VcmMc
cYk6AbuiTmBdjIM/GAf/kV/BH4yDj9AbT7X/Blb3NeAdzsWwv1DzHeoH1kd+
g/2gp7rvwDj8gHHkD/BOXUfGfWU9xLrIQ7AX5gWGf2Ef8Av+gf7wD+ZDXwAM
OWAnNZ+r5yzyfqZyXrwPPTAvMOIDeuE7+AP6AIOH8I/a3+A9xCcw/I7v1HMa
NW+qdQ16qPYHH9U+EPwHDyEf5ke+gDyIHyl/5fdyf9z0XKzeYJX3udfut+yq
Sbggz2+WXNi41Bya/8w92cHPl/fQFPnOUR5FDm9ifOiSdq/du+eT+GpuGVev
Hjgw0RbkkvK8e7jNKe2QMk7tv6qJqUPJM/eji/56f0/EvWJ2bXStMj8oZfVc
+cHmXwdoAkv43ZZDVpqf+O4jp55ssjHqSrnMo0Gdz8RETHCyes673a9FlDnU
d8/V9NCC9eZQ333diR3TzmtDsnhKx9V51riLMv6yLrxWYo3znZNA3wnTzNMt
SSkc8/fwkbag28/cGzxpmnROa0qV+n9dp8V1u/YS7x/0XVxE3xL5fqKwK6n3
XQ06NZ1h0++T8yMu8T0wvgeG/Or50sm272Z5PKcI+mAc9lLvf34bMyDTfsC3
b2k97/P71vsZBPtDT9hfvZcPT9pXbL1/l+BP2AH+V++ZaZ7rUnCrMgL/4Dd5
P9Ul8rpnVAWBv+jvwV/Z71fKEV2vVKf5pkLadWOdnkvNk33n733CclsbZrrp
s7enj7bpj3Ov8dM76Sa62VgautxsOUQx9w/Ossxx8+rqeeuiOt/j4XVsx7Uh
Fby12tLNUYOf9j9DTq2LuFfENwP6ntCWlbMp8Pz6qMS7fPTK1hPaM+UU2+7T
HHv6XbassB/Vv59F7Vo3m2u2MDdutyo8YNyfhGffO69vjEpO55BkZw9dQBbl
zjA3NeiYk25taGMckEWFDt3ggBcruPvDhhZtyF1K2hy1I+J6OU16s/dIx/y7
VDfZ/dCeXiKf9Z47mxLsSOeSy0fj9Gku2tzc1E8z6iolv9DuSXyAm7bti7wQ
HJ3LZwIDk4MLKrj6rjHPGwc84C7Vyt4y5JTxOtfsFA/f4oLONeuZPnBx4Lax
2/XNM2ngVu6uGfV0n9Mj9ZS2LIcmfznlDcNMJ894+9CmiJUPqKxX82k2P9/v
MXTCnxzs/b5Q5u2aC4eFGFoX02dprloJS0r57RWBL5o2+e4boo+eaW48UsY/
N6npjHff58ntF57U7i+j2Z5Z3TRF92VeGiP4xX9f6hyiu+HkWxM6TrfUvsnN
dAuKrfVcPCX09GFtoxsce/i6RXumgpYd/PmB/btsbjZhxIYog5M+2/1+O531
Lw66teWaZ5qTtOY0d/ynGfxk6gvVTcNuyefjLqcDTZty+RVvvkjloXFX2ht0
O2hIUO5gR/gtTgz55Wtz6Fm65hxez9TkOg88+/ZHAelOmmN9/S2d+wInfjiy
rybQTlsOH2hoXJPCU2MOddUd+ee8z3rB47nAnznWd9VMe0AbLnz3U9SMVF48
J+8dw9hiOnq+boRNf47tX4SS7ocSarbzULZdu5vrL1hXz+R00hF7LX+T7Xsp
X6CQj/D9VvE9xT5/Ld1z20mj+u06ojWdJ9hnpLAPwX4Xhf0oevPLtz0/ZfN3
tt/nWpJsBP2ShH4EfRYKfWS/FiHyGw19UiPHGlck+wDY93VhX4L9hwj7k8aY
7Imv5uRp/4qeYQvKIdj9gXhSn13Fi8wW330K/Bkp/Cn3vZtFfqe2jWasMEdW
yP4FfNom+EQDZyT/FlG3mHdaIxZZxpfKPHRP1BfKXrd1S1Si79wcfB0t+EqI
lxARL1L/zqK+UWJRgt6x2Xe/gng7KeKNymaHf2Gz5PCY7zt74oc5CfGWJ+KN
EF8TRHxRZ+86dnJM+DjY+J7vfuaNt8520nV1y/6h89Hnwx1hbrm/SMuq9akj
vJyz/u9hB8OObLmfn1lgXGQx5Mj+PaN+7q/6zHyZt9G//PdOWqBpTTmv2qFZ
Z37y7L1gl4/cbmucg6Gvel/zd8vp4xwZDhn3QZ68FM+ihwz7Yh6hb6msA7Bb
45z/nAiOfijlnpA1L91+4DbDv+iDLvd7R2Oo4ZR1q7ix8b/xg1zP3PccF/WM
R3y15L/WON/9T7vi0Jsessv3Me/a2V+1MA5Ik+c274j6x+Cjen+pr2gx1fZt
uty3hu4rHOkItrHrdLd8+/K0Z861M0U95tVLx71qvJgjxxE/6v1mjDfvnJZ4
qcAEfVHPoQ+wvAcT+si6Hyb6F4J86n1mT6EPQT78HfW1UPQ38h6ovdBX8mq4
8BfB3ohf+At22HnScDHYv/yZe+q6gi8Efqj3lg0EP2QfuUD0j4R6AjuBv+q9
YYjgr4zzR4KvhHql3nOningixIt63uYW8SJ5iL4M8afer7YW8Svt2l7Er+93
NKJ/JsQrvkf+2i3yFz+37KcYffMiDv34Ul/N5VI+XDqqg6HUwStbnpjomPS0
nlbm850in/OU2jOTtEPu8PYmMzrq3Ddk/S4W9ZuiN7zysaPbQ5rV/5tptpNl
tOejph0ML1/lBqPXzrY8cbHlk4hbdm0KX3ncLtzRzc1f3Cw4Hpx8nPo+3/dz
23Q3u1rEhmoSkmllqz6F1v5uRv9xSfQfvDt8R3fNtHs0aZ/2u6jBFYz15on1
2K960HMJp0rkE31NffHkbbkVq80jSmlts7g55idF/LOfrnbCsFLa1Oiv9eba
xYz+aIboj3j44wUGR3IFNVpe7UrwpGwepsnuGzDuGEXebpRpT8+Q/Vgb8ZT2
WS/sQ3h/snifMF99MR+h/1st+j9Cfzhf9IcEfywT/iDIHyXkJ8i/QchP0PtJ
Ne+T4N8uwr+EfnSI6EcJ9hwv7Cn95S/8RfDXJeEv2e92F/0uwX+9hP8I/lsm
/CfP0x+dfX2pOdJ3n9lv1ACtrqtT7qsvxXpCdOOcvHFSwqeOR764SYoeWm7t
X06po6OueDifa7YMGBRwtkLOg/o/V9R/Dl52NyZiiJN/mNl2gGbYHbZ54+2G
7/d9lXmk8NWkpsY1h/iR6F9kXKHfWSj6Ha69qVlT40Mnpbmbhxh0J7m4a5vX
jL+VSL3QX+3c4e2vKOpB+WPrqhLqs7B9jN6QQJfG1WlqdPvuFdB/WXO8/Rcd
vMFHtWVOajVsx6Yox37Zd4x82a9vQG6KzA+phWFzbMWpBHkR9+gXh4t+kXa+
mT7XkuikyNKXXNZjV2Wd6b19kUZnzJR69rS1amNc47sf/XbB56aICZkE+0KO
jFfmTbYtruCO16NeMU7JJfgHcqG/niL6a7lenaz8r8yRLtl3TS2LLLJucVFM
8y9+itAcZsfuF656prl54HFdW51xDf+8cW2s/ks35411vmmokceJY/c6rCkV
ss7WE/Pxw7z8dPvsp3W8V/X1Ua1cjP1KudivcFLt6i8Z11znNtnOpOBYl/T3
DLE+r7lcJ8OzKJ0GN287wVbs4nttfo3TZ16nzrF34vQnXDzxUajNfiCT+iz6
bV3UYBcv/n3q1+YR5dw1/uCj+Dv5jHoDfuIcpr23vhcw9lt9xX6LYb8uwn7s
L/gk9crstHCiraOLd/Rusj1i9zWuL/bT0o7vGpI2RLVyUpQ3H9zmpII5/qZN
LnnPmlhrwRzLHBd3z0vpbKjxJ48OXPIfx3wXx42YONGxOZWXff6+v+nQU7ts
HtPYZDsl7bJ/sHt7hCZJyvGJ4AdjPxkq9pMc9uKqIuuG61ztzMX1EfrbPKHH
45eNA/Lk+vceWcc4wu0c2/6M03r/Ko9emLfcPOIu13zwz77awtsPDXrZ+Fse
T6y3p75p2Dn5XZjgH++b/Fam542rHDRu+HqzPosHHhz9fYTmAju0g9KDo7MY
+9lLYj/Ly3j/ErPFKsfB3xjBXw7fumWf3rCfXamuEQG1sriRuffuCM0O/vJA
r2PBYbcZ8bFaxAeH+q1rYrzokvN0WTt0W8R5F+/19kf7+F6qmzSXXXx/XWCQ
MeBHxvgsMU4Yf/ytd9x3Ht/Re/5C/d7NamM4fVfOP7l36iTb9Ls8MLlHXZPt
CAM3FJgqlo+zBofZqP2gk7USzKclX+uGrNqjN5yXcblA5Af+w3uukUcXx/FL
htOXZR+UJfIFz0hYdtXTIZ9CZ607ov87lVfPK/+3IzyfNq348StL7T/ZcrNT
eXy1hzTivLGpqUkqI3+dEPmLkZ8MIj9J/iH/gF+7Bb8I/Noo+EXgZ0fBTwI/
fxT8JPAJ84E/573nMhYCf/oL/hD4tlnwjZCfD4r8TIgvxD3iyyTii1AP1N/Z
JYp6IO0fJOxPsH/BO177E85jSlp5z2MI9m0v7Euw70phX8L+fLnYnxPsPVDY
mxDvkAPxPkfEO6GerRP1jBAvdUW8EOKlQMQDgf/Fgv8E/k8V/CecP/QS5w90
YkidPPsnFfSk964gUxPfvfjGw/s7GE5nE86jtovzKEI9Pi/qsdwf9Bb1nJC/
40X+JuTrNiJfS3sOFPmXkH/bi/wr61+y6Ado+P3+e/Xv59GkXzK0unzffX2F
6CdkPSkU9YRQT7aLekI4j9sqzuNo6jHvOGEcfcFmcb7HGEc9kvck4rxPnq+e
F+eJvD84Z4U5NE/eM2N/Pl7szxn77wqx/2boM1XoI89B14rzRp6UNddhvZ8n
79E2jqYtESsLKNF/3w1PQjkbGjT/IGDcA3lPgXuzkL2RrY0BVzhzfliah32/
J2jo5Zfv/z9gHHphHBjztRHzEc6baovzJkK+SRD5RvaPuJdBvSg57a0X8tz7
eXFeTsjf4CvkOijOzwn6xgt95e8TTp54c6W5UQVBf9z3ot63EnlHrlch7hfk
frW6uF8gnEeGifNIQr3vKeo9pfT5I9XDyfyr3+8fBrzn5pywzKGO4BTquGTW
jxF93dwqZsBwR1gBz27brYtuXTk369d4giP8Du/2xoeTM9ec+1DzzR2qn3ok
3VPk5D4deydoZxVS+y2NGpo+KOMeMwe/bqxRQiXNW681Jzr4yswa/TXfOPi1
852zPbeL2V83bKzDv4xrLk4e5Hj0kJd6918OyvDm82L+I898TDvLyfpjm14y
bcpixG/NPt74Zcctz0XPRxeIf+wZbban8f1/x+XY45yUk3s52mxK45zM9z8J
GJdGc0a7xtr0Kbz0dpcIy7VCalv8Hgf7X+RXDEHddS1LaLx+V72nYSRxW4EJ
8+8V81Pa4tz+msBs+jo68IS2URJhvXSxHkHevkJearK2wTJLUhZPmJLxmS01
gwzaM/0Cco/S/KZdQzVFGYR+q5Potwj2eLLIaw+C/R4K+1Ha7mKNrmshTx1W
cCm4bRnBP18I/0h/7hL+JPjzbeFPgn2vCftS2z2/pAUXFPP1YfPe0/3gYINd
s1/foIwS/5hSGl+tkNt+WX2so5udO3nPSdIY+v8i9JfjrcQ4wd7Dhb0J88WK
+eR6aWI96l4/qKbpXzepx+zyvfrMAwz7RAv7SL68KvhC4N9OwT/6H85exII=

                   "], {{
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[0.3], EdgeForm[None], 
                    GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxdmgn4l1MWx++9r0plL6IsNSFRjUjZlUJUKFmylhaRVKKFkbKEStmKSFOW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                    "]], PolygonBox[CompressedData["
1:eJwtl3m0llMYxc857011i9IqRaK5hUbNaJBSGRpouNLkEpW7jBHlikjFiopC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                    "]]}]}, {}, {}, {}, {}}, 
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwl1EVsVUEUBuBHcdcNTnEosqBscLcWK17cizuEsIHg0OK0WII7bHB3S4AF
kAALnBZ3lwT4Jiy+/uecO7e9b+68Rg8YkzA6UyQSifHjaVQkcpb4zJFIAdlW
bpZb6Mko/UPrtqqfylfyNS+J5g3p5mOt66Muy3k66hPoTCe2mfWli7qf7CrL
ye1kuH+cfqC6IoMYr39mvjP8LTlJP0S9m10MJcUsSVbhAhcpEp7P+j3yrZxi
zXB1dfYygq/U4As1mchU6z5an0vG6q9yjet8Ny9pXkd9g5vc4rd5JfP66tvc
4S5/zKebz1Q3p5a6hYyVc+Q+2lBPHy/ryjhZjMzU1zfggfohC1imny8PcZgO
LDRrL4uTjTn6xWHv6UwnNrCeIa4tD3srl8nB8rjME55R3UM2k93lalaFvQp7
x2N1U9mEYZTU5w7PpU6TZzhNPlqbtQmfl1a0JK/5KXIxX58qT3KCJH2J8D7l
I9mNxuoVMk2uDGeFhuouspHMKY+Rg3n6pTKBJczVZ5dHaccilpulyCNhz0jV
J8uDHCArs83mhfMffgez9FnkfqIoyn3u0ZLarv/1nmfIWeH5qBzeWziPcprs
JaMpSynKUJpE8pGf3GF/yBP2np/u+8U3foSzF/bEfKT8TDU+EcMwJrv2xnNc
UV/mEh/5wCvzwrJq+C7wnnfhOcP7D+fevS+sKaReRyUmmD0326HuT7J+gFzD
WspTgdLh8zE6vDfrC4b9DueRdHUpzoVzqu8tx4RzZN0zdRkyeMFznphvlJtI
ZGQ4+2b51XHqJ1H//0/9A6F3la8=
                    "]], LineBox[CompressedData["
1:eJwl0rlOlGEUgOFvhk07QIZNG8JSyCJgZJNClgJaOmJQgZoZ0MgmO6FFSLSE
S0C5DCjQAgrgHoCgEtQZ4PlD8eQ958w/ZJhMxUhqIBkLIWwyHg9hPSuElN7S
xA0xt8AghVx7Q4Hm84jXVFFNJS+9p0bndEPn9RXfCay4rWkfx7yzl+iwttDK
iX1ES3VU22jn1N6h/bqqMd2liyUW3NI+X3E0s2lf1Hqt4ym1/PVMg2Z0UZc9
080hQ/Y3rJjf6jMaOYq+E22mx9xLJ7PMu/3zt36af3BAO0/cr9zndMbexjSf
7H/cH0f/r71Uyynjt3tJ9F24F+sLneKzeVIT/PLMF/u+eY8ic4KP0efRS69/
M1/otP2D+Tk7TPDV7b02k2d+yAPOPZ+jucTJJosz97RnM/ynkSRjbLMVv//9
3AFrLz+4
                    "]]}}], {}}, {
                  InsetBox["\<\"\[Mu] = \"\>", {-1.8, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["0.2`", {-1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {InsetBox[
                   SubscriptBox["C", "J"], {1.4, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["\<\"=\"\>", {1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["3.76`", {1.7, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {
                  {PointSize[0.05], PointBox[{-0.2, 0}]}, 
                  {PointSize[0.0125], PointBox[{0.8, 0}]}}, 
                 {PointSize[0.007], PointBox[{0.4463998339305619, 0}], 
                  PointBox[{1.2771956561278897`, 0}], 
                  PointBox[{-1.0806611991222994`, 0}], 
                  PointBox[
                   NCache[{0.3, Rational[1, 2] 3^Rational[1, 2]}, {0.3, 
                    0.8660254037844386}]], 
                  PointBox[
                   NCache[{0.3, Rational[-1, 2] 3^Rational[1, 2]}, {
                    0.3, -0.8660254037844386}]]}},
                AspectRatio->1,
                Axes->{False, False},
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                Frame->{{True, True}, {True, True}},
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLines->{None, None},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None, "TransparentPolygonMesh" -> 
                  True, "AxesInFront" -> True},
                PlotRange->{{-2, 2}, {-2, 2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.02], 
                   Scaled[0.02]}, {
                   Scaled[0.02], 
                   Scaled[0.02]}},
                Ticks->{Automatic, Automatic}], 126->
               GraphicsBox[{{GraphicsComplexBox[CompressedData["
1:eJx1W3l4zFf3j13JtKit0VdRYaRVS42fJXUSKZW8llhqSWNqi2LQViOMhmqR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                   "], {{
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[0.3], EdgeForm[None], 
                    GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxNmgf8l+Maxt/neVFHRokTZVQko6GdLUWRkbbRlJQiFRVKVDJKWpQt89ij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                    "]], PolygonBox[CompressedData["
1:eJwtl3m4TmUUxc95X0PmsRIeJTNlCMk8ZwhXFzfkiYvCTaaIkgapqBQhT8Zo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                    "]]}]}, {}, {}, {}, {}}, 
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwl1EVsVFEYgNFpgQSCSymeELwt7iTQFe5a3IvT4u4JrLDi7iS4a4K7awIs
gARY4O7OuWFx+t3/zpvmzZ3XFu2Z2iolKhKJxPvxJjoSuUK7dJFIfk3S7dqH
9tZ9dSc7eO36z/qFT8TzlTf2J7h2gHUC1+hs7kI3urLL3kC6Ww/SHlpWd/PW
+yeaU60rMIRJ5nf291l/0CnmYdYH2M9wltoboVW4zg2KhHtz/cFwnzrNNaOs
D3OInubRGtEa+peaTGa6vZ/eE6OJ5jvc5R5RlLZfV+/zgIdkoKL9hvqIxzwh
IzPtz9aW1LZupXU0TVP0iB4N50w9c5IWJwv1zQ14bv2ChawyL9ATnKQTi+11
1BLkYJ55aTh/utGVzWxiqNdWaqquCOes5zWG5ta9tZn20g2sZ0w4L15ZN9Um
4cwpZd7COkaa1+oovayxtLZuQ4vwuWlJXvuXyBM+j3mNXuRC+D7NJXWYvgzf
E42tV+laXR2eGRpad9dGmlvPkYsF5uXahWXMN+fUM5xlCavtLdZTnGYRafay
63GyMdc8XzuEs2SOOaseIzPFeMbT8BlJ9HomnaVzwj1TybqRVtYZmqD1tIzG
E0dy+HujQDgX8hEbzp50pCeKWt4XrWP0D9X5TbVw7kz12mfP7G3rW9zkFz/5
aL+wVuUbP/ge7is8C+GZ9973rikUnuFwHuZKupc9DA7nZi9FN1KQcpQPn4V+
jPP6C7+jQDiz8Czy1ro0V8Mzau6v48P36rr31nG8C/fHB17Z36rbSGZseO7t
5bNua/06+v//qX9UC5gW
                    "]], LineBox[CompressedData["
1:eJwl0ssu3GEYwOG/cT7WoTvHUYcVuiitY6gKC9VGcAHSOLV03RYphkFLrB0S
q7oHbqMWrQULegu0oe3zxeLJ73vfmX9m5svEx98Pz6VEUbTDfCyKdlOj6JNm
a4dmaS45vKGcmH2ZllLBBI000UC/1x9rUvd1XQc5IYdtux0d4ZIZc1zfajc9
XJnfabXO6nN6+WV+oX2MOo/xki9s2mVoFRscmDf1qbbwhGZS7Z5pZnhOv+oQ
50yap9hyntZW2rgwt4c74ZXzawZYDZ9ll6Zn/ORH+I7U20e6rgntZYWk+Z9L
rwu/y/xIa6nhr311uAP7eLgPXWbPeUkrufOeQ/Op8/ewc67is/Oa3nr92PmP
JsyLzl0shM83/7Z/qJ3mIi2hmBv7B1pIHgXkc22fEe6LdNo995EPHPEtdv/f
+Q/vcjnW
                    "]]}}], {}}, {
                  InsetBox["\<\"\[Mu] = \"\>", {-1.8, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["0.2`", {-1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {InsetBox[
                   SubscriptBox["C", "J"], {1.4, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["\<\"=\"\>", {1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["3.75`", {1.7, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {
                  {PointSize[0.05], PointBox[{-0.2, 0}]}, 
                  {PointSize[0.0125], PointBox[{0.8, 0}]}}, 
                 {PointSize[0.007], PointBox[{0.4463998339305619, 0}], 
                  PointBox[{1.2771956561278897`, 0}], 
                  PointBox[{-1.0806611991222994`, 0}], 
                  PointBox[
                   NCache[{0.3, Rational[1, 2] 3^Rational[1, 2]}, {0.3, 
                    0.8660254037844386}]], 
                  PointBox[
                   NCache[{0.3, Rational[-1, 2] 3^Rational[1, 2]}, {
                    0.3, -0.8660254037844386}]]}},
                AspectRatio->1,
                Axes->{False, False},
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                Frame->{{True, True}, {True, True}},
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLines->{None, None},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None, "TransparentPolygonMesh" -> 
                  True, "AxesInFront" -> True},
                PlotRange->{{-2, 2}, {-2, 2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.02], 
                   Scaled[0.02]}, {
                   Scaled[0.02], 
                   Scaled[0.02]}},
                Ticks->{Automatic, Automatic}], 127->
               GraphicsBox[{{GraphicsComplexBox[CompressedData["
1:eJx1W3l4zFf3R9E2b6JCSk2JVtEpsRQTkheHd7RPherU0rSpJ1RtNZQ3KKNa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                   "], {{
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[0.3], EdgeForm[None], 
                    GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxNmgn8l1P2x597n+yhIuuUNqKFSiGJVksqkla0KK0INZWIyBalskQylmRt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                    "]], PolygonBox[CompressedData["
1:eJwtl3m4llMUxc+73xtpUippUEpSKVJRpEGKIgkp1dWkSVEJhTQbr7GiAQll
jugxz0MpQkKPJDQJPSVJRYTfetb9Y91vrXPO973nPWfvtfetPXDUBSMjpfQt
KAA18pSOBNWylLqi/2XyAGgKL8XYcPhc5t+CP8DYZfB1jL0FP4ux+vC7GLsV
XpqxY9A/gQ/g94PF8AuYP4X5jehy6DvQU9FF6Orw9oxVz7yH+9F3oPsx9zb6
bPhqsAt9pNYwfzp6EXoVmAsfwlgH5s4E58OPDe+1JXoGfA5jC+GvMNYNPjQ8
1wL0R7+EHsZcO3Q3+BqwB300+iDmu4NW8HJgB/iR+b+Zfx9shW8Jv6vGiuCz
WT+fdc+hR8NHgXfha/X+8NNYU5H5w0Bf+PzwXGN0BXg71hyvvTPWCn4quB1e
n7E94BHWfKP1oCp8N2PL4TvAwegWrK/H2JdoXfZ09Ez0Ubo/9DPgB3glMADe
mfmmzCsu9vJnHyjIHAPn6/7AEvhAvSN8P+ikZ7GmJd9dGz5bPXMWvIixCfA3
GHsO/Wz42cvAcczdFT7rOqCmYgHdPTkGZsJvYexa+KuMDUbXA/8kx1Qz5k4C
xzD/InoRc79n/u0NoI/mQE94W8ZzeIBm6DLoQ+AlwJPoQxXTfL8QNICvYawB
c13DezsK/KdDyZ0L+o03wzGs2P0R3AfvFeZfgbHwGayfxfrH0G3Q5dGHo6uA
1uEY0N1XApeix6C7wWezvjK8EugM36kzZ/4p8L3eXeuZGwBWo0/XHeW+I91N
XXQ/eFvGGmWOoU3o7XzOZX4/2Iiuq5yAvwfOYe2gMG+e+SxOyR1rOpP+6Ct1
JvD75BvoNuiGmWN6NPp6dC/0AnRfeE3GBsD3gcvh4xjrwfxD6EL5DWP9k3Ns
A3xzeG/a0yr45+Az+DPKYXiW++7Kgnnoy9HnwLuA6uhPw2d1HnhFZ5H7bLag
h6GvQV+IflDPVHzDT4SXUA4yV0Hrk+/ocHi78LM/AXfDBzG2OfnMt8sbw+/6
ESit2MjtneUz55LuTHelnDoOPgIsTc651+CvC/DJ8lDWVw7n3s+gt7w0HLtt
FOPwg0Cf5D3Iq14Wkj1rcO531ru2Z/16+Hfh38qSc2eZYiA5hz6Grwy/2xPa
A3wqv3EFi59FP4h+F2yV/4I6zNUFNZh/AX0Dc9XAaeiVyd7cK/de5dE3o6eh
R2f2jKXhGFNsbUN/L+8J81x3prPTGcJPyrzXLrm59lxL3h72UsXEkLCHy7v1
ncbyytyxpphSLZjDmo6Za0J5+J2M3ShvYX5hOIYUO+vRE+U16MeVa5ljWR4r
b1VM34C+OpzLhegJ6P18Nkf343MS+h8+26IHZfbi51m/KdmT/8hcA1X7HgW/
ZfYseZViYjLf/5ex9vChmb3vEMVssgdOQU9CP40envmuIhzrujPl1i4+Kyfn
2N+Z32lg8Z50FwWsvyj5Tm5F3xv21vGZa3eDsPeohv9X/Ew9Sx50M/yesNeO
ZewAODS3dylntPeKub1N73CTahXrF8OvYuxudONw7hUphuAXqqbBT02uFWUY
m5JcM7rDa4F1yTHeU7Uj3K8oZxbAh+Wu9W/qTOC1w71IJzACXSd8t53RPdEl
c3t9azCGuV/DyaE9tM79Ha2Vp41ULuiMkj3mnfAz9NvKiSyc88p11cB9xTFS
WOwp6m36hPemHud29OxwLZyU2YsfU44me/Is5m8K59Y8eSx6Gvp59AOZe4nb
0L2Te4rHw54sL9ZvqLeZHvYS9TiKdeWwclcxr9o/Cj0/uQdQbbpGHp5co2ai
rw97wZzMvZ56BPUG6vm09i9QMvN3jsh9pjrLI0AP+ArVqGRPeBjeJBzr6lE+
hC8P9ybag3qp3+V3mXuq3fDfwMLksR3w5vJ8xaI8Ab4r7LVao95pQth71EOd
we+1z53bTdA7mbsOdEj+DfUC9cDu5J5Atf/g3L2ceoBbwj2mesvP0Y3CMVtU
nFP1VWsYuxheM3Mv+wv6QHJPe264Z1CvUBucAG8C/kqugdvkxeHap+80z+3Z
8mr1MJfIS3P3Huqpx4U9Rt4iT/oCfWzuZ+sdOsA75n5XxWiz8JnprBTTLeB/
hnsz3dmT4Z71/eQeQu/SJez1eqc7wz23em3FnGr9L5lrh2p+2XAMK3bVg3ZE
187deyvHlZulw72PcrRk2DPkFfKwUmHPkdcox28Mx7xiXZ4kLy3IXdvlqbo7
xaRiUXeo3lA5oVxQj6heaVvm2qGeSb2Oemj1zup55B3qgdX7ykNU+3dm/t9E
PcDEsOfKa+Wp+l+jUe5eX/9zKNca5r5L5ZxqrzxNXqYa/DX6xNy9lu54fLgG
yPuVA0vCHidvW5FcC/Zm5qoJVVhbNXfu6H+Yo+ElwrGnGjtUdxHu/VXD/oCf
HO5V1JP/D9awnZ8=
                    "]]}]}, {}, {}, {}, {}}, 
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwl1EeQVFUUBuBmKGDIUQbYwJAHxIDkHIacMwoKMyQRnCHHFQtAco5D0CJn
pIgqSUUKqFKrYEEWUHKOa79TLL7+zznvVtd7797u1Mzsnlm5EolEmo8bSYnE
b7TLnUh8INvLbTKDDupMuYPtPLX+rrzHf1ThPs/MJ1g7TF2VM3TWd6EbXdlp
Npzu6hGyh6wmv2GNeqTcRU1GMcnshe/drX4lp+i/Ve9lD1ksMcuWH/MHZynL
a+v3y3dyujVj1Qf4kV76cXHPfBbPRB2eM5Vlrk+TjTjHeS6QoLRrLeSf/MXf
5Ka8ebq8yCXmsspsjqwR70GmxXuI55ML5WB5SB6mD/X0veO7yEd9fQMuq6+w
lNX6JfIYP9GfxWb9ZAUKMke/Qn7OLxRhvtkAuYmv1WtiL+RqOUKekMVpoR4k
m8uv5EY2MCbeM9fUzWRTRlFRv5n1jNZnxR7xq74k6eo2tKQ1rShhfppiLNCv
k6c4GWdBnypHyqvyS5qo18ocmSMH0lDdmEYU1R+nMPP0q+QXrIx90BeSP1OA
7/TLZd/YZ2br88ujJDNLvzjOSJwNdV3qxLnmiFmmHEIGi/RD43zLg+Rlpn6e
bBv7Ec8uU+UMWS7eg0yRZSkT+0Zy3AN5yEfeOAe8inPMC+rykvE8oTaP+TT2
hmnWv3XWf1B/zydxls3emO1T91Q/lI94wEexX0w2f2lNGfWHLNLXijMb54SJ
+ueup6irs1CfJisxhHH6R66XVndU35T/8Dud9EPjnuVja26rK3OLf7kTz2K+
RW6N3wNj4z7NSsU7VF9Pev//9D+meY9f
                    "]], LineBox[CompressedData["
1:eJwl0ssunHEYwOFvZnSj6lC1YUziULqgLYsiLRJd1KELnUTjLHEB7YaSUIPR
1oKNYGHpFnoTFu2iEtwI2hlm9PnH4snvfd/PNxGjYf5z+lMsiqIdvsSjaC8R
RYuao4t/3JBnzLMyYuaHWsojxklSTx0Dnqd0Uw80q+/Y5ci+o206qmdMh3d1
Rtt5zrl9VlM6py94yYW9Qzv5YE4zxHeybiWaZItD+zcdpNHcTBMPwnP9ocP8
YcI+ybZ5Sp/Swqm9VZ8xYn7PW9bZdItrHb/5RY3bE+78UTc049bPWnjHXnSv
1j57pT6mioJ7hfa6l+sb/cq+eVVr+Wg+0deskLHfeu9n+I50zb5s7mEpvG/P
u5dotz2mifA7k3O/c4vCZ2iRQvi+3a/1L5e84irs7qt+dsF8HL//X/kPS7I+
pw==
                    "]]}}], {}}, {
                  InsetBox["\<\"\[Mu] = \"\>", {-1.8, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["0.2`", {-1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {InsetBox[
                   SubscriptBox["C", "J"], {1.4, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["\<\"=\"\>", {1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["3.74`", {1.7, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {
                  {PointSize[0.05], PointBox[{-0.2, 0}]}, 
                  {PointSize[0.0125], PointBox[{0.8, 0}]}}, 
                 {PointSize[0.007], PointBox[{0.4463998339305619, 0}], 
                  PointBox[{1.2771956561278897`, 0}], 
                  PointBox[{-1.0806611991222994`, 0}], 
                  PointBox[
                   NCache[{0.3, Rational[1, 2] 3^Rational[1, 2]}, {0.3, 
                    0.8660254037844386}]], 
                  PointBox[
                   NCache[{0.3, Rational[-1, 2] 3^Rational[1, 2]}, {
                    0.3, -0.8660254037844386}]]}},
                AspectRatio->1,
                Axes->{False, False},
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                Frame->{{True, True}, {True, True}},
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLines->{None, None},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None, "TransparentPolygonMesh" -> 
                  True, "AxesInFront" -> True},
                PlotRange->{{-2, 2}, {-2, 2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.02], 
                   Scaled[0.02]}, {
                   Scaled[0.02], 
                   Scaled[0.02]}},
                Ticks->{Automatic, Automatic}], 128->
               GraphicsBox[{{GraphicsComplexBox[CompressedData["
1:eJx1W3l4zFf3D/qiaQZVayh91RLUFsaaOmpU/SjyhFeVSGmtjaW1hCG1d5Ba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                   "], {{
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[0.3], EdgeForm[None], 
                    GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxNmgnc11P2x7/3fi2hDQlFmxYV7UpKqayRiFEhbaIkJVtaKISQrexUspOd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                    "]], PolygonBox[CompressedData["
1:eJwtl3nUUFMUxe9QKkmaU1EpRUWDRBNfA5oozZMoJVotqUxRkUYimYqIFKFk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                    "]]}]}, {}, {}, {}, {}}, 
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwl1EVsVFEUgOFpKa7BKe7uLi0UJ8ACtxYpLVpgQUIgOLQ4LQ7BdYM7rIAV
7u7uzpKEBL4bFl//c+68vkxmXlsxeVLviVGRSKSqH4+iI5HHvDQ/1Xf6XF/w
jFfhNd47f6NveU2FcC0fnI/NFokMNVfkJAn29nSkA5udDaOTebh21ko6kkxz
sm5hKymMd/bJfbeZtzOaLGejdAdjWGgfqzU5xWkK8cXv7dLvOsk148172E1X
e5p+pW64lnp8YzIRrzfRvzRlGlOc/XavwhpnP8NZzvHH+VTn083tKGFO0JKa
rpW1u1bSHlpFF2lf3af76UN9e+/we0TRwN6Q8+YLLAvsS/UQ2Zlj76cbKUUO
5jrL0qMcITfpzgboJpLMq3SwJjKE4/Z8xIdd43SwrmMto+ypXDO30dakUDZ8
f3pVW2nL8D1Sxp6X5eYrepkW5hGUNg/XS9pcmzGMWPtQvaiDwmdvXq0rdY0O
pFH4bmhMHvsxcjHfvlL7s4J59px6mBhm2zPDZx7eE7Ps2fQg0cy0L9Fe1DHX
oy6DOBDuGz6/8FmzOLwX7al7w/PCDHuGdgjfQ3juNVZnaHGN1yJajKLheSCG
7ESF90I03fjp2l/h2Q3PBD+YwOfw3vhEbcYx0fXfPH8bzOupFa519tXZTnMX
8wf9yHtqkEqa88+uKWiuxgJ7da3KiHBv+0evFwjPLxn2KlqOREbbX3k9v7mt
+bre4ET4G7An6Rh97Zpb5vLc5A63eeP8nt7nLg95wFvnT6L//z/6B9R2ilc=

                    "]], LineBox[CompressedData["
1:eJwl0slOFGEYheECEwZFEEVYIEMvFNANYMKcuGE0yngHXAA0DY0IAUQSEF3A
lhsAvAREFzJcD8jQNKM8f1i8eb9zqv6vKl0dGx4dHMmIomgV8cwo+vYgikZ5
A3XIlhs5ixu4EKcO5Mi5+CXv4Bku9Vt8w59dmzW34yfm8F03zx1Yxpq8xC+5
l/fQby7mAX6FKuzLg1zCQ1yNGhzIr/kN+sJZdOErpnW33uO5+Qt+yAvciVJz
GV7gv3tmeFHfjb/4IH8MO8N7oRwV2HWtkmPoMb/Hu/AsfNJd2VVk/oPf4bfS
PUFan+QpXVu4FxPyub6AW+U8zsdjpPSPuEX/kJt5EivmJD8NzzZvc1PYhXH5
zLlN8wkn5IT5LcYC8rH+1lyPq/CdcI1/+ovw/ZBCGuc40p/yGY5RG3bjUB+3
b8S8nnn/v7kDFsBFsg==
                    "]]}}], {}}, {
                  InsetBox["\<\"\[Mu] = \"\>", {-1.8, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["0.2`", {-1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {InsetBox[
                   SubscriptBox["C", "J"], {1.4, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["\<\"=\"\>", {1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["3.73`", {1.7, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {
                  {PointSize[0.05], PointBox[{-0.2, 0}]}, 
                  {PointSize[0.0125], PointBox[{0.8, 0}]}}, 
                 {PointSize[0.007], PointBox[{0.4463998339305619, 0}], 
                  PointBox[{1.2771956561278897`, 0}], 
                  PointBox[{-1.0806611991222994`, 0}], 
                  PointBox[
                   NCache[{0.3, Rational[1, 2] 3^Rational[1, 2]}, {0.3, 
                    0.8660254037844386}]], 
                  PointBox[
                   NCache[{0.3, Rational[-1, 2] 3^Rational[1, 2]}, {
                    0.3, -0.8660254037844386}]]}},
                AspectRatio->1,
                Axes->{False, False},
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                Frame->{{True, True}, {True, True}},
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLines->{None, None},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None, "TransparentPolygonMesh" -> 
                  True, "AxesInFront" -> True},
                PlotRange->{{-2, 2}, {-2, 2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.02], 
                   Scaled[0.02]}, {
                   Scaled[0.02], 
                   Scaled[0.02]}},
                Ticks->{Automatic, Automatic}], 129->
               GraphicsBox[{{GraphicsComplexBox[CompressedData["
1:eJyNWnlU1FX7p0xNcswFt8ktFxpX3Eiz7Emn3LVxqUxtLDVTR80lNczXNG0k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                   "], {{
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[0.3], EdgeForm[None], 
                    GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxNmgnYl2MWxt/neYdU2owoWwtKatpVlBYkW6GUohSSpMkyWbKULdIijISs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                    "]], PolygonBox[CompressedData["
1:eJw1l3n0T1UUxe87L5EMpVKa+BEZMpY0GMuQiJCEaECDEhkiQ2hQq6wmJZVU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                    "]]}]}, {}, {}, {}, {}}, 
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwl1FeUTWcYxvEzIwhRo4YZY2YEI+oIg8VauGAEI6OOXm5cMWrCWmaIXrLU
xI2SREvukYQg0Xv03oJLPbogfu9y8T//53nP3mvv/X37nPRRhb3HJiUSiTQf
fyQnEhvRokQikc9D+KL5TrkyduBP7MIl8928B39hH/bisvkBPoj9OIxDuGJ+
lI/hCP7GcVw1P8mncAIf4zSumQ91/d5yFWxCtv6/eUteqvfB53JfbsVVeQCm
y/15GQrwtT6Qa8YzYYY+mJdjKKbowzgFP+MXJOMf1/qOb/Mox4yQV+J75Oht
cEmui4tIj+fHaNxFQ9xBFu5hDJKc05wT3CKuw4VcmltxKW7NH/KUWA/uGOvP
nWItuCu6YLW+BrmoE3P+CE/cb5peF5v1LbEmKNKL+Ue8cMx4/Qt5MWahWJ/J
6/Cf7yfpPeQl+FKeyz25F/KwQX/juKZyMzSJ78wWYgEGxbpjm9yYP0MBKsY+
8e/ciLNiv1BB78e/xdpxg9hblI+95l+5Pn8a7wXK6fm8lfNQT57HM3l+3Gvs
iZyJDLx2r+vNXvFEfY7cHbMxQX9p/pP8nMfp38jd4n1Bof7M/Af5KY/Vi+Qu
qC2nIiXWC2vjvFhb5GJaXIc78yo8dv4YfarcBmXkHC7L47gkt+QSnM0fcAe0
xyP9X9zHQzxAW/N2uCZnxm8NGfHbwkhcQBrOx3uC4TF3/C338a28CKkYYXbT
bIXcWj7L53AmnjH2M841v+GYJPkTfKXX4hqxdximX48/FLkaJuvVuVK8Qxis
X/D9WzSXtye//995B+W1hQY=
                    "]], LineBox[CompressedData["
1:eJwl0klOFGEYBuBiBmVagCA7E4YEBDZsAJWhmwtwBOhGpkCQKYAbD0BYgt7A
gfFAoMwio4oyw/OHxZP3/b6/qlKV7hddw51DKVEUzZFIjaKptCjqlvNU8Jca
/lBNGj/dcC7/8YWvZHBs/1Geyn7PGdEb+cQ7ZuxGZVPofDBPyyIZkyu06zky
Jot5xqo5Lp/IDllCKWvm57KMeDjjFRMM2J15jyx9jPfmcdnMUz2PXH67ZlBO
2r9miTfmFtpoJZ8Clp0VyuxwDS00MESf/YlnZeqLfOOeO47se50P6vXh3Xhr
PrS/0W+55JorftlfyDr+U0s/0+7pk+nhO/TP8iW99JgP3Leg78ukuUevIknC
vGd/oFeyF37HcC279jsh2WSbLXbsv8sfrFPORji37/a8Ln029fF/8wAkP0pM

                    "]]}}], {}}, {
                  InsetBox["\<\"\[Mu] = \"\>", {-1.8, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["0.2`", {-1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {InsetBox[
                   SubscriptBox["C", "J"], {1.4, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["\<\"=\"\>", {1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["3.7199999999999998`", {1.7, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {
                  {PointSize[0.05], PointBox[{-0.2, 0}]}, 
                  {PointSize[0.0125], PointBox[{0.8, 0}]}}, 
                 {PointSize[0.007], PointBox[{0.4463998339305619, 0}], 
                  PointBox[{1.2771956561278897`, 0}], 
                  PointBox[{-1.0806611991222994`, 0}], 
                  PointBox[
                   NCache[{0.3, Rational[1, 2] 3^Rational[1, 2]}, {0.3, 
                    0.8660254037844386}]], 
                  PointBox[
                   NCache[{0.3, Rational[-1, 2] 3^Rational[1, 2]}, {
                    0.3, -0.8660254037844386}]]}},
                AspectRatio->1,
                Axes->{False, False},
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                Frame->{{True, True}, {True, True}},
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLines->{None, None},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None, "TransparentPolygonMesh" -> 
                  True, "AxesInFront" -> True},
                PlotRange->{{-2, 2}, {-2, 2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.02], 
                   Scaled[0.02]}, {
                   Scaled[0.02], 
                   Scaled[0.02]}},
                Ticks->{Automatic, Automatic}], 130->
               GraphicsBox[{{GraphicsComplexBox[CompressedData["
1:eJyNWnl4zNf6j6WWMHbRO9UU1zKWll9qFMWbNqqlbkzVj15l7EQH0VCEWMtU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                   "], {{
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[0.3], EdgeForm[None], 
                    GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxNmgnYl2P2x5/7fsJESCWkVVGIEtpXqYRWpZSlEFkihSFRlKXIEE3WsvQ3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                    "]], PolygonBox[CompressedData["
1:eJwtl3f4jlUcxp/nHCqjiIwiKyM7I6sfki2UlYifkWRlpJTQFl11hSTaLhrG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                    "]]}]}, {}, {}, {}, {}}, 
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwl1MVTVXEYBuAL2N2BCHYrijHO6MJuUBFbN+pYCKgzjoWdY+vG7lyqG7u7
WxHjH7Cx2+c3Lh7e7/3OueeeW1QfkZWaGRWJROL9ORMdieyicUwk0oRe5mSK
c5YSnOOBcy/Ii5znMpd4aH9VXuMKN7jOI/tb8jY3ucsdHtvfD9fjHiXDNXhi
P9Dzp5hLsZtE/Zd9U7lC700zcx+ZJEvLfsw0p8qVpDFR7y/LM4hsfaBcxWAm
6UNkZfawl33keq418qUc6pyh5nWspYXeklxzHE+pyjNG8ppavKI2bxhPlMc0
khHZWEbLDFlQNpMFZJIsJKeG1y7bhPdFtpWlZXvasVHfRAeqhH14HO/db5ze
0XyEo8ximl223Mon54zTO5uXMY/p+ly5na+OT9C7mpfT3bxQdpHdwp6d+g/n
NTA3pD497JawmP56GqfM9WRd+lFUT5UnZR1Zm74U0fvIE+G9kzXpTWE9RR6X
NWT18L0kmZ7hOTkW7pFFZOjf3Ve1cK/hc5EJxPPNfofdF5muLwivifnh89E/
228zf5Rj9TnmTsxmjJ5nv8X8QY7WZ5rbUckcS+XwnrLZrqPsRAdm6BtYz1uP
PSwPcZDmZDHFeZkyv0yUMeE3KPPJdNlafpB54Rrhc+YdrexHhe8pCTwnnhcM
Y7Ljw+UB9ofvCjnhPPfxl6XmWIY475m+OtyT+XH4HfIovD4GhN+L/VPn/KFC
uG+9oixH3/D70nMc+00ZPVMvK4vRM1xDv+/YTxqZT0f//5/zDwhihoM=
                    "]], LineBox[CompressedData["
1:eJwl0rdOHGEYBdBZoogFsSVIBNNQkOM7UBswS7Ili7hEiQegQyK8A7nA5m0s
gslBFDbJ2Ibzi+Lo3u+b/Uc7O1saH+0aiUVRtMRJUhT95JRDyyN5zAElYRe6
/cfkKOrRF/nEpLlXLlPKbyr5RQURJ87dywc22CSJS/tVeS373WdMr2ONcabt
JmQ9cyyYZ2WebJd7tOtpskPm803/zrx+577peqdeQCH75iJZTEe4RiNTDNjd
OJMSnosZc0I2kKFnkcmtzwzKafsmdmg2t9BGK9nksOtarkwNn6GFWr4St79y
r2R9my1e+c+FfZ/rX/QaPoff23xu/1f/xzMv/OHM/kl+4JFqhkk4MyRj4Tn1
dVnFIL3mU+dWwruXPea4Xk4f3eZj+yu9jPPwzsJ348j+TP6Ivf933gDysUrt

                    "]]}}], {}}, {
                  InsetBox["\<\"\[Mu] = \"\>", {-1.8, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["0.2`", {-1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {InsetBox[
                   SubscriptBox["C", "J"], {1.4, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["\<\"=\"\>", {1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["3.71`", {1.7, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {
                  {PointSize[0.05], PointBox[{-0.2, 0}]}, 
                  {PointSize[0.0125], PointBox[{0.8, 0}]}}, 
                 {PointSize[0.007], PointBox[{0.4463998339305619, 0}], 
                  PointBox[{1.2771956561278897`, 0}], 
                  PointBox[{-1.0806611991222994`, 0}], 
                  PointBox[
                   NCache[{0.3, Rational[1, 2] 3^Rational[1, 2]}, {0.3, 
                    0.8660254037844386}]], 
                  PointBox[
                   NCache[{0.3, Rational[-1, 2] 3^Rational[1, 2]}, {
                    0.3, -0.8660254037844386}]]}},
                AspectRatio->1,
                Axes->{False, False},
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                Frame->{{True, True}, {True, True}},
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLines->{None, None},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None, "TransparentPolygonMesh" -> 
                  True, "AxesInFront" -> True},
                PlotRange->{{-2, 2}, {-2, 2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.02], 
                   Scaled[0.02]}, {
                   Scaled[0.02], 
                   Scaled[0.02]}},
                Ticks->{Automatic, Automatic}], 131->
               GraphicsBox[{{GraphicsComplexBox[CompressedData["
1:eJx1Wnt4zEf3j8tDG120FA3VUo2Ie3S1WpywquqWbWgRrMrbKKKo1iWaF0WW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                   "], {{
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[0.3], EdgeForm[None], 
                    GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxNmgn4l1MWx99730jZDSqikorSoiLaQyRtiqREIilhKCVrUtFGwtirkSaN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                    "]], PolygonBox[CompressedData["
1:eJwtl3m0T1Ucxc85V6HEUhSZS8KrPK8iIcoUkplEolRKSJrLqlatpEFF41oa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                    "]]}]}, {}, {}, {}, {}}, 
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwl1EVzFVEQBtBHcJfgBJdgOwoLGjxoCLDCvYoq3J3CYYe7LoEN7u7u8gdw
d5fTxeLk6+6ZeXNn5lYqDxqdNSpbIpFI8edwUiKxkWrZE4nqtFG3JSdHyMVR
rjr3uDzBMU5xkmvmZ+RZTnOec1w3vygvcYErXOaG+bU4Hr9J7phx07yz+7dT
52ETNfSfzFPlfH17aqo7yFoyr+zEGHVHuYDODNV3kQXJZKy+m1xId4bps2Qx
NrOFrdxxr8Xygcx0Tg/1UpZQV39X3ovzKMF9evOEcjwmhacM4hvV+RrPwvdY
G3+ozW/q8JfR8S7co16883g28lCfFWYrSYs16xvLBM+sM1nfRL2bPUxkpNkE
uYZXzumnb6aey1RG6afIdbx1fKC+hXoezdUzZJO4hqZs0H9wXmV1FSrRymw2
s+ioz+CguqKsEN+I7PHN5AFZXqbE9yUp9pjcH+9Nlo19RzZ9a7lPlpGlSY97
0TLWyF7H0pkZ71j/3rpKxXF9cVmSErwzX2/2Rg7QT49nYxr99a/N16pfyr76
yeqmTKKP/oX5avVz2Vs/Xt2IIuqGsqhMi2/BKn1D2YgGjNMvZ1nsDdfvkjvZ
EfuI4Yxw3jD5K/Y0P0jlJ4N5QYX4xvHuYh2xLh5RKvYoJXlIz/hNv9dLbmdb
vAtux351/6/MUSfTLfaxflHsQXUdbsXzcDOej67B/LbzvlBIP0RfWBYggy5x
nWOfyRdr1ueXOeIb0kl/xbGPVFUfSvr/v+YfnrOEYg==
                    "]], LineBox[CompressedData["
1:eJwl0rVOBGEUBtBZpEFboIEFGgpc3gOXBA0Fbm9AjSzvgBfIyxBscQgFrsHh
TChO7ne/f2aymZ1oz2jdSCQIghiHCUFwwBE7yn0zzi5Z7LGtr00MgiZ5khb6
7M3mFNPkcUUub66Pcy3fsMAiH7oTZuUzs8Uz+uQ5YvQzqBswixlnwj5mpphV
5hoV8o/7K81U1nUbjMqX+l+q5DTS2XSWYWZSLddQyjCtunPXfzFoH7IPmSUE
cgIRLpy3mSP6MlbCa+yllFNGIkmsOks2v91THv5eiuilWX+q/2TZvsQrLxzr
mpx3y4V00Wg/0j/Jz9zzyAOH+juzgFvy6Qzfo3s6zHfnxfK8HKWdBvuBfkbe
N+vtbXJO+C6os+/pz+VsTsL/itPwm9Afm1uR/+/mDxLqTio=
                    "]]}}], {}}, {
                  InsetBox["\<\"\[Mu] = \"\>", {-1.8, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["0.2`", {-1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {InsetBox[
                   SubscriptBox["C", "J"], {1.4, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["\<\"=\"\>", {1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["3.7`", {1.7, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {
                  {PointSize[0.05], PointBox[{-0.2, 0}]}, 
                  {PointSize[0.0125], PointBox[{0.8, 0}]}}, 
                 {PointSize[0.007], PointBox[{0.4463998339305619, 0}], 
                  PointBox[{1.2771956561278897`, 0}], 
                  PointBox[{-1.0806611991222994`, 0}], 
                  PointBox[
                   NCache[{0.3, Rational[1, 2] 3^Rational[1, 2]}, {0.3, 
                    0.8660254037844386}]], 
                  PointBox[
                   NCache[{0.3, Rational[-1, 2] 3^Rational[1, 2]}, {
                    0.3, -0.8660254037844386}]]}},
                AspectRatio->1,
                Axes->{False, False},
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                Frame->{{True, True}, {True, True}},
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLines->{None, None},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None, "TransparentPolygonMesh" -> 
                  True, "AxesInFront" -> True},
                PlotRange->{{-2, 2}, {-2, 2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.02], 
                   Scaled[0.02]}, {
                   Scaled[0.02], 
                   Scaled[0.02]}},
                Ticks->{Automatic, Automatic}], 132->
               GraphicsBox[{{GraphicsComplexBox[CompressedData["
1:eJx1Wnt4zEf3D21dwqKoy1ZDFe9SSrHErUctoaq1bdO6NL91aUWabemriijq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                   "], {{
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[0.3], EdgeForm[None], 
                    GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxNmgn4l1MWx997X1opRGVr16K0qiFatWiVhCSpJEvIEqmkFCrZQ2PJMCRh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                    "]], PolygonBox[CompressedData["
1:eJwtl3n0V1MUxd89LxWSRtE8KRqlhGal0dgkqp/oJ0WpTLGItaxFaGWoTC0a
jCsZMw8lmjQRGRo0iZJkbEBRPtv+/rHX3fue+977vvvOPWd/6wwd02d0ZFn2
BSgBzsyz7CYmPodvBTXg+0HFlGWVwBrQmzXdGJsRb0esPbgPzlQ2En4t8TmI
59Hz0Evh8+H7QVf0GOLPMTcVXRf9D6iCPh5UINYS/Sqx1eAwPDFXjdgc9HD0
JeiL0S+gX0KPRs9A/4Huj94OjkI3Ab+BtWApsXXgK/h3xEsxtkCfAx/G9bej
a6AvRQ9A90fPRrdF3wK+hjdk7iP4x4wfoP8CnVjbEbwFXwO+JtYXfS5jO90f
3gu8l/key7n+MLEp8AWgPvpysAJeVXsGnw1+Qf8KesDP5/ouxB5DP4V+GuyA
Pw3ehB9PvD7xd9GN0Uega6JrgTfQx6Hrwd8hfhL6ObALXl3vAV8YfpcHwVr4
sWA6fAlYz5pf0OUYO6B/1P3ALPgy8Dq8EvevS/xt9EF0bT0j8zt1gZ9HvBPx
h9Er0Z/om8MfAhOUa8QWwTeCRdpfcAA+GbwLnx/OnQfAWPgo7jcxOUduQF+D
noR+Dd0U3SycG0WgIvx7cGRyTtys/Wb9yORv1kRrwe/w2szNgs/UNejtoBr8
Z1A2eQ+6wa/g+lvg5fX90fXQjdCl0APR/dG90c+iV6FXwh/J/M4D0P2In8/c
M/rmyme9M/xY5Sl8WXJuaA96oceyfjZzj6JPRjcK52ZfcC18MPEi4nP1fRgv
Q49gvAt9FvFi9Dh0aXR59FZQMvkM3AgfQnwY/HXiJdFD0aN1FtE/MF6KLma8
Vc8k3gfdEz0TfQ/6bnB65m/4DfMXEe/L2FVnWHsfzt2PwCT4ZmIr4ZvAH/CN
YHnmnL5ftQRckHnNVfqtuXO5BShGX42+M3nNEPS/4drRHFyt5+X+lgOV0+gH
wEXwT8Au5qeFa9sEMD5cw1S71oIT9G6gPRNfocvBTwOnoj9Ft4SPCt9rM/hW
dSl8VvWMjPhW5lZlrlnDiI1kbgL8wszvqj3Qu+udu+Y+ozqbbYhVRp8Nzkw+
s11ynzGdrTOSYweSudZURJ8FTk8+g8pV5ZRySTn7K7gN/QTXN9IeJJ85nbWF
oIXOPnPr4a+AKuGaqVr5FGjFvaeG31V7MBk+Jby2GNwLnxhe2zZzrt+B3pA5
5z9VHqK/yfwb9Kzvkmu7nvk9fBDPGMQ4VjnAWIS+jHE8ug58d+FsbQP7uNfe
cG7tBHt0zsK8F3gx3BPUCwaBZly/P5nrjE8nNiP87tNACeL7ks/SbnBBuAbo
7C9WDQzXJNWiv8H74ZqkWrQPHFJdRc/L3AOXoN8LxzT3YbjGqrb+mbl3LA7f
Sz1EvXFBOKYe2Tl3T1Ev0TfdRuxbcErmM6taVgkcnVzTyqo3hX+ravbn8GOA
Evoww2fw1cnf/l+wBv1FOKYzO05nE2zJ3PNV+8qE16oGZvAV4MPMPaujzgo4
mHlufdgTyAvkhV77k+5R6Lm7o9CzMs9V1rcK95ZZ+n3MbUKXSH7HDcoVEDrP
6HXwcuF7a64be3Mw+ay0BVVyz4mrB6pXrirULvVMeYt64IRkj6Heqp6rXqse
u0P1Uz0jeU8vVi9gbJpck78Mewp5Ce1pLfiBcO9Tj1NuN+CZjZNzXF6pJqic
7JlGhHtu9UJNOJq1ZcBe+GDQPFxjVFteAi/r+6HrJK8pm7unqZdpLtB57lzt
o/pJbA+oQKwjujSxUrnPpjzAyfAnw71G73QoXFNVS7UnHeC1c9e+9zPvxZ9h
r6c9Ue/pGfZG6kF94MOZuwM+I/O32xj+ViUKZ78m8ZOSa8Bf4Rqt2qw9qUWs
Ru5naU2bcM1VrZVHkjdphD4l2aM0hTfJ/a6aa5i7p6iXaM9PlPfJ7SXVg6vm
9mzyag1ANXT13HxS5tx9PFxLlMO/q96FvU2FQi2SIda3UE1Sr+8e7r3q+eql
ncPeRT1VvbJU2NuoZ2pveodrofZIveqKsBdWz5LXPDdce+Q55YXPDnsJeWJ5
pRXJvVqeqZ3eJ/dvb43uAf9H88k9qntuDyjv9/8cukPutW/qjMP/hrcErUBr
9Nxwr9eczr7WKKYaIG+9pdCr5LHlrbcl56o8trzXmLAXkAfTf4ELw7mg/wTq
/YPC3kceQF56U3JtlqeWV9leqPVFhVp/Xdi7qObLW8ijy5vLY8jbXR/2MvJ4
8tb9wt5DHltea0Mh9+W51GuvDP9XUM+V11PPV6+X55M3OiO8N/JI8j47C71G
Hkhe57Swl5TnkVdbl+zl5dn030YeQ95C/3H+AxzjoMI=
                    "]]}]}, {}, {}, {}, {}}, 
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwl1EVsVFEUBuChheLuWqRIwgIrXrS0OCUksMGLJCRAcSe47HDXJbDB3d3d
1gT3HW7fCYuv/znn3Tfz5t6Z1srN6zc+XyKRqOlP9eREon2SWs6Wc8igHb9d
Pyr/yGPysjwhT3Kc05ziivlZeY4zXOA8V80vxX1cjD7Wcs38uvwrr8kEN7iu
7+U5OqjzsYVa+g/mteVCfUfqqOuSRpI+izx1F7mIbEbqu8oC9GCCvrtcTE9G
6XvJImxlG9u57b2WyvuyrzW91ctZRgP9A/kwrlOcR/TnJWV5QTleMYivVOcL
NfjG0NhbavMrPk/sMWNI8R4N47llIQrShFVmq2lK6ZjFa3nG55TRN9PvZV98
Vsaa5cl1vLZmiL65eh5TGKefLDfw1vVh+lbq+XH28Z2gDRm0ZbP5e+uqqqtR
JeZms5gZe6rvwRF1GyrHftONX+7rKg+bV5IVyeaneZY8ZF5Blo8z5Id5pjwY
eynL0onOdIzvBwdca80MhuvfuWeTumXM9dNlKzlNboy5+rs1LeR+fQumxlno
35ivjzOTg/WT1OlMjDPUvzRfG2crB+rHqxtTUt1Iloq9JZ01+mZybJyVHCdX
soJn7t8jd7OLtHj2OHfrhsmf1OQ7qfxgcJxP7E+cI+V5wwCexjPwmBI8oQ+j
vV6O3MkOinGPu97/M3PVRcmx7o5+ibqeuj531YW5QyG6xWua37LuEyn63Phe
yvxk0lt/w7WPdNKPiLOSydyM3xS3onZ9QfwOXE9N/v+/5x98sIhT
                    "]], LineBox[CompressedData["
1:eJwl0scyBFEUBuAebMTCRtxYyPFRDINBlYVcVFFewF5+BnkhPIuSc9zJ2ZLv
lsVX55z/9u073T1lveMtY7Eoiha4SImicy7ZE56qZxyTywm78nhqFDXrJ2lh
yBxXp5imkHsKeHX9EQ/6R5ZY5l12zmw4T026R69+njn6GJH1q+WMMmEeUdPV
OnWDBv23/Y1qBpuyLcb0t/IfmvSZZLFtLVvNoT7spzI8A52yK9d/MhDONA+q
FfwSM0dcW+9Sh2VVrFFjrg33DL+NFFJZt5amftlTHa6jjB465BfyD1bNK3zx
Gd67rN16t76ULtrMp/J3/QcvvIV3HL6N/Fkt4Yni8DwM25MM14Xz9Yv6onA2
CfOxfEZ/qLaaE/p8WsO3NR/I7/R5XHPLDfvyK3Un9v+/+QPfvU0U
                    "]]}}], {}}, {
                  InsetBox["\<\"\[Mu] = \"\>", {-1.8, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["0.2`", {-1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {InsetBox[
                   SubscriptBox["C", "J"], {1.4, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["\<\"=\"\>", {1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["3.69`", {1.7, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {
                  {PointSize[0.05], PointBox[{-0.2, 0}]}, 
                  {PointSize[0.0125], PointBox[{0.8, 0}]}}, 
                 {PointSize[0.007], PointBox[{0.4463998339305619, 0}], 
                  PointBox[{1.2771956561278897`, 0}], 
                  PointBox[{-1.0806611991222994`, 0}], 
                  PointBox[
                   NCache[{0.3, Rational[1, 2] 3^Rational[1, 2]}, {0.3, 
                    0.8660254037844386}]], 
                  PointBox[
                   NCache[{0.3, Rational[-1, 2] 3^Rational[1, 2]}, {
                    0.3, -0.8660254037844386}]]}},
                AspectRatio->1,
                Axes->{False, False},
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                Frame->{{True, True}, {True, True}},
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLines->{None, None},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None, "TransparentPolygonMesh" -> 
                  True, "AxesInFront" -> True},
                PlotRange->{{-2, 2}, {-2, 2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.02], 
                   Scaled[0.02]}, {
                   Scaled[0.02], 
                   Scaled[0.02]}},
                Ticks->{Automatic, Automatic}], 133->
               GraphicsBox[{{GraphicsComplexBox[CompressedData["
1:eJx1Wn18y9caN6wzBNe8hmGGZYxVJzaGBzHzMpP1brbZFvRaV+JtXhfjDrVw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                   "], {{
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[0.3], EdgeForm[None], 
                    GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxNmgn4l1MWx++9b/YkRbZBi0pSKUqWFhXSRtqIlOzGmuyUbFHKnj3EUExI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                    "]], PolygonBox[CompressedData["
1:eJwtl3nYTlUUxe/dVx9NihSZZ/oUGQpRnkRl/nxkyJRIA2UqFJVKE80ZUsRT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                    "]]}]}, {}, {}, {}, {}}, 
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwl1EWMVEEURuGGwX1wd3df4DA4g80MvoIEdxIS3DW47XC3JbDB3d3ddgR3
WPHdsDh97n9fvX7VVfW6wpDxaeMyJRKJij5qJCUSnTMnErV5MS9BR3RCDpxF
TpzDLeMv8EWcx2Vcwm39q3wNV3AD13FH/1Zcx03cjV5Y/z7nwj3kRldMN4cu
/AB5sAd19H4ZX5dXyd1QT90A9ZFX7oUZ6p68Gr0xQU7jAuiDmXIGr0FfTJT7
cRHsxT7sx0PPWsfrMQCNjevPTXgDN+UX/BLPURyvMBhfUBafUQ5fMQJJ7qnO
mbkGZ+HRsa5cJ9aZ68Z68GQuyE05mQujEFpjs9578xuqbqFeFt+ND3pl9Fqq
j+JYrAem6E3nbTE3Y0bG96iXYw6myrN5B765Plpup14R66xOjbOBrrEv2K3/
07hq8XtQBR30qvIP/bG8SO7HZ7g9Kqv7og+yyxl8mitxRaQjm5zGp7gCl0dv
ZI295ZOxnlw29hgL5R7cHSfUKViAMfJ389ilbhtnWJ4f55nn8U50UGeJufFx
boO5GCV/de/22D8eIc9St4qzg+HyJ/2t6o88TJ6mbo5S6mZcmlNiDbEl5sBT
4hk8lTdhI965/wgfxqE4zxiLycaN4exci7NyTc7GI/lHrE/sFcrjO4bgLUri
NUrgDQZikvsG8UEcQDE8w2PP/4ul6qIx1rhH8lp1Q3UjPFUXxhMUQnq8D/oP
jPuDZHmcXJDzx36gv3zPtd9IlcfHHnG+eK/iuXiE+66v5JrxO5P+/wf9A0Fl
hYM=
                    "]], LineBox[CompressedData["
1:eJwl0rlSU2EYBuCTUKJgAypIoWwNBS5MQMCLoGULyDJjQQQzcYaCC7CxA4Vr
ULaC5VIAZUsCMSwdm0B8/rF45n2/72xzTvJ8ONUzEYui6CuFeBQd84cdy7w8
IkstObbte8uiqE//wgCfzP1yljnqueAFf52/x6V+xU8WubPL8T08Qw67x4S+
wDwpMnYfZSufmTFnZJVMyDW69JjsltWs6xtM60X3jevv9Mc8YdP8VNbQrnfw
KrwD7+2OXVNiMjzTPCVfUq4/5AEFx0dk2v41K7SbO+jkLRVUsurYIxnJN7TR
wgeG7PPudc+yeYlYOJesXVKO2zUzxqD5MJyvl8K3Dd+RWw7sb2QT1zQySto1
I+EcxxP6D70hvGv47cz79t/0XdlvTup14Vn0mX/bn+vPOOGMU37ZF+VW7P//
5h/TCk2E
                    "]]}}], {}}, {
                  InsetBox["\<\"\[Mu] = \"\>", {-1.8, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["0.2`", {-1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {InsetBox[
                   SubscriptBox["C", "J"], {1.4, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["\<\"=\"\>", {1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["3.6799999999999997`", {1.7, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {
                  {PointSize[0.05], PointBox[{-0.2, 0}]}, 
                  {PointSize[0.0125], PointBox[{0.8, 0}]}}, 
                 {PointSize[0.007], PointBox[{0.4463998339305619, 0}], 
                  PointBox[{1.2771956561278897`, 0}], 
                  PointBox[{-1.0806611991222994`, 0}], 
                  PointBox[
                   NCache[{0.3, Rational[1, 2] 3^Rational[1, 2]}, {0.3, 
                    0.8660254037844386}]], 
                  PointBox[
                   NCache[{0.3, Rational[-1, 2] 3^Rational[1, 2]}, {
                    0.3, -0.8660254037844386}]]}},
                AspectRatio->1,
                Axes->{False, False},
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                Frame->{{True, True}, {True, True}},
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLines->{None, None},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None, "TransparentPolygonMesh" -> 
                  True, "AxesInFront" -> True},
                PlotRange->{{-2, 2}, {-2, 2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.02], 
                   Scaled[0.02]}, {
                   Scaled[0.02], 
                   Scaled[0.02]}},
                Ticks->{Automatic, Automatic}], 134->
               GraphicsBox[{{GraphicsComplexBox[CompressedData["
1:eJx1Wnlc00cWZ9WllBpFt/VIXU+08T4qVq31aWN1tdVGW7seNR71jq2tVWtY
pV6N1Wq1isVb8SpVBOstRp4nCh4FigSPcgZERIEAIR4162b4TvYzfuCf+XyZ
+c28933HvJlJswkzh02q5uPjM6+6j8//2qtHWjUItWVy8vENwzS55dy25uV7
9qAUiV0x/qssjhiJrQITcCMxXuILYj6Ju9eNNNoMD/mbcRULrRYHL/5s2qmg
0LsSY31grA+M9YGxPjDWB8b6wMFiPYk7CXkkRgs51RbyAkNeYMgLDHmBIS8w
5AWGvMCQFxjyAn8t5KWqeFXlVlvIDwz5gSE/MOQHhvzAkB8Y8gNDfmDIDww/
Uf1A5VmVG1htoQ8w9AGGPsDQBxj6AEMfYOgDDH2Arwt9qKq4Uv1c9SPVLpAP
GPIBQz5gyAcM+YAhX1Vxrsad6teYDxjzVZUn1LhV4wLzAWO+qvKMGvdqXKl+
qrbgDxj8AYM/YMgHDPmqyntqHlLjXI0b1e9UO4NXYPCi6gGsttAPGPoBQz9g
6FdVHlXzlBr3atyofgp9gKGPagdVbmC1hT7A0KeqvK/mVTVPqXGuxhXkB4b8
qt+oPKtyAqst5K8q76t5VM1DatyrcavGnernql+ovKpyqnlPzTNqnlDjXI0r
1Q+zPeNv8UKPHBX8hme8nQM9bRnf8/QnyH4fz1+sFfiK6CfgZDGfxE3EfIT5
/vT0F8j5EzzyFMsW/KP/hhgvv48T4wjj1XmbCkzqOtAL/cDIL8CQG3rj/+AJ
+qq8gResi++hDzD6MR58oR/6qbxjXXwPjPHAUq/KedGiHy3+D35UO4F38IV+
YPTDDpBDbVW7qHaoal5g8Dxf8CB5AQaPwNAPGHoCq3ZHPIFnxBMw4gkY8aT6
N+ZDPINHtPAD6AWMeaqSA/yp+5TqH5AT46uSG+uCJ8wn/aJSD9UfoBfkV/cn
1b7IL+p3mFfNZ7AP9ASGHsDQAzjYkyez+VfN35aFW53cqXbPQKP+HnfxjLvA
FeM7NTZrnteLnvVyZYv/pwjMTwTmWWI+wnwYj360+E6dB+u/KtaX32Ee9TvI
v0esR1gfGPwjDmAfYMhp8fBhk+tv8/Tvk7wjTrCvAEv/rYwTYPCMeEQ/MPoh
n8w3lfIBQ772nn0tXcYz1gFW/Rr9qpzAGJ/oaRP5k5NJRfEml7Q7cL1THh4k
Bi/AsBPwWTGfxOATdtQJLO0K/d4R+rGat9R9Fq26r2Cfxzxo1X0I+qsY30M/
VR7MA3mA4WfgERg8Qn/wqNoNGHEM/8V88Htg+A++B1brGugFebA+sOrfyF/4
HhjjYWdg2Bn2+0bED8FPMR76YDzWg39jPWDwjnkgJzD8B/EPXoYJf5N6AkMO
YOQPxBn8UM3D8Ac1z8i8XInRD38CP7AH5IY/oB95Glie+yvtDb7Qj3wBeWWd
XulfkAN6SLkrxwFDDvABOYDBNzDkAoZcwNgvUcfgPACcd3r+Jbe7iHf4r/5A
F10i/4/vcP4BHnJs7FGDsZRXTL5dHhVeKONWbeU5rtIO8Bu1jgPGePgDxsPv
EE/gGRj6Yn/AeHlfUun38EPUbfgeGOPTBR9yPPYT5JMtgidpJ/RDD/RDD7VO
lef+Sgz5ISf8G/kffoE4hX2QV2AfYNhnsbCPHI9zF+wMPWFX8AD/AIZ/QC/8
H+sBY36MU+cHT/CbQULOF+YBlufVSj0wHnarah+C3yAuwXNVeQ3xj/FqnIAv
8AA5MQ8w7Ao/wL6h1qGQt6q6Rz23qHWHGpfgE3ZXzy2qn8BO6IedoKd6rlH9
AnZBP+wCOfB/6IV8B4z8jnjFeOgp73UrMcYjPtQ4wv8RR8gr4B9YvZcAL5Af
fgZ+oDf4gV9DT/CFFv+HHPBDyIcWdsI+Cb/COrA78iH2E7Xewb4A+bGvYj8B
T9ivsD70k3xX6o1+5EHwBzsh/2Bd9CMPoh/7EfqxX6EfPIIntIhDrKfW1cCQ
V81zsAPmV/MW7IN8Cj6xP2Ed8I+4BVb3d/AFfwKfWA/98DvMg3Uwjzy/Ke8Q
4A/ygT+so96DyPePynWhH+Ic8wHDT8Ab/BHxiPgAht+AR/hrVecqYNgX8mMf
BR/wN2DYH/xgfnmfXKmfOh/yI/ZtfI/5+2m+bmAe7JL3DPkvhz2NSnLJe4RN
39lGOW65pJ2HDQiba53s4i82f5vq/vauzL9Pj3z+oa528QvvZtUu1+6u/9Vb
911/z3jTnVHOez5s2NH4eqncT4ZUrzbTFlD+wvtV5oO74x237Owa0WKG7aBT
+oHvL63/adSffuGdym/PhDrmwXekfuELaw7R/d97lf7JRf/oeO97FcZP7JiZ
ok1IlHEeNP7VvrqO+fI76P+v0gNvGpckSn0M004/id+fJP3gacO4S0GhiVyz
V9cpjlslMi9gPqyLfvUdcMG5ljfd7osEedR3iPj2EVqz5hKBD/wffKj3vMsu
jeml75FD4Bdyg3/13fbMwK6vmK8VEeyJOEZb/u6bqVp/7763fvWAZubBpQR/
wLqYN+ZujUTtilIZhzvt6+ZZ+1dIfU7NnvKubmYFxXRfcErbpohPlI7taCx1
8Ku9FgzS3Xbw1/HHS6IePeTF+pfHOoKd3ObqS52N1bO5xdGj02wB+fxowOfu
dbZY/nnsHYtlVjoZv5qy0eI4zwM8fp3PG2ac3m3SHaWQjH88iX/FQbP3J3cw
6g/ThA2aLZZZybL9NPdgd11RIX19KGmrZVYSfdIn+7ChWwpHbWr4pvG5nK1v
/9bUqD/FsYm/tTRfy6TG7XT9dR+WU6MPvt9pmppH6X4Box0x+dx00sVq0UPL
yflxZo591V1a2Sklz55VTq0G1pvqGHWWj5S81Ed3yUUH+i5fEW49Qhsq6qS4
M1w03vfruKCPkyjm2sTRjhUuCjjUr6752m3+IOv4p46ECt4wr3ykY9RNrnuk
w2Xt4wpO/PlGlv1oGi2M7NbK2MLFfWoG1Ah96w7dPt6moTm3gs+U5SVq/XMo
0eaKMjx7Hjdr6v1pn3Sf/1lxrU7ozDIOKJ38NP79Etk+XLf/rHbffTo4r0GN
6J/K+Mv1/NA+qYRmi1bG9WXhH7z3YXXSn/Sei0KapBw29C7jtVnNmxmr3+fi
ZYbhmtFl3P/8o6NBEQV89U6nuqFvlVHXT+/8aS8v4PwbnXeZ/JzyXHRne/Y6
S90Knhnfsq3+0R328Ussjr9dwYXp1F3X8RpP6P5wmq24gtP+YW9g1lzmvC9v
acyD02XbK9g6yWbYR50HnTOH90rnGRHjbW53HB3q3K2L/lEa1/V9Odee66T6
f/jusHR5ft4pXWINKnNS73cy1lscFzl52rql4Y1cHJzQp6VZEy5xNYFlfG4W
8clZdf6pCa3vvd/3OT5/jtX3JvU7/HCMQ3uJp2/JLrCvz6FY847vLbOucf2f
FsYGpeTS5CnOIvvRRB5hbRxjiCqmeRUJW0wR8dw2tJ7Z+tRJ/QtGDtIV7ZT4
+j0PJugfI/Qn8HNd8EOYb5SYj6BfU6EfQX8/oT99/HDjGMegCm6ed/U187Wb
pDuckKjV5nCyx4/TCPq0EvoQ+Nwp+CTot0PoJ+P9och/tPqg/9rw+d73Cdgp
VbQy77l2e/IvZV26v88UcVbum/Cf3sJ/CP61QvgXGS2lb+lPlsv9NDCk2meO
nmX0e+r6Tab8AoJf1xQtxYTY/KKzvOc0xENDEQ/kunLmUfyVbJ54fpJel+Ek
xM9VET9066UD/TV7CuV5CfH5LxGfhHicL+KRnJ78mSnvq5H/9or8x5vCHOEG
Y/oL728/bDyRoF3hzess8iNjPvX9IaXv60M1p51yH90o8jEvumRsYqxe+MJ7
24hdWSM1F0tk3o8V+Zmhn6zrNG2fxb9fLPcF8Ba8fOLq8Kclct4PCqN/MTS+
L/eJR2J/YPCNddu9W/9RfNtSuW+Ax5V/Heigf1Qgz6mrxX7FsC94sQxIP2DY
9uJ7iXNj/x76RylccwTPtiVmyfOUfxtt9ehmuXK8zDOzdnTTm1MZ/qa+7x26
7GeyGWzs27uJT3SS9z6sqWe/8dZJsz3xkCrrLNjrrtifebo+N0kb7K3DEA/q
e1/TC8a5Vstlnt3tDaPjsfd+DeshTjC+mhhPGI9+8KO+U90V/BDyFfQEPxgP
fq4JfmTd0VPUOwR91ffE3YIvgr74P/hTfweEeIe91HN8mqj3CPuD+h7VT/gb
wZ/gx/CnpcKfCPuT+m78sfB/gn/DbzFurvBvQvxg3mrRyTY350k/BV/LRLzK
PJQo4pEQ34h/+FEfUW9LXoaIelrmn6ki/3BdT32YJffFnZmxrY0tnLws5j9v
60/mMPJ1tsjXPOb9Ne/p9pSTT25a9eijdsL+jTbCk3fu8mRX+98MseV87Pzv
gebBWeR759Ug/cjncVRZr6wR9QovHr9rrWlqETX1K91kqVvKkamDF1rzHBT5
bMQYW0ARZ2vbcNDs53V865WhlkN5jHooUNRDUh4/IQ8PaTHhiraNkxJ+OPly
9Pgs3vnF0oOGxnlsav7sD+2gJC6bHWW27s3jwDnOdaaI64y6bJZoZb13WtR7
hO9Hi+8J3/uK7wn1YnNRLxL4+1bwR5DnnJCHoM9WoQ+h/jSJ+pOg/26hv6xX
j4h6lcBXI8GX5HuC4JtgzzRhTwL/1QT/hPpI/n6hcj+zif2MgzvWmOBIeF4/
7cvab4jN520/2muGvlUh8x328y5iP5dx9Vm7mQuslgtsbb6qpXFJvnw3qpV5
b0n4/Hx+sqZ2gFmzlQYGXsxwk/d9sP+hFZMdPR1UsKLtZotjrfTvzx73stmP
Xpf3RGkTR/XWN0wmyIN14bdjRT1HF2rXTtAWOHmT1j7d6psh8+659r/+tc6W
Qam71g3X/N/vs5An+69t4x/dLEvK9WRUl7WmiAzJF+QAbifqS8mj70fL6oSG
eceF3LodZkn23o/u3b75U8ct7+8LvmyvjTRsc8n1HEkLs+y5Lu87eeDmqbaD
LlmnBDy4sjT8aYWcb5+Yj/N7rnjdvCqVOxTdvKRt45J14mwxP4ct27rE6pvE
fl9E+4d+4+IhtuatzKsS+djBYZGGEBfjvHBCnBfY7snLcdwubsbJoCMuaUen
kI//qjf8S5vhCD888kUX/U0XZ/+49YbbHcZlG3ICjTkuxnljizhv8NrBH0YZ
jGGE76FfqtCPk/o9znK7z1DvWVfWWJKf18GjO0cb0uOoa07IVNsZF+O8EivO
KxxpGdMw9I1EulNjaVF8mEv6wauCHw6gveGm/FTqVTxumq2PS95v+gv7MM5P
geL8xO+e2vAkavw9rnEiY3l4o3J577JY2I/TrwaWxO+/S02rn3pLf7OcV7fN
nWyLuEcdir/joD7lfOCiriJe7/190IqKB/11GWU8pOfROda8fIY/7hP+yPbG
bk1omFPaMXbV7p2mEU5Kq9O4OCorg0NEPqHt967Gagf9yTs3x2lCjzsp2HPu
tUm8tu1HO0wRz+uHwn459lzv74m6NBiQ6t5ewRN7DA2x+qZwXPiv201+Lt73
4bKpDu1Z7323iAd2dL/giBqfzt/fX5fgpnTGefSYOI9yrR9rT7GtuckTGrf+
ztoqkxE/2Gex7hARP+yTdqCJOcj7Pc6zceI8K/3pldGe+OKh3w0sjDfFcP0f
ay21xmXyDPOSy9qEMK6xMbuvvmEmR+79333DAbJ2jZhh9U3n84sG6nVFThlH
MW032dzP6+hW7X8YpZmUxI3XD9eEVjhpRmKL4wbjOV7Q82mkobHXjwPHrdpu
avDcj4oTBumiDzHwlwLTyrw64aZed7nepcgWxnXx8nyfIs73jHx2/ydPPpN1
wyKRr7jVld2NzA9y6XWPPt736DyRv/jqoXFF8fvzyfL5zUVW32T+8c2/3tEV
3aNtf0W+r+uYzLgfWCLuB3hN4/Xt9K0L6Vi/w/tMl5MY9wsHxf0CI3/e+sGT
P7npS2ss4c/Pc9AX9duqgrsnDMbfZP03VGCC/8jfe1X6y0rhLwR/Gi78icA/
xoPvIYJvgj3qCXvI/PWe2B8I9yd9xP0JjRt9xie0fjqZtxW3N54/T+DnG8EP
gZ/Vgh8CHxGCD0I8YR3Eh0nEi8RLRLwQ4u2yiDdCvK0W8UaIh3kiHgj+jPsZ
+Gtt4a8Ef326weOvhPuBZuJ+gOC/kcJ/CfkCfoF80V/kC8L+207sv4T800jk
H0L+aSPyD+E+JVLcpxDyfQ2R7wn5/pDI94T8XSDyNyF/F4v8TcjHPUU+JuTj
TiIfE/Jrd5FfCfdBNnEfRCPm9Mq3v5bLMwqTh2qGOxn1LOpuvCft8NRVTna7
qv1bMylHvjdMX3eju76H9/cGuEdemzdqaXivfA54O2mY5mI5RdbtUWAvz+H0
NqM+t/k45T39yV+mBVt7OeU5AO+KvTz3CzaGv4UJf5P3JSPEfQkhfmuK+JX3
mH3E/St1+3t8sNU374XfH3QQ8xPy5SiRL2U9Dv/BuettcT9MkFe+T5ZYDxqe
lfM7CwP2mqba6ZPYlz/S7PH+vgv8QC7ws0LwQ9jPfMR+Ju+Tnl3y3I9L+0wV
9iHwDz0wb4K4PyfcB9YS94GEeqONqDeo68H5LcyaZPn7CNQPOlE/SH3t4r6f
UA+g3sG58mdx/0/Y39PE/k4/W5eHWPP+kL+nCAzY2l0/MpdSelQPts51cu2d
i2IMc4v59OBhLcwtHXxu7Z2/R/9UyrOa3PjZ5PeAwed7gk8e13t5lpuy2P/6
702M52/z1N/9TmsHxVKtPv4bTZdvs/XCf7rpOl6nFh6/uMF7xt7eZYq4QY/H
d/5bqO0aJ0Ze/Cb80yKa0fKrkqhmv3PyxT+nOIJLKDv3nQtBoeckviCw3E9c
cZ79hDD/a2J+uv7Rrof2OVm0u3eDN/XmywT/3i38m6DPdKEPZXr2EQd3OLn8
hnZ6MUH/k0J/Wnuh9urwdg6yN6BW5gXFVPY07XvLsAccsig9xHqsVPKXKPij
M2E9btrXP6D867V+MaWV0p36J5ZaJ2dyjdcOlcSPrqDdL/XdbtmZSYUrnc+i
zBVy/S5ifcb8i8X83H/gmO2WtcXkKmvvF93XwTM893eldL1L1jhbwAO+NXfO
d+FbKjh0pKtO6L9TuPlXTSc4YuzcNHXeLTfdYPBxTvAhx1vEeML4OmI8wT53
hH0I68WJ9QjylAl5aM2ybZNtifG86ezZLHeTLKlfsdCPwUeh4IPBZ77gU/rP
42se/6H/AuXB50I=
                   "], {{
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[0.3], EdgeForm[None], 
                    GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxNmge0V8URxu/uVVQUBUUERKSIIFIEEUEeTQFpUi0gqEjRiEoRxECQooKA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                    "]], PolygonBox[CompressedData["
1:eJwtl3m011MUxb/f822QolBEKqUMpUlFWKVJSWl4eqrXo3ollLwQTUKUmcwy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                    "]]}]}, {}, {}, {}, {}}, 
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwl1DVwFFEcwOGL4U6gwIO7Dk4gQCDBHSqCBYINDBbcZXDrcJcSaHB3CYTg
bgWDQ5AWvjcUH7/3333H3d7eJmH4xL4ToiKRSIJ/asdEIsnRkUg9XaJL6UBH
4jhHHs5z0/6LeokLXOEytxy/pte5GvZxgyzHs/R22EM2d8LseI7m5S756Mw0
n6GTriI/KfR27I79q61z9JE+5iGF6E6mPd10DT0Ya+6phenDdHNvXUtfxpn7
aQn2so/93Pf/r9cNDKChff21kW7UxvpCX/Kc17yiieOD9Qdl+E5Zckknxvmq
Gq3VNFYzwjVqrXD9WlsL6CRtqSUoSXFKEU8iW5z/4HOmWTe3Xs5f80cqONbC
fJRjzGCyY9N1O1/tGW5uZb2COUwxz9ad4fM7P9Lc1jpBT2glrUhnosK12ZNu
vcA6kT38dCzDsfbWtfSsJlHTerH20ljtqWe0hlanBzHhHupprRa+p3AviTZ3
1VNaRSvThUXmVE3hpHU7FjLKnOtz7LZuQyfzfE3Webor/KatI+H3rce1NXMZ
Yf7mtTusv+gw86xwH5jJUPNnx7dZf9Ih5kzrZpSzbqrlw/WTxNbwuXSqttVp
uplNvPf6I3qYQ9RhDBPtGx2eCa2hceE70jw6Un+H9wjfdXhPfpHGO0rzhlK8
ZSDjvW6QHuQA8TwLz433/8My65L0s++BeZ11fesGPLUuzhOKhfsXnhvH79n3
myLm0eaiWjDcp/CcmbOd+0VquKZwv8Jvmns8CM8Xd51fGa7b+box///+/AO2
cYVB
                    "]], LineBox[CompressedData["
1:eJwl0slOU2EYBuBTWYLISqgkaGXjgsGhDFGuwogUKGFKWKhtQVlwByxZMN4C
groQuBVQ5qHMw46prfCcuHjyft/7n/8kPWmsL/M+HQmCYIyjB0FwyDF/lPvy
gD3KybKi/1AUBAnzKB2k7O1ynAmeckkVV55f58p8zXfmuNHtMBW+X3Z6xyfz
DNN8ZlD3RdbwjRH7V/lYvpa/eWsuuP9OlrOgW2TYfKj/R4u5gihLzp7ISt6Y
49SRIanLej5Hyj5kT8tais0PKWHfeZcc1NfzkwZ7I800Ucojfjkrk3l3Xppf
8YKB8Nvpd/W3/LDPE9EFbOvaZb+umj4S9q3wN5nvyFEgz2b4Hvk8/LbE6CXt
Tk/47Z3HzbPmZ3TTZt/QT5rX5Ed70hylk1b7qv7CXMEp55zxV38ilyP//zf3
vjNO1Q==
                    "]]}}], {}}, {
                  InsetBox["\<\"\[Mu] = \"\>", {-1.8, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["0.2`", {-1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {InsetBox[
                   SubscriptBox["C", "J"], {1.4, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["\<\"=\"\>", {1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["3.67`", {1.7, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {
                  {PointSize[0.05], PointBox[{-0.2, 0}]}, 
                  {PointSize[0.0125], PointBox[{0.8, 0}]}}, 
                 {PointSize[0.007], PointBox[{0.4463998339305619, 0}], 
                  PointBox[{1.2771956561278897`, 0}], 
                  PointBox[{-1.0806611991222994`, 0}], 
                  PointBox[
                   NCache[{0.3, Rational[1, 2] 3^Rational[1, 2]}, {0.3, 
                    0.8660254037844386}]], 
                  PointBox[
                   NCache[{0.3, Rational[-1, 2] 3^Rational[1, 2]}, {
                    0.3, -0.8660254037844386}]]}},
                AspectRatio->1,
                Axes->{False, False},
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                Frame->{{True, True}, {True, True}},
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLines->{None, None},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None, "TransparentPolygonMesh" -> 
                  True, "AxesInFront" -> True},
                PlotRange->{{-2, 2}, {-2, 2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.02], 
                   Scaled[0.02]}, {
                   Scaled[0.02], 
                   Scaled[0.02]}},
                Ticks->{Automatic, Automatic}], 135->
               GraphicsBox[{{GraphicsComplexBox[CompressedData["
1:eJx1Wnl8zNcWD9XUkkEtodNUWxUdu2Ks5ZTRPmtN0VgaY+liGUubUgZ99lGU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                   "], {{
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[0.3], EdgeForm[None], 
                    GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxNmgn8l1MWxu+9r4pI9igliSztSkSbQotCEUlKiJQWjZJKsmTfsu8MY2xj
G4w1TSaRpcGYwTBjX4aZIcyYwTTn2/P8Pr8+n07n3Pve99773nvuc55zf/9t
x08dPqWklG6oUop/qeSUngx9XkjDsJ8OfUHIOmE/Ffr8kEZhXxr64pAXw14R
cnrIuVEOldYLeSGrv/VDmvB+SIOQLUIau35ItBkccknYg0KvG3rTkM2SbPrZ
3Jp3Hos2vwk5I2SDpP7pd1yUx4bcHnYz983zrTz2hiHNrZuG3MtcQxaG/DPK
m4S0CtnGNnNovdZctrVmLh+GPBNyUch2/h7GbGu9Zcj21oy/gzXjt7NuEfKr
GLsJ3xFyeZRbhuzs9zbwvHdxPXNrv9YcD8iaX4eQazyPjiHDs+bRKeTprHl0
DuniOTGXraO+a+i9Qn4XcnVIm5DDo37X0L2Snu/g+a7yvHbDD6LN+Vlz6eF6
5nh11I0MuZ5vzRpvz5BDssbvmdQ3/e3o8Tb32t0XbTYN2SSkVci/oq5/SD+P
yTg3hdwYsnvI8yG3uM8x0f5Wz/mGkD4hA0L2z3q3b8iwsIeGXMuYoTcL6R32
0pCrvLfXRN34kJ+HfVTofUIPDhmSZO8b8lnIiyG3udzXc1ySZdOuTdjbhgwM
+0f3cTDrsFZ/F8fzi0L2D3tC6GNDfhn2MaGHsQ98X9g3h3wf9s/5xpD/hv1o
6EdC5obsGNIuZHjU3+1xxoY8lDXeOL7FY48MeYpzHbIo5PMovxpyJ/sX5XtD
3xNyV8hhIceyzlG/POS0kNlRPjFkSsip1lNDJoaMDjki5ATrMSGrPf7kkGez
5lF7H3u830cfHTLN+piQ57LW4LiQkzyXCSEzrKn/mfXxISdbM5cO+GbWXK4L
PTnkvrAnZY1/itse7nmDE83sh3M8J+YCpnD+OIfzQqZ7LqdZM5f51szliuj/
pKy5vB7ygMd6MGntFjDPrLU7I+RMryNjnmU9N+Rsa8Y8JWu8hSFvsK8e808h
D7ufN0MecX9v4R/uj3lv6W+b62/iG8B18BvcBMsv8LeC8Rcm4TO4Do6Dv2A6
2Aumg/FgemO/v4HX7+2Q33ju4HIT9wNOg5FgLnh5WRL2gvdg/SYeA1wFZ2tY
T7mx94TyE0mxqPgbjrFPMM5W/k7W6myvG7i+KAljwffmHverJKxvmer4XsN7
dKtUx/rWHh9cbeN3wLmdUx3TwdMaplMGx9t53CuTMH2nVI8N2/l72niM2pmZ
mOr4zhhgUgfPYeMsnAKjP0nCa/AenO/oPsH5Th6DOYG9nT2nri7XYhJtrkjC
YnD4myR87+5vA2vBTTC+h+dzYRbuX5eE8WD6Hkk439NjHeCYwDoSX/b0uMSU
vTwP8L2XxwbL+3m8McbkvZOwFPwGx/sm4Sy4epExbYjn18/PwdJfJOHbzW7P
M7AcHB+UhNdD1uoLGywea6w+yGX6B0N/SsLuESH/TopH+3mfd/W3gNng9agk
7AQ38ctbjc3s7SPGZ/Dwi5CVSTgNPo/1WIuMjWvmb4wHl8B9MGqY50WbcUlx
jNjG+oDLnAPwGpwGNyf4PTDuOPc10WXwHowHZ4kDYD/4+6skP2SeHHSwe1IS
bk9O9TgCdp+Y6tg9JdWxe6q/f7rLzOskl2vYfVKqY/eMVMduyu2NncwVzAav
Z3k88POUVI89sz3eHJcZb67LjDfP5VeycKOygHtgHTg93+NemYXd94f9ZRJ2
g9lg9QKPxRjg6xmpjtdnpjpen5XqsYGxwemFLnfOwu5fh3TJwmswumsWXoOb
dzFWyDlhvx/yeKrjL3q9VI839Ply0t4d6u8Bw8HbUdHHYVncaHES9jZMwl9s
MPCsLM5O33dwdsB3113q+nuYSxZedw/dzXj6UciSJFy7PkuDGb9NwhTwZE8w
IasMxoFlrUPewZ9cBv+u9nPw6xrX1Tg6+Hp39HFmVkw60NgDvhwc9ogsnvlC
EucDL+CFYAp48m7IcpfR4AKY8F3ICpeXeVww9Ijob3QWj+R5jd8NsQ1P+2U8
n5eVX9zPtxt3Lg19R9I5vRO/yuJyzyXxTc4p68h61vIO7I2Szgu4wVn5fRI2
1HABG/zhfN3jtsdlndUxrrvX9X8NeS3p2RT7MmdpVtgzs7jCH5L8eoH96CH7
0nshf3R5Rpaf8nx62NOyeMwJoSdm8SjW7ROvHWcA7sG54Bzgy5yF2dH2Mdfh
v/gz/AE/J5YTxzmXcJHauYSL1HwZLoI/z/acOfv4LxyCNcTvliTF5KZZ/ofv
9cjys1q8XJrqPojvEVP3iDa7Z8VR5vqov4PvoQ4//NTf2dH+9Zz3kRwBnxtg
H1phP8FHXrSf4Asv2R/6Z60v579FVt5CvPy16+Z7/19JwvCdsvxgrPeSPQWX
Oeuv2hf2jjb9snDq797XBV6n171W+M5K+88HSVjQ0HvMXtf45HuuYw3e9Drs
F33vuxY2veV1Yj/f9p6yru94XfchXuc6D/2T/YE9/7P3vXYOOYNgzPv2C+b1
ofcWvvSR95b9/DgJQ1ibv3h9yAHfdX+s/Wdee/Dwc68TZ+JvXlfW8guvB+v0
pdeJNfiH12GO8a/GC9Fwsa+T+GJLt8HeOMnvvnb9DVk4CH96wBpu8m0Sr+ru
NtjwwJvCvjHX+QR6oOvhGfAffHxdY29jz41xdwj9nyS/usX2ASE/JHEG7NG2
4R7kjDw7MOT2sG/LdU6DBmPo43v3SRt4D3zpYXDAPGCiNTwgZ23oJLdJ5jFr
znGun+MGWef4cPfPvMiL22blqqwx37WGd2fl/P293uv7e4k58Gm4NLwLe0fr
JrY3tL11km6a65x2o6w1JxbBO2v3Gti9rTe1jcA/ec7+bOb5oDe3vYVt2qKb
uZ412z5r3Yin7Bl3Wc2z+DE8GE25p+tb2IZHwpXhyS2z7L1c19Lv4iOsD37C
GdoyC3t6Z61dfz9v7TYInBb/Osj2cOs2trezTds+WWXsLp4rfH68zxOY85L9
Dz+BpxFjiC9wW+4gjkyKTe1s4xc72TdO8DvwOjBs56zYRR/Uzwy7Y1beTtvH
szgHewpO7JqFJYvsEy3chrszyru5Pc9fc1+1MTu4f2L7EV5b8iniBBhGHCMe
gPtX2Ffwkyey7qQo98riNFe4Hrtbkt7LNljVy20Ys5PHZU/6eG3BpL5ZeAZO
g+HEVjAJTKcOrkjMAJvBU3AVTIU3grPUMVfiF/ENbAara3wS7KYOnB6Yhd/w
u8E+a1fZbpSkh9h+MAu/yCvgWgdl8S3eIU8nVyZvJOeErxELadvX75KTgHWt
k/JAckDqhrmePqkn/h7kMTq4LTa87lq/Q9+crd72bbge45Lfwm3huHu4Hi5I
jH4m9OKsvPQwa87XoVn5Ku3RlOGN3FWOcJ/Dbdf6Gel61gquPMg+QR7b1b6E
3ct1o+1Xt/oZ9bd4rsyhNifmcGRWrru3sWWM26N5Rh/wTPLS2tnF5iyjx9le
Gvq3Wfntbdbkr0dn5b2D3AYbroLmGXeb12ZxVnLXl6zBabgrOe0ot8EemqQn
2OZ8c87hn8fb5ryTT8Ed1+RUtk9Pun8jfhA70PBIYsey0L/LyvGmWcNbTszK
/Wa5zWS/i+bZfcYZxoYfTc3CkZnGE8pw31q/9MMZm+b+0dNdf7LnvSYXzbKZ
cy3mTfKZ5bze5TZ8G9yNeyfuuchX4NfkinAeNOUFSZx7puvRs1wP5+auijwR
noy90HWU4Ven2l7oNpThX8RMuAjxkViJTSwlL+HOgVhP7J/rPbrdz6jn3nie
/Wq49xL7VM8brk3eQv4C1+Lud779gdyUe8CclIticz93jp9Rz29A2HB78jbW
p4H7O819Xuhn1PM7Dja89Oyss9bIeINNHormGbkpORN3efB/ckRsYgG5E/1z
x/C/pHg8ws/PdZv1YlKHVMLTZ+17k+0n2Cfax5blet2zruecLfU5OiqpflxS
m2Xuh7G5e+Fug3XhjpR70Zd9xng23v0c5bVc4TVEv+h16xBzHFIU73jvZa//
ctv0Q9/ca1Qek3ac39p5ru3Xix6HPOsV9z87XjqsiMOudD8veC4r1+p7pduv
9DPso+O/1kX4yZ4+731lXss9LlgBdjAX1vO6XD/72JzfS90GPKndI8DT+G2C
nJo7DXgZ8ZfYyj0kd4/k98QkbOIFuRZ3gkO8L9yjwVnIz8jTwDryc/rkbo31
v8b7SN39HqvG3bvbj5bbl3p6DvBE4gMxg28nbhIban56lf12pNt08n497zUB
V7hfAlvQV9q+32VwCJ/Az/axvy2xzTnmDpGz3C/W/swiPGsb+7hdJb6wfejn
i3Bpx7DbVeYLUXdOEQ7tHHU7VeIIHUN3qsSr4HdPeh1YE/aAdfwopEGluNY+
9MtF+NOF9yrxra6hryriad3CHlnExZrSfxGnbBT2x1nx7umoW7dSntMh7A0q
7VHj0DsXcdnWYW9T6feoraNuz0q5eO/QXxX5A/N70nt9TNR9V5SfHxG6Z6W8
fULYe1fKt9nDJ3Kds2Gzt/BHeCTzh8vgA7vZFx60Pwy1zXPubMmJ4LToh22T
u/I7BziWXL/a+MregbHc3/I+ORd1j7oejOTdDY3T1LPnPez3u3ss3gVzlthP
BhhHwVD64F6f3wDaej+f8p7CiaiHz/f1+33sq3AduMli2538HY/5W1Z7bMbt
7rXqttY7nT3mYr/b3nPm9wJw97wsTs55vdDf8h/8ouhO5cfQ2xfl9G/E8x98
jv4SdRsVxYrhoa8suit7JXSTopizIvS+Rdy4Regvi/K9sbHnhxfd9XwYerOi
PBr/3c8+/Ga0+zErhu4W7b8oyiNHh/2HrDsJ/Gh08R1h6GuLOP6Y0L0q8f4x
od/KuquYU8nn8LcPou7WIr733yIfxT9Xhv591v1Xs7A/L8p1BxadMebWl/NR
lGv+OeSnLGw8JOo2L1rPF4rONud682i/pCjP/zr0P4uw89vQLYs49TahLyrC
zgNDb1IUT6eH7lqEkV1Cb1wpj90kdLeie6wZYS8sui+5JfQO3q/zQ19QdL8z
JdqcVpR7DeZce4/Ghb65aN8bRptSKae9MOqaF933tAn9fRHf34X1qJQz8cco
YAT4MDH0TkXcuDP7XOke4c6wTym6+1lehI9gY47nq4vy7CPDfjtrrP3Cnl3E
504P3acoHvUO3aZSzlaF/jAr734i6tsVcfkZoXf1mhD77jS2k1uR85PvN7YN
RyP+ctdJ3IS3w+nhYnD+G42H3YxB3GdwXrgXxs/PsQ1/aeI2W/u83+2zOc99
giHHej5wN3yLcVl/YiO/jY00ti+yfYifYROLL8v6LmI2ZXL8y2wTo+njkiw/
4V6F+6xVnuc9njMx/Ab76iUel/i8ys/4jYB1Yb3IKQfbZt3ga9w9cSfVnzhW
dDd3ZuzFnKJ7zItDX1J0DzigKOYR7/pyvoti6VZR16zSfcSk0CcX3VvsHrpj
0fqztxAn9rdn1HUvWrfFRfGJ2ERcal/zvbCnFt3t8rsed2pwac4bNndt3G/x
u13t7g2buzjyMr6LXIx+uePjLof9v8k+UCv393u3+N0f/T45HfHgVo9by/fo
k7s72n/vcWkD98dnj7XfnmffYo+axLdMKuJHNxXFVGLijUWxljh7HWuc/dtz
2OOLOA/n73ifQbDtvSx8Y/1+5jUEY44yzoCvWxRh7N84V0W+tCl4m32fFPa5
RffFu4R9XtG9RedK+AK2gE+zjFH4wh32B7BkHePJp5yzorx4JnMpin2T4/nf
s/DhtqibVuST7Oft3lP8YrJ9Y1QRpoPnh4dev+gOZe/QB1W6ax9RCX/B3mFF
MYN48Y5jD3Hn7Kg/sNJ9M1i1r/Fqn9BbVsq9iHUHFMU71uDgSutwOWtWdGd/
aeiGRb/twLO6V8IB4tv1RWO1LYqpxNPBlc4JZ4QzcYbPBWt/Um39+Zaic0dc
PbjIN06Ld+cW3Zf/K+Z2f1GO/A34U5QL3xP6q6x8n7pVWfX3hf1dVg7Oe99m
vQu+zjfGPh76saJ78QfA/CwO/FDR+rK2q6Nu90p3W29E3R+L7pR/Cv2/onvP
DZljUU7TKPSwSvdoz4a9tCj/ey70sqK7amIRvAE8bIxfVLovY29HVdrfp2hb
9Nsg8fnVIhx9PfRrRX8LOSDablbpbBID4S7EQbjDlkX84YPQ7xf9XeQnoT8r
ignE2/eKYu7rUf5r0e9bcJMRRfzkF6G/zMpbPwr746LfABYUrRdrhU+dVeRX
/2DNiu4y3+asFN25Ny3iT3AneMS2RVxiVeg+le6u4QjfFPGEd0O/U/Q3nq2K
eAOc4dMiX8FP4BFjXQ8vG+r+3+TsFv1N6DOh+1fCpFOLsJtzOjD0oEr3nl9n
cQV4wnFFnAm+NKSSb+FX/87iHPCN5pWeUQ/H2aIS7s4r8ld8tWXoVpXulInh
Qx3HP8/Cbs44HAEsAAe+cGwAf/av5Lv4LXwErgBP6Fcp9oOf6xTtPfveIOwe
RThMnGnhWAMvgDMRQw8tyrGXJGHtD0V4+38ZAtxY
                    "]], PolygonBox[CompressedData["
1:eJwtl3nUj0UcxWfmeXktR+UUkUK0WLJlS5a0ibK+CKUSFak3kSiHLG2nOKFy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                    "]]}]}, {}, {}, {}, {}}, 
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwl1EVsFlEUBtAfSJDiboEEd5cN7lqkpbiFsCAQiru7LnDZsIMNbgGWuLu7
OwkupZBwblicfvfeeTP/y5tJyw0bk5KeJZFIlPenVrZEokvWRKKuXC5X0InO
5OESebnMFeuvynxRc51rXDW/KW9xgzvcjmvm9+R97vKQB3Gf+WOZn0cUIJm5
9tBVrqUg3RhgdsP6dfFM+UK+5DlFSGWeNSlyPb2Yqk+TRWmo7i3ryQbUZ4O+
kWzMe3UJ3lGSfgwyv+u3Nqk3M5imZoNkM7lFNpef5Gc+8pUvtDBvyU91OX5Q
nl+MJMm16jKXrCFzy9FxFrJOnK2sG2ci29OOEpSkOKUpFe+M7dZ9ss/R6qbq
VWSPPZmlm82O/cY+1M1jHzI5zphd+u/WjYv9qlcznzn6eXJP7Nn1ifq26kry
jKwoK8R5k1P/05oJ6sXqNuznt9lks47qmvKi7EAN9TLZX+aOs5YXZHVZjb4k
6fvI87KqrBLvj1z6NHlOtqeyemm8b5nKWXU7ljBJn2EP+9St6alfJHvIhXIv
3dU54huTp2UrFjBe/8O9u9Xf5Fj93HivcTaM0X813xnvW56SJzlBE2Yx25qZ
cgfT47n6GXIbW/ngvuPyGEfj24zv3Zo35iNkur4WedQ1ZV45SmbG+ZNBhThn
hsd7pGzslzIMYah7HnreEfVhDlE6fpv75n9ZqS4V37e19/Qb4+yZFu9CHuQA
xXnLHWv+UEz9ije8pnCcMQPdd9P1TLrrp+h7yEI84RlPueX6Glk7vvls//8H
/QP+KpDf
                    "]], LineBox[CompressedData["
1:eJwl0jtPk1EYB/DTvhacEZyq4oDI4iAKRSeVRHB0FBKgxWrRUFQUr4u7uDhx
CXhJFD4AA+LlgxDkKhFS/AJa+J0w/PJ/nud9z3lPTns6X745nAohvGMhHcIe
FdqTEKoeLNOnvmU2yQQrZgNmp9RvGOC5vl/OMMsZ/tFEYM2a/7LKV5ZI8dv8
g/wjS/Yoqz/xkRFemj2Q5xnjtf6J/MwXnnLfrGL9XDy/PKE/SZbGeE7+ms97
3qXu5jrP9DfkuHxLB5e4yChDnu1Yl6gf8kr/SLZSp74gj8ld79yTj/Vt/OCa
/ojslPU08FN/XGbi/ZLjXDw/d8y37ZNWf+cbR81q2TIvypJZC3e5rd80z8ga
0vF7JGzEH1Sm2Pfu2bg/L/RFeVVeYVHdHPdiUL9u3Xv1qizoC+pG8pH+l/m0
OstlfW+8L9kjp+L9xe95J5cc/pcOANY7RJI=
                    "]]}}], {}}, {
                  InsetBox["\<\"\[Mu] = \"\>", {-1.8, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["0.2`", {-1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {InsetBox[
                   SubscriptBox["C", "J"], {1.4, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["\<\"=\"\>", {1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["3.66`", {1.7, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {
                  {PointSize[0.05], PointBox[{-0.2, 0}]}, 
                  {PointSize[0.0125], PointBox[{0.8, 0}]}}, 
                 {PointSize[0.007], PointBox[{0.4463998339305619, 0}], 
                  PointBox[{1.2771956561278897`, 0}], 
                  PointBox[{-1.0806611991222994`, 0}], 
                  PointBox[
                   NCache[{0.3, Rational[1, 2] 3^Rational[1, 2]}, {0.3, 
                    0.8660254037844386}]], 
                  PointBox[
                   NCache[{0.3, Rational[-1, 2] 3^Rational[1, 2]}, {
                    0.3, -0.8660254037844386}]]}},
                AspectRatio->1,
                Axes->{False, False},
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                Frame->{{True, True}, {True, True}},
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLines->{None, None},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None, "TransparentPolygonMesh" -> 
                  True, "AxesInFront" -> True},
                PlotRange->{{-2, 2}, {-2, 2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.02], 
                   Scaled[0.02]}, {
                   Scaled[0.02], 
                   Scaled[0.02]}},
                Ticks->{Automatic, Automatic}], 136->
               GraphicsBox[{{GraphicsComplexBox[CompressedData["
1:eJx1Wwt0jNcWjqpHU0FVPaZuvHUaKpFrUlXXVtNGq8o0pYo0RUO1UXqVatRF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                   "], {{
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[0.3], EdgeForm[None], 
                    GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxNmge0VtURhc85FxtFQBRioSkKokiRJki1AipSxFgpFlQ0FkBABESxgGIv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                    "]], PolygonBox[CompressedData["
1:eJwtl3n0V1MUxe+7r1QkKk2KBlKhSYPiR6VZ/ZqUkgqleTWQIsMSWUlSsrDI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                    "]]}]}, {}, {}, {}, {}}, 
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwl1EWMFFEQBuCBxd3dFvcEd3d3AickwWEXdxLcTty44BrgiLu7u5Pg7npB
vgqHb/+q6tc9Pa97Nnlwas+UNIlEItmfckmJRIu0iURFOVPOohnNycgRMnGU
89Yfl5k5xklOcMH8tDzDKc5xlovmFyLjXC5zKZhflVm4QlZaMc09tJTzyEZr
eptdtn6++pq8KW9xg1x0YLo17eUCOjJO30nmpqq6s6wkq1CZhfpqsjoP1Pm4
T3660df8hs9aol5KL2qZ1aE2y/R15RP5lMc85xn1zF/LN7ziHW9paP5H/uU3
afQJGpGeDKQjExlpSi5yk5O85In9YUVc0/0NVddUzyZtfJbZMLOxcb8UjvuV
RWRrWrFG/8m6keq66jlMZKp+glzHV8fH6Buqi8t9spgsGvtKkv6LNaPVU9UN
2Mh3s9S4d3VZeVg2oYx6RuxjfE/ZUx6SpWUyPWIP9N3lQVlKlqRb7Im+qzwg
G1NCPV12iefKfnWjeHdI0X9zDxvU9eNd0E+Jd0ROlutpF+8KbWnD3nhmTGKU
/rPz16o/yhH68eo68U4xXP/BfLX6vdwjd7OLGqQyxZoUuZJVjGGI2Svrl6tf
yJ1yB9upEL+neJfMB8pB+nLxPNVlZZIcEPcT3z0+N54JH+jPy3i+cd143vF7
oZ9zbrveNvVWtlCIR9w0/0UB9UMKsphFsaeMd25XuZlN5OUe153zkzzq29zl
DjljT+njvCuO/6CNfmzssczONXLENbjq+FxZ3vEKSf////wDO9+I6Q==
                    "]], LineBox[CompressedData["
1:eJwl0stOU1EUBuBdO8PLCJVEE6wkREShMIJEI74BkGCRaoG2AgqRAeiEBB4A
0YBoFF+AgYLwMASvlCAxOlJQsJWL34mDL/+/1j67SU+byA6334+FEGaYPxJC
gTXq4yEUHayQ0lvtHjHJqt1NuzP6ODcYMXfIaWY4xw8q+ev5D/zUt3jDAnt2
BWb1DdnrM7L6c56R44FdXl7gHmPmu/IFLxkkb/fV/Tn9mzxpPkU5FZzmu/0r
5y36da4xZJ4gFn1fktTST9b5F3cOuGN+aO6TNZTpF+VRuek8JwfMl1jiivnQ
/qo8xnGW7U/IIC9TRzU9dNuve36ft+bF6N1E7y36LewyzjN6Fbcj5s/2Rb3E
Dn/Y5ZP9L/mbbc5zi1F30rJZNvFaT9AVnZs/uvdUfy/T5k79LKnoGfM7+8f6
E9pptGuTUzToJefJ+P//0D+teExh
                    "]]}}], {}}, {
                  InsetBox["\<\"\[Mu] = \"\>", {-1.8, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["0.2`", {-1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {InsetBox[
                   SubscriptBox["C", "J"], {1.4, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["\<\"=\"\>", {1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["3.65`", {1.7, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {
                  {PointSize[0.05], PointBox[{-0.2, 0}]}, 
                  {PointSize[0.0125], PointBox[{0.8, 0}]}}, 
                 {PointSize[0.007], PointBox[{0.4463998339305619, 0}], 
                  PointBox[{1.2771956561278897`, 0}], 
                  PointBox[{-1.0806611991222994`, 0}], 
                  PointBox[
                   NCache[{0.3, Rational[1, 2] 3^Rational[1, 2]}, {0.3, 
                    0.8660254037844386}]], 
                  PointBox[
                   NCache[{0.3, Rational[-1, 2] 3^Rational[1, 2]}, {
                    0.3, -0.8660254037844386}]]}},
                AspectRatio->1,
                Axes->{False, False},
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                Frame->{{True, True}, {True, True}},
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLines->{None, None},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None, "TransparentPolygonMesh" -> 
                  True, "AxesInFront" -> True},
                PlotRange->{{-2, 2}, {-2, 2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.02], 
                   Scaled[0.02]}, {
                   Scaled[0.02], 
                   Scaled[0.02]}},
                Ticks->{Automatic, Automatic}], 137->
               GraphicsBox[{{GraphicsComplexBox[CompressedData["
1:eJx1W3lY1FX3J/Xt7YeOuaNkbrmQqZk1uaSedNTIlczEhSY1F3Lccod4c8vJ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                   "], {{
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[0.3], EdgeForm[None], 
                    GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxNmgnYl1P6x59znnYVk60a2kSpVKJdVKRSliKKqDClTcoSJS2UZWIYu2mG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                    "]], PolygonBox[CompressedData["
1:eJwtlgnw1kMcxnf37dYtHRQdOhSldOgQ+vt30OXfhVRESamYacoxk9xH0THO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                    "]]}]}, {}, {}, {}, {}}, 
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwl1EWMFFEQBuBhcXeHRS+4u7sfICEEd4dFE9xO3LjgHuCIu7u7J7i7k+D+
VTh8+1fV6+7pntezJfqN6pSSKpFIJPtTJHUiUTcpkRjPO30tWZsEO0nFLo5a
2yOT2M0+9nLM/IA8yH4Oc4jj5kdjnSOkjhknzE/KNFGTlvqkuI96cjLpaEAb
s5OOn6I+I8/Kc1GTiaaMckwTOZVmDNI3l5kpoS5JMsUpxjTzUrI0V9TZuEx2
WtHO/JzPmqmeFT1lzMpRltn68vKmvMUN7nCbCuYP5EPu85hHVDb/LL/wiW98
pYr5L/mbn/zlD9XN05OBdGQiI7WZG9d1f93jntQT+KV/Qg+zIXF/5FBXkDlj
f6nDQv0Lx/VWV1JPZAQj9cPlYl5b76evqs4jN8vcMheN+W39FX3Vo+MZWM5b
swFmNdWF5Q5Zg0LqcbK1bMV2dUFZgJb8dV4Luc08v8wX+8cf82Zya3wf5FWP
jT2P/WaLuhpj6K9/4/il6mXxTtDILEUuiXdJ3ZD68Y6xKfYknps++pfOXaR+
Lnvph6krMpSe+mfmC9RP5Ua5gfWUZXB8h44ZJOcxn4F0i3fB8XPU9+QP1qnX
Ujx+X9ZvmXWWXfXJfKcoP+jCs/hOeEK++Hw6xvViT7hLLtrTwXUuut4a9WpW
cZ1rnDf/SA711XgnmMF0WsQzxF7IlawgK5c465wPZIlrcJELZKQxbZ13yvp7
GsZz6xvJ9JwiA6eD9UnxbPEeJv3/n/MPpM2MyA==
                    "]], LineBox[CompressedData["
1:eJwl0sdOVGEYBuADIysEN5IgkhAQBDeQSMBbEEKdAUSKFF1QEmCjF6BAlBLK
FbAAKRdDaKIGCIENvSslbnxOWDx5v+/95z/JmZnM9t5oT1wQBJNMxQfBT9bJ
iQTBpYNFysyvdV/4zJKuQvfY/JEKOuzl8ivfeMIeqfzx+VX2zQfM8J2/ul8M
mzdknWc0mEcZoZEuXZPMpJ0+e5scY5z3vNVtuz9h3pEP7Ukk8ohkdvWTzovN
ryjig/0T/5zlyRdk08Ib55v6G5rt3fZ3Mos48zMZL7ec18vW8Dtjnpf2W32h
jPCABX2CvNM/N+eSQT01+t/6a+bss1xxGf4eupjzOnM6tUTt6/pz8wUnnHHK
D/2RPOaQp+Hz6XQnJgtkPtPmtPBZVNvX3Bsyr8gqe5U5hcqQfVk/YB6klDxd
iewP38V8Fb5X5P4/9B8/LUl3
                    "]]}}], {}}, {
                  InsetBox["\<\"\[Mu] = \"\>", {-1.8, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["0.2`", {-1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {InsetBox[
                   SubscriptBox["C", "J"], {1.4, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["\<\"=\"\>", {1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["3.6399999999999997`", {1.7, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {
                  {PointSize[0.05], PointBox[{-0.2, 0}]}, 
                  {PointSize[0.0125], PointBox[{0.8, 0}]}}, 
                 {PointSize[0.007], PointBox[{0.4463998339305619, 0}], 
                  PointBox[{1.2771956561278897`, 0}], 
                  PointBox[{-1.0806611991222994`, 0}], 
                  PointBox[
                   NCache[{0.3, Rational[1, 2] 3^Rational[1, 2]}, {0.3, 
                    0.8660254037844386}]], 
                  PointBox[
                   NCache[{0.3, Rational[-1, 2] 3^Rational[1, 2]}, {
                    0.3, -0.8660254037844386}]]}},
                AspectRatio->1,
                Axes->{False, False},
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                Frame->{{True, True}, {True, True}},
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLines->{None, None},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None, "TransparentPolygonMesh" -> 
                  True, "AxesInFront" -> True},
                PlotRange->{{-2, 2}, {-2, 2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.02], 
                   Scaled[0.02]}, {
                   Scaled[0.02], 
                   Scaled[0.02]}},
                Ticks->{Automatic, Automatic}], 138->
               GraphicsBox[{{GraphicsComplexBox[CompressedData["
1:eJx1W3lY1FX3J9dS0TS3xjQ1l0ktiRxcIo86ZEqmk5El+Y65EYlLmZpj9Irb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                   "], {{
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[0.3], EdgeForm[None], 
                    GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxNmgn8l1MWxu+9LwltJNKQ+qdFqaRkSqksoaSFyrSpLFEhhaRJRZas0diF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                    "]], PolygonBox[CompressedData["
1:eJw1l3cUl1Mcxu+9r4aGhITSptOW9iRpqdOkpZO0jOPEiY6EOEZZ6dijkjqE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                    "]]}]}, {}, {}, {}, {}}, 
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwl1EVsVVEUBdDXFnd3d7dSCqXYhAQYAMUJQYpbCc6IAQyACe7BR0CCu0sp
7g6B4powQAtF1w2D1X3OeffZv/+3auqElLSYKIoq+VMmLoriY6MojTf60vqm
6kP80q+U5cyay7bykNkR9W95WB7jKIf1J+RJjnOaUxwxPyMzSOeP/mw4R56X
f+U5GdGCYe6RICcTQyLtzI5ZNyVcX16WOblELpIZbk1rOZU29NO3lbmppK5M
eSpSgWnmVeQteZub5KVDYH7afe6o77KGtXwwy2Cm+qLsaF0n9WxmUVOfKZ/w
mGc8pY75J/mZj3zlC3XNs+R3vpHNDxqYz5FzqR4+B321sMY9HxCrj2OH2U6y
zB7TzSw1PEd4F3V+8tGEReF5rOmhrq2eyAhS9cPlEl463ltfX11Q7g3PSAF1
Ii34Yc0LeqnHOFaPFbw26xPupS4lD8rGlFSPD3sikzmgLiGLh/3ip/OS5H7z
YrIorcg2byn3mTeiiHqsHCnHyYYUUjeQheUr65eplzOaBLNRcinx4ftLs/Dd
Zk/Yk3AteuqfO3dx2CuZoh+mrsVQuuufmC9UZ8rv7FbvogZDAmsGy/ksYBBd
zR5aO099T35hu3obZfjJLbOtcgubw+dGCgOd2z3sR3hvnod35AWdGeB4F7mJ
jWF/eMRZ19sg17OOB9wn3fw9+cKzkJ8ZTA+/Lfq7Xnu5mlXc4DqnnPOOPOor
XOMqOUiivfOOO/427JW+b9g7GcsF4sLvhBOOT5Jlwx7E/v+f8w8Hfo+y
                    "]], LineBox[CompressedData["
1:eJwl0klPU2EUBuALRXQjCYIxOFIkkmDA/9BarUORoEwWlGjCkrJFNGqiLhxW
LFk6sICfQQJGZTBqjLAVkJYCEncyPF9YPDnnfU8voTeN38u1DZREUTTCaGkU
LfCLeCyK8g6TJOwJ3QOGmNIldYftOS6RlVPmY55whN9UUvT5TyzZl3nHe9Z1
czyzfzOv+Ru37C94Tjt3dR1mDT30y1nzJa/opUX30/Ovw/9vHpDLKeMQB1nU
v3Fvtl+giTvyIP/casN35iTdXHf/rt+kU+6Tu8zj/OcE2/xwz7jdtp9inEb5
r/68uSPvMkEkb+lP289wjJtc1X/Vb/BBHuO+bj509lnzitxqP8oN0vKMvhje
I3nWKPBF/8dcZYXq8I7Cu/JMxmwwz/HWXhW+K5flz557av9opuS0vSLcuChP
6x/aH4VMvS5pDnPWXnCvi+3/jvYAHiZKDw==
                    "]]}}], {}}, {
                  InsetBox["\<\"\[Mu] = \"\>", {-1.8, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["0.2`", {-1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {InsetBox[
                   SubscriptBox["C", "J"], {1.4, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["\<\"=\"\>", {1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["3.63`", {1.7, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {
                  {PointSize[0.05], PointBox[{-0.2, 0}]}, 
                  {PointSize[0.0125], PointBox[{0.8, 0}]}}, 
                 {PointSize[0.007], PointBox[{0.4463998339305619, 0}], 
                  PointBox[{1.2771956561278897`, 0}], 
                  PointBox[{-1.0806611991222994`, 0}], 
                  PointBox[
                   NCache[{0.3, Rational[1, 2] 3^Rational[1, 2]}, {0.3, 
                    0.8660254037844386}]], 
                  PointBox[
                   NCache[{0.3, Rational[-1, 2] 3^Rational[1, 2]}, {
                    0.3, -0.8660254037844386}]]}},
                AspectRatio->1,
                Axes->{False, False},
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                Frame->{{True, True}, {True, True}},
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLines->{None, None},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None, "TransparentPolygonMesh" -> 
                  True, "AxesInFront" -> True},
                PlotRange->{{-2, 2}, {-2, 2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.02], 
                   Scaled[0.02]}, {
                   Scaled[0.02], 
                   Scaled[0.02]}},
                Ticks->{Automatic, Automatic}], 139->
               GraphicsBox[{{GraphicsComplexBox[CompressedData["
1:eJx1W3lYlFUXFy0zddTMBZHMJZLUFBdM+dBj4ZafykimpjaaK4lbmsuY5ZZT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                   "], {{
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[0.3], EdgeForm[None], 
                    GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxNmgn4l1MWx++9b0aiLKFkqZS0L5aaqLShRQtFliKJZCpMhEgh+9JMRrJn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                    "]], PolygonBox[CompressedData["
1:eJwtlgkQV1MYxe/7XqlslcpSad9IRfuilGghbbRINLIMGQrF2GqQbVpkTRll
SbbKVikUhRahLJWi1RoRyVIov+O8mf+Ze8699//effd+3/luzaHD+14VKaWP
QAlwBuKCPKURWUpnosvA18OfgTegnQ/eZk4p2rn0/Ui7CrwL/w3cxNhq9Hvw
zWAvfCl98+B3g/vgy0AZ+r9Fb6E9h3cMph2tddA+zfif8G7gS3Rfxs+lHYm+
hbGbw2vTO1rABzI+jPFy6A3ojaAiuj36YPhm8DZ8MqgOP4T5xzPeEAxE90b3
gz/L+DnonuiztQ70avQacBi6Kvoo+L/6Bvg0rQ/+BTg1+Z0z4E+BP5K/4TR4
d57Xk7FH0f3hz9K3Hz6UvnngDXRJ2lfpexP+Orgrua8svAtYij4a/RdYGJ57
J2jM836mr6f2GpRn7EdQlb5q4Ah4N/AOYzXQT8CfBHvQXUBz+CU8YwJjE9DT
0Y+Hz3Iq6AO/lPFJjD+Gbo1+AOyALwDj4RPC8TMGBHyl9pj55dG/0L6AznSO
6D16dvjd2oNTxHl+d8YfRs9GzwEfwGeApfSfzngX2kboRxmbCnbp2eAR+GSw
E/5T8truB98nr/E3/vcSOqe9XHsK/wSUQx+Hfgj+MPgBPgkcBB+uM9VeMifx
7l20vaB/g4aKndxnqTPpwdwh6GuY0wP9odYe/nat4TP4p+F3aY03wm8Ix+Zb
YAn/mxJee3MwCv5e5rFNoDK6CpgOHwDeZawr7+tB21rvUD6CxcnfoG/TN2jt
+sZv9SzFGGNrwfrwO/WuCrRK/lbhs9Q376BvGVgCX5e816XCc7XnV8NHhM9C
z/xIewsOz5wjH8NLhPdyob4P/lY49+UZ1eD9wfvoeugV8ANF7L0Geiq3+b4+
mb9ZsXoRenTmmG2K7oTujB6H7hyOCcWCcvxE+MWMj2f8HsWovCRzrryi/UPv
K8bkSQcx9+Dc3jYTXZ/xI9AnoZuBH8A0+nYz1glUZaxx+FmtMnvZftrxyZ5W
W3vBnEbwJjojeCswW2cDxjE+GHwI3w5WaS/C36KcOT/8DP1Xc+ooVvn/avgs
UBa+ibFRyn3aAWFPk5cpZw5j/NDcXimPezG859pr5UAfeWnY6wagr4HXp+9k
+Jf09VN80/cSfEjhvTXRzyV7cOnce/b/XqHXgVK5+SrFO20JdF3alcl7USu8
1kaF19cNf4s8X97TLOzd8qAL0YPCteC6zLl1VthrlWPyot6KoWRP0lk3Ucwn
n7li5YPMZ6WYeS7sufLaA8lev7HwAnn+7sxr1lrXJ3v/2sKrVAMUi2uK3FZM
ysuXF7knTx+Ebq8cQl+ZOXbqoZtmjiHt7Xe07TLvsby5HDg2s0fvhv8KuvL/
6soxxXKYq6bskDeBynqGPChcI1Uba9OuRdflHW31bvBVuGaoVhwF9iu/wt6l
GrFT/lw8S2tQrVKNUG1Qzfoa/k34v23lL/DvwlxrGBrOEeXGx/Q9Fq45qjXK
kZKsZVbYuxUDz8MrhteaFd6yDV2p8JiazK+Ru7a2oa8WvHZuPlFrhFcDpRVn
OvNwDir3vkY30PNzr0U5VgG+NXMt0hlk6FAMFx5+HPOPQX+WHON/ov8CtTKf
wT74XtAnua+Dzhe8mPwf3Y3ODNfCEYUXdwzXLnnyF0WODShy9PZwjig3toA9
8M1gDfzz5NxuCTpkzvFeWh+ok/mO8TrtZegNyR5zOXwYmJ8c859mfoeevRzc
C58Ixia/YzR8DHgq+ZsWMP8K9MbkZ9wKvy38X+WU7npj0VuT73xVwzmi3NAz
Dg3XCNWGKcl3lcXKv8x3lgvCHidv051A73ojs7frnYvCd0jdHfUfxa5qlGqT
YnhbZg+S9+gbGmq+agq6JdgOquTm/FKL3HuqvdQezlXs09ci85ldHP6P5r6c
vJcnhLn2VHfHluFY0x3yzvAdUHe/bcl3W91pdZfVHfdV+JH8pzn9c9DnhT1L
XiWPfFDnHc7F+xWPYQ+S9ygGt8APCd9FdSfTWc8M39105h3CniIveSj5bvQO
vHHyHUm1tk24tqrm6m5UOoq56GaqXWAFun1xlk1zc51pP/Qd4W9TDVYtXVjk
lmrqP5nv6LqbK+d0t9CdRHcR3TGuhY8Ei5LX1C5cQ1Q71Hcd/PpwbMgTt4fv
lLpLKufb5d5D7V1HeSL698y8kzwrd5+4zrBe7j3VXspD2+auqaqlp6ArySty
c53JH5k9Qt6gmLlU/pr57qQ9+Q/f7pFm
                    "]]}]}, {}, {}, {}, {}}, 
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwl1EdwTmEUBuA/EczovaeJ3ltE9LBgpYToJQlGT1YWLLDRO6MvsdFblCB6
720Qvc1Y6UTn+cbiyXvOuf27909idm56TlQkEonzZ3CxSKR5dCQylhf62vqm
6gN81S+XdcxayG5yv9khdZE8KL/JwzJPHpFHyaeAY+E85ifkSY7zXX9KHpRn
5A95Wv6UrcJ9uEZLOZFJtKa72SHbJ6uPyAvyrzwvI7RjnH3ayikkM0TfXkZR
V51EPIkkMNW8nrwub3CNYqTS0/yY899Ux7CaNbwJz8I09VnZ235p6hlMp7H+
gSzkPo94SDPzd/I9b/nIB5qbF4U1DGsd1iKsD63MZ8pZxIb70tcJx7nmHWL0
xdlutoOd4Xrmfc0Gq+MprS5LGdoxP9yPfdLDGqjHM5ws/TC5kKe2D9TXV1eU
e8IaUSGsJcl8ts8TBqgzbVvGUp6bZZg1UdeSeWE9qKkeI7vKLuH7UdeQ1enM
F8d1kvvMq8mqpNKRDqSw17ZGVFFnyQkyWzakkrqBrCyfOddi9RJGk202Si5i
RHhm/UiZRDl1XVlePnbcgvCuZH/9UHVC+Ibopy80n6d+ID+xW72LOAaRaZ8M
OYe5DKSP2V37zlbfku/Zpt4aniN87+GbM9siN7MpPAu9GenYXuF9hPfIY0rx
hB7hvdneU25kAyW5F35jzrdermMtd7hNgflriod7oQS55JDC0LDWchUrucoV
jjrmFdHqi1zmEr/N2sg0xx1WvyRWHcdZ81/6FfIcf9Q9zPPlhPBbiP7/P+cf
IcOPvw==
                    "]], LineBox[CompressedData["
1:eJwl0ktLVAEYBuDjDGhKXiLS0pULLygo6k6zWoyKTpOp0EKiQNGlmYkG5aLL
T2gTeKkWqb9CKKk0JUXUbVnN5GSGaLvKnkOLh/f9vm/O4SCW9t3qHsoIguAp
TyJBsMUmZdEgSDosENMb7W4zzCu7FrsT+gAX6DU3yzHGyeUjJ9n1+zd80neY
4Rnf7d5zT/8gO7yjXZ/gPh3csIvLM3QxaL4qH/CQbhJ2G55/FH6/zAq/jUxy
yGbb/rF7vd5AHT3h+zhwK5YlnOUKcfc1+x9cNt80J2QhvyniD+vh3a1TP8dL
asz79rXyr/mYWQLzT/sMGeGX3WnmuWaek0ccsup3ezzXX9DvvhJ+j74s00zr
U5wK/5YUsMeS265Mk+QbKd7Zf5Ff+Uw+rVz37hZZLauY1POI0W5+67m7+qJs
M1/Ss7kYPm9+bX9HH+U8lXZNcoQKPeVeHv3///UP0RlOPg==
                    "]]}}], {}}, {
                  InsetBox["\<\"\[Mu] = \"\>", {-1.8, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["0.2`", {-1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {InsetBox[
                   SubscriptBox["C", "J"], {1.4, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["\<\"=\"\>", {1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["3.62`", {1.7, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {
                  {PointSize[0.05], PointBox[{-0.2, 0}]}, 
                  {PointSize[0.0125], PointBox[{0.8, 0}]}}, 
                 {PointSize[0.007], PointBox[{0.4463998339305619, 0}], 
                  PointBox[{1.2771956561278897`, 0}], 
                  PointBox[{-1.0806611991222994`, 0}], 
                  PointBox[
                   NCache[{0.3, Rational[1, 2] 3^Rational[1, 2]}, {0.3, 
                    0.8660254037844386}]], 
                  PointBox[
                   NCache[{0.3, Rational[-1, 2] 3^Rational[1, 2]}, {
                    0.3, -0.8660254037844386}]]}},
                AspectRatio->1,
                Axes->{False, False},
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                Frame->{{True, True}, {True, True}},
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLines->{None, None},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None, "TransparentPolygonMesh" -> 
                  True, "AxesInFront" -> True},
                PlotRange->{{-2, 2}, {-2, 2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.02], 
                   Scaled[0.02]}, {
                   Scaled[0.02], 
                   Scaled[0.02]}},
                Ticks->{Automatic, Automatic}], 140->
               GraphicsBox[{{GraphicsComplexBox[CompressedData["
1:eJx1W3l8zFf3jlb5UWOp5dVQW0mHt5U0jCVvONWxVSsGUall7IQgbVSZ8NaS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                   "], {{
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[0.3], EdgeForm[None], 
                    GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxNmgv819P9x885H5JSLiH1N91U0qqli3WRdPtXSCpliKREKtMo5ZYiscZy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                    "]], PolygonBox[CompressedData["
1:eJwtl3fYSFUcx8/93VcSQkpEIZJNRuQ1klIe6q3XqEQZPUKlpdIulaanJw3t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                    "]]}]}, {}, {}, {}, {}}, 
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwl1EVsVUEUBuBHkeLuXqC4uxcvJASSLnAo7lCcFQksgA3uEpwlsMFKC8Xd
3UtxSwgeSrFvwuLrf865c/vunXltzPCkhMnZIpFIJT+GZI9EmkRFIhN4o6+g
b6RO45d+raxo1lR2kclmx9S/5VH5Rx6Xh+RJeYoTnOE0Kebn5F95VkY4T6q+
q9/XTJ2NdVTSV6a5OkZOldNoQTf9YfdMVx+Vl2VOLpGL1oyzppWcQRsS9W1l
NDXUNalGdWKZaV5L3pK3uUke4uhhftzn3FHnZROb+WB2ijnhPWQv6+LV85hL
fX26fMJjnpJBI/NP8jMf+coXGpv/lFlkhn0N+04z8/lyAVXCO+pj5A+f+YBo
fW72mx3gIOnmfc0GqatRUF2YQmFfWGr2zJoBYQ/USQxltD5RLuel64P0tdXF
ZUrYI4qp29A6PK81LxioHuXaGlbz2qy8WUN1OdlAjg/nQmd9J46EPaKsuiMd
yHJfXDhf8zKyNO0Zq28XzpBUdT1KqUfLSXKMrEsJdR1ZUr7yu1aqVzGSMWYj
5AqGMVE/XNakiLqGLCqfu29ZOC/ZXz9EHctg+ukzzJeEc5WZHFInU5WBjLJm
gFzEYvrTx+yhtQvV9+R39qn3hvcMfzvhe2e2R+5mV3g/vnHdPMH9PcNzhnOj
MN3pbX7B9Z3qHWynAI84bb5NbmUL98Nnc8L8PfnUd8nPbGaFPQ7fg7DnciMb
uBGegWPueUdu9RWucZXstCQ+nKnrb6mirhqezTyK9VwkR3hu8zRrpoTvfNT/
/zv/ALyIjyg=
                    "]], LineBox[CompressedData["
1:eJwl0jtPUwEYBuADhQEESUSJUUBdQaIJRhgRhARKta0FWRwAByNQV1CCiTKI
/gISVuU2oP4FEzXxGjUQbpOIIi0VRWSThzA8eb/3+3pOztBTXbfiyawgCEYZ
yw6CRRaoCAVByuEFLeY6uwH6eWkXtjto7uUinXqDHOKNe1Q/ZO4jo7/lq3mF
CSbZtPvEPfN9LnHTcxE5zGW69ag8Rjs9ept8wAhXabOb956H5iWZrx8gj0IK
WLZ/5F5jruU8HXqSf24n5EnKuLLHfdb+DzH9uh6Xx/lPKYHdnHtCJvRyZqjW
t+zPySyyeWofkn/tc2QuO3ZHec41/dnet7DNF7/7zZR5mhvun/WM+aP8xbj5
CSWkOcIGH9zWZYof/GSN9/ar8jvfOEyYLu9ukWflGR6bi2kmpr/z3F3zaxnR
m8xFNNKqv7K/Yx6kniq7C/I2p81p98rQ/v9rF+chTjE=
                    "]]}}], {}}, {
                  InsetBox["\<\"\[Mu] = \"\>", {-1.8, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["0.2`", {-1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {InsetBox[
                   SubscriptBox["C", "J"], {1.4, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["\<\"=\"\>", {1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["3.61`", {1.7, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {
                  {PointSize[0.05], PointBox[{-0.2, 0}]}, 
                  {PointSize[0.0125], PointBox[{0.8, 0}]}}, 
                 {PointSize[0.007], PointBox[{0.4463998339305619, 0}], 
                  PointBox[{1.2771956561278897`, 0}], 
                  PointBox[{-1.0806611991222994`, 0}], 
                  PointBox[
                   NCache[{0.3, Rational[1, 2] 3^Rational[1, 2]}, {0.3, 
                    0.8660254037844386}]], 
                  PointBox[
                   NCache[{0.3, Rational[-1, 2] 3^Rational[1, 2]}, {
                    0.3, -0.8660254037844386}]]}},
                AspectRatio->1,
                Axes->{False, False},
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                Frame->{{True, True}, {True, True}},
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLines->{None, None},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None, "TransparentPolygonMesh" -> 
                  True, "AxesInFront" -> True},
                PlotRange->{{-2, 2}, {-2, 2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.02], 
                   Scaled[0.02]}, {
                   Scaled[0.02], 
                   Scaled[0.02]}},
                Ticks->{Automatic, Automatic}], 141->
               GraphicsBox[{{GraphicsComplexBox[CompressedData["
1:eJx1W3l4jNcXjtJUoyHUGktQy1QVTY3twSlDEVuEosrYlzbWlKRRLVUZpD/7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                   "], {{
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[0.3], EdgeForm[None], 
                    GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxNmgn8l1MWxu+9LymJpIlCkySKCmkTKdlKixJFJG2TrZQslSj7PmOLTFMp
Gsq+jmEwhpjGOsbOSJiIjCXDTIM5357n92k+H8c573nve+/93XvOc557/+0w
auLgCSWldGqVUvyXzg/JIfVCrsvy1Q+ZHfb1ISvC3izJv1HI1PCdFbIy7Ab2
bRzyesj9IReHHBDve4dcEvac0DeGfBR2Y4+zacgNWfZWIT+zj3G39nj03cQ+
nrexb/OQA+Pbn4feLeThkF+FtAi5ImTLkO2T3jdy/83tb+R2W3kuLT024+xg
H8872sdcWlkz/k7WTUN+GXOoE7JxSGv7moUsjeeFIVeFvavnwvg3Z9lt3Zbf
sUXIVeEfHzIu5JF4vtpz+UPIjSFdQ+ZlzaNDyCFZ82sfsrvnx7z2TJrHziF7
2MfzqpA2IXuFdLLNHE6MfgZkzfHQrL4Z64yw+7H3YTfMGqMb65I1RnfWL2uM
vUNWu+8eIZey5yH/Dfsar2879id8DULWEBtuu1/IP233Zk3i/Tehe4X0sY+2
a20fErJdtFkX+qCQn+wbHHK4bb47ItoMCZnLHEJPCDk55HB+V/iGhVwY9gUh
/w77/NDnhXznOdXWqZFjqLnjpYWfR3i8ISHvhDwd8huEMUMmh+wQsih8C0MW
h31ryJiQefF8ZMiokFuy5jImZKzndVTIOOujQ3pGm/dCLwv5hX3D+Tbk2JDx
7KPndFzICfbzfJJ9I0OmRD8jQiaF/duQ00NmhEzwXEaHnPp/c5loH8+T7GNe
R/NbPO6OYbfMmlfrrLGnuO8TPK8zrJnLWSEnh5wScqZ9PE+1j7lM99jMZZp9
E92O33F8yM3e82NC2mSNcU7agEdg0SyPR98zPR7P7bL6PS/khZAlIeeGLA+5
zeO/GLLU370Ucof7uyvkghCw856Qi5Kw7+6QC5Pw8dIkPK2bhJ3gKbi2Ignr
stuBZ/W9V7X4PdfrtX6uWTgKRvQ2doJf4OtlSbgBpoKhxCljgFs1fEVv5TGa
+B1jbu1n1mkbP4M7Td0n4zX1OzDp8iRMY2zyAPy6Mglnt/Pvb+C+T/H+jPL4
YFgLr/ssr2cNT2v4im6ZNmAr72p42sxzae13YCoY2sbzALfAsQONYcyvflY9
AEOpCdQHcvbNJGwFk8DS9h4bLG3nOTA2WAcOfpmETfsn4RM4BAb9MgkDwVjm
AU6AF58k4WzHJEzt5LmBo2Brl7BPysLc65JwtavHAku7eWwwFkwFWz9LwtZ9
Q65Nwt09Pd5+ntcXSZjaM2S2/Z28Xnu4z9b+jucb/FtoB1aBW2DEnCTsrP1O
bPD0hyS8Hehn4pR4JZDB30HJ2OpvwNqbkrBxiDF3aBK+grXgGjgL1oHFF7hW
HO1+yQfymhoyPwnr6HuE3xFbYAKx9m1SbTg4CYPB2pFJOEs7cBYMBnOJSzAY
zB2dNuBsDXfRYzyPX/jdAtvM4e9JGHyL5wKm1bAWPd7reJLfHe851nDrZL+j
Nozw+iz0/GhLfhKDO3guYC4YCN6CraclYe0kz40xwdkp7hfMqGHtGX7HmGf5
HXOZ6mfWb5qfqQnTPRY4O93vTs+qGYuTMHaG+3w/5LmkGsI4YBbYe0cWJpCX
LydhBPgA3s7yWK+F3JmEj2DteR7r9iwfuAU2gqXgym+z8LbGO8FbsP2+JGys
k4RX2GDXRln4C/Y+kMQ9wa0rqVFZuPmG3zHXLuHrbIxjjWb694z2WrBOi+J9
XXO5x5PyhBxpkYQvYMs/Qh5NwoZXQn7nd+znNd5T5Gp/93v72/k7cpv83CfG
6Z713Dd0H3Owg4wZYNzArDwnxx9Lymdy+a9+5t3Xnivvxvzf3j7kOYJdV0c/
p2T9nlND/zopH68l1pzDV4Qeax5FbIMVI0OetH1EyLshf0wbcgy9Pvecv+DG
U0m5RB696mfeHQX/yarn9LvQffwpyQcODI73g7J4MLl2i/3P2ibvdsp6hpf8
OSk2a/GKTY4Q18TcNMfRvY6lv4X8xe+OcbyTY8eFfbu/IybgCcQ5sXyHY2XP
LE4AHyBm4QTEKTELJ6jcbqn7eM+/jfkT7+QCfID4pa4Tw42yeD+1oWtWPFHP
Nsnav50dR/haEAfhr7Jimpgj9qh5nEEeTMrBvakveUP9Q+/gWHnM8XODY+YA
7yF7Cn4SF084Nogd4pVYJX8Yk/wq0feHXs/53l/2Gl4AJ9vce/Os96tXFp4+
6/15znu03PvBXuyfZS/3Pi/zut1uX20/2bvzvMYveJ07ZPG2WV6nV7w2rMfL
XhP283nv6YKQZ5KwnrimloxMwpLX0gZsWpHEs1int5Nyh/V4Kylnn0w6D9AH
GPW69xaMf9frSu6/6X1Y5pioxfPf/Vs/8FjERs56xv7Q68k6z7af2CPm3/da
grtveH+IU7jszKQzO9+DmR8nYSU4ebzxDe7COZ13+KfZB9eYEfbZWXzo0ySu
09F7Dy9t5H7w78LeZH0Pd/k8icfAYUYZ39bYhrvAac6xr1fSOHwHt5npMXu7
z8887ldJ/Axuxtnt+9D9Qy7KOj9yNjw3q1+eZ2X1BVf4VxJvgDNcZt8hbvOt
+4QPwFHgCGDjmXC4sP+TxGH6+x02fIGzJO8GsN9Z84AzNffc+nkNv/Q6fOx1
2yQJJ2l7mPuCC5E7nKN/TMLPbW3T/+VZ84Z7cfcALoAJw+wb7DnA2w50e4KH
37tHVjzhInfBDWokNRDODd9G13Gfrf2MDV6S58TeaPfP3H70nJlbPccSMQDX
hNfCP9lbzv69HAubZe0j67F51poQa3wLpwaTtsjCJPrc1PWXvuDNcOYts+xu
tsFNMLNx1rhwaHAKPl2bS2O357st3Z4x67n/Jlntu/u7Ju5nG9v4iSfuKYix
L/yuu2OqWVb8sMDbe83ZW+4s2N8nHBPEAxj58yzsAW9aZNU/ahA8b3ISHmGP
s97RfrCqVdb7VvZjwwnhimAsud4xK9/Re9nehf3Mwlv4G9yOOvmc3+Fvm+UH
G3fLej7HbbFnuM2utp93O9pQX+F8U63bZ+Ewmmewenf7sT9IqqPFbTq4PXNs
7fm09pzhwGAbNY/45VzMPSN5dFMWn9vWNndzxDXnQeoodQDcpRZS/xBqIrV0
/dnK+/jrrLsqnntkcTLeo/fl2W32sQ3293AbeAi1rYbl+2Vh/CWeK3jJebB/
Fq+73LlH3sEjOcc2t4bzwffQPFPTD7Yfu3Z2bek2vIMjwhnxt/d7nuGZZ9jG
vyD0/KxzKb6+bjPIvq5u08/t+9vmDPuRf8smzpetnSPMlXNvW2t4KhyV/gb5
W3yHZfGOGz0eY4Fb4Ncg+wa7/WHup3MSBoPFnCfvsh5mP+fMQ51r4OlA66FZ
fATNMzl4hdtzJgW7Rrs9viPcz82eD1gKDxyZxTvIQfITfsi5bHgWrznW/sn+
7ij/Fny8W+wY5htyk+85d53q/rHPThrnONvgEjV1F8fmKMcnNRb/KvdBe7jQ
cPdPjoBLtAd34e+ch4/0+g/wenInOdbrMNftaMM5ifsguOhlfsbmHmacY5X7
avwN7Rtv/wm2GzoGTvRY+HhHvBOjJzq2OX9wd9DHvpPcnvM+fs7InCWYP2ey
Of6mj99PcBv0xKwzyyTHCft4uG3wFs07+Cx3wvTTN+m7CbbJBfKE3OQMNNn9
3+TnIV7zKd4j7nvxcw5ij6c4Nvq5n/b2ne72nPvpk7MUvACO0c+xd6Zj+qgA
wtGVMHVI2KMqYfPdjnvuLzhfcDYu3rfF3uNbbbOn+8R392SdT2rvRrufW93m
gejg3qyzysNh35d1hnkw9PtZOf778N+fVf/bht24Ui2pQpdKmMcdJ/PhvLNx
/O8tx2GPsB/I4sIbhV2nEo7XDX1nUU41DZ0r5RF93Obfdb1t+uaec0nWXSd4
AnbBAebZZp3h3HO9F+vvtWzzfoHb3Jl1hwj/X2S7jfdrgfvmmTtGcGyLmFer
onp1mvuc7DHneQ6cDbi/qGu9xDZ9L/VYrTxXMJvfQLt6zvFFHpO9YW/H+Fv8
cJL1PN79MH9s5rddzO3ponq3Tdgn234p3n2WhT+3hm9tETddHb5vi3haz9DT
imL+rNBTi84znUO3qHRG+Uu0X5XFIZ8N/XHWHeMh0WZG0dp+FfrFLF5Djl/l
3B8WffQoOsfuH/YjWWfXp8mLImz/IfR/i/5OQh99K/WzLOx3i2pK39CHVjpX
vR7+AZW4zwthf+Icfyb0G0W87j+h1xVxqS1Cf1mU781Cjy3K0U9Db1bEqVcV
/U5+4+qwvyjiaj+F7lgJz38W+tGiXGhIvBfx6K3DblqJcywJ39IiLtc89KaV
uBF5fHRRLm9fFPfE/Jqw21aqRz8S7JU43Cn0XXROXRz6kyKe/VHonStxznZh
n1i0zh+E/riIj64o2if2CMw4ogg32M9ORXtKv0sdV3Cc9TwmiYdzPuGshXAG
62GNH34Ox+dOdrg15xPqJnyYc1YvYzPYCjbDv+BhxOQat2Fuq90vfXIW4Fy3
2n7OjHu57bluP9/jDTQmzDY+rHJ7zhH8rYTzLfwW3ou90u+nu83FbkcbcOV6
97PC/XKuR8Ab/mYCh+fsBDcBn+ENc/0buTsjd+APrANrc5nbw/nX+hn7J9uc
MamZVzpHxrrPoV5zzqecHSZ4Del/ibGvrm1wA/z4IGkdVvi3gJvXGaO4vyM3
Gxlr+BtQF+8FXJOzJ+d8eBxC/42s53ism40z23teszw3cISzLufevWPxNiqq
lbS90xj1u/B9m3XHRp2h3oBrd9nm995N3hfd2dT43NC0oR287i7yuOie5p7Q
LYvuMx4M/U3Wfds5RRgBPuwacd6v6N7qBvK1iGMu9Nz4Td8UYSK/A1x5Oevb
QUV1iBp0X+ivsmosNWo716kh1K6iO7s6ju9tvafg3jivC3/P4BzPeZB1Ixao
8/z9o3ZngN3fOUV7MJk7g4uNRfgutH+d35H7YAFt1jnvLnJ7+jvffa71nnFn
cmTMeU/jCRySnCcXO3v+nO3hIXzLHMdH212L6jV1jjoKV3ksfFcWxc4fWb8s
briPMYS+3w4ZVOk+roHHAluoM/u71jQJ3b+IXw8IPavoPvSC0G9kcYYLw34n
iy+dH/abWTj8StitK+HMn8GzLG68ZdgHFeXm2UX1j9o3uaiegXsl9AtF9w6P
sjaV7knfDN/rRXcBL4b+a9Hcp4d+JQufn2GORXu+eeg+RXxw3+ijTREvep46
UnTW5B/WPJ51RvtD2N9lnf/mhf2PrLt5auCTWXXwJ/ai6G718dBPFN3LrAtp
Vokz08duRf2A/R2M/43i/VaVzvf8pr2Kfhd6om14AVyBWO0Z+qGse82rw7+8
6DxxZugdK+3Xh0V1hZryXui3iu5Njg/dtYi/jwr9UdbfHKirh7u2vl1Uj6nF
9fm9RXci1OGGrsVjQq/J+jsAvGBZETeAb1JrqbPDwndZUSzBCw4u4gYNwj6m
6E5zRU7rAZwY2LZSPQbnyNHjnKdwhAOKeMLnYGHRGWdE6GOL7ogHF8Uc8QZv
JRaJw41Dv1p0P3V76NsoFmG/S54W3Xu8mhVzxNvwSjFNPH9exCfgEr2L4oaY
2SzaDC+6p24Q+p9F90THhv/Ionvc+pXOAHAGMGxf49gdRRwI/sOevON9WZ5V
+3sm4XG3IkyGu80vwoeHw36q6G8M8P2Hijg/HIRYJ86/z4oPYqNjEW9jX9qE
/roIW/5VxJ/gTocWYS54C+6OLrLhKZ8V4dWnWd/z7S3sVSW84ZzxSNFZY2bo
3Srdj/87C1/AlpVJ9Zq/HXydhftg/mmhpxTduwwtWjvWDTxYYUy4l7XNuuts
XYTdxMOXWfgOtoNh7T1Wl9CnF509nwj/pKL7kO9Cf190T7dfEa+F03Kuur/o
bLV7Ua6Sp3A3MBe8rYpyhnwZWBQfxEb3sFtWuksi514qyjv48k7uv1WlGsa+
dyKvK/09pF743i+6c4Gfgo9gI7g7zPlybehriu7pfxX6w6y/T64M3bzSnVfn
SvWV2toLLMz6uwFr8FTWOuSwnyu6e51NTBXd5V9StO6s+Vxyuug+nrjuUim2
/xb2a0V3uJeGfi/rrq9rpdpP3SePu1XKZXj9YUWx/UPWnJjP2iw+AZdoH74O
le7UqAMri2rBHmHvXunfSe1SdO5lX14uwnTwfO9KHAL+MId1LbojAQO6V8KB
RWEvLPr7wIFF5wfwirMvWA/ONy6qN9Qa6iTnW2rl/wAYCpIJ
                    "]], PolygonBox[CompressedData["
1:eJwtlgnQl1MUxu97Xn1RtFjTp+VrsbdrlyXVl5IWPk2WShnLNKRiMIMwRFJJ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                    "]]}]}, {}, {}, {}, {}}, 
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwl1EVsVFEYhuFpcddCWyhQXIu7s4ZCi0OR4M4CEhawwT04C2ADbHBrS3H3
4CS42wIpTnF4Tli8837/d8/cm3NzZhKHTEydEBWJRBJ89MgVidSIjkQG4aG5
uLmavBvvzAu5hK4mt+FdunT5Pe/hD5wR1vNe/siZ/ImzeA/v58+8j7/wAU7n
tu5XS/4qL+KS5lKoLZfmkTwKddDOnGHdaDmLT/B3Ps4/OCnswZp6PAb10dPc
gH+6Hi+XQ1nEIRbjXCvPp/g0TuKXtY25k36/fEb+y0t4KZ7JhzBJnhzeCRKt
bc2VeQpX4St8FZdxHddQXf803ANP8ALPUUP/mt/gFbLxFrX1U8N3Pa+zHCMP
C9fM15Ejf8MWbMU23NQnW9tNjsUfRMx/uTHP5NvWdJPj5eHojjRzKs/GPddT
zQlyft4e3hPyyU3RBNnW3EWK3Me1BZiPB7piuqpyUa7CAzEArc2twhkK7wpF
5DRuyS2wM7xLFJb7c3Nuhh1yJRSS+/JQ7scVUUCuwAX5vmfPleehd3imrhfP
QQ8MMffkcsgt50Ue3PG9Wbpb3NWcIschSs6FaDTCDF0S1w/nDA3D+QpnSt8V
/eVkno4y6BLQ3XDfafIVfo3N8qaw//Abw0XdRt6A9WGfeIlz+nW8FmuQBzdw
XL+aV2ElonEJh/UreDmW4QLO44D+cfjBy2fDvsK9w9nQjeeG6BX2yIPxW9/R
vI/Hhr3IR/hoeAZy9HW5vT5TfoQY+aDuEBbjWDib+g76vTwinP/o//83/wAu
goxt
                    "]], LineBox[CompressedData["
1:eJwl0ktLVAEYBuCjE5URZtpWKzBIdFmaQaWNc2l0ZQsvizDbz6iQWNDlF7TN
WZQuKn9EUGJqWCku7OJdI/NCC0sNzIKeg4uH9/2+78wcBj3dnmlM5wRBkOVR
bhB84D3FkSBYdnhJVD9nlyHNK7s6u4h+kws0mavkbYbcE+aDejvfzG+Y0j/y
hKd8txujR79DLW0+VyPvcpUWc1Tmcy18nzkp73GfFPV2k77ngT4l/8g9dvnH
3/C99g9lhWfrZblskLf44VYkT3CcePgu93H7tfC3mlvNMXmMTQr4yYR7yi2h
F/KMs+Z1+zL5y7zFc7bZsN+Rv1nnKANc9+wLucZq+Dfw3Cp9ej833N+Zl/S3
coWs3ssRFshjkVG3OTnPNLPMMGL/WX7hE4e5QrPvvizPyFIe64e4RNI87HPd
+qCMmy/qB6gmZn5t36l3Uckpu/Oyg5P6V/eSyP7/13/ZT1JD
                    "]]}}], {}}, {
                  InsetBox["\<\"\[Mu] = \"\>", {-1.8, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["0.2`", {-1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {InsetBox[
                   SubscriptBox["C", "J"], {1.4, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["\<\"=\"\>", {1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["3.5999999999999996`", {1.7, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {
                  {PointSize[0.05], PointBox[{-0.2, 0}]}, 
                  {PointSize[0.0125], PointBox[{0.8, 0}]}}, 
                 {PointSize[0.007], PointBox[{0.4463998339305619, 0}], 
                  PointBox[{1.2771956561278897`, 0}], 
                  PointBox[{-1.0806611991222994`, 0}], 
                  PointBox[
                   NCache[{0.3, Rational[1, 2] 3^Rational[1, 2]}, {0.3, 
                    0.8660254037844386}]], 
                  PointBox[
                   NCache[{0.3, Rational[-1, 2] 3^Rational[1, 2]}, {
                    0.3, -0.8660254037844386}]]}},
                AspectRatio->1,
                Axes->{False, False},
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                Frame->{{True, True}, {True, True}},
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLines->{None, None},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None, "TransparentPolygonMesh" -> 
                  True, "AxesInFront" -> True},
                PlotRange->{{-2, 2}, {-2, 2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.02], 
                   Scaled[0.02]}, {
                   Scaled[0.02], 
                   Scaled[0.02]}},
                Ticks->{Automatic, Automatic}], 142->
               GraphicsBox[{{GraphicsComplexBox[CompressedData["
1:eJx1W3l4jFcXt9PUNFpbjZYo0qm9mHz2g8HTqmUQS1Wn9iKEpkijGmqZqpYq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                   "], {{
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[0.3], EdgeForm[None], 
                    GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxNmgfUV8URxXf3RelFwYaGJorSRKkKIsUSQEAREBAQEDtNUQRExR4bsYKJ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                    "]], PolygonBox[CompressedData["
1:eJwtl3kQ11MUxd+7X7QglUJTlkrRQqV9UYoWFbKNaMaSNYYs5Y+IhmxjiZBd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                    "]]}]}, {}, {}, {}, {}}, 
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwl1FVwVVcUh/FLgrtDcXdpihX3GZ6Q4FAsg1OSJ5hp+0DhBWlxHaSFF2AG
aHF3CaG4FpvpAA8dmrRIcf+t4eHL919r73ty7jlr3+ppGanpuRKJRB1/+icn
EnWTEomRuK1OVufGQfW/6iWcR12PO/AmvcPyf3yIH/ER3szH+DEf5Sd8nLfw
SX7KJ/h/PsW/cUfXqy8/k5dyXnU+NJDz83iegIbopP7dvonyNu6ibiS/kJdx
UXUxlEBxfKvXGCXl0iiFl/Yu11uBO/IOpMu7uJv1L+V3cgp3V++Wz8rveSWv
wl/yPkyRp6I1KtpbGZXwnXoBvscPKIh++gX4Xnx3jFSPwgg8UGch2/o57qXX
Q/4R07AQ03HR2mJehDIYi4d6l5AT7wo7sDO+D67pp7pWH7l8PCe8xPO4X/xj
/Tpeya+xB3vR0mdaoRlaoDnm6P9p71uugjeojEEYbn0g51i/gb7qwer5mIdb
ekl6teVcXItHxOfQXt0OB+SaSMjDuC23wX65Bj7im3jWel9jn1wdHzAEY/SG
crV4f6ga7ww3/e+feS4GYJh9/fkn9MVodT+uhBT5q5gBpKpno6mc7RpNYhbU
FWJ+8UXMbMxXzCBmyfViluMsoWHMMMrp9457l3vxTJRFT/TRu+zaM+Tz/De2
x2yjMB7gjN6WOFvYhEK4j0z9jbwB65GMqzisv47X4td4nriC/fq/8BqsjlnC
hXjn+nfxAefiOfN5fssZ3CSem/tsymnx3vW7qnfy5JhDuSz+iBnSO82vODPu
HVnYrp4U58C+QnEOUASF4wzEPFrvLG/lceo6SZ9/kz4BCEiWeA==
                    "]], LineBox[CompressedData["
1:eJwl0jtPk2EYBuCvLQgLIkICOCj1wA/wAERRUaQVbIlhUXSruHJQEx2EBfEv
EFYOAwzCaAIERRISSYh4AkQqmhaRAcVf4NU4XLmf536/92vypdFUV1tnKAiC
QYbCQbDCO8ojQbDp4CUx82ldD91M6+K6kPkeNdyyn5OPmXPeYs8zd7Blf8VH
8yfGmeCHbpGn5l4uk3LvkuyjgXb7FVlES+737M2yn2fc4KZu2XsGzO/lb/mH
Pf6yzwf9c1nt2YQ8JZPyPjvOSmUZh7hG0vlbfYar9jv2RnmQDMXEuKtvkllK
eMExXda9Krlt/8kk0dyuPy5PsKM7zBQn7XHZKpc8s2v+xSgjjPGdem575qIs
5BsFuW/MgnubMs0XvrLBG/2aXOczB1hlXp/wrgvmo3JY5nM+913tr50/Mc/K
ZnudOUwt1+0z+ofmR5zliO6MfEClOe28IvL/f/UPguNMgA==
                    "]]}}], {}}, {
                  InsetBox["\<\"\[Mu] = \"\>", {-1.8, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["0.2`", {-1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {InsetBox[
                   SubscriptBox["C", "J"], {1.4, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["\<\"=\"\>", {1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["3.59`", {1.7, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {
                  {PointSize[0.05], PointBox[{-0.2, 0}]}, 
                  {PointSize[0.0125], PointBox[{0.8, 0}]}}, 
                 {PointSize[0.007], PointBox[{0.4463998339305619, 0}], 
                  PointBox[{1.2771956561278897`, 0}], 
                  PointBox[{-1.0806611991222994`, 0}], 
                  PointBox[
                   NCache[{0.3, Rational[1, 2] 3^Rational[1, 2]}, {0.3, 
                    0.8660254037844386}]], 
                  PointBox[
                   NCache[{0.3, Rational[-1, 2] 3^Rational[1, 2]}, {
                    0.3, -0.8660254037844386}]]}},
                AspectRatio->1,
                Axes->{False, False},
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                Frame->{{True, True}, {True, True}},
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLines->{None, None},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None, "TransparentPolygonMesh" -> 
                  True, "AxesInFront" -> True},
                PlotRange->{{-2, 2}, {-2, 2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.02], 
                   Scaled[0.02]}, {
                   Scaled[0.02], 
                   Scaled[0.02]}},
                Ticks->{Automatic, Automatic}], 143->
               GraphicsBox[{{GraphicsComplexBox[CompressedData["
1:eJyFWnt4jNfWj0sdxZA6cTmpQ6OkU1WXMLTaWohSlA5V9zPUrZFpUZf6Rl1S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                   "], {{
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[0.3], EdgeForm[None], 
                    GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxVmQn418MWxmfmR6LSXkpSiahUlEhZQoksaSO0SipSqWSLEEqUIltZsu+u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                    "]], PolygonBox[CompressedData["
1:eJwtl3nwl1MUxu89v7QpZEukVEqKiKJFihRFGSHNZCaKYWxZBlFZRmVfUvas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                    "]]}]}, {}, {}, {}, {}}, 
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwl1FdsjmEchvGvw6i2irY4owSJ3WHveWCPcwf2LLFJBAc4sVpUddklQZEQ
EpsmiL3VqL23ODN/Txxcve7//T3v+73f87xp2ujpI7KjIpFIqj93MTU6EnmL
eNSMiURydUXyPS7k+1zM63gzV3AJP+AtvJ638UPeyo94O2/gJPdLkB/L0/gd
3iMRHzAIg8P3opa1edYNkfO5jrm2/ETO5o/4hC/4jGGog6/4jm94au10noFz
cgFGyEWc6n715Jdyfa5rLpZ3yK94Js/C+fC7sEfei7mYh4u6nSiT92MRGrvH
Jd0+tJPbIwuXzQdwxZqrWIlVuK47hGshYy1ycEt3BDfkm8gN+x32Fsf0Dd2z
jfxbrgh7H84Ff823cRwPw96HfUceqrimKqIRixiM15+ytpKjw7kgCl3Ryudd
+I7PT6KRuZt5CibjjO4Vx4U9RHX0QW8kWBuPTXI1vEAv1NDFIV+uiufoGa7V
VcPG8Jx4hu7I1PXg2HDuiAlnitO+exKf4DRrOssTMQEdkaHrxBF0QMtwFjwO
WUg3t+M/rs/kFuYMHou2AXM6//J5a25ubsVj8FPXkhvojsqj5MPhrLBGXo3y
8L7hoG4FL8cy/DCf5TJeykuwOLz75oNcygt5AebjbXiXeCtfwBx5NnZjF0p0
5Xgd3kXzGy4N+80jORXNPGdd7h/2W59iLuTh5mQ0Nadwv7Dv+uRwbjzUnIQm
5lrcF5X62uGceIB5YDhTJOpywm8LzxKeAwXR//+f/ANY2Y0F
                    "]], LineBox[CompressedData["
1:eJwl0klOVFEUh/EHLIK+AEHaRJaBTA3SCQFZAMQxhoEyEBi6ABIwoU0gVTRK
zwDpJQGENWhUpKcAxd+Ngy/f+Z9zK6/eua+greNZe0oURe/xKjWKRjGCc6wZ
9CM9LYoy5eeowYBeht43rpJzUSrncAOG9LPlH/xU3uJhxNU/+Q2/RTcm5Bfc
hAI88bt8bsYjlMmFfOlcKVfKJdyC1jBHTG/G/KX6Ex/yVxzgGEeY02/jFGfL
OeIKrsa+WRK3uEaRXo55XL0bevJN2Aeu5HecxC0e43OY6/fwHb6o73kdG+jF
H+zp/+XNsBP04QHFYYeelzDfUW/jNTrRhUmchf/lzDmfYllvFSsYlxd5Kbwn
FjCPMf2PYSeYwW95NtwxT/MJJ/gXT4V750b+wFmelaf+ro5xpjyorlPXIzvs
AlmoDfcT9mB+kfr/O/oHB9JXbw==
                    "]]}}], {}}, {
                  InsetBox["\<\"\[Mu] = \"\>", {-1.8, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["0.2`", {-1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {InsetBox[
                   SubscriptBox["C", "J"], {1.4, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["\<\"=\"\>", {1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["3.58`", {1.7, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {
                  {PointSize[0.05], PointBox[{-0.2, 0}]}, 
                  {PointSize[0.0125], PointBox[{0.8, 0}]}}, 
                 {PointSize[0.007], PointBox[{0.4463998339305619, 0}], 
                  PointBox[{1.2771956561278897`, 0}], 
                  PointBox[{-1.0806611991222994`, 0}], 
                  PointBox[
                   NCache[{0.3, Rational[1, 2] 3^Rational[1, 2]}, {0.3, 
                    0.8660254037844386}]], 
                  PointBox[
                   NCache[{0.3, Rational[-1, 2] 3^Rational[1, 2]}, {
                    0.3, -0.8660254037844386}]]}},
                AspectRatio->1,
                Axes->{False, False},
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                Frame->{{True, True}, {True, True}},
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLines->{None, None},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None, "TransparentPolygonMesh" -> 
                  True, "AxesInFront" -> True},
                PlotRange->{{-2, 2}, {-2, 2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.02], 
                   Scaled[0.02]}, {
                   Scaled[0.02], 
                   Scaled[0.02]}},
                Ticks->{Automatic, Automatic}], 144->
               GraphicsBox[{{GraphicsComplexBox[CompressedData["
1:eJyFWnt0jFfXj1urGFS10hGXtKJDaVNMX5Rs7aiXljRCKdVBKy5JqKa075BP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                   "], {{
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[0.3], EdgeForm[None], 
                    GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxNmQfc39P1x++9DxIjkWEGGQQJGVbsksQoLUEkYsSKEQQx40+oUSOSGLHV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                    "]], PolygonBox[CompressedData["
1:eJwtl3nUllMUxe89b0qIUEKJSkqGQoTCKg0oJCssQ4hlWsiYcVVkIUNolKSk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                    "]]}]}, {}, {}, {}, {}}, 
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwl1FdsjWEcx/HTgWpVhTsjRqI1qtTeLux144a4sfeomQgucGPPokWJGkFI
RGKTGK29WqOL2vtGYu/6PHHxPd//7/c+5z3PeZ/TNhydMWR6VCQSqeXlFiZG
RyJP8BTRiMFtfSbf4Y28ljdzAW/iQs7idbyF73I23+OtvJ7jYyKRWPN98yR+
hud4iRfojT6ohARrN1jX17yRE+U4c5F5Mr/CWfNr7o+qeIN3eIti16bwVEzD
ZnkgZ3MN96pufmgexElopKvBj3QZPAPnwt6Ra96FmZiFC7qd2GPei3mo5/15
uv1oZU5HS+TLB3HBmotYimW4qjuMPHM+lmMFruuO4FqYsRKr0ATJ7pfCI/DJ
mkL+ygX8hW/gKO7K33g1r0GU90XjrznCFTwaJ6y5zw/COeGH3I6bWtOWb8rH
UUduL0/AeJzWPQr3Cs8QFXIX7ow4a6tgvfmvvow7obKuEtaZ/+hLuSNidTFY
a/6t78B15VPmEvMvLuKfXMwneRwf49rWtTGPxRikI03Xmr+HcwjPLZwDj0KL
gJzGn11P5RS5OY8M3xupcjP+6HoyN5Ybh/PCB90lvoLLYW8YHp5b2F/4TNTH
MAzFIeuX8GIswnv5JB/ghbwA88PfgbyPc3kuz8FsPJZ3cw6fRw9zOde0p208
ONwT27ED21Cmz+FqaGhdIndHqT5JzuIBcjwayAncDSX66vIm7hfOK3yXcJbc
NfxG9NXkTO4p9wq/K1TVrdGdQXnYMzZE//8/8g8FQo/k
                    "]], LineBox[CompressedData["
1:eJwl0skunWEYB/APV4DDOWoIaqU3Ub2AKkUiysIF6E5joRbKDVh1URU1npqH
irGNhEZMl1ApWmKoqWw06e+NxS//53ne7/3mosbXlU0pURR10ZQaRT185IRl
C+9JT0NfznM+mGWa/ZBP9Vk81sfkS3rNs/U/ZZl+VX5iSL0vW+Vb2kjqq2UN
OZTal5C1PKJEnxvux3FF8om+UNbxiuKwz2zCer16Sm7JbTbZZYdp8wb5L9wr
9+HcPGPD2gWXnJFnFnfOUfUaf/QXzHOqb5eXXJHPAufm7+Q16+obucgSHfzl
u/lteK+s0MkdBSRcb8z6N/VX3tBMCwMcWStwzLH8zazZHF8Y1E/LGSbCO2Ay
7DMfk+OM8Es/KvvlZ3koh+WBTMo+WRW+v8xyrbh6L3xLGdN3qyvUlWSGZyaD
F5yFZ7J+mvrwH/0HBBZVHw==
                    "]]}}], {}}, {
                  InsetBox["\<\"\[Mu] = \"\>", {-1.8, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["0.2`", {-1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {InsetBox[
                   SubscriptBox["C", "J"], {1.4, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["\<\"=\"\>", {1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["3.5700000000000003`", {1.7, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {
                  {PointSize[0.05], PointBox[{-0.2, 0}]}, 
                  {PointSize[0.0125], PointBox[{0.8, 0}]}}, 
                 {PointSize[0.007], PointBox[{0.4463998339305619, 0}], 
                  PointBox[{1.2771956561278897`, 0}], 
                  PointBox[{-1.0806611991222994`, 0}], 
                  PointBox[
                   NCache[{0.3, Rational[1, 2] 3^Rational[1, 2]}, {0.3, 
                    0.8660254037844386}]], 
                  PointBox[
                   NCache[{0.3, Rational[-1, 2] 3^Rational[1, 2]}, {
                    0.3, -0.8660254037844386}]]}},
                AspectRatio->1,
                Axes->{False, False},
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                Frame->{{True, True}, {True, True}},
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLines->{None, None},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None, "TransparentPolygonMesh" -> 
                  True, "AxesInFront" -> True},
                PlotRange->{{-2, 2}, {-2, 2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.02], 
                   Scaled[0.02]}, {
                   Scaled[0.02], 
                   Scaled[0.02]}},
                Ticks->{Automatic, Automatic}], 145->
               GraphicsBox[{{GraphicsComplexBox[CompressedData["
1:eJx1Wnlc1NUW19LcwKxcJ0NT0CkrUN+o9bSjTpqZ5ZiWL7NxKTemTMkNpZe5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                   "], {{
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[0.3], EdgeForm[None], 
                    GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxNmQfc19MXx++9T6koEVraRklDCRFJspLRJImSpFTKSlYSGWnYo6iMjOy9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                    "]], PolygonBox[CompressedData["
1:eJwtl3kQjlUYxe99lL1oH5GSJRVl7CGVlkkalWnfVZrSoiYkJbTSjlS0kWSX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                    "]]}]}, {}, {}, {}, {}}, 
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwl1FdsDlAYh/GvQ7VVamvtkhix9957XFCbOwlxQ83YIoIL3NTu0NZMrJCI
xA7CRbVU7dVqzSs3ErvG78TF0+f9v2f0+845bdrcjPRFUZFIJNmPEiyPjkQq
UIkaSMJ9/Rwu5VzeyXn8gA/wQ87nXXyQH3EBP+ZDvJtjYyKRmuon6hX8Bm/x
Hu8wBbXwAcmYhqnYa36ctXXVz9T1uLq8Tz1DncUJciJeqBvqveRG4fPrZatn
qXO5ptxYXa6ezU3QWq8pv9ZbyauwGnnycT6BNViLm3pHcEp9GpvCHtbfCj10
VW/U68K35TMolO8gM5wbCvXOoUhdHM4snA+K9M6jVP2F94Tvjp5oa78evBDf
jP1EM70fXIwL4fvK/Yz/Uv9FFVroNccf9V1cRIo82LwIohGFe/qTeERYj+Go
wjJcNVbGCXiFeIzFmLDeXlHICncSzh2jw956f3k/4vACo/AHv7EP1TASjc29
4nc8V8fiKWLCXeOy/lK+xKnmDVMvwWIMQWe9oWFP44O4vTyQM9AfneQB/N14
X24n9+FF6IWOcm/+arw7t5G7hfeOz+HMuCScT9gDC8LccAfhjtAB8zEPZ83f
wduxDZ/k6+Gd8Fbegs3hrYd3wUd5A6/HOlTKJ7mAb2CiuoKTfaZ8niN/DOtw
DIdRFt4jp6CVeak8IdyTfpKcwzPl+kiTG/B4PNePl/fzdLk2Wsp1eFy4A/1q
8h6eLKcjMdyLXqbeNZSHvxlkR///v/EPBXKKlQ==
                    "]], LineBox[CompressedData["
1:eJwl0jlPFVEYBuABe4IoVrJ6QZD1jwgJtYBeTIhCoKMlhAIoWBJqCiAR0ITI
qqwq4OXGUoEfoGHflwYqnhOLJ+/3fWdmzpw7Ny/eWtOSEkXRIG2pUTTOGAd8
szBE2oMoytLX8ophs3Szv/KlPo+YPle+4YP5I/2urNKvyzE+q/dkl+ymh0l9
g3xLAS/cF5ONFIaZ/rk8c12ZLNGXyne8p5wnZrPWm9Tz8o/c4jc7bPPFvFne
UcEtlVTzy9o1N1xQZPbYM6fUCU70p/zgXN8b3ifUFLPGpXmfvGBTfRnOzQb9
XJEM+8ifJBjgJpyZTPtNW0+G++mgnc7wG3Fs7alrTuQRK+H7sMon/ZJc5iuL
LPDRfD6cnVkO9XNyQs6Ebyyn5L6cDt9exuWozLDXM/U/db58qB9R16tfkxPe
iWzqOOK79cPU//+jeyYSWJA=
                    "]]}}], {}}, {
                  InsetBox["\<\"\[Mu] = \"\>", {-1.8, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["0.2`", {-1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {InsetBox[
                   SubscriptBox["C", "J"], {1.4, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["\<\"=\"\>", {1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["3.56`", {1.7, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {
                  {PointSize[0.05], PointBox[{-0.2, 0}]}, 
                  {PointSize[0.0125], PointBox[{0.8, 0}]}}, 
                 {PointSize[0.007], PointBox[{0.4463998339305619, 0}], 
                  PointBox[{1.2771956561278897`, 0}], 
                  PointBox[{-1.0806611991222994`, 0}], 
                  PointBox[
                   NCache[{0.3, Rational[1, 2] 3^Rational[1, 2]}, {0.3, 
                    0.8660254037844386}]], 
                  PointBox[
                   NCache[{0.3, Rational[-1, 2] 3^Rational[1, 2]}, {
                    0.3, -0.8660254037844386}]]}},
                AspectRatio->1,
                Axes->{False, False},
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                Frame->{{True, True}, {True, True}},
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLines->{None, None},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None, "TransparentPolygonMesh" -> 
                  True, "AxesInFront" -> True},
                PlotRange->{{-2, 2}, {-2, 2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.02], 
                   Scaled[0.02]}, {
                   Scaled[0.02], 
                   Scaled[0.02]}},
                Ticks->{Automatic, Automatic}], 146->
               GraphicsBox[{{GraphicsComplexBox[CompressedData["
1:eJx1WntUlNUWN00iEjUj05E0jWyulnnLyUfqzoW3bmY2+Ujz4ojlC0fUTC24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                   "], {{
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[0.3], EdgeForm[None], 
                    GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxNmge0l9Wxxb9zroUiCkTFCiIqdopoABsIYlfEQpDYEAFBwYANC2iIYsFC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                    "]], PolygonBox[CompressedData["
1:eJwtl3nQkFMUxu89X4lsoVIqiWgXsmZPYSpbtkHZDRljL2TwhabSQpJ1ypcs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                    "]]}]}, {}, {}, {}, {}}, 
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwl1Xt8z1Ucx/GfUbnT2uaSuS4UcktXKSVdFaNCqShRiS666X7RBelKyd0s
dxbmvimXWk0KEXJL5B4pShfr+Xn0x2uvz/tzzvd8vzvnPLZaPfpl9i2WSCRG
+DEmKZF4Cj9jD8qjAjYaG8ubeByP4gm8mcfzD5zFozmbt/BE3sqnc8PiiURF
/hjb9AbwXuzDAexHZyTjIM5AV3TBWPNLeT5NvUNdiUvL49S3qydwWbmqeqf6
TC4nZ6nviHdyRTldvVt9J1dHhl6N+F31nuFn8RwmydN5Bp7HC1ilNwOz1Dl4
Jdbw/Gq9XDRTv6o3EJ/gV70aekf5CD7TW45lmCsv5U+xBPnIwxz9RbwYC3BY
XsizeT7/wnN5HnLjPfK9PJ1TvKte7KO6buyfPE19t/oe1IlvQm30wBF8Zfww
P41pmBrvwJf67bkWzrJOTe4e4/rJ8j7OjDHUlTO4J2bpp8oHuaP8NedgjvoQ
D+LBGIL5ci/ujbPRyHP1+QGcg3pyA/7dvKZ8rtyEH0Qz1Jebcz/0xVLzNsb9
xPdxH+Nuxh7rP8RFOA8n0QKdsM7YnziBY2iol2bdRepvcFReic/xNn6L74lv
xRc4bs47fAzfqo9zQewf3sUfWBPviL1GId7Difh9UMm7FhtfHfcr9ivOPd4d
6+F9DMNavSVYEzWG4wN8p5eHDeq/+EMegQtjT619AT+Cf4wVoabeSV4f9xFV
5EuNJ1A8zltO4g3GlqGqfIVcAqfilNhb/Zv56njOeFsuxk/GnhjbxWWxE2Xw
U+yffro518c6PIpL40dcF+vqlcBIdSnswLXxTfE9+EhdEtegmrzSetvVp2EL
tmErVug/wcvjb4B5V6kfx2O4Ek312sT3ojUayJdzf7RCE/ky/tfzLeMeypfw
o7gIjeWL+W/jD3M+V9Y7P85avY7Xx7nEGugTc2P/43ziedyP+7DQ/Ld4KN6M
uyWv4Hn8Br+O13BAns0z+WV+CS9irzyTp3AhOqj3xN9a3zOZ75IPYXLMwSTs
0q/GFczJVt+kvjHOSF1ebyJ3kyujjlyF28U56ZeRx/Ntcgpqy6l8A7brl5TH
8C3yrSgX5xNnqleA3fLopP//v/wHKnnbSA==
                    "]]}}], {}}, {
                  InsetBox["\<\"\[Mu] = \"\>", {-1.8, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["0.2`", {-1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {InsetBox[
                   SubscriptBox["C", "J"], {1.4, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["\<\"=\"\>", {1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["3.55`", {1.7, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {
                  {PointSize[0.05], PointBox[{-0.2, 0}]}, 
                  {PointSize[0.0125], PointBox[{0.8, 0}]}}, 
                 {PointSize[0.007], PointBox[{0.4463998339305619, 0}], 
                  PointBox[{1.2771956561278897`, 0}], 
                  PointBox[{-1.0806611991222994`, 0}], 
                  PointBox[
                   NCache[{0.3, Rational[1, 2] 3^Rational[1, 2]}, {0.3, 
                    0.8660254037844386}]], 
                  PointBox[
                   NCache[{0.3, Rational[-1, 2] 3^Rational[1, 2]}, {
                    0.3, -0.8660254037844386}]]}},
                AspectRatio->1,
                Axes->{False, False},
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                Frame->{{True, True}, {True, True}},
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLines->{None, None},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None, "TransparentPolygonMesh" -> 
                  True, "AxesInFront" -> True},
                PlotRange->{{-2, 2}, {-2, 2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.02], 
                   Scaled[0.02]}, {
                   Scaled[0.02], 
                   Scaled[0.02]}},
                Ticks->{Automatic, Automatic}], 147->
               GraphicsBox[{{GraphicsComplexBox[CompressedData["
1:eJx1WnlYlFX7Jk0zasrMXEbELLPJXCvSrHxKtE+xjMo+y2wyxaIwJVJsiMQl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                   "], {{
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[0.3], EdgeForm[None], 
                    GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxNmgn411MWxu89KWVXShtKQpttSqUiUZFJ2ZcWpJQShamQGCqERLJvWWYw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                    "]], PolygonBox[CompressedData["
1:eJwtl3nU10MYxWeeNi3aFyEt2u1JUtZkyXLQIQk5JxzH7thLyJISZadUlHba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                    "]]}]}, {}, {}, {}, {}}, 
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwl1Xe8z1Ucx/Gfe5Ed2SO6ZERRJJUolSJUiLYdWlYJhQZaaNmbssrKjuwZ
ySoje0dEVtk8Pw9/vO7r8/6c8z3f7/d8z703pUnrOq1SJRKJQX4MSEok3sJu
7EF6ZMBGYwP5dx7E/XgI/8GDeRMP5f48nDfzMN7CmbhociKRkUdgq97bvBf7
cAD7UReZcRBZUA/PYKD5qVyfTb1NfRMnJV9/3mfVQzi1nFO9Q52L08hD1c/H
PTmdnCfeS/0C58XNevniPfXe4Q7oiJHyGB6LTngXy/XG4nv1D+iKXK7Pjcn6
pfgDvfcxAX/r5dE7ykfws958zMMkeQ7PxSz8hNmYqD+DZ2IaDsvTYz2eyn/x
ZP4RU+I55MY8JvbYvQrHPqpTOKM8Wt1A3RAF45ninfEyjmCp8cPcHqPxXdwD
S/RrcoG4zjr5+aUY188g7+Mn5VtQSC7EjTBeP7N8kJ+SV8R+YZL6EHfnHvg4
3kFuwk1xK4q5rgg3j7MSa8vF+B/z7uDi8u3cEqWRIpfh1/Bq7KF5G+KcYn2c
yzirmKP/Ov+PO/Ef7sLTWGPsFE7jOIrHubPudPUvOCovxCJ8hmPxPCiBxThh
zud8HKvUJ2LvYl/RE/9itf5JXhZnCL1wCrfhRveaEfeKvcJKTJVXxbXcm7/A
r+qZWB01vsRX+E1vFtapz/DX/A3uRmFrl+M3452NnUdevXO8FnORTb7P+AX1
ZeSTL8V6cV7j90yubPxK/P5xIvZWXZsfwTk8jPNoF/tkbCffgO1Iix2xh/o5
rfV4rIV+SINteAyXcQl9kRp/oiouxrOhD5LxKHJYZ4H1tqqTsAlbsBnz9dvy
PM5uXhX1VXUbfhAl9R6KdfUqxbmTH+DWuD++iVwxzorxe7mIXIFboXx8d/ke
Pmv8DZ7NWfXKqk+q1/Da+C4xBy3iu8R9cRql8AqaYZr5K/Gp+pM4W+oFPIW7
8Uf4EAfkiTyOu3BnvIfx0cO3+stQS72X03ueUfyifAijYg5GYpd+7vg+5gxX
11A/gZ3qtHrD+Dk5OwrIObh6fEv9ZHkw149zi/xyVq4W3yv+ecgDuI68If7e
xt7HN1Uvxi51/6Tr/1+uAT2t3gs=
                    "]]}}], {}}, {
                  InsetBox["\<\"\[Mu] = \"\>", {-1.8, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["0.2`", {-1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {InsetBox[
                   SubscriptBox["C", "J"], {1.4, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["\<\"=\"\>", {1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["3.54`", {1.7, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {
                  {PointSize[0.05], PointBox[{-0.2, 0}]}, 
                  {PointSize[0.0125], PointBox[{0.8, 0}]}}, 
                 {PointSize[0.007], PointBox[{0.4463998339305619, 0}], 
                  PointBox[{1.2771956561278897`, 0}], 
                  PointBox[{-1.0806611991222994`, 0}], 
                  PointBox[
                   NCache[{0.3, Rational[1, 2] 3^Rational[1, 2]}, {0.3, 
                    0.8660254037844386}]], 
                  PointBox[
                   NCache[{0.3, Rational[-1, 2] 3^Rational[1, 2]}, {
                    0.3, -0.8660254037844386}]]}},
                AspectRatio->1,
                Axes->{False, False},
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                Frame->{{True, True}, {True, True}},
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLines->{None, None},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None, "TransparentPolygonMesh" -> 
                  True, "AxesInFront" -> True},
                PlotRange->{{-2, 2}, {-2, 2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.02], 
                   Scaled[0.02]}, {
                   Scaled[0.02], 
                   Scaled[0.02]}},
                Ticks->{Automatic, Automatic}], 148->
               GraphicsBox[{{GraphicsComplexBox[CompressedData["
1:eJx1Wnt4zNfWTt2KCtqqMkVxXKa0KJ3UfTkd1TaIcHI02nTcFempfuqWcARt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                   "], {{
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[0.3], EdgeForm[None], 
                    GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxNmgf411Mbxs85Iimh7NW2S4hIkxQaFKWlUkoZhSRKb5Noem0SkT2yd8je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                    "]], PolygonBox[CompressedData["
1:eJwtl3nwT1UYxs99f/Zdyl6WLEmL0EYaUYZqEjKt0mjas6RENZURUaFl7Ep2
soSxpuwRlchSyJooNZVdkfR5er5/PHOe59z7vffc877v855vtU5d23aJlNKX
IB+YmKX0EhPH4NeCu+F7QRXmd6JPwI+DSfC14G/m/wET4b+BX+AHQWEwCL2L
e8eCc/DKzB0Bx8EY9AEwlGvDwO9wplMZeNm8lNogaqC/YRzB3FT4c2A1fI7m
4CUZT4JrmFuN/hWcRa9Hl2E8H1wfvkfXvgCr4BPAQvhhsILrq0AJ5oagB8Pf
Bsvg74FRzN+M/hpeAXyOngwWaW3gfXge623AWAddlXsXgaLoi8Er8B8ZA5zg
+jTG3loTvBG4CF6B39/LfFNdD8dAe6/ftEOPZpyN3g46oX8GNZjbi24DHw7/
GP4d+BG9El0VVAOH0dXBEq7tAxvg34DOyXu0B94dvKa1oKeAB9C70Q3AwvCa
tdYijH3RhzLzv5hbjP4UnIU3V35oHoxTLoCN8NFc/wjeAzwE7wiaJK/pavjT
emZyDGfAD/Cb/CAfOA06h2M3HtyuWDD3LLwX+ANdTWuA12K+pr6X/ewJf5u5
C3Ud3QM9GN0fPQCcgTdTzsLXZOanwcfwJcwVy/zMqdrvXC5njPtBy3Ds31JO
wnuAefDe4NVwzBVrxfgt+EDwGfxdUBFegPVcx3MGoGcxLmOueOZ75jGuQ5di
XI5+Ef4COJpck5NVe+DK5Lnl8EHhXNUzJoGCPL8xY33menKtVzjX+6nO4WvB
qOR3rAb9wrFUTJrDtylvk3N+rGLB865hvATdR7kCPoEPlEeEPUC1vwbsQC9F
F4D/CZ5Az0W3hv+kNcOvUo7Cfwb1wzmjXFmlGkX/iR6ZXIOj0Bsy5448YAF6
PrgaXkjvgVdlfc/Bn2fu/nANKPd3oT+Af5u7phy8Cb0lc+7I8+qhnwIHk9c0
Hf5T5m9TjU9B70O/mewZl6IL874bmRuenEtV0N0y59RSxToca+VQM/h38lT0
V6A2+lGtUd6nfIPPCud6w+TYfA1KZ47RlYpd5r1bkeyt88LfLo+dDx5D7+fa
aNAwvMfa288F5XfYK4dpDeHf6F69oyB6J6iYi9k++PPh3JSHDM3sMfKWGWAk
ui36++QcKSnO3LZkD5oZ9hB5h2p4PJijnM8cswrw8uxXe3R/dDn0PeHe0jf5
3tnhvdBvKnPvZej75H3oovCtjFsVq2TvmhDp/+YhDxvGeKdinLznp9Bfgm+T
PUmxmpnZqxSz6aAD9+9JzmnlUn50/uScGgPao39Avw7uCvco9aYd4Dz4jsxc
Hj0i59ny6lngDPorsCm5R8qLKoe9Xp4kr6qBbpnsWWXh5ZhrB++TvFflw7Ws
PXtZXhr2IuXk5eE96pSrmaPoxuBS9aNc7e7O7bVq+IbwPbpWF2R57nHqbfUY
V3LtCKiduSe+EfZYeas8/rbwM+rmvukYvCvonvxOedu4zL1QHqfeqBgrtuqR
m8EzYW/4F4T8A1ye83T1wiph71ZPVG6VCu+lckyxLxbOReXAQfivoCbzi5PP
BuqRe5PPCL+hXw97u3pyJZ5fJ1wLHdGF4K3BZnSlnHfK4+Xt8tCKea5Z1WqH
zGt9J/NZRWtWrC4Ie6Nidkz+DTYmn3EeDPcg9R7lWOnwnmuvX1VOKPcze7N6
SK3wO/Uu5cQB1TZYAK+ungRKcr2V9pG5vfKG8DX17PHw3Xpn5ppYrLWEz0Jd
mCoS9kB53zRwa/jMorPKBnSevCh81lJZ/RLeY+2tzhyPhz1Q3ifPUa0VDj9L
Nae1NZUHJK+xCbwEcy0ynxnvQA/JXLva8xJhj5Q3zkz2luJhLo85BT8JJsPX
geI8q1H4LNA887MX575N71Dtjgnnlmp4HPzD8F7rDKqz7PLMZx2daQ+hW4W/
vWau1nVm1VlVNb9V3gfKZs5xecnCzL1OnrIlHBPFohxjEdZTN3yWvAm9Pbyn
2svymWvr4fBZTDVWKdyz1KsUY519zw+fJXQG7gbfFv6tzsg6KzUIe7vOTMq1
BZl7p3JOveyKyPWK5F41m+utknuWcmMZ4/rkHJH3qwaU++oBt4Q9SN6je7Tw
TeG9V0xXcE+LsBfqDLJZ+Rz+du3RI+EzzPLkHrcoc8wUK5055+b2SHujM4G8
/cnwfwF5/Dl5dfi/hWJ+SbhmO+a+4T+Ew52n
                    "]]}]}, {}, {}, {}, {}}, 
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwl1Xe8jmUcx/HHOYdjkxGZ2SOKEipUirQzWtJSGhJJKtIuLZVzsldkbyJ0
KOUg2SNZRUYo51S27Pfv5Y/P+fy+v+u67vt+7ut6nlOhfZdWnXMkEomB/gxI
SiRewGZsQTJSsMrYQF7NgziNh/AaHsxreSin83Bex8N4PefiS5MTiZw8Ahv0
uvJWfK/exnciFb8hN+7GXehn/BTnw0Z1fj6N/uqWSRee+SwXwiZ1YT6HQerW
PJST3LtI3E/dhoviYr1ivE2vG7+E7hguj4nn4Ff4VWSqR2O8eif34sLWv84T
MQH79C/S2897MVtvDr6JOfIs/opn8gx8HevkaTwdU/CnPJXHczv+g/dEH7tR
Gg9hFxYZ28kvY4e6FOdy/1HqB9XDOFkuoX4A98f18IP+Dn4Ro+OZsB0L9ZvF
e0EJ64rzfRipn1PezrfIl6CkXJLbYqx+qrybW8iLeRwmq/fw2/wO3sVk+WF+
BGVRwboy/DjKxbXl8vy3eVW4olyZn0RVlJKr8VPogNnm/czLsQwrsSLeuf7T
/AxqIo91M/SWoXq8R7kG/yMv5qVYgply+9hL7MfeeBb8hVtxW5xjzMMBc3uH
Y706i7/FB/gQ5d1jqv5PyJYzMB8fxX3js8c5N2ea8e/ie4AFyJI/5k/QJ86G
vDD2DZ/iM3we5yeuzf9yX05DbZRxzVrcEQeNHUERvcPxrjAH+eQrjR9Vn0BR
+Tgvx9z4jskNjP+vPh3fP6zA7XqNcAjX4TC6xHMb28i/YgNy4Jf4vPqFXOsG
9Qn0QwLrcT2O4xi+wDlz13GTeC4cQTrO6jfmgq6ToV6rPsOreA1Wx3uXO8e+
cAHzrlWfVD/PDVFF75q4l179OGvy1dwJV6GyXC8+l/G6cTblOvwcLkcl+Qr+
z/izPIvz6l2mzlb/yJlYFO8cT8TcOL+xP7Eej+FRTDF/Cd5XvxdnK945T+K3
+E28gV3yJB7Dr3FP9MA4jMWXcV80V//OKZ5nBN8bGSMxKuZhS/w2xb6YM0R9
s/ombI4ffb3B3EougOJyQW4a+6l/hgfwPZwHxYzn5Rtjj/VPxv7xHbwyfmvj
3KBvnGtsUvdPuvB/5TxLXt9N
                    "]]}}], {}}, {
                  InsetBox["\<\"\[Mu] = \"\>", {-1.8, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["0.2`", {-1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {InsetBox[
                   SubscriptBox["C", "J"], {1.4, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["\<\"=\"\>", {1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["3.5300000000000002`", {1.7, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {
                  {PointSize[0.05], PointBox[{-0.2, 0}]}, 
                  {PointSize[0.0125], PointBox[{0.8, 0}]}}, 
                 {PointSize[0.007], PointBox[{0.4463998339305619, 0}], 
                  PointBox[{1.2771956561278897`, 0}], 
                  PointBox[{-1.0806611991222994`, 0}], 
                  PointBox[
                   NCache[{0.3, Rational[1, 2] 3^Rational[1, 2]}, {0.3, 
                    0.8660254037844386}]], 
                  PointBox[
                   NCache[{0.3, Rational[-1, 2] 3^Rational[1, 2]}, {
                    0.3, -0.8660254037844386}]]}},
                AspectRatio->1,
                Axes->{False, False},
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                Frame->{{True, True}, {True, True}},
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLines->{None, None},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None, "TransparentPolygonMesh" -> 
                  True, "AxesInFront" -> True},
                PlotRange->{{-2, 2}, {-2, 2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.02], 
                   Scaled[0.02]}, {
                   Scaled[0.02], 
                   Scaled[0.02]}},
                Ticks->{Automatic, Automatic}], 149->
               GraphicsBox[{{GraphicsComplexBox[CompressedData["
1:eJx1WnlYlNXbJk0zdNxKK1KTXJpKw9QxNfJRxrKfEo5bmtK4JaFkfaUZU5pr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                   "], {{
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[0.3], EdgeForm[None], 
                    GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxNmgf811MXx++9pZ0SyUhDSmkQoUSIkkpGKhXRoqElDULDppA9osJj75lN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                    "]], PolygonBox[CompressedData["
1:eJwtlnnQj1Ucxe+9L7KTPUtRikwyoTLqbSFhNCNaprSbkqmJqWjHvArZkiVZ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                    "]]}]}, {}, {}, {}, {}}, 
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwl1Xe8jmUYwPH3vHbIMcpoGVlpGO1IKSvKLNqFpIFESxMRGcex915FdmSP
Y2elMiqJyGiYIZG+18cfv/O7rut+nvt+7vu9nucUa9a2YZuURCIx3J+eyUTi
BazHBpxW68VLuCV/jTPiv7gz9+Gl3JuXcRp34XRezn15Bf+DApkSibPcT20l
v8gbMUO8ie/DOfFm/per8f3oKj7G//EqXMRxeTd+kLvzSU5ijTgTn0IPcQ3u
xWc4C2qhJrLiMs+TLfZp/CV+Ga+gj3xw7JVbcxu0xQD5MN7Kr3Nm97fnb+TD
eQdnUdvJ2zFJbQomY5h8Ivfn8TwOEzBUPobHYhS+l4/mIVyft/Au/gE7cTnq
YXusF9fjO7yKza7NHWeHfuKHuTefjb2iLurgW8xW38atMAgDYx+YpX4H50BO
e8nODyFd/Rxv4rs4V2A8Jz8Sc6ifj7n5br4Hg8Uj4/n4LX4b72CEvAHv4lS+
wjx5uDHyIrc8X+zZeCG+Ul6Qm6BwnIG8CD+Oppjouq94AeZjERZikvoT/CSu
if6Jc45rcZU4j3mu5r3yubyPv4zfhh/ln7AbP2IPfkZlVEF+TI0x177Hv2Ce
eC9Pw/v4IK6zxij1+dgn/wLT8SF+RQFcwGjjM2NNnhHr8kfcCZ0xRj4rnoG7
8MfoivHyeTEXd+NPUBSp1r2On8Gz+M14VrUDvACT44WXlzR2UHwE2eSHeSGm
IEV+g/Hf433Hn1iEe9VuwSHcjMNoEXsztobXYhVOyVfHecQ7aa5K4j/QAyfV
MrhizI8j6I4T6iu5PIq4pwIfV1vOx3hFnDsv46O8mJdiCT6XN+fPOOnem2I9
cTMuF72jdmM8t1pZzicvw8+jFArJS/N+49dHL8pL8HMohoLy4vw0nsKE+Bbx
tfH7i2dHn/CcONM4czyGA9HjMW/0MhqhIUZGv+Fdccd4/nj25KXv8Jv8Bjpg
m3wED4w+RTvxaxiKIegba+JO8cb41nIa1+Yt2IoBWK/Wn9dxZj6NntF3uD1+
N/6bP+XqnEAOe07h27Ba/UT0GD/A5zm78Qt8qzyDj0ZvclVeHPNF30Qf83Ss
i/mTl/7P/A+lc+XM
                    "]]}}], {}}, {
                  InsetBox["\<\"\[Mu] = \"\>", {-1.8, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["0.2`", {-1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {InsetBox[
                   SubscriptBox["C", "J"], {1.4, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["\<\"=\"\>", {1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["3.52`", {1.7, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {
                  {PointSize[0.05], PointBox[{-0.2, 0}]}, 
                  {PointSize[0.0125], PointBox[{0.8, 0}]}}, 
                 {PointSize[0.007], PointBox[{0.4463998339305619, 0}], 
                  PointBox[{1.2771956561278897`, 0}], 
                  PointBox[{-1.0806611991222994`, 0}], 
                  PointBox[
                   NCache[{0.3, Rational[1, 2] 3^Rational[1, 2]}, {0.3, 
                    0.8660254037844386}]], 
                  PointBox[
                   NCache[{0.3, Rational[-1, 2] 3^Rational[1, 2]}, {
                    0.3, -0.8660254037844386}]]}},
                AspectRatio->1,
                Axes->{False, False},
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                Frame->{{True, True}, {True, True}},
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLines->{None, None},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None, "TransparentPolygonMesh" -> 
                  True, "AxesInFront" -> True},
                PlotRange->{{-2, 2}, {-2, 2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.02], 
                   Scaled[0.02]}, {
                   Scaled[0.02], 
                   Scaled[0.02]}},
                Ticks->{Automatic, Automatic}], 150->
               GraphicsBox[{{GraphicsComplexBox[CompressedData["
1:eJx1WnlY1NX6d8+rjplp5WQa5jJpmT8Tl5/ka6JoLjR5u1pko1kuCamZC2Om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                   "], {{
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[0.3], EdgeForm[None], 
                    GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxNmgf811MXx++9fyENqZBKQ4qikoaQjIwiUaSSlpa0hSQt2SOyR3Z28dh7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                    "]], PolygonBox[CompressedData["
1:eJw1lnnQz1UYxe998BaispM1Em2SaJF6WyQ1ajCjRruakQoVNVPTqlVFKJRC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                    "]]}]}, {}, {}, {}, {}}, 
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwl1Xe8j3UYh/Hf+R0kM6RBxtFe2rs0pE2lnVJpL9o77cjIlk1EtEuhZWdE
Cllp0VCpaGdE78/LH9e57s/9fJ/zfBenrE27lm1LCoXCED+eLhYK1+NjfIJ1
et14Kt/A87FevY47cA+ext15OvfkjryeN/AHuFG9AAuxUe7FM/gm/hRvqhfx
CfhPvZg38RKeyU25E2/kEsxWFzMWndXNuCtv5vKYo67AhVLrUZ+s7sGlckX1
qTgFW6OWXqWs1/O23A63oJfcL3vAt/HtuAP95EG8mO/mat6/h5fIL/NyvpaH
8kv8GY/hF/FCccsej+ZneBSPxPMYLI/g5zAMw/EsBum35EW8kr/BCtTA2fgK
X+NLfIFbs6fGbsMVzK2v+kx1Ty4nV1W3QHN8jvH6y/nmzAl9M2eM0z+Cq2Bb
71XmM9BHv7y8kI+Uq6O2XI3PwgD9reSlfJR8NAaqh/Iyvp8fwINZn3xO5sG1
uJ73avJ5+Sa2k2tnXZ7X5fpyHb4IO2F7uR63wsXZX+Pe54l4D5MxKXuvfwlf
ioY5d++N0puI+vIOcoPsrfw2f8vv5Fz4fP4eq/AdfsQPOAZNMseMx2t4HQ/j
p3zfu6v5DTyCRzNn3xmROeJneWzuPh7DL/g1a8J1mRPW5FyNfSvnzI/zE3gy
90Qel7PnDtwRT2G0/G7myp24M3bGjr7diC/HFVmD59X1VvGk3FVUlvfIGjO/
3CF5NU/O3UYVed/MVb0Wa3CcfCz+wgH4HX/iD1yT9Rszlz/Ch/hHnpO94tn8
N8/K+3wIH5wx6aNLfpf+TD4QjXz/oPzu/L+Sb/GM7D1P5994Ck/DVLwqX82v
cFXv7p89Vl/FjVGmt1/OS28frivvzVdiz9wVea+cv+e7cx15N26DXdBA3pUv
Q2uMMa6SXpl6pXo8r+AJmRvW4gJcmPNARWNHen6uenjODQ+p22fumTeG5S7i
PvW9GILB6J+7irvUd2IgBqB3vof56C8v4NP5NCzFMvTBPP3eOZf8e+WiuXTP
XcPh8lwu0evGJ8mlqCmX48NylvqbckZ8Im/mGp4X1Idilrwhd5KP5yn8b8j9
5bGYp+5a3PI3539VyuRK
                    "]]}}], {}}, {
                  InsetBox["\<\"\[Mu] = \"\>", {-1.8, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["0.2`", {-1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {InsetBox[
                   SubscriptBox["C", "J"], {1.4, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["\<\"=\"\>", {1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["3.51`", {1.7, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {
                  {PointSize[0.05], PointBox[{-0.2, 0}]}, 
                  {PointSize[0.0125], PointBox[{0.8, 0}]}}, 
                 {PointSize[0.007], PointBox[{0.4463998339305619, 0}], 
                  PointBox[{1.2771956561278897`, 0}], 
                  PointBox[{-1.0806611991222994`, 0}], 
                  PointBox[
                   NCache[{0.3, Rational[1, 2] 3^Rational[1, 2]}, {0.3, 
                    0.8660254037844386}]], 
                  PointBox[
                   NCache[{0.3, Rational[-1, 2] 3^Rational[1, 2]}, {
                    0.3, -0.8660254037844386}]]}},
                AspectRatio->1,
                Axes->{False, False},
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                Frame->{{True, True}, {True, True}},
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLines->{None, None},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None, "TransparentPolygonMesh" -> 
                  True, "AxesInFront" -> True},
                PlotRange->{{-2, 2}, {-2, 2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.02], 
                   Scaled[0.02]}, {
                   Scaled[0.02], 
                   Scaled[0.02]}},
                Ticks->{Automatic, Automatic}], 151->
               GraphicsBox[{{GraphicsComplexBox[CompressedData["
1:eJx1Wnlc1FX3xje3UAwVM8c1c5ks01Qy15PxvmlmNpLb66uTWZI2mmvpmD8j
0nGLNN9xN3LUyszAXEphXo8LoRgqIDKGioCgbC4Mm7nNj+bw3Pl8rh/45/t5
5t7vvc895znnnnu/PD1pRujkf/j5+XV7zM/v72fS/k5P2V1ZnPrbhtCAvHJ+
ruHJgtzgNIXvxPpH2tyxCjsFE3Ar6a9wvIyncMR7U+OC7dd53sTKcKfNzZgP
GPMBYz5gzAeM+YAxH/ACmU/hl5vsNrtMN9UTfIDBBxh8gMEHGHyAwQcYfIDB
B7i7PBUGT50XsP4EX2DwBQZfYPAFBl9g8AUGX2DwBZ4jfKkmv+p21XnrT/AD
Bj9g8AMGP2DwAwa/mnSt6073u25XzA+M+YAxX01xo+ta15UeV7rudd3pcafH
ha5L3e9YDzDWA4z11BRnus51Hel+A299XmD9Cf8Cgx8w+NUU93rc6brWdQS/
AcMvwOAPDP46T2D9Cf7A4F9TXtDjTte5rkPwBQZf3a+6HXVewPpTj3s9zvQ4
AB9g8NF1pftRt4s+3xnRvZoPGPMBYz5gzAeM+YA7e9tzuYP3WcZ+3r/DznAv
j0puK+2E9sve8Qv5lHec23xeMAHDn8B44r0EwQQM/QJjHp1Xjrc9Qz3RXuDF
pxQGf+B28j7p7wH/Ie+r9lR5Koz1A2O9wOANHsDgAYx5MD/m0Z+YDxjzAWM9
wLCPjnXewOCB/uCJdlXPVLdDj8BYJ/pDf8C6LuBvYOgaWNeF/h7iEFj3K+YF
Bl9grG+h6Fnxhb4RL8C6LjEe7Ap+aNd1D774HbzRjvXrekecI76xTvDV163X
C7p+9byu6wDtGA8YvDAvsNp/q8fHvLpuMB4w1oe8g3a9rsA4sKueV3Qd6HWk
nld0nen5GXrAuoC7P9G3gzmkgIf/+s4Bk7mUr/1v4QmP55Z62rz9XLzAO14O
J3nzaB7h965ePpl01Msnmbb4rxpmjCmhiLCL5dGOYvXE7ysE81bBbJT5CfOj
P9rxxHuZwovATx/33rvd21gDynmA8OIn4/5e7y7Ff57wfoR/svBXfNA+VHip
dryPJ+wBjPeB8T7sA36YF/PMFn4EvsBYP+yCdcMO+hN2gF3gX/AAP2DEC3hA
p+ALjPWr85a2fugaWI9TfV9DXYv8inZgtCN/o13l8+r2mvYFtNc0rj4v8iba
gWuaFxhxiHmBsX7Y7ceAWksdzgoO8v4eT8CwI7Ce9xHHwPBbmthZYehb+aka
gz/8A/3B38DwC+bXMd6HrjAP2pHPwBcY/KBnYOgE46C9h9hHYfDQ6xrUc1jH
d2I/tV+jPzD6Yz70x3zA8CveB8b78B/6I06Aa6pb8D78jf7gD//DzsDgB4z5
gKEzYMQr/A47ws/wCzD8gbofv+v7M/QEPsDq/FSNwQfrwvr1/KnXXfr+AQw9
6fkT69TzmL7vYv2V8p7SJTDWCXthHZgH+zHiD/s1MPYtxKNe92K/BY7y4l0q
XvG7/lTn1up+2M8wPtqhR7SjTkCcYN+AP1Av6PW8OmdW7xfwF8aDnzAe/Ai7
wZ+wG9rBF3aHPYBhD/gJ9tbrI2DYG/kD9qopb+p5EnZT9XO1faEH7MtYB56w
B8avSRcYH7/DL5gHcQb7g5/uH9gbWL/fQTveh70xL+wFrN/XoB38YH/4C/2h
L9gFGP3hD2DoCLrQ9xm9TtbjGr8jr+B31EVoh47QDl7wO+yDfAL7wA/gDb2D
B7DeH+sH1vUKv6Beg1/0OgLrAkY+xTr0czQwxke86PlGP3ejP+yC/uAL+wDD
3+Cv77/oB/0Awx54D7/jPcQFMOwOXejnaD3u9boMOoC9MB50jLyA33Ue6Kfz
xbrwu4rb6n1F9aseH/0yJy65lVue9cg98IXa/Rra1/vO2ysOPdXZvL1Sjbe1
zpiC3I/L+IfDG3aYMosf+X5xpWXkOcOKEpV/m0R/lOW5UsIX5fdHvifUanqy
n7FbEQ9bknHWsK2U9Xu8Fts317GPKeKV728b6zZsUnnge/v2xvalvvP11o8W
7zG18dUh+D1hMj9lPn5Fradd94fzHP2v8KG5H7xqnOG7V83YOLiV+fgNhfev
7bLPFOU7b/cfvi4vd23FI98tRtwbk2I4lcq05rkbiUUFrN9z1tvv3y/kr3Nq
PRP6hL7rSk5S44EX3gfGepB3wBcYfIHBV//OtaDNrG8txgsE++n3243T52d4
6LyqQ4xpv5wxDE0j2Bf94R/9ProwatEWW48cdV53udv+HhyUQ/A37AC96N9l
bsRunukylhH0iHoT/lsT9PqfniLffWpq3HSHpX6l4p//Z1134nOViufQXzqH
BnSsoE4ne+R4rmRx+NGo3iEF5Txr+uA4U90sWvif+rVi3qzgnG5rkg19S3nc
P74d576bzzmjmz1r/iKdjeNO/2Z6mM3uKd0iHf2P867eKT9ahuTwTXdIaECz
Co66Mzc/tzyN2y2/+7Ppq+t06ch3tWMGpXHWybe2WZZVjZs3ID7YfoyLE9ND
jN9W8LM93nZHO6JpZ3zPVtauVXXuhf8cDw46R0k7bxtD+tykUX1GLHLWTSP7
LweOBNv3U1TTLQ8TG2RRQkCHF82lJZQ2rQ4bulT5uXV4K/P2G1Q4OfuKp5ub
lq29+qkzLI/Tk8/vNZ0p41+bHv3ImZ7EYRt6eKLHVHLDxn/vB1Ze/U1kC+vP
lXzg+Pqm1oBP6bV7C3uFxFRyaGH+ZovxFM189l8T3AsqOf9J64PoERfIdnex
y1NUwQdTtxwOjs+jWTN6jAx4UKb0XiL+4rjV7rcCJl9X+0GvdiVznNcKKG1g
v8uemFI+6o27WypP5T5Fnaz/d5vy5ckXVje7m7jZd5/8SqP0583vlfGEwNwZ
rtVV+36HeRc9MWVcmDG1bsygq+x/84WNtiZlNGLI3RWOhbl8JGhwV/MzZRTW
OmGmK7AKS3+a0PrE2+6MSyqvrRD98/4Q0zrbXt95cX5ihyHGbr775UnTM953
JZ+irnb3nejsDL73QUSSp/Nl6tvsbgPrhLMcPSV/VECdMlqUXu/5EGsSm3bf
uplYlK/O4/HZU8e6+xbyumda2m3udZwZeWKYcVUJXThav4V9TDIP/yIiK/fj
Av7qUkGGxxNPyR9WbLD1yOVn5n9QlFiUQRh/ooxPCfWLTxtiy4hOLrgfnX2B
YI8csQfBXqPEXgT+rYU/NTRvL0gs+oNenHo4M/fjDIK9zGIvgj1fF3vSojWz
BoX8u2pflKeK08aSfymj341u5u2+ezr4E8/oBY99Y1lWwP7T4me5wktV3DeS
/E/m1e89THzutrpngF6SRS9Kz6miZ5WPtsh+Q0O38CvGd/LV+WikYVQL62kX
j733qdl9qoKg/0mif4pP3lvfvj6Re4dlfuiaUkmIhy8lHgj6nyb6p9itr620
uf+gw9ccccFzKwnxECHxoOrRPcuG7DW18X2nTZd8xM+4a//h8fxP3VfbwjKa
2F3H1X018lWx5CtOC897w/hEjsrTqB9uZy59OWRyOb9085N9wUHFj3x3cUb1
nuy+62bYQ7/v3rhq8NPWN0u5VZwp2/NOySPfeUJ7GR7+d/0thj/0+++dS9Ln
uQJvq7gOp16B9jF5DP+Dx/hJh790LPSdv4sbRKy1nLys9l3EVfuuK8cFTM5W
9VBo7clfODtlq3NM8+Xp7ayRV/l6+dee6KevP3Kvvjg4/vWAvAy+03ZXf2OM
7/tPeL025YmW84/cSz+1pFaq4cNUZY9eP/3zSHCa7/7c06pPXqLljMpnr8r+
TYhn1KHgA7+Bz1zho/abIbm1O1sDktW5sL7Mr+Kkk8yv4olk/1c6zhY+hPyE
+hZ2/FXqF0K+QjvsDR6wi0Hsrc6rgVLvEOynf08aKv5QfJ4QfyhdzRf/E/yt
/9/KX0289Rshn2Pd0J/+nWWo6E/lgR2iN1UXom7A/oF+iAf9u8xBiQdl77Wi
f8L+hHXBf7slfpW/iiXeVP2SJvUvIZ717w82qYcJ8Y125L9Gkv947MzaSxyX
rvPBJXdrxzQuY+RXPF9b3npswO9Vdb03PxfypsJu5zzv/Mm3WwV97Nqazdgf
esr+oPaP3bJ/cFjT0btMUQVV+e9v/R5T+1Ur2a9oYOaHayzLrtDElLMnPXSW
sJ9Pl/2cDicMesc97hotyri43pZaRvcOvhpl65FNNw99v9bWpILRHiHt/Hvr
68tsQ2/wwGtBT9ofczPqkZtSjzDq/Jk/b2ptfuwGo365JPULb3hQ/oK5Wymd
/iasuTUvn0csyzwefMpN7S3969kthWwM/OblkH+Xc+kp80nPZ1f42RGhSYZt
5RwxqsP3pocX+VizXYNC+mSp5+/hUUF2115u0r/XB+6MbN7z4OsRbsNXfOT+
tGzPW9mMeup7qad4TOfeBuub1zn9v+/9YNl5jmcvfv558/E0Cpcnw16LxF4c
PjjzZ1PUdeot9TCbLElPm7f78sn+q90+d4bl0LDoA83tzVPYcGJAvZjEHGof
sa+DdUIKo757X+o7fulozzmuPW6qf/RGG3NIkvJfX/Efob5cLfUlgW+C8CXM
11/mI8zXROYjrAdP1KdnpD4lrAf1PdaD/AR+hUe8/Aj+uCr+IPhjtviD4IdY
eRLq53ZSPxP0nC96JvjLX/xF8NdB8RehHg+VepwQH8ESHwT9/C76IejHIPpR
58wpoj+CXvuKXgnxuF/iUZ0PFsr5QOm/UPSv8hz8j3ON/n1ptOR/1Y77Nlv3
lY/FZOfShOODfjVlpqrz97TXen7mtJ1T7cOlXX1XmCDtKp/fGbneLyayQtWZ
k26180S/W6n2qYzZBS2s1kq1L4RO6/ZSyCFf/yDvfpSj+ic32n0gOC2D488O
b2z/zfddAvXmcKk3+cnIn2a49pTRgydG14p5Op3bD1u2zTLFN24fxx2rc2HV
+XVGg9CA4ATedO6S0by9Qu3zf6266050VPAmbz79gU68vSPFQ757IdTL37f3
1svk93nXMFdgIZ8vajc6IG8fYT7wPha5Y5tlbAW/8eHUAGvkGbV/VKw6v8rh
TCGsB3bAeeBNOQ/Qi0sdFz3ry2jH4Tm9zE2z1P6XldShJPGnSpryhiXHw1m8
eNon0123y7lR6o6PnNcucdQAzynDpAqevSFgi212Kq9OuNvZ/EylWkeuvM8n
Nr33V7Qjlhef394rZGMlH22Y96Mp8xBNPLy5hfW7Sn6/48xG9jHp9MIEcic2
qOThT0w4Y1jg+/+Zl/t+nZ+bV8ZlgYea2XvncGDq9pWOVr59y5jV8AXzvlJa
3aA0xLjqGo/95Nv7ic+l8K+e2K8c43N4uKt9J2tkMh+aVV4v5t0cxnp3y3q5
1ejWSYYj5fx4r9ZznOYMxnk0Vc6jDPtOFfuq86tDzq8Mfzap4/Unw1+Ni73+
Uvt07dVef3CU/36nYcFNMrU82NV89RynNz+42Bl2m2DHn5dMGRjS2E1tvv7c
YYo6o87P8XJ+JugrSvRFGO8VGY8w3iQZj6DXm6JXgn2xz8O+xWJfdV98ROKB
NvW8Py6gYwqZcgY+jM52EeyP92H/ZWJ/9X2uocQXwR/R4g+CP34RfxDuE7bJ
fQJhHx9ZHB0fPNJ3X1km8a70GC56JOhxk+iRZtRu6fJ0drHluyC/GJfv+6FZ
8oOy85eiV4I+w0Wfav3pkj9UHhqSsjTaNLBSxdFwyScE/XYR/RLuU+bLfQpF
T2j2qWPhZbJNbNnIvrRC1a9fLj12LbeonHFeGy/nNQb/GcKfcV7rJ+c1xnns
mJzHGPyGCT/GfCtkPlUHD5f7Hz54vXayYcVViur427+Mq8q5MKfpDsuyvEe+
H4b3vb/b1CafJw3odNrQxff9EP2Mjf3eNM7IVucSt9x3qTpsvPhP3ftdkX2A
cf4eJOdvhr4mir7UuaKd3L9x+IK4CKctRX3v2ts+sqP5iwvkP3dohDMhReV3
W+3dsSZzMtuX7/7R9PBPtd+g//053v6E85H6/9jq7wKBF/cMCLGmKv/Ol/EI
46nvCdV1e+U+7/0l4T7jlNxnEOLXT+KXYD/4AfZrJ/ZT3zvni70J/tkk/iGc
h3H/h3v8Kc1emeg+VU7wH7534T7rVbnPIuTb8ZJvqdf+EbNd3a/yhZWX19km
Vfl1lOVybnAcvzB9xlbLhio9tfQbEpAXp+63R3r9cp1W/9FjpWN8Gdft8NlK
W2oRBa59MdxZ4eYHcQfiDP63ePfynxKCe5Vwx0vj33KPu0XxLT5b7RhfwtHT
2x0yDSyhxxd/u9XU5hYbm53fbFvj5lc6JBwz+Bdx4dpZhbnnS7nRPKczOO0a
p42ZPyBko5uifmxY1968iHe+//f3yYW0ydLkE1dgNg+V/EVtvOeobKWzWl1a
XkssusxldfLGBOQdo66rYtdadl7m6D5ZZz1URJcfnzPDlZzGu+nTwcZVZeQ3
8N5sV3IqO736yOfU3zYGG2POqP5npT+h/+0B3v6E/eKvnt79gsBvjfAj8HtS
+BHWV1fWR7BHLbEHwZ4NxZ50uv+IzuYvqurbO3FtrV3LlL/SxF8E+6wT+xDs
fUTsTeGLvt4fPLeIhxyLDbKfcPO2u+YoW/sSzv+mlcV57Sb7nznb1nz8Ik8c
uDzbQ9m8YMeXyxyX8jjFO69L4WOCCf3HSn+CfVuLfQnjZ8n4av5/yvwE++4X
+xL8VfKs118EPbwseiDoaafoiaDPLqJP+n+HwDjd
                   "], {{
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[0.3], EdgeForm[None], 
                    GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxNmgf811MXx++9P6mURKkUTYq07IwSRRFJ0VBaSkaDyIpQViWjhGzZe2/h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                    "]], PolygonBox[CompressedData["
1:eJwtl3fU12MYxr/PXVRIKkVDirc9qBQ5r2QkJzIyTkKccqyQ3jJCKYoQFRmn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                    "]]}]}, {}, {}, {}, {}}, 
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwl1XfczlUYx/H7eZ7M7Oy9RZGiQUSSphGilAqpSLTsZKZSoUX2yhayKrtk
78yQvUKDrLJ6Xy9/fO7P97rOOfc5v/v8Xq+7SPN29dsmJRKJYT4mJScSA/Eb
9iI9JmOLsU95H25EqpREYrDeVHkrT+FtPI2/4tTGM8jb5c94Pw4gI77BDv3P
+SCWy4e4MTLhMDLjCHYae4qHcBrfmU3eLd/EadVD5SbycE6vzhlnl3PFOdUj
5Gfl0ZxJnUd+Dk1xFHnxbZzN+Mw4DxfkLOaOlefIh3gQD45nwyR1duMl5N/l
1+KZeDGf4gW8CAsxTd2GJ8aZrSkut8Ir+ABr9CfgE/ljFMOraI2P0A8v47g5
p/kM/kZRvIQ/8Rf+iL3xJY6ZW4Sz2W+8/KI8hjOrC8gt0BwnsUr/BH+B2ZgV
z4SV+nU5P4pbl4+b4Wv9rOqjXE9dGCXUhbglpujnUJ/gJ9T1MVWeH/vxCB6J
UZihbhtn51J8i3Ul+XXcjJLq0vGMxm/nW9XluQvuQCl1BX4HXTHfvLW8Ln5X
bMB6LNDvxu/iLuSxbq7eRlSMvdR38j/qFXyWV/I8fitqnItxXMB5NEBDlMGH
eANvxjOgPwbEe2X92/wdt+cO8QzIab9ZehtwUf0jfsJY/Iv/UBYd427NKce5
rJktL4v753FxFxiP79V5jd8d55RXxRl5NVfCFfREr/h+/cLmXuRNWIj86vti
X/lKvDvqy7wZi1BA/YDxq3ISJ9AITyLJWK0Yi758jd/HMnN38W7sRFr8Gs+p
v4PTYDtS41E8ghTrkzFBToVteAi36T3MN2BLzMPW+N181y+cjI3YjE1Yqt+X
l3Ahax+Ur8k1uaB6sfyefIlrxB3q3c99UA3l1NXjro1X5dLqKtwbleNu1Pdy
D3THD+bl07tHPiP/zKd5OV+OfdAJneNZkNvcOcbbyTN5PcbIo+PscW5M11uH
4fKw2CPuGZPjHcdQeUi8W/GeYlzcNw5jrvoIv8DP4xiOYwb260/nfZybMzrL
qHjvUUe9lzPojeRn1NlRTJ2Da2OPfrqU6/8VT6uzoKg6Kz+Gx+Oe4+7jbmJu
3JvxQfG7YI96YvL1/5n/AbdQ3bU=
                    "]]}}], {}}, {
                  InsetBox["\<\"\[Mu] = \"\>", {-1.8, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["0.2`", {-1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {InsetBox[
                   SubscriptBox["C", "J"], {1.4, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["\<\"=\"\>", {1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["3.5`", {1.7, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {
                  {PointSize[0.05], PointBox[{-0.2, 0}]}, 
                  {PointSize[0.0125], PointBox[{0.8, 0}]}}, 
                 {PointSize[0.007], PointBox[{0.4463998339305619, 0}], 
                  PointBox[{1.2771956561278897`, 0}], 
                  PointBox[{-1.0806611991222994`, 0}], 
                  PointBox[
                   NCache[{0.3, Rational[1, 2] 3^Rational[1, 2]}, {0.3, 
                    0.8660254037844386}]], 
                  PointBox[
                   NCache[{0.3, Rational[-1, 2] 3^Rational[1, 2]}, {
                    0.3, -0.8660254037844386}]]}},
                AspectRatio->1,
                Axes->{False, False},
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                Frame->{{True, True}, {True, True}},
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLines->{None, None},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None, "TransparentPolygonMesh" -> 
                  True, "AxesInFront" -> True},
                PlotRange->{{-2, 2}, {-2, 2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.02], 
                   Scaled[0.02]}, {
                   Scaled[0.02], 
                   Scaled[0.02]}},
                Ticks->{Automatic, Automatic}], 152->
               GraphicsBox[{{GraphicsComplexBox[CompressedData["
1:eJx1Wnl4jNcaD1oXFVLXdocqqoyqLY8pVbwqakmpJLQ0GEqRGlVNLY0qqWVo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                   "], {{
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[0.3], EdgeForm[None], 
                    GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxNmgf4z1Ubxs85P5nJv0SFFFKJCkUqFdKiZVUkhZQSoi3eiCS0tbS09x6a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                    "]], PolygonBox[CompressedData["
1:eJwtlwf4jlUYxs85n2SXQgrhUv5GZjS0EHKVloY2aVxlpa4ibVGkhAZlJKOs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                    "]]}]}, {}, {}, {}, {}}, 
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwl1XfcjmUYh/HnfV+UvWVllr1nRglp0BSVikp2hSIlisqqNEnK3kTKXiF7
z7KSjGxCUpTC9/z443D8zvO87ud57uu6Pt7CLTs17piUSCTG+udkciKRGQ9g
rfoEZ8I32KX+nH/HGWRBVuzWn857ODtXSUkksvG3+FlvCJ/FOeTAd9ir/wX/
gXXyeW6GnPgTuXABv5g9ySM4t8/NJ/8q5+c86pHy0/JozqcuKB+QC3F+9Rj5
GXkcF1AXkZ/Ds/gLRTEPR8zn8lEuzoWsnSAvlI/xl/wVhmGquoh5uXgvuXO8
E2/g87yW18d7xR6oO/HXXNgzZeUX8QI+xGb9KfhM/hRl0BEv4RN8jA6x39aU
5uo+oxS3RwnUUpeMMzFfwad5JU/mtjyeC1pTTG6D1vgPG/Uv81AswHxcwgb9
R/hW/INb8C9aYZLZD3yKl/BJXsrLsQz/o13cFf2ivvMcN1Y/iunymjhvHs1j
MBYz1S/HmXOSZ8rLV5CQr3IXJMtbeGvsV9wLayfyjfppkR7p8Kbebcgg1+Be
eAuLrd8bdynuY9wf7MMS/d78NmqiuOfm6/2IjHIm7Ix9UE+K+x97IZfQX8Dd
1BXjO9WVuAmaogI+Qle8isoYhMGY7bnXeCG/zt1RJfbZZ8zR244UeZvedkxA
KnVqVJXfiHtrTbU4I7258Xvlv3kyT4m7hkXqkua15Mvy7jh33sO3I7PZu9wH
V/Urqa/wT3HGKKOuG+eAlHgHdTLvMFuGsuq747fhBqTB43gMucwacnbOiRwY
qF7juWN8HEeQEUexWv9wnBsOIT1+wyr9Cp69X76Jp3E6NEJ59Urzg3Ja7I/7
gANYof8+f4D7kM3ae/k9ZI0zNc/CU9WpcQ/KqZfrD5CT0CDuhN5d3B/1UFtd
P+65dXdyDXUd7ot+uAOl9ZaavyN/z6XUteVLsbd8kXfEnumnQQ+5J6qjmHqe
+SvyLN6G8fI4bMJGzNDbilHyyNi72CdM09uCEfLwuPPx/ZiotwnHsUh9gp/n
lnFn4vdgDg7rz459j/+n+OaU638P1sceo6L6ELcwax5zVNMrwA/H/pvlVY/i
p9R5UFWdlx/EQ3GGyI191syId8TM+L3qJ/gUTidf/xt0DXZY3Uo=
                    "]]}}], {}}, {
                  InsetBox["\<\"\[Mu] = \"\>", {-1.8, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["0.2`", {-1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {InsetBox[
                   SubscriptBox["C", "J"], {1.4, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["\<\"=\"\>", {1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["3.49`", {1.7, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {
                  {PointSize[0.05], PointBox[{-0.2, 0}]}, 
                  {PointSize[0.0125], PointBox[{0.8, 0}]}}, 
                 {PointSize[0.007], PointBox[{0.4463998339305619, 0}], 
                  PointBox[{1.2771956561278897`, 0}], 
                  PointBox[{-1.0806611991222994`, 0}], 
                  PointBox[
                   NCache[{0.3, Rational[1, 2] 3^Rational[1, 2]}, {0.3, 
                    0.8660254037844386}]], 
                  PointBox[
                   NCache[{0.3, Rational[-1, 2] 3^Rational[1, 2]}, {
                    0.3, -0.8660254037844386}]]}},
                AspectRatio->1,
                Axes->{False, False},
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                Frame->{{True, True}, {True, True}},
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLines->{None, None},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None, "TransparentPolygonMesh" -> 
                  True, "AxesInFront" -> True},
                PlotRange->{{-2, 2}, {-2, 2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.02], 
                   Scaled[0.02]}, {
                   Scaled[0.02], 
                   Scaled[0.02]}},
                Ticks->{Automatic, Automatic}], 153->
               GraphicsBox[{{GraphicsComplexBox[CompressedData["
1:eJx1WntY1NXWJm911FE/Qz+a0JLUJm+YOh41dZmj5C1FTqUhDd5QExI+7xhH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                   "], {{
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[0.3], EdgeForm[None], 
                    GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxNmgn4l8MWx2fmlxYtolIqWkkpESlbC0JSKktI2tBGllCKK0kqooWyy75v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                    "]], PolygonBox[CompressedData["
1:eJwtlwn0lVMUxe89r0ij5oQIzSgpJZIhQ5EkEcvCIiRDpoWMsRAyL0M00WBu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                    "]]}]}, {}, {}, {}, {}}, 
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwl1Xe8jnUYx/HHQ2bIznZsGdmjkjJKQqVoI6QoFC1URsMslYxskpEZysoM
WUnZI6GMUJERkXpfL398zud7Xb/ffZ7nvn/XfU5Kmy7NOqdKJBKT/DiUTCQy
oD5WqQ9yekzCD+qB/CuOICM+xY/6g/gojiETJmOb/mA+jt9wPT7Ddv33+ARW
yye5GTLjFLLgd+yw9iB/wjemTiRyyLvknJxXPUpuLo/h/Oo88p7YywXUY+VH
5EeRH38gH/7EYziNM5iJA/bO4J+5MBd2/QR5tnyIP+AP8VHcgzrFeqm4L7kD
98cAPINnURJXUQLt8S/W23uFh2AJFuMyvtWfjCJ+Z3H102iHfngXbeMZWi/G
Vewpym1QBDXUKfHcrS+MM+BFcS7cmsdzIXsKya3QEpewVv8iv4+D8iw+h7NY
o27IBXEef+MCnkxem5EFcf48L2aB5/NX+BL/4ClM1S/qc0/wPepGmCYv45M8
gkfG2eJzdcc4e066prT8H1LJCTwvp+ZVMS9YGfNh75iYTf0MyISMeFmvcsya
XIVfxSvx3ezfGvfB38fMxjzH91a/xt1RNc7NdXP0vkNmOQvW6f+lHhtnFc9I
LqU/l7uob4pr1WX5XjRGGbyNTuiMcihmz0zXvCB/wRt4Y8wFNmMT5ul35evs
TYs0qKBuEnusvcPl8WLMs/pmLm7PLPmbmG0eF+eOCZivLm29Wpxv3FecKW/h
G/Szoqe8SK+sfJGbqrfwYpTTuyVmJmYXFdWX4xliCcqr68R8xx+QODe+n+9D
Hmv1OCfnRi68Fednz4F417Af6fATVujv47TYE88Ae7Fcfzenwc6YBezCMv0d
nMS2mBdsx9f6fbgv6iKHz72TeyO7vNV6Np6ovirfwRXUS+VeMcN8O1fXq81v
4lbUVN8W74P1WlxNXZNfxxuoEbOgt9B6D3kBl1FXl8/Ia/g0r+VKcd/WuvFL
qIgS6tnWn5Nn8CaMlkfFs4nngOl6GzFcHhb3iqWYEvOEj+WhMV+Yi4l663AY
c9S/8BP8eMw0CsT7F89ff3qcB+flgr7LuJgp7I05U+/jh621QK54z+Jc+W7s
tpZPPZofUmeLe1Rn5wa4C1lj5uIM7ZnC0zAVI9UP8OH4fslr/4P+B84Z3rU=

                    "]]}}], {}}, {
                  InsetBox["\<\"\[Mu] = \"\>", {-1.8, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["0.2`", {-1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {InsetBox[
                   SubscriptBox["C", "J"], {1.4, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["\<\"=\"\>", {1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["3.48`", {1.7, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {
                  {PointSize[0.05], PointBox[{-0.2, 0}]}, 
                  {PointSize[0.0125], PointBox[{0.8, 0}]}}, 
                 {PointSize[0.007], PointBox[{0.4463998339305619, 0}], 
                  PointBox[{1.2771956561278897`, 0}], 
                  PointBox[{-1.0806611991222994`, 0}], 
                  PointBox[
                   NCache[{0.3, Rational[1, 2] 3^Rational[1, 2]}, {0.3, 
                    0.8660254037844386}]], 
                  PointBox[
                   NCache[{0.3, Rational[-1, 2] 3^Rational[1, 2]}, {
                    0.3, -0.8660254037844386}]]}},
                AspectRatio->1,
                Axes->{False, False},
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                Frame->{{True, True}, {True, True}},
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLines->{None, None},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None, "TransparentPolygonMesh" -> 
                  True, "AxesInFront" -> True},
                PlotRange->{{-2, 2}, {-2, 2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.02], 
                   Scaled[0.02]}, {
                   Scaled[0.02], 
                   Scaled[0.02]}},
                Ticks->{Automatic, Automatic}], 154->
               GraphicsBox[{{GraphicsComplexBox[CompressedData["
1:eJx1WnlYVEf2xRjxF7SjMhgNcVwZQzQuUTGJGm9i5+c2LrjE3RY3grZxwS1t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                   "], {{
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[0.3], EdgeForm[None], 
                    GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxNmgn0ltMWxs85H6WSylA0l5QQGqiEZrMiidBVKRISGlAhQ0pEknkeLjLP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                    "]], PolygonBox[CompressedData["
1:eJwtlgcU1lMYxu99vyRpSZFRpK1khDKSQmgYZWZ3rBAn27FnJJu0I6M0tRdR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                    "]]}]}, {}, {}, {}, {}}, 
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwl1Xf81VMcx/H7uz8hCikkkl9a0pBSadh7Kzsze5W9yd57t0slTbQUUiGh
PaQ0FIqMFKko4/l+9Mfr9/p8Puec773nfD/n/so6dm7XqaRQKAzwZ3GxUPiH
W/N4XsSbuRtP4wf5GyzDv/LuPJ0f4uX4Fv/Je/AMfpi/w/cooCdmqj/CK/Ch
eCUfixL8gCJ+xCxj23Kr0kJhGz4ec9TK895q3cQniHtwTXkF8TxxRd5H3lN8
svgU7IhV2AE/4VT8jF/QHwvM7ccLeQBXwXrsgg1YpP4kP5V9ePZe2T+qZ7+4
AA/gPtyP83A+9sx5Yg90yFniY8/axE9gNEbhb3yk/jpqe341+bk4BwPVuvDZ
OXvx7nygOVX5LOyK1vLdeKnxEbyER3JfPp17cy1zKovbox3W4U/8gd/xOL42
bwivxq+YJD+Yd8ZvWIs1OA19jA3ntzAUi+XD+B28jb9wZnFLX9X12cv5UPlh
eEM8Nv3Cz/JzeB6D5BenZ/LurSmPcnn/2BqXGNuOJ/DE9E96y9wXeCf1KeJK
fLV833xvcX2+FtfkexmflnfPU/P+eXq+M1/HnbBf1lo3RO0zVBZXwaT0p/zF
vKv0qLi++lC+PD2J5vIyPhxH4G7chUtxGWqinjmDrblCPIw/4cnpC0zBpxiu
fhVXMLcitkct+ZEZN3ZPehz34krUTm+bUye9zivMeUn8cvpD3jC9zA34c6zK
3nIX+Auumv7B9eKRag3Eq/mozOdRaKjWJH0gXosm8jVZj9FoJG+eXhLfyu/y
/mrr+Gh5DXGr3IncH1THnfIPjC9M7+ErbJIv4Pd5fu4Gz0s/8Zf8Hs/ljTyb
N/AcHsezeD3PSG/zTB7Lt/MdOCh30ee25NtQTTw1d4q75i6IW3Bj+RjxzeJb
ct+yVq0Z34QD0EbeNPck++SW8sZ8A25Eo/SS2gjjnXNP+DV+Fa9gpbwetzCn
bs4B47OP7D37xFbGOnKRS1GCGvKLcCHe9IzJeEb8dM4cY9A/fYVDxMu4jnX9
+IycW+4ZBuce5hkYmPuDZuZV4sfwaN5HfpO4F0/M+aOvfD6fxCfmPqJpepTb
Yq6xMnl3Pk5eLueV+5szwwT10uwNs8W9uA96o6v8GF6CpcUt/4/+ByRZ3xA=

                    "]]}}], {}}, {
                  InsetBox["\<\"\[Mu] = \"\>", {-1.8, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["0.2`", {-1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {InsetBox[
                   SubscriptBox["C", "J"], {1.4, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["\<\"=\"\>", {1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["3.4699999999999998`", {1.7, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {
                  {PointSize[0.05], PointBox[{-0.2, 0}]}, 
                  {PointSize[0.0125], PointBox[{0.8, 0}]}}, 
                 {PointSize[0.007], PointBox[{0.4463998339305619, 0}], 
                  PointBox[{1.2771956561278897`, 0}], 
                  PointBox[{-1.0806611991222994`, 0}], 
                  PointBox[
                   NCache[{0.3, Rational[1, 2] 3^Rational[1, 2]}, {0.3, 
                    0.8660254037844386}]], 
                  PointBox[
                   NCache[{0.3, Rational[-1, 2] 3^Rational[1, 2]}, {
                    0.3, -0.8660254037844386}]]}},
                AspectRatio->1,
                Axes->{False, False},
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                Frame->{{True, True}, {True, True}},
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLines->{None, None},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None, "TransparentPolygonMesh" -> 
                  True, "AxesInFront" -> True},
                PlotRange->{{-2, 2}, {-2, 2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.02], 
                   Scaled[0.02]}, {
                   Scaled[0.02], 
                   Scaled[0.02]}},
                Ticks->{Automatic, Automatic}], 155->
               GraphicsBox[{{GraphicsComplexBox[CompressedData["
1:eJx1WntYlNX2xssxE8e8WxOaoSKh5nW0U9bSxmPlQZ2Mo1g+o2newsSDpI4/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                   "], {{
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[0.3], EdgeForm[None], 
                    GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxNmnW8l0UWxufMRQkDFARbUVQUE2xQLyaSCmIgEqKIKOoqqIDYKHat3a1r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                    "]], PolygonBox[CompressedData["
1:eJwtlwf0j1Ucxu+9yEgiOSIUWZVCSGYiSVLSOI1zGlaniEql04mUvTXsvUdk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                    "]]}]}, {}, {}, {}, {}}, 
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwl1Xe8DlQYwPHXe2WPlNESijQklWgbpVJUqJRCoUVISyp7b+6lbN1ryx6R
nXmvVVFSRskoLdmS0ff5+ON3f8/znHPve85zznlvqSat67bKlkgkPvYjK5lI
/MPleBqv40z0xDJ5a96ITTgs78XL+U3ejK9wRN6bV3Ab/hrf4Kh8C9+BSjgm
/5e7cmXuzgN4IPpjpfw0iqSYx3epreL/oi7uwXdzLz7D53gtzuOsvDffy/ch
G7YigW9xP77DNgzBenPTeAMP5Zx4I/YkHxn74uZ8MVqiVvye2qP8GAriAAqg
JvZjjvF9/C7GYxz2Yrb6wFinOD8ewcNIU6vBDyFffJZ95+UHkRtF5Xl4i3np
0VPO4AFcnfvyOc6BaqiKXdiNndiBd+LszBvB2fE9Zspv4YuwHT/iB1SJczA2
msdgVJylfA//gp+RC7PU+mGs+FO8h7Z4H6nqk6Ln/CF/hPbJC3dtcpwBd+CO
mC/+BE+Kh3PSfq+I9Yg78d9YKD7E9XFl3FVchefwLMYa/4J/4oWxRl4U6+IG
/DyKI8XfHhFzcTjuLGZEj+SdoyfRM3F280ZyPfmlKCQvzLfic/XXuA7qokjc
M+PD1J+KfvHsuAfRI8zDXIxWf4b/wJ/4Pc4Wt2GBsdf5afyFYmgV56Q+Pc6H
W/DV8flxvvL5cca8gI/hKBoiQy2H9ezl2+WLeBxyql0j3yc+gHzy/bwY45FL
Xtb4r+ImPInzqh3kpfIeWILFOIWl6hORx5yb5K/iFXwW75EP8eo4P17DU3lV
7I+/jB7wSp7CK6IvvCz6wst5Mjfjl3EjTuIGNMWJWIvx49wdv4mv59zWMkH8
ovglXIfCamW4Ma6N3spLx102r1Scr7wkN8IetRLxJtTSxS/EG+Bu3BVd4o3I
L+dLzLmMp2Gb2pTYe+wTB/FErCvuTvQ05uNx1MZQ8+fhA3E7TMQEDFabiwri
rfHl7DMG8QNxtzEs3ki8I2yMd8NJFDQvhd/GW8gylsp9eEZ8n2OQPJMH8xq+
h89wAb97lsvLV8f3LPfkO6PnnN/4Kb5ZPj16jhNxhuij1g990U1ekddjQ/LC
/5T/AYy+5Kw=
                    "]]}}], {}}, {
                  InsetBox["\<\"\[Mu] = \"\>", {-1.8, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["0.2`", {-1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {InsetBox[
                   SubscriptBox["C", "J"], {1.4, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["\<\"=\"\>", {1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["3.46`", {1.7, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {
                  {PointSize[0.05], PointBox[{-0.2, 0}]}, 
                  {PointSize[0.0125], PointBox[{0.8, 0}]}}, 
                 {PointSize[0.007], PointBox[{0.4463998339305619, 0}], 
                  PointBox[{1.2771956561278897`, 0}], 
                  PointBox[{-1.0806611991222994`, 0}], 
                  PointBox[
                   NCache[{0.3, Rational[1, 2] 3^Rational[1, 2]}, {0.3, 
                    0.8660254037844386}]], 
                  PointBox[
                   NCache[{0.3, Rational[-1, 2] 3^Rational[1, 2]}, {
                    0.3, -0.8660254037844386}]]}},
                AspectRatio->1,
                Axes->{False, False},
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                Frame->{{True, True}, {True, True}},
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLines->{None, None},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None, "TransparentPolygonMesh" -> 
                  True, "AxesInFront" -> True},
                PlotRange->{{-2, 2}, {-2, 2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.02], 
                   Scaled[0.02]}, {
                   Scaled[0.02], 
                   Scaled[0.02]}},
                Ticks->{Automatic, Automatic}], 156->
               GraphicsBox[{{GraphicsComplexBox[CompressedData["
1:eJx1Wnt4zNcWDYrQTKmG1lS13oNqI9dcVXRjVElSHaGqytTjenVKaSmJtzJ1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                   "], {{
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[0.3], EdgeForm[None], 
                    GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxNmgfUl8WxxncXQewogogNY72WoMSGIYgVBJSAJaCIgGIBBTU2QCwolhhb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                    "]], PolygonBox[CompressedData["
1:eJwtlncUz1UYxu+9CFkpUo6IhFBmMkp1VEpKpNJRnRNFVCTaKS0yIyOyZ5It
WVnZq5AtQikku8hIn6fn98dz7vPc+x33vvddxZu1bdQmhRC+B1nBzYgFMYSa
8MlgJHoUuAgvBUbAt7AeoucqoGfE/2XoD65FnwTVmKiNHgfvCy+t7zPmRW9j
zAZGMvcouhCYCF8LjsILJ/9beyoCbwd+glflncPwguBL9GrQh7nR6Mg4Av0t
4xDwFfyA3mFtPrpG8D8aoh8CVYO/MQb+Bngt+BtfgEuzhFCPsSFzyxk7sL4P
fgI0g5cGX8N/BOdYv4Lnm+hM6E9Z6w1egJ8Cn8EHgrPwEqArz/VJmTXwr+yE
XgLPDX6A/xVty0XgNLw7c8dlW/jt8J6Mg9BLwRl4j+S9lYAv17OMV4OrtAYq
MTeX9TygVvIe9O/F4H50PVBBtgDF4HtkAzAV3RQ9Bj5dewMb4YOZGwxvB6aj
16CLMrZAj2bsgj4Kvxtcp3+D/MxXBwPgGxjPBdvkYfSwzL/WgJzYclz0u3UZ
x7K+Ndp3soAP5W8gt3yBZz6C/wzPCY6gH0OPhE+DrwPF0U8k7/0W5jeB4egL
6B1gl55F54j2scmM+dlDY8Zm6JLJe9JeeqAXoH+Fdwu2yXH0woyvHwLvojuB
8fCOoBw8H+831L3LP9Hz5IPwy5ibBzqifw/2yQnybVApeO7pZJ+UL24I3utu
9PbgPb+JfkvPBPvwi/ACYCd8K5il+OW5rvC8jNnRr4L9wXcoW+7TnQXb9CV0
A1Ax+Budk20s2+pOJ8GngOw82wn9C+Oc5LPojpfo7hkLggLgPfT7ybH4jnxW
7zPfPPiZoejPk33pfPDdbI7eu+5oPDwX9qsfbbM9um/QHj5UMcj8MPSQ4Dmd
7RXdUfAZ++rueeY0/G/llOg58ULav95N/vdNrFWEr2ZsExwz2eR/oBRzZZTz
FFfsp2V0jGeHD1dcyt8ZD4I/QG/FCujFux+jn4efVIwmv6NnOytHMK5irkh0
DD2b7IPyvU2gLPpwNJ8Z7NszmcuT8fETmZhXrBcGxzJ3INtfCb5RrtIegt9p
CX8OzAq+g/LwFrJ58NwgeC5wYyZG+8M/ibbVGVBGvhrti8qBs6Jz8Aj5dnDu
+CA5FpRDVFyUA6pnfHZvJoYVu7kU98rtGV+aEmxb5UTlQtn4lPJh8rOy8T3J
d6a7WoF+XbEGLlEsoG+AN0/Ozb2Ca5FygGJfNWmxakO0LRcE22Z2cmzIRhuS
c65ybTHl4eh/6l9vy4ZZ/A99u0HGNw8w9gz20Xys1QUr0aNkA/hdYDm8A7gX
fl/ymnLuA/AHwbjgmGsP36g986098u/kHK/crrnL0fXBquB3XoavT97r7mBf
Ogm/JtqnFqHPglp6N/quz4Ca0Xeubx0ElaO/eSDZprJlJeZ+UyyB4dqvngEB
PTC4Zk2G/wmqROeEtcrTimnWlimm4V2ia2NtxmXRZ9TZVNOUGycy1zQ4Ry6N
PpPOciy419if/G81GdrrnOi9ac855T+gLLyc4ly+npxra+iu4Tuic7FypM7+
XfSabKBeRDVGtUU9SU/5e3Kstgqu7eejuWr8hegz6Syt9U3Fg/JltA9G+EVw
J7wt63fA1ymvBtukK3px8l30C85V66NjSzlLvcYmxUx0z7FW7yfbQiaoobsD
A4L7Nd3tEhYWBt9xDvROMC84J25JfkfPlmS9W3QPod5Bd9gdfatsEpzztmnv
yb1KadZuSz6zzqpnOkf3EIuD96DcVj25V1GOm6j/R+d61UDV5qLJsa0aPSE6
hhpk7rwfa2sytlKOni27RPci84NjKU9yr6iYKpWcY5VbZ4Dd6F3Jval8QLX7
SMa2quErWJvK+ExwT3QokwMU+8rR1ZQbkr+lGFbua5vcGygH9gaJb9aJ7mFX
szZNeTo4xuaCKsm5QTW7NbxVci80J7j2Pp7cy6oGN4Y/AiYF96SKnUbJvaxi
SLUma7LtVXM2w/+Jvjv5xFPJNUS1Y31wr6seSr2Tet6x6CeT17oH7105SLlH
ZxgR3XOr11bNbyLfSu6t1fMPje6h1Dtpj/Ld7cm1Tz6ss69MrjWygXxvUvRZ
5YOKBd2h7k4xoVhQD6reUzGhu1iWXJt0J5WTY1ixK5/NnVxTVEuUc1JyTlEu
Uc+7X76efDb1YOrVr0/uzdSz70vuEdQblEfXge9N5srB/wGe17EX
                    "]]}]}, {}, {}, {}, {}}, 
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwt1Xe813MUx/HfvaXSnmQrOxmRkb33DCE7WUmJ7MgsaSFF2lIZGSmj0h5a
SIiistoJSUvr+X7wx+u+zjmfz73f8z2f7/d7azVp2bBFUaFQ6OHHF8WFwjo+
jIfzLP4cz2Gy/B6eja+wXt6Rp/C9PAdfY4O8E0/l1vwNvsVG+VxugOOwSf4v
t+PjuQO/wC/ieUyTb0PNEoXCVj5JbXoa5S3pSXwyd07NnmLxLHEJLpJ3EZ+S
/nke74DvUBLf41TMx8t4BT1yX/b25HJomd7l/dI/38XVcTcuRk+1C/kiVMMK
VMUFWI6R1pfxg3gDQ7AUn6i/lD71WEV+Ps5LD2rn8LmojBrWK/HZqIBd5BXT
u32Dci88mLvxmZkZF9tTVnwGTsfP+AU/YREeyBnZ15fL4Ad8JD+Cd8SPWIgF
OC1nYW0Av4b+mCtfzEvwG8rj45wbBopfx0N4GI9ktupvZ878GLfF4+glH5rr
8xP8JD4V98Zl4r5cyr3sld7FT/FfGCdew42xN/5GLVyLa3J962PTG4/hxTyO
B/F1fD1qo7S/3U9tPNbK/8EHmZf8aR6euYnL2NefG8l3xk7ymlwfY9Tv5Mtx
Rc4nz5j1PupXigfwh5kvRuTcM6vMUv1q/gO7YjV2w1EYa605X4U/sTta5TzU
h+VsuAXvg1H4VT4ys8NorMONed7Uy+llGR8tPwZvisur7Z/nU7wSVeUreELO
CRXldayvEt/C73IVtdU8Ud4BEzAemzBJ/R1UtudQeTPckVmqzeS1PD3nxDN4
GE/jNTw1Z8qf8fs8JffMkzIbnszv8W18Ow7BRtTFrdiAidbX87P4XXwwV9LL
UHFT8VtcQX6Q+GY0wQGZu9qBvNT6TTyEy6rtl2dbvG/eB/lg8Q3igdye2+EZ
LJLvmWfCnj3Sf96dzCI9Z27pBw0zS9TAyjw/uBSX4FX7R+NRcZv0mjMq/u87
PApHiudxSdfozmflvNEbffL7mKPei0uhun2l+X7ch9nWunPXPIf5tqOb/Mt8
f3gmF/E2dBLX48MxQ7yVO/IJfCK2iDdzex6R7zaqud7mnB865zrokrOQH5vr
5L36/3/Kdn0C43Y=
                    "]]}}], {}}, {
                  InsetBox["\<\"\[Mu] = \"\>", {-1.8, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["0.2`", {-1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {InsetBox[
                   SubscriptBox["C", "J"], {1.4, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["\<\"=\"\>", {1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["3.45`", {1.7, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {
                  {PointSize[0.05], PointBox[{-0.2, 0}]}, 
                  {PointSize[0.0125], PointBox[{0.8, 0}]}}, 
                 {PointSize[0.007], PointBox[{0.4463998339305619, 0}], 
                  PointBox[{1.2771956561278897`, 0}], 
                  PointBox[{-1.0806611991222994`, 0}], 
                  PointBox[
                   NCache[{0.3, Rational[1, 2] 3^Rational[1, 2]}, {0.3, 
                    0.8660254037844386}]], 
                  PointBox[
                   NCache[{0.3, Rational[-1, 2] 3^Rational[1, 2]}, {
                    0.3, -0.8660254037844386}]]}},
                AspectRatio->1,
                Axes->{False, False},
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                Frame->{{True, True}, {True, True}},
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLines->{None, None},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None, "TransparentPolygonMesh" -> 
                  True, "AxesInFront" -> True},
                PlotRange->{{-2, 2}, {-2, 2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.02], 
                   Scaled[0.02]}, {
                   Scaled[0.02], 
                   Scaled[0.02]}},
                Ticks->{Automatic, Automatic}], 157->
               GraphicsBox[{{GraphicsComplexBox[CompressedData["
1:eJx1WnlY1FUXllJUcpLU/HQ0E9cpM8wYxCKPOT5mln4TkgvZaKWGTq5lOWam
luNShsW4ZKROiln2gQsu2OjBXArcEFlcEGEckC3EGRjUTD6b63vneW4P/PN7
3vnd5T3nvPfcc++PkLdnRE16oFGjRm0ebNTon2evFn+UufTZnLVvXZSmuJZv
HghaaXUfkNghMAF3FO0lXvzOlF/1tmv80YS6hQ6rm0+m9GhnyyuUGOMDY3xg
jA+M8YGPivEknifmkzii1S+mPGOVfIIPMPgAgw8w+ACDDzD4AIMPMPgA9xFP
icFT5QWsPsEXGHyBwRcYfIHBFxh8gcEXGHyB3xd8qaG4qn5VeatP8AMGP2Dw
AwY/YPADBr+GdKbGGeMDo39Duld1qupEXReqjlUdqbpWdQV+wODX0DpQdajG
WfUreKjzAKtP+B8Y/gcGv4bWpbouVN2pcUYcgOFnYPAHBn+VJ7D6BH9g8G9o
3arrQtUh+AKDLzD4AoOv6keVF7D6VNelug5UXYMPMPioulLjqPpFHf+00L0c
HxjjA2N8YKfv/UXu5vu9hrMEJuCevqdLvr/se1/OGT5e1TKP4P3jor3snyPa
E9rjiXGOC0zA6AdeeIJHmQ9nSNzI93fIofJEO4yLcYDxHvbiPfgDgz8w+Krj
nRDjSbtVjHnQHlh9Yn5gzNcQT9gPLPf/++3BHxi6BYYf0B/6AUa8MA74AKtx
VNthPmDEqbPwi7QHGLyAwUNtjzwv/XcfY72o+kMeBB/YBV7IM+gHXWN9gTf8
o+pNrQNUfeA94iPtuM9fzbNqnNW8puoR7zEfeAIjD4AveOC9qhtgVVeYDxjj
qfsdxoE9qp0YV9UJ4qXmUzX+yF+YV9UP3lt98+fxPN94Tu7T8rluJkMZ4/eT
vnbFst3iyZdqk+yVlBAU96ou+Qb19vEqoLq3+nSyaGrpBYH5L4EZ74HRf5Po
zwUH5/9eX3+dSsST2/76D7+fJR/0y/TZkckfCR6SD/oDo/1h0Z5gD/qpT9gH
jPHUeWYLPgR+wGiPJ+yHPxAnxGXY3vF7jCaPHBfvERe8h9+AMS4w+CE/qXkd
6x35D++B8b6hvIz3yANYz8gTwCMEHxmvhuYBRjwQH4wDvQNDt+CD98B4D354
D37A4Ic4Q0c/aQKW2h1eqTfgNr5+RwkYcYauMB/WMXQMu4CRNzB/tpif1TyP
+AMjvqr+oRe8V/d99Ym8gHmhH/CEH+BP9ANGf8QJ/XWiv9Qv4o18Cr59hR8l
hi7hP+gB+wrwCpEfZFyAN/j6/yzjAP3DH1g/8DfiBvuxnmAPMOzBeMhPwIgX
9IR4AWN+zIcn1j/sRv4FRv5FHBKF3gh+A4Zf0B8Y/eEntIefgBFP9AdGf+gd
7eEflQ/WA+IMjPmAsY8CYzxg+BPrB/sIdAmM9QMdQp/QIdYH1gEw4oF+0Av2
VehB9ru//6r7GzD2XXV/Ue8BoAfwgw4wDzD4qedd6AW/A8NuNe8AN5R38MT6
AsY+i3WFeGEexFPN52gH+6Eb/A770R/2gif8DJ5Yd+CFugZ8gcEXcYF+MB70
oo6HuMFO7M+wU9WhrLMUHap5GvpBHNU6Tc0T2HfQHvZjHPhTrXvgPzWOsAd+
UfdljIs8qJ5T1H0S7cEL46vzwL/wD/yJfACdqHlfravVPK7WycgXeI/5Ma+q
e/gX9iJusEs9N6p1O+ZT9Yp+wFiX8BPaQ4fyvH+fD9qBD3SGeGJ+YIwDv8Pf
iC/WAzD0DTsRD/DAPoM4A8NPiFND53j1XCLvy+7vi7Af42EfU88N4INxgZGP
4Sf0B0/wQTtgjA//oD34Yhy83/3zvjBd6BVZz5b8XrnSOrv8X/fC1QVLIwyT
/OfjUYeaj9Qk1vIMnXOoZlKFXC+Xx0xrZ0uuZvXerVHqoA3WvvfyWvHgr+2V
/vNy7IxNK+13/PfnYRtbPJRs3yHzPr9y+1nDLf89OX7/YefXz5ri/ffPrc8F
brL2LeTty4buMnYqln5ZYawY777tv/9NfXt4gWuP/3wLexqvyomzO87KPDZn
5KMLHYHnZH/Mg/7qd5MOi/N2Gk3HCHyxjsBHvbc/WdjkLXdMDsFe9f720KKX
DbrruXL9LGzaqTbdnCPPuZGttn/ssOYQ/Kfet67ZnxJqOuKU+SdxZ9fb6fFO
/31z4oKq9F739oP78cK4sP+tyCP79W3KCPFSv3tMb/367/rsaoJe0A96UL8z
OMbSy7o4j9Qb6ivwfmmle6u51CP5L/12f4Z2hVfyXxGdlmTsVCf309ILge70
XnXSXxuf+NJm3eWlQ3dHz3MMyeW5KY5wwxQvD2j09X8sp0o5++mHQk1dPVyw
aWo7k+e6fG55eOJ31iw3F/Cg6vRepdyxbf946+w8Ptb/SqVrjpPnL22xyZx5
jTtFP7zbmJTNT7+Y4nI9eo2OGPuutfbNYUf3+vF5q/6kR4pDrrn25HDzlISA
5Fu1PGXBsE/skQ5+6/XpUZq/azmnaEecdXYq/VH+YZBtbSnH/f3LK7rQLArf
qdPrrhdQxsjNVa45Z2mw5c+fzBFumuCLaxbpHmk0XDejiGPHDL9aT4W0q/Px
9paV+2hxyKEp7qmFFKSLvuiqraQJ5hMDDBdu0ModQd/Y599rt2dFS9u+WgqZ
/dmHeZmZHF0wJdl4yMuRY/PDDJa1/Jh7dZIxvI53fp9t1BQfp/yNznhrqzpu
12GWN337vTonvuPMvJk1vObtJkf1KU6umvDTfIe3hp+cEdNfF1fJ1V+NqHIl
3mDjnMhS16PFdGjgA2WuxBq57mcLffDyM80OaodVybx2/u68bpZPbvDtEbsT
jQMqufEno8NMXaupmXiyt33L7WbbDaIll3bp36v05yGhV87QdHvG5PHXcQfm
ZIzSLPHwXxFHWtrWFvPshaMv12/00B81JZnaoKscEVDTy3S1hnvHHVht3naZ
t9nfWuIIzOSHy8cO01138uAO+3ubrnpopC9e+Xx9x8F33Jke0o4o+sBhuiD9
cez8uK3GgkuceGJeotF0koxHBn1r3nZJ3iP0F+ufp4+43NFyyn+e+6aoS4jp
wQpetv8f+ydI3GynD1PURz0X2VuU8w+/fPKmO+Z3At/HBF8CnyDBh8DXIPjS
3XnTFji8987PZa1a2/ZdJfDdI/jSRz7/n5b7FPyTJvxD8Eeg8AdF+fLKMb4d
MnOS+6KTEC+3iBdl5Wja2pq65T0b4ocn9FEp9CHzxp39vvxPQyyttKYHr8t6
EHzXC73Rc2mZJvf6Enkeg36NQr80/U3rEybDcT6ZdzPJeNdL0HN7oWfKWnrA
oEteQzGWGK2lfx1B3+eFvmnnM/r/6kIzKXb6CxZHiZeqKkL665LzZRyxD8dv
XX9CG+Q/z30l8o/M+5Ui/8g6qLkj5Xw9eeU+libyHa870/Ri/afF//r+MbYy
6ag+2p+3XxH5j2G/ev8cPfzjs9q9brmO/nqiQ0l6xZ8Mf6r30TE3n7aZl1Ux
4oV5fzk18LR2Rc2/vrs8sXl9F8tKp9xnN4j9Q/pj/vKJcfY7RdIfv53oc6U+
3invJW7279HN8r8iXlWz8Vtrlv98CX9cEvud3BdPif2NoU/MMyC8sIfpSJ7/
++19/07O7LrPaMqSdWFu/Ds/mred4+hHXvrcsdV/fw37W8+vedyi8d9nd9yy
z+nSb5N4y2YfJqxXnPsxv3qfPUrM7z/PiPkJ86v3243F/AR/q98VQoS/aWLj
5cG2nv46PPtws/a20f7vu/DLB8L/8n6jWvib4G9533c/P6rfzTxCL5JflNAH
IT+r39FeF/qU69wo9EfQM9Yn1o/6PTBOrB/pvyZifVB9wv73HYEX+VX683z9
416O1r7e3nIqj9ssCcjSTnVybOwPAba1l8lq6jMnb9VZygzK/cxRUk11u4Oe
N9w6R9gf+on9gVKGNx9o6H6DogpLHrbs+ZOCfHnoXr3aYecE94pa/iWn3JyX
mUvhU0M86V94eWBAu1S96zxFTF691B7rZeyXe8V+yV16HXvG0L+Mhg3uHmkY
e2/9DrwyQDejjNY8ptlmHuph7LcTxX7LmD9GzM+VncuO6I+6aa7r1Rd1LUt5
3GeL/k7fXiifWVG3l1jdSXx3cuwixxAnp+YGvqxL3sxhXfYlWFs5Gfv7CrG/
896ddzebbbV8yDM+1OTJ4vceHTjBnVHLj5w+87jpyAkOHD1ugvtADrURT0Y9
cVHUE9Kfq4U/2eTjXUTeDQsSrH2zOGLk6aG6M1cpZn32j+bYc3wx9ce59vwq
WvAGP2YZnsOoR2aIeoQRj6YpvnjwoOWPjdEcc1N5bOhKe+Q5Wf/0FvUPgf8O
wZ/A33PKx59QXwWL+orAr0TwI/B7RfAj2Isn6rEUUY8R+OQLPgR7pgt7CHGI
Fk9CvXdQ1HsEPbYQeiTEyyviRYjXUyJehPoxV9SPhPjPFPEn1Jm54kmoRzNF
PUrQ2xChN4LevhF6k3quFHqW9e0Hor6V62moWE8EvfcVeifoPUzoXeYJb5zv
vCPr9MnivEPaK0u+tCd4aIhvH8rlNefbfGnP91DS8LRxmu6FBLxXYC7w1rS2
9fPX7bjHKT87LlpTnM0YL1yMJ8+j7Wir3VzqlfvHhq9cLWz96mQe1lky6pMC
6nhQP8PzhgseeY+Deidf1DuyzkI9h3xV/dJ7HS2aXA7pdLWPIbVMtkO9lSbq
LW4cqR+mSSznwzv3bjaaDsp9H7xKc57ZbG7m5eTm/5zDFxHGA89W3914Ny+4
jJecXL3ROtv/vSZ79exT9Rvz5X1y8c0Hn9OF5hPswT6C+tUj6ldqZH4hUzvV
w31CopfZ7xTL8UYHu2bkrfJ/z84f3+VS/ZUa+rQuPdVY4K/v/277+sw8YwoP
bL4hXftkHbd9btobmuI0Kn335FxHjzrpxzfEePKcs2lEt2hNk1rJq1CMz9hn
ImvXndTOq+URrzV9wXDBSbExEfMd4bVc+dTgrpbebv595Jaz9VQu7yu2DV2e
79pTwbAnQtjD2ku3OlssHmmX/b/tQ00dPNRjSffx7qkl/GX/dXuMAzw0xne/
UMyfTxo5Ky/NQ40fCG6efLiIA4YkBtv+46/TOs/q/Lb7QA0n5VSMcK+/wkMW
jl1uj63lUeVHH7b1zOXjVxawfnAtp8RsHqibcZ6RB8fp54earjr51fDGP5oL
/v29yCXixzh/zRTnL/aOtS50HHdyWJOMN/MyCxjnuQ3iPMfQQ7zQg9RJrYg/
NwtLGqVZfYQG3Y3QGewF/FTCd7uNpqP08sXVBs2kAl6VceZDx5BSGnXRNsG9
PodvLuw9OS+4nFyfLu5nuHWvfhpzNSD5bC33Ozi+qW10hjxfPuL0nS8Zeo17
yKdXLltcM8sRWCH1DL0vEXon+BP7NPw3VPiP4L+twn8Ef28Q/ib4D/1hX19h
H8G+/sI+wvlpoDg/yfrCKdYrwf6hwn6C/bnCfsJ5+0Fx3ibTMWO+K6eCnvbp
K4egL+gY+rkT4NMPQW+dhN4IejMKvcn8hPMQ9BIt9ELLOtRPdGuPcELCE10s
p5yE9REh1gdhfUwU64NwPj4gzsdy/DYi/8n1i/PNmnm/LnZYDzPOK4jbepEf
Ces7UqxvOubLsylU+XlBT9OzdTLfdBP5k7D+XWL90xtd7p7TDjtLLcq8esMF
r8zbX4j7Fi4dfLuovt7//fcT333OJY6I/yogOcArvy8Fr7rV0XKwlnEeyxTn
MQZ/3CfgPGYS5zEG32rBl3Eee0+cxxj8ggU/eV7YLO53uN1raU2S7efk97J1
M64d1Ye5qduF8jaW4f57qCni/op/295+snue+1/fLcKrPtytb1PJ23p9OEx3
xX9P1SL+pQxtRq78zkA/LVhr3pbPt7dP+N66q4hRn+N8A3906f1FjGZSEeP8
/EAX3/mZoZctQi9cfrriTpJ9vxy/cuaFJ02f+b+/HT/+4nh3TAlPWfRrdv2n
5xnnA+Qn3GdHfba40DXngjw/rhL3g4z1ECnWg7zXGybuC/k9u3aE7kw1/XZo
7WF9m2w5P/yM97vEe/l/Gz22D07TZ9/D9/d7tMd+f0ns94T82E3kR3kOXC/u
awn+dAt/yvu8h8T9LSEesAv3T+Xi/omwXyWI/UqOXynup2mc79zilN8Lod8w
oV9Z/0SJ+2s6FdtnpiMwn6K6vn1C+6SXgxs/HmpILedgX/3nZs/TI1/WdK8g
6/oOV+o3urlVx+yg5MPV/Edh4GBN9yp+t+0frvTtVVSyN+wNTZMbPHdK42dN
V6sp4eN3bebYKk4rjD+jzYinXF89XsQ/P3/9Ur3ZRY/+z9IkOf0cvzArd4/e
Uc7uabHn6ilV4r0CE/J9e5HvCf2biP4EvcQIvRDmOy3mo1m+c+NZ6hnxY19D
6nnCfs1ivybYkybsIaynjmI9EeyxCXuocOZFjWV4FWtdB6+7cqoJ/hL1spvg
r8XCX2T662OTO6OEW4557XnDWY/09wjhbxrUY8dcR/g1+nyaeaiuaY0cv5MY
X/rXKfwrx2stxuOasKo0/Qc1PC3w/eP66CJu66vPLsjzCjDuU9F+kmgv518m
5mf4K1z4i/8P9sgl2g==
                   "], {{
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[0.3], EdgeForm[None], 
                    GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxNmQv81+MVx7/PY6aILooKUxTSzWVEiYoSIl1EaqlQ5JJIaiK5jI1hmzFs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                    "]], PolygonBox[CompressedData["
1:eJwtlncU11MYxu99i0JGGRHSUk5pkRBKUgcZlfFPZpQRZRwj63AamjS0l7S3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                    "]]}]}, {}, {}, {}, {}}, 
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwt1Xl813McwPHftmrpGpUzIUdRchVC5L6PRIhcIxSVQlEoKiuxskmbUipq
m0W3dNBtRyvdOToclQ6Rbl2e7wd/PHt9ju++v+/3+/tu1Unv2KJDUiKRyPbP
/OREYpfW13E6V+fRg9nm7fRbitht3lPn6LNaTAl7zN/QufqclrKQRZRxIRex
1/5O7aWN9C3tE6V3fI75QWqkJBIHtLG1izlkvFsz9BLtp3v1iJbGjRjv423j
S+OzdakmsZglfEcTltGfd+L4WHfsu1qRp2LfPFuX65P6DE9zE+9bu0Fv5Gh+
IY3r+Zkv7a/X5/mIoaxjivWB/GNcjeu4Nvm/53+1XkPVOKf7rqLNqERN88q6
0nG5OoQPGWDeNO5B92sqV3A5P1CB71lNR5Y6LkvLxX0xybyBlmcFq+IzuIxM
e4P0g7jf2Ddfo2v5iaOYHM+MwcY5dKIzL5Bl/YAeE9dgPCKuSavrwTiv8Uj9
UbtoV6YZ53Bb3J8e0VqsN35Zf2em8WZtwclsoTb3cg8f25+sv+ok/U2n6Aht
qfdxCgnPdIi1r9lqnkc+r1AQ36P1JMcM1TvjO4h7MT9Wz2W69XS9nTs4jsPk
Wr8rvnct1LF8xhd8zjDrd+sGjo/r4wQaMsPeE9qcjWyiLWusj4lnr230VMbH
e2c+TicygW08wCfWy7nWjXqe+fl8alze2ulxXuMtVDXfrN+QR0Xzs+y35qG4
bmuVrW3Tr8xfZ2q83/zNLOsFVHLMOeaP81jcq7U5cYzO0h06O+4/Pkv/0pn6
Zzz/eEY6Q7frNP1Dp2uhPqKPcnach3o8HD8b54mfieN5ja2OrxvvpuvJN37Q
eIymmp8Z74/xGVrBfLRxK+NRmmJeJ74T49M02Xyk8f3Gw/VV7U431pmfpNUd
c6KOjt8Ha6PiGcezj3ePW7iVGhxisGNu1kHxLHnJ+MV4X+MzeM/aVFYxzHy1
XqVXxu8IA+MYMllib0BcJ2muI0U70J7F9vppf51IGRnmi7Svluhh9hj31QkU
UcV5inVB/H1il/3eOp59VLO/X+fxpr352kv76AW6gJ3//z/yL1of5Fo=
                    "]]}}], {}}, {
                  InsetBox["\<\"\[Mu] = \"\>", {-1.8, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["0.2`", {-1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {InsetBox[
                   SubscriptBox["C", "J"], {1.4, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["\<\"=\"\>", {1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["3.44`", {1.7, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {
                  {PointSize[0.05], PointBox[{-0.2, 0}]}, 
                  {PointSize[0.0125], PointBox[{0.8, 0}]}}, 
                 {PointSize[0.007], PointBox[{0.4463998339305619, 0}], 
                  PointBox[{1.2771956561278897`, 0}], 
                  PointBox[{-1.0806611991222994`, 0}], 
                  PointBox[
                   NCache[{0.3, Rational[1, 2] 3^Rational[1, 2]}, {0.3, 
                    0.8660254037844386}]], 
                  PointBox[
                   NCache[{0.3, Rational[-1, 2] 3^Rational[1, 2]}, {
                    0.3, -0.8660254037844386}]]}},
                AspectRatio->1,
                Axes->{False, False},
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                Frame->{{True, True}, {True, True}},
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLines->{None, None},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None, "TransparentPolygonMesh" -> 
                  True, "AxesInFront" -> True},
                PlotRange->{{-2, 2}, {-2, 2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.02], 
                   Scaled[0.02]}, {
                   Scaled[0.02], 
                   Scaled[0.02]}},
                Ticks->{Automatic, Automatic}], 158->
               GraphicsBox[{{GraphicsComplexBox[CompressedData["
1:eJx1WnlY1NUaJlMqi7TU8o5bbjgiqZkgrl81ZYmmk3rRXMY1syDN7KLDLTW1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                   "], {{
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[0.3], EdgeForm[None], 
                    GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxNmQf81+MWx5/nCdmioaGUjMqI1tWQ0lDR1JB2klHJTlRCywjZmffa5MYt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                    "]], PolygonBox[CompressedData["
1:eJwtl3cU11MYxu99Gypla0rKHg3HIaGDbMcxsiMnhdQpI5zIrIwm2pGymio0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                    "]]}]}, {}, {}, {}, {}}, 
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwt1Xecz3UcwPHf/exx1tl3pWujKCqjRXupXCmVhJZKNEhbS+UyQpEtK7Nh
lXMnK6NIhUjRwKGSeYesnu9H/njd6/1+fz7f7/fz+bw/d5fZoUtW55REIjHI
j2+SicRuPoOn89f8LJ7DQ1iJb7HH2PO8gB/mVfgOe+Uv8ELuyN/jB6zBatTF
Odhn/F/uxedyb+7Br+BlLJEfRHqRROIA11Orj0PiI9yHz+N+fIwPx1pxvvgI
V/bc0dgP1qsd47W8Dj+iAX7Cm3gLPWNf5rzNxXBPrF3eN9bPd3Fb1PTee/ky
fKDegVPU7uf2aIc2KItLcQm24Qtz87kTRmA4tuJz9ffj8L2jjPxiNMVgtcbc
BKVR1XgpboQSyJCXjHM1bwgPw1C8J7+I+/NxLooLcQF+QxH8ik14LHpmXp/Y
A87CmdiIJDbgF/yMhhgYa+VB8Z3op3wzb8EfKI7ZagMwOM4Hj6MzuiT/v19J
604VrxWPiV5wuViX+lDxxOgRP8FPYo54GC6Pc+Ni5lWJdYmf4n+QK97F18Y5
xf1FtbijsRdj1/FYnhtnwDn8O+fyOL6eb0D12IP3j1TLw175x/gET+PTODf1
EuaM4ivk5eNb8gp8NnLU7+RmaI6K0QPjw9WvFI/m6TwDn2EWZuJD9av5JHOv
4Ur4Cw/gQcw13pqvwt/YifviDqtPi17x3Vwj7lT0WD47zi/uHvbhJnykXto3
NnPt+F48I8/gm6OX6ttQSS2fv8RkpMpPMd4St2KaWgW1HTFH3h3zkIdDmK8+
FeXNOV1+B1rFntWWR994aeyDl8XZ8pLYGy+OvfNXcfa8iP/k+bwQC6Iv8tv4
dpyGgzgVWSjEARRgP57BdvMzuZz1TBHfIp7EZeW1xFvFJ3MZ+URxC/EELiVP
j/strskl5ePFN4rH8Dx0E3eN35P4uxP3yJw0nor1apN4CibHPuK90Ye4kxgf
dxA74g5gJEZhiOdGx7oxAAPRD/3xbtxfvIPe6IVV5mfzca7i+wnxo3gEb+D1
eM7YLKzAq/KV/Bovj7/FOCruyzOjN6joPcuiDyjEYePZPAP7kWa8IPqDF40t
5pdiXVyHV2DXif8p/wHc++I4
                    "]]}}], {}}, {
                  InsetBox["\<\"\[Mu] = \"\>", {-1.8, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["0.2`", {-1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {InsetBox[
                   SubscriptBox["C", "J"], {1.4, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["\<\"=\"\>", {1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["3.4299999999999997`", {1.7, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {
                  {PointSize[0.05], PointBox[{-0.2, 0}]}, 
                  {PointSize[0.0125], PointBox[{0.8, 0}]}}, 
                 {PointSize[0.007], PointBox[{0.4463998339305619, 0}], 
                  PointBox[{1.2771956561278897`, 0}], 
                  PointBox[{-1.0806611991222994`, 0}], 
                  PointBox[
                   NCache[{0.3, Rational[1, 2] 3^Rational[1, 2]}, {0.3, 
                    0.8660254037844386}]], 
                  PointBox[
                   NCache[{0.3, Rational[-1, 2] 3^Rational[1, 2]}, {
                    0.3, -0.8660254037844386}]]}},
                AspectRatio->1,
                Axes->{False, False},
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                Frame->{{True, True}, {True, True}},
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLines->{None, None},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None, "TransparentPolygonMesh" -> 
                  True, "AxesInFront" -> True},
                PlotRange->{{-2, 2}, {-2, 2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.02], 
                   Scaled[0.02]}, {
                   Scaled[0.02], 
                   Scaled[0.02]}},
                Ticks->{Automatic, Automatic}], 159->
               GraphicsBox[{{GraphicsComplexBox[CompressedData["
1:eJx1WntY1FX6xzLX1EHbKPtNitKTNt7StcbK26tOpeJtNG/1o8n8LWagkXgd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                   "], {{
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[0.3], EdgeForm[None], 
                    GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxNmnncl0UVxWfGTEPJXXEBQUSR3FBQVFzAJREFRFAUUUBxAUQwwS3XNHdy
39dSS9NMc9/3Si01McvMpUWzMivRsiw73875fV7+uNz7zG+emXlm7jn33nnp
M/XwsbNaKeVt/bOY9Bq1lNUlB8jeS3pPySOy95aeIHlM9kTpfSRPyL5Dcp7k
QMmaauslOUh2T+nPSy8jWbbYXkKyXPSSkuWjvyBZIbqbZMXopST7a5zhku0k
d+r5fMmhkrX03EcyXfaFksMkq0tWk3wx866RuZmzd3X7qqwtbczfK5r514xm
/h3VfwfJyqxL+rWM/ZSkh2RtxkzflST90r5q1tH57osks7KWYySbSAZJ3sjc
/SXrxWb+AdGM/aXoPpLJWsMr0gskMyV9JRtINozNei6RzMlavpJxN5JcITky
Y18lmZuxj5LMk6wvmZ3xNpbsrLm+XDO29OHZs3cl70gGSkaqfRfJprKPznt8
23H5vs3xCf0+WHqI5F7JDZKvSu6X3Cg5QfJ8fh8u+ZvkJskpkuMlm0m2lnwo
+bbka5JDNOYW0ttLtpK9kuRHsteR7ic5SfYeki/zHZIp1WOMYM2SbSTbSg5Q
+1TJs7J3yTz89pFkoWQ79q96nlHsp+ydpHeXjC22mWMGfiI9WjJO9gDJ14v9
pV/8YVzWwhpG6ffdqtcyPm3Mv3H1GBMk+0jGZK7xah8oOUP2xEXm3zeab50U
zTxnSc6U7Mk5670jJbMkN+v57Iw/Rs+bV88/WPoc6b0l/8zckyX/znxTJJ9l
vqnF3AAfgOE9wwdgGD6AA8DtwcX8AeYnhCfANjxxSDGuO5hfPv3AyjKlC/8r
lC6+4Dd4pWcw3OEOfuuRfcb/4YgVMz7Y7V2MTd5ZLWfBWGCxg9EOZ9wiOTd7
Ca/AFz0yR8+80+ELnuGHGcXYhJ8OzVxPF3NE39LFKb3yTb3zvHf8hTPuVs0v
8NelkiNKF+7giHXzPljuX7o4Yr3SxRE8L4jdJ3MzBnieE5v9uUdyWTE3wAcb
ZZy3izkCXvhNMUfAC3DAxhlnRDUvsD44AKzz23ckp7IfxZxwbDHmwfmQ2PDE
oLxzcjG2hxbjH9yBc/gA3IPBnxTzwrBifJ9YjDGwPzzjwhPwAVgG/+AUXoBz
4B7mO62YD3bKXu+TvQf38MLOmR/8jcjcI/O8MDbjg2m4YLdivI/KfLOCWdYG
zuCIMZkPbIJVOGKPPDPfuDwz3/g87xYsMu/oao44vZjPns0Yo7P2CRl3Yr4H
boA79ipdvDCxdPECz2B9UuZ6uJgLwDy4npL+8AD435/xqzkCHoEHJmcu8DE1
Y/6jGDPzi/EL3sErOCHegSuwDCeAx6HJC8DiN9L+OfZc7dMyBvrg2GAJTBF/
Ly6OeRtkXLACZifp3X0lL8neT3pYNb/cVRx3O3Hr8Kzr6uI4h9/+IuPyfGsx
9sAKeAAfYK1f2sDO5WkHM+DtyPS9TXJlnomj4AYcLkH+E464uzjWrp/f5maM
32VNxM9rosHIH/NMvnBtNP78reL4in9fV4wx8HWf5PpiXP0579BvSPqAi9nV
v+PvHxTjcGieweE2ETCIzx9B3A/2vpk+4BTfPqnYJznD83K+vAMetyv2NXwF
P+mvMdZNTNyInCKxbP34OBj7Yb4H7oBLTss8xDB8EGw8VBzbaLtd8t3MMa/6
HfoPqfZH5h9EblId88AN/g52dq3mKfIW9K7hLHyWPHL1+MtF8Znu+v3VRXwF
jR++XpxvdXwE/9kwPgLH4j/LVPtHh1uvWMR38Bl8aTn1WbZ2ce5V8ZHl1fbL
RfwDjd+uoPbfxz9Wq94LcLii7D/l7I/Nfg6O79B3k/jH9TnH94v9afP4yA3x
E87/ppwne3Zz9o2z/XbOF1+4Mf6CnxAD4P/jMj++Oj/r4iyoIx6VbtmzW7Nn
7Mdt2Q/O9ns571tyxpwvfPD9Yn6BN6g38DvqgB8U88PS1RgDX+D0npwDe3Bv
vg9/vy97gD/fn+/A1x4o9mm+78F8I3PjY/AdvEbOQ97xeHHOw7c8mvaa32gn
r/lp+tGHugl7sfxGLgQvbhneIld4QfJk+jyZPtjUWTzDk33TFy56pjjP6Jtx
sFfhneq5mffHxXGRM/1LnrEvyPu8u336EL/IpemzZTG2iTvEK7BLLCbuHlQd
m/EZ8ufnijnkufTfqjiWEDOIF4tXfxvf8rPi72WdcMaLxVwNh/MbdRx8SR7T
J99Kf3Iw8LAg54t+JTb657HBB3iZnXVOy7qJE+Ti5H5gFywTS36V9nWiee4X
/XpsMP3r4pyHXOzN4nzsrdhgHF7/bTF230w/2i9LP2zwB2bBMTXUe8X8Aybf
iQ1uwO8xaXs37QPzDPb/kHba/iX5pDg2cybv51zYd+I4nAdG/1qM6e2Kcxpw
Db7/XozpXllzz5zjBzlT+Jn+u+a9j2J/kvGZF87At7ZIG7+RP3yc/szZo/oZ
m3gObsHsp8V+Qv6xWXX+wbv/zW9Tov+TuYgl5Cv4F4DDnpo2nqdE19j/55tq
LKAXiw0WP1ftk+jFYxOn8T987+DqepvnJatj+Yy0Y69VHGfhXM6NfIQcHl9b
qjqnp+21tONj+Ck8ha+SexBX8Ed87YvVvAj3EwuIFeQAcD2+Q06+XGIEuTpx
Be4kfyBOXJ15umUuME3eDK73qK5nuqdt5cR09CqxH8w5cUbkh6tW8z45HjEG
PoZ/qf06XIhdo9eIPbY6n+vUaWhqLPK+XmmjD/biaVszNuskR+ydNbJWuGjf
rB8eQK+Vb+GZvuB67ep6ad34MnbPaH4jnsNP5NNwFHU6vDY8beuk/aQ8w39w
B32GRfePPV360Op6YMNo6oFNqnPxvdJnQMZfGCyR53wp7dQRaJ7Jizao7gO+
OuPS5zDpmdX5/abRxOLx6TMqY/P+6cHTp8HLYVkPfTrvszbaWCs5GG2D0g5+
wSC8cXZ+m5A28EkuQB5GLUEdQa6FvZ/sLaqfsVnXRlk/bfw2P+/xTD4ArxO3
iAVPx34q/rlVzp1YhI0v4xdbV/vRtvExfAbN87T4wtBF/I7fqCOoCbgXIEfd
vrpWX7o49gxLO238Bj9x3zgsfajZeXel6OGxiR/EUWIoXLZD2uFral14fafq
OwJ+Jy+kliZvpI3f4JOts+buGYPf+hRzPf0HRu8ce1DGJ6/rnXf6pG1k2olV
9N8wekTeJca+XBxn8UVqzl1yptjk1XuLIH9QvTdLyn4h/vkcftLME+dKj2qO
FQ+q/YBmbttL+o6cxVPSpzTHuZ2kH67OrzeQ/d/q/Gtp2T+LH34g+8/Ve8qd
FXUH+SS5GnUL8YiafU513T47Nu2dZ+qY3TXOK9X+e6/0ms054mrSb1Tnjx/K
/k91Hjwj+AIjaJ6ps8m/uM/qFn8en3UOjD0qnDAu+0POSr3MXh6Yd8nZwCS1
/Mjo0dlnfp+YPo8X54iPFd+VYROPiF/kzXAt92zYxK8dsm5yN7ibvaLtsfSj
T+cdclI4Ew6dnu+akPE785GT8s3cZYwJV8zMPpDXk98zz/0aeEpz7LtHunfs
u6XvbY6L70tWaK6jHpB+qDkm3Sf9x+pY+oHk0eb66kHpPs0xay3px5pr95uk
X63Ocb4l+8bm3OIy6Uub74Ovl76uOUZ9U3psM8880uxz+Ntn+EJznXOx9CXN
ec8znGdzvXKh9AXNd8/nSZ/fnDOBiVE5r4fV9pfq2L49PtWcl4+THtZ8Vuwd
9z+750yOiA+/x/cH7/gPvMwec190VPU7M9M+Ku/OypnOS58dMzbP1Lmn5jfa
r5W+q9mXvie9R3Msvln6l9X5FL+vmj7MOzfvHpV17Jh552buWWkfkz7zsk44
HD/fL/6+e+wBwQLxbhPNs2lzTXWm2m6pjq0/rz4nzuhu2XdW8/kEzqG6zlvY
fGac14H4TzXXviX9/XDLr9V+ejiku+wtm9dwidq2aI5lf5X+qLoWPFb6uup4
8arajwkP3CH7zuYc8HzJ4Ob4Pl/2d6vtgWr7RjUObpVeublGvYi9aI5xq0j3
aK5RH1D7pGaevZ225txzgeTl6hr3Dc6nOXceIz26OX//p/TC6rphhOxdmrn8
RbWt1MwlT8h+vLrmOEX68GDnWunzqmvZt2SfVV3v8je9xZvr2n+r7enqu4Hb
1HYLRKHn96SXa651X5N+tzpHfx1sVd9TLCb7p835Yn/pj7O3U2VPbq7DrqZP
tW/Cwcs08/Av2L/mPP419rY5R4cvyKfJsSfHhk+oJbjn5e6KPOuQcB329PgY
d7zUd5un76FpXy82/eG8SeE9crlpGZO9pj6kjdhL3tk9PIlNHkHuMDY+w3sH
5t1eaSe/eClzkIfCBfD5E+l/UNY2IGtmXb+RrNGcVwzONxDP2bvJ+fZDmjkU
/jwRH6/OkY6Xvj7rfAIOq64Xvia9dnPeO036T9Ux9Gjpa6p54Gr9c2tzrTQb
XmyucTt/G+MemtyY+EobecKkfB95EPeqrJncZ//YxH7q/2fTh3byI8agnbjc
OVfq9Tn5bWhs4jVzg61rmvH1YTUG8P/jpb/aXN8QH/B1/BxMfFKNi91kP9ec
J97MeTbnjfjytvHnzYhF1Xn1ruCg+q6RvGaJ5tjNexvnXThgfrA/B/w11//H
SB/dXIeRv8BB8A94GtmMKTAB74CLE6qxBI7INVZszjduAn/N9wWcFXkP5/Ud
9q/5Xu7UauyBu77NcZGYeJb0mc115wvS5zTz6mnSpzbXiy82fzPfi1+cVO0b
/WQ/Un1H9lJzngQ2X5Ze0FzvrSd9Ws3fi6W3bq7H2ZuW/YEPBmRtX4eTmu8s
4ODLq3l4iOyXqu9r4cgLqnmS/Av+hXvJ+5Zqzqng7IurefsE2Sc235Uc2ezf
rH8o39pcm7KuS6vXRmx5Iftwo+xnmuvn8fB09V0YuLkr2NmmGQ9ggfyFnAbc
/aSav+CumdKHNd8lnVvNofDnPtITm++tzqjmcTh8v2asgtMZsqc31/dPSj/V
XNtztuvnfL8iPbf5ruiG5r3mW66Q/Xz1XcmVzWfJOZKP/7Y6JycGkmcTBzmr
dZvP63Lpq5rvXA6SPrj5nmsHzrC5xiLevl0dc/dU2+3Vd3PElm7N8eXZ6vhx
suxPq3Nl/BYeuj/feJTa5jXfQ8Ax5BzwDDH2zXDmPdLvhHtP1u9PVt9dXVYd
b8AmiSrxnljfS7pn8//vgCN/F575H4VZlB0=
                    "]], PolygonBox[CompressedData["
1:eJwtl3nUjlUUxe+9iPhEskwpqwklWWFZlcqSJitSKs3GzKGUKWQqczIPZYUQ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                    "]]}]}, {}, {}, {}, {}}, 
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwl1Xe8jXUcwPHjVgjJKESSjCZJJaWSKFu52qSiNFEoM2RlVJStrCLXSO41
rnuzZaZU5Noke8+M5vv78sfb5/v7Peee85zzPOco2ax1cqtsiUSih3+eSEok
qvEtM9hq70mdrg9rKmlss34qHqfVdSZjzbP0Goqy3TpLO2ox7aLPaWOejb+x
/oOz5l16re7WI7pHr9PidDVv1n2aTgnzfj2qB3RuMB/U2ZrOHK4ng5doxot8
5zHN9YSW0QW6hMV8TSd7teKc6cAKJtpfrjVpz3ssY4L9Xmw1n9Vb9GZ6m2/U
m/jTfFzPaFk9pef0tC6irfld2tHTurR21y16XEvpDSzimPXCOGceZb71a3pE
C2qB2OOodabOi/dLyaSL17a1vk0rFlov1e9Zwknrr/iAd6zbUJs6nLd3Qs/F
cV2q3eNvtYde0JP6ly6jrrkek8x9uNXcV7drNlaa6+sPTDav0Qok8SOX8BOr
HLtDB+qYOKaj45iO1UFaUe/kUnbQz94U1po/4mMa8Amr7e/U/lpe/9ZT+o9e
pSn6kN5GOf613qYf6u06QAfpp3FODOazeB37Q3UYQxjB8Hht+7/rZfFezXdp
dkaxxnqkfsHn/EyleE77u2OtV2uuuHe4nMr8Yn8965hGIXt54z7jCu5jpP2D
ukG/1GTGM47f+Mb+CA6Y81OVBxkdzxnHmcJm66lxjjpZN+kk3agpcd7xndGs
uHd0Ynwn4v1ZPxCfge7XfNxPFdaxnl/jvdAwzsnjrtR98Rma79WhulfzxGPN
uXVPfL7me+Jzj98Ozclacw7dFdfGfHdc7zh3Hjc/xor4gdPT/GceoMu1b9wP
cd/E/UGfuN70pDe94j6kK93ozPt0ifuYt2jJ67zJGyymBa/yMvO8zit6SI/p
YX1Ea/ACTeO541qRQRPrTH1e58TnwKZ4XR0fv7Ecsp6taXGPsdG6k45jB4et
d+oMnjan6jNx/lpYi7DFvEE7xPeL6eZGSRf/D/gfXNbhPw==
                    "]]}}], {}}, {
                  InsetBox["\<\"\[Mu] = \"\>", {-1.8, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["0.2`", {-1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {InsetBox[
                   SubscriptBox["C", "J"], {1.4, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["\<\"=\"\>", {1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["3.42`", {1.7, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {
                  {PointSize[0.05], PointBox[{-0.2, 0}]}, 
                  {PointSize[0.0125], PointBox[{0.8, 0}]}}, 
                 {PointSize[0.007], PointBox[{0.4463998339305619, 0}], 
                  PointBox[{1.2771956561278897`, 0}], 
                  PointBox[{-1.0806611991222994`, 0}], 
                  PointBox[
                   NCache[{0.3, Rational[1, 2] 3^Rational[1, 2]}, {0.3, 
                    0.8660254037844386}]], 
                  PointBox[
                   NCache[{0.3, Rational[-1, 2] 3^Rational[1, 2]}, {
                    0.3, -0.8660254037844386}]]}},
                AspectRatio->1,
                Axes->{False, False},
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                Frame->{{True, True}, {True, True}},
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLines->{None, None},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None, "TransparentPolygonMesh" -> 
                  True, "AxesInFront" -> True},
                PlotRange->{{-2, 2}, {-2, 2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.02], 
                   Scaled[0.02]}, {
                   Scaled[0.02], 
                   Scaled[0.02]}},
                Ticks->{Automatic, Automatic}], 160->
               GraphicsBox[{{GraphicsComplexBox[CompressedData["
1:eJx1WXtUlFX3xktm5nyoEdp0UVyWk2n6M8eUn7ktzNRURjMxK7yU3abSCLVB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                   "], {{
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[0.3], EdgeForm[None], 
                    GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxNmnf811X1x++9Dlw4iGmCDBFlmIKEaSqCsocoIG5EUUFAS9xKjhy5skSz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                    "]], PolygonBox[CompressedData["
1:eJwtlnnwj1UYxe+9UWQfpUVlSBqjxTAqjTItpm2aStomS5ayJD9LIRKSNSqK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                    "]]}]}, {}, {}, {}, {}}, 
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwl1Xl8z3UcwPHfhpKSUlJRUSKdSiHd0aWDhqTbOlWuUYsKHSpT69IhlmM2
OcqUY+2q5dg6HENa5Gbu0F0qnu+HP55e7893P9/7tzVO7ZPSOymRSAzzzw3J
icRFfMRkltrWQSdoK53CVJZZ36jZ2lqn8Y75Y63DUSy3XqJ99GhN0446SW+J
Y+iP7DFXal1dqVW6SidzjHmALtPVWk+PZY15i66NYzLDvE4/0Tymcxyfchvd
6Ep3budztvj8ifqZ5jOHLPradlmcN735kjG2f6GX0ovHKWK07TV1lxbrTi3R
kxlkbqgnscO8TbdrA92qe3Wbzqan+TEeZaD1CZqu32uVHq/1yWdznKvO5pK4
Rut7dZPO0pm05R7ujutjlJ89yXLzxrhfPGR+mAfj/1h/wFM8Yj1LL9cr2G3e
rj9rety72JcWxOd1j+7QvVrIlearuJqnrU/RZ3SF/hX3kb/5wfpZbaIv6sh4
h3ibr6zfTT74Tr6vc/U9naej9CU9XZvyj7lSB+tYFpif43na8UI8w3jXdIg2
1l90p/6qh+mHeqE24jfzfP1dT9NTGWoeFseNc+UVXo7j2J6hIxjOa7wax7Z9
pe7TUpqZ/9UyfZ03yOQt3qSc5rEPn1mtC7SWJuK+s9/6LD2br83lHGE+nOrx
jKjGubF/P9uo3+lovY5v4/nqIhYy3jqTDeZDackFce9ty9FcslliPTHOUyfo
Yh0X+9Hxce5xz2OfOibuI1lxfdbnx/3Q9XoILTgvziXOjW/iWrg2Zp+roevi
/pnPiXuqazWZMnOSriHDfGY8A/1J/4/nxX+siueiZ8Rzj3PlGnN7Ssx/ssv8
hw7VYh2sRTok3q941+J9jXeTgfEOMyjeSQbwBP3oTxql3M8D3EcqPSigkLvI
s/87dLreqet1q27Qi7UNXegc+493Pn6X0ck6hVuZFtfL0jh2fB+YwibrqZob
3ykqrPvG9yd+f7DZekU8R24y5+jNcQ1aW4+kwrxY4w/BSCaZr08++PfgAEUH
3vk=
                    "]]}}], {}}, {
                  InsetBox["\<\"\[Mu] = \"\>", {-1.8, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["0.2`", {-1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {InsetBox[
                   SubscriptBox["C", "J"], {1.4, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["\<\"=\"\>", {1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["3.41`", {1.7, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {
                  {PointSize[0.05], PointBox[{-0.2, 0}]}, 
                  {PointSize[0.0125], PointBox[{0.8, 0}]}}, 
                 {PointSize[0.007], PointBox[{0.4463998339305619, 0}], 
                  PointBox[{1.2771956561278897`, 0}], 
                  PointBox[{-1.0806611991222994`, 0}], 
                  PointBox[
                   NCache[{0.3, Rational[1, 2] 3^Rational[1, 2]}, {0.3, 
                    0.8660254037844386}]], 
                  PointBox[
                   NCache[{0.3, Rational[-1, 2] 3^Rational[1, 2]}, {
                    0.3, -0.8660254037844386}]]}},
                AspectRatio->1,
                Axes->{False, False},
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                Frame->{{True, True}, {True, True}},
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLines->{None, None},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None, "TransparentPolygonMesh" -> 
                  True, "AxesInFront" -> True},
                PlotRange->{{-2, 2}, {-2, 2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.02], 
                   Scaled[0.02]}, {
                   Scaled[0.02], 
                   Scaled[0.02]}},
                Ticks->{Automatic, Automatic}], 161->
               GraphicsBox[{{GraphicsComplexBox[CompressedData["
1:eJyFWnlY1NX6x42KoJWKxiXFpXELQseFzDfDXEhrNK94TcfdVNwyDQdxSW00
Uisb00tkd0xNyxgzFZfJV3MJXBGRUVSUYQYBQeULQ1x/5lzuHD+H5zk+Pj//
8Dyf7znnPe/+vucMLcbOGDyhfkBAQEntf/8b2wdnlLgNOZydvm5wiMfLNfuC
Vlq0fRI7BCbgJmK9xIvHTd5vsF7nhNF/LXJYND65s02Y1XlNYtAHBn1g0AcG
feAjgp7EieI8ibs9s83kNN6UI/gBBj/A4AcY/ACDH2DwAwx+gMEPcKQYJQaf
Kl/A6gh+gcEvMPgFBr/A4BcY/AKDX2Dw+zA7qnpU+cT5wDgfGOcD43xgnA/8
kTifHuZHqh1B/2F+ptpZ9TvV7qofqn6A8x7mp6qfqHbAOSodYHWEvoChL2Do
62Fxovqp6geqXaBHYOgNGPwDg3+VT2B1BP8PixvVL1U/AX/A4A8Y/AGDP1Vv
Kh/A6gh+VL8EBj/A4AcY/ACDH9VuwOBHpX9a5FtJHxj0gUEf2OWfz+NW/u9V
nC0wAV/x41I+7ufjtoxrzL/kH91y/XmxnrAeI+gcE5hU/LKgI+mCL3zHqH4v
8ePjEgf4/x1wqPSwDueCDuwHjHmshz4wD3mBIS8w5AGGnVQ9g0/gE+I8qRdg
1S6YB1ZH8AcMPeA7zgWW9fr+esgDDHkepgfoCRj+B4z9wNCHOq/6DbDqJ/iu
6rm50JPkExjnqPPoTxBf0DPoqnVM9UN8R/zhO+QHhryqP2If5AOGPSAX+FXz
LuaRh1T/Ah/AyAPAOAfnq36g9gmqP6l5HPPgBxjyA0NvsAvkUv1BrT+wH85V
7Yl8lug/z8UYI5+MbmWKKWGLn56TT/rXeQg4NeiLAXp7BeF7Rz//+fTXmMhm
5hAvvS4w/5/AjHlg7M8R+xkj9iWIc+R54Aff1RF8AIMezoVcs8Qo+QO/iEc1
78Hf1bwDjHk17wBjHvZHnAKjr4A+IOfD1gG/s3vULqOpUtoL58EfgGF30MM8
6AE/v/9/63/irSH1ltkc1Rzq/36EgKFP9Vxg0Iff/1vII+0GfWMf/CDLvy9L
4ihxrjwP8Ql5ID8w/PyQoCPtqhfnSv/J/z3pT5/v1gP+C4zzoQfg9f5zfpL6
g93RXwEnT7zkTbOVyf3A2A960Csw+IYe4Z/4Dv+FPPDvxYK+xJAPGPIBQy+g
j3nQhV7VvgJ5CPaIFXzKeAJGvCC/ACO/QE+YB8Y89LZJ+BtBb8CwN/YDYz/0
ivXI4/Bf0ANGXgeW/brin2r9gL8gruCf0CvmgdU8jXnYT+a3+/lf9UfIAQy+
gdV7DvI6zof9Zdzfx1iP/Ac+kb9UPhDXiAPENeIc9RAj4gO4SPinjAvQgf6Q
j4ARD/BbyA2/hD1hL9CD/KAHDHqIJ9CDXkAPegM92B1yIl4gF/oqyAsMeWFn
rIedoQfELfSL+IN+Eaegq47yPnX/HNCDPREvsCfs/f/1mainiG/Ijzyg2hny
QG7Qe1jdgV4xD73iHLWPVfUMuTEPuVX/Qh7CPmCsQ73BeuQVrAfGeuQZnA++
pB3v2wHyQb+QD/YEPYzwT8Qn9Ih9al8KvtW8gHm17iBPYB71BfOQH3kBdkA8
gB+1PwGGv0AOYNCBXtS4UO2FPIx9iH/MQw7MQ1/IGyodGcf38wT2qfc+0AWG
fiA//AzzwLAz5IC9sE4d1bqBeICcKn/y/em+nOBH7bvhhzgHfAFjPfZjPeiD
b8zP6b9pr8F6Qfa/o0fXjHMaL8l+9uqgK0d1sSUPvGuO7Z4yRgusux9+/D43
NQ/08sT66xOckbdlHJ6ul3lWl1z3fvvUX6+9rZ+hyTy4oHG/fvrGVZLuB+H3
zuliCyQO++3mSE2X/sC70c2LgVpm++vcfEW/97WUYlm/ER8/jpg8WUupez8N
DvTEhXiy5Xr4Ac5X3xtf8Z/rJPCDefCjvj9OH7psnyH0grTHD12mr7FE5cr8
sWrMBrtxfa7Mu/dW9z2uO55L0I96nysJdh8zhBbI/D7P91FcSOtCmR+i4p4+
q9NcBH2q7/ptNweP1FKuE+yhvqtnXPm6jXngbYJ9wRfW7Xw0442YvXX3/KxX
Ho8wtayU/oJ+DP4i75f3+diT9sGz1mWVkv9QbcAJXZe6fm145xcbm09Vy/qc
vneUScurlvqc8ZgnwD6mmqbaR/fRR5znDdcOtDW1rOb47oMWOAKPsLHTarNj
dzVvzJ77qunwWYq0bAuwf1LNfUM+CjMPLOZhhqQIU6HG3eK3Jtim3pJj+Kuj
t8Yv1ziv4WvB1rXXOdC24qpvlEYjXD3vpRVc526zv9prvHdNjivqF31liSrm
nrGHvrHMOs930rKdPi6itnO8243559lx+VVvWr1yeibB4TDk5PLSw8vL3c9p
5F64uGvMf86zMcP8ovWFa2ToNL3MvSub3v7reGr8lr001NFsnzHtGiU9fma3
cZXGM0P2vRvy6XWaEtTvOWuCRpPSg9zuOddpXcTLwfZ616ibd91JXaKXptcU
mR2WzXygfYrTd7Watz0yoYPphyPU5JchduPxau6+p80hwxA363aHLXC0qeLI
oPqHdEFlPGtEeJRpXAWHZf/wua1J3TvLzg5/33B7XZQ375di9/kqDjx6KNmW
6qZ1xb2jYybX1o+Ei0m2pDJ649knvrSlVtT9niH8h18fb5ln61Eu82/D9vNf
sHatYOOP6Z9bdtzg7v/aTzGDKujIks6X3Z4bMo+8KvyThzv7/GZcVcW7rzf6
zTDkMi/Ou7TWkl3Fkz/Zn+NbeIFr5u9vb2rg4aXrK54yr7zMz2SudeiST3Nq
hvuK791C3pnomOA0/sSLek/9yPmlS+aZHiJ+uUuPpE9sl0t46a7e+3WxZ3hb
r+RpDsspem9B7Hxbj8vS74O/9scjv7Jz0CxnZKXM29+ktmtkXXuDl3e928Bu
s0q8rosf07qk41uMC0p556HH7qa1yCTwP1zwT5Bvs5CPWh2+s8CxuZKbJXYM
tb5QG8/35Zst5CPIM1fIQ52f7N4rxpwl+/3Ll079ndbiAqemtg03n3IR9GEV
+qBK71e+tBZ/sitvcqC9V6HMN0UiX9KzO2IiTA0qZb2AvfoJexH8ZbrwF3p8
3027IfSm7G/gX88L/6IW+vf+ymzv5iYpK2c6I6sI/pQr/InmUuenrHEeeZ+D
/+4T/kvNNyx4S2/fRJOmv252FFUT/DlM+LO0w84Y4zeWHXX3JJPIHzLf7xf5
Q9bT3LEzl9vKvLJ/Xf1088WO/Iq632FEfmLwh3ho+fuoR6xxpTKPon5OCu+b
bozVpJ/TysrPLDvKZF7dI/IlQ19Y98X2oNW2pNsy70KP/z7V61fDkHIZh7OP
LxsR8lbdO+oPG3M2GPOvyLq2ROR/KX+0yP/yXeKq9tJRQ6iLYV/QkXVO1CeG
P0GvzmDPVmP+RZmn5Tv2+wNX2BzneNoTTcdrKYUP3G/3/LrroMFaW2+b/uMP
XewNyRf0vd1TvcI24rCch52kPcQ84Xz1fTVbnE84X+3bfhLnS7tNFfqj1v68
7HngPfZroU/5HuEU+iLEu/Sbo1c+0BIrHvidpquwN8GesDvsuU7Yk5AP1d9x
Vgn/I/gX4hLnjBf+Jeu/SfRXhHyN+IHdtot4qNOX8HdKaRRX4p7jpnCfp9i9
K4cDdvR+xnzqEt0MXTVeG36OkM97iHxOzSPvJdh6XOXZJUs3xvfzsremQbQ+
4jIPmDT8untNbT84ZVI70+HzNP7MwQ3x/ap57GcTZjmO5dErDd+86LvlZdSn
HqI+8eWypQNDjhaTvnWjWP1LlRxqPuHKPHGLmoiRUd9mivrGY9usPO3z/cwR
y558zrrWxaiPJlEfOT9idZYuupI2vjci3djTxYs+TMvStaukJ0r/Gau/5eJ1
9RanWAZXUkNP+HHfwnyu/3abuJBBldRswjFPZuN81n3aepQ2JZfaiVHW47dE
PZb6uSv0wx+eHvFz/KQCyr7w/mFD6DlZ/yNE/SfMHxHzBPoY0R80Fv2BtEeo
sAehr4gUI0H+l4X8BHmq3H55CPI8IeQh6CNV6IOgj0ChD0J/ky36G0LfEylG
gj0wol8aIvolgv1aCftJ/5gp/IPgH/2Ef8j+bL3ozwj+Mlr4C8Ff2gl/oTVf
9G1hHlj5wN833G3k78/lPL7jHr95bfSGeGu1zHdTRb2Q9/aaYS2nOrdXy/yZ
XPhqR1NEFXeznXveurZCxuHUTrtamssrKGu0JdvHJbwlM36hY2Kl3If63EbU
Zw6KiRunBVVxQN9HW5s7Fsh3qynlhonaFJd8Z+gzent/fW0/gnj+87scY4gn
V+aBxKjBT1qd57m9iH+5D/1Dtugf5DzkQv8yUfQvdOe9G49aE0p4SM/PCnx0
Vr6PZjw/9D1Nd4UgD/Lk37dLFzqaVXK7jvbr7gkegj7AJ/ozh+jPZH69k/xd
B9OSKtLX/FHm/jSbc+5eHBQyqJq3hNSf4rCc4XYbuj5hTaitt4PvfGrR0nhi
cobFdrmaw6Zn7zSmHabJh74PsdbW5x45MWsssUW8uPeuoSFfVTL6heaiX5B8
3hPn8fZuw97Wj3KR7vToBvb/1Ob15VfK3Z4KPhbknOjcXsLIz7An7tHQG/rp
uaKfZsgfJeTn0l/2znBuqfv9vChm7SldaW2ffKOh2RHo5LxN8x+3j7nGBw6f
aWUeWMAb3n+km/7dK9yh0aZydyMX//PR6GxdbDb3DKqX76NCHrq7Yp7D5JX2
1Ac/fUrXxcvLR249p0s8y/lRbcdofby8wmUJMxWe4Rc2VVZlLvGysfKXTqYl
B7nzBUtT8zQvBxyY53Yb/mTjnSqHYWcRLyxu8aUl6iKjnoFfvMstNRzpH+LJ
Y/jDeOEP0m8uCH/gTiOXBZtDmJKad80wDKntL/x57Cj1+VVv0N/K5wuJsTk+
Lqbi6OTG5pW57FiXWp75cwmZjBv1psO5HLAiPcE2/had9OU3No/M5UUfF3Uy
jbtNbzbKTHQE5nLbNndamQ0VtPvsc03Nv5znmm6Hn7SurfsdbX3r9Lf0X3iZ
11YcMFh38cbHOnSL+ZeX8z5v/61FW82YXyLmCfOlyf55Kn/97j+0lBuS3sze
04Zqw2/wsOnVvfT2dAZuIjDBHtAD9B0l9E3Qt+t3v74J9por7EWw13RhL4K/
oM7CX8KFvxDyQ00ff34g6Hu20DdB312Evgn3jxhx/5BxuEfkC4I9Lgp7EOzx
rrAH4b7ZUNw36Z1vR3SI6V9Gwafi9abCXNmPTBX5hmA/h7AfwX6dhf0I99Vc
cV8l2HOLsKfsN8aKfEeIj90iPgjx0UrEh/Qb1CPERU+RHwnx00XED4UN49nO
rEM8d2X3fN9LhbTkUtYsZ7FGb9Sfd0p3x024nw8R93NC/s4Q+Vv2dxaR7wn5
ZoHIN4R88rzIJ4T7rVXcbyV/G0R9kfkuS+Q7Qr5rI/Id4f1hgHh/oMAf9dEx
5iMc64/batlf4j6D/DhW5EdabBvzqSNwOxWfvakze+p+76oS9YuQPyeI/El4
3+gg3jdoz3M/9YrpXtu/e8YMCllTLfvy2v7ggs9QzeDnHcEPuzyvHzFY/5C/
j+G+hfoJfsoEPwz6RYK+vD98JN5j5P06R7wHsY422+KLi+S7Nup6hXi/YtxX
N4r7KsM/0L/hvloq7qsMf1gk/IEHN6g/w/lU3e9zeMee7Xizr95e93vdDvHe
xqamx2Y6n3LTtpITl3wLc+S7tn7QwUZ22zlGvDQR8SLvb9+J9zn+9rekk7rk
unsmMO4v4Ad6AT8TBT+E89eL8+X71vfiPVL2NbPEeyklTrv4iSPQJX+fi/DX
sTyeWNPxV+MBL+cvrvrQEXiJctueO6Er9XLY0/UiY7qX8jefz8rWtdM4/ONh
Rw1VBZxVNvqg4UgVH3C3GhEy/zY3n7WlKPPbco6ZW3NaF17FQSuXuXz2azyp
nrbQoSvkF4fYRjjnXuUU46HizPhUGsJTP9D2FTDir5+IP7m/vthPqE8zRH0i
0HtM0CPQGyDoUaK+YIKWkk2RzpaPWeNq1xfkBdrrVVJAetIcR+BFQn0/IOo7
gf8wwT9Fv/biNMexcu7Tf+T3ltW3CfKvFvJTs4kDl1mibpLDlLAtPuO21N9Y
oT+C/rKF/uid/Ml244EiSu6fMU47Xinpxwr6PGx5fpbPXtsX9S0IN0/Q+O6M
OZ1MP9ymjcv7r4kvLmct7mCclpJHA7bO32nMP8c7/tw0VIu+wVtbFF50G36X
eJrAhPU9xHoCvVRBj3CeQZwn+Vsl+GPId1DIx9DnG0Kf0v4nhf3pv8EhsmA=

                   "], {{
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[0.3], EdgeForm[None], 
                    GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxNmXW8l1USxs85IooFCgZIoyihCAqIKKGCxCUuSAkIgoAIBiaKgR3YXago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                    "]], PolygonBox[CompressedData["
1:eJwtlnnwz0UcxnfXVSTVJB3SICUzhkozSsnoj1LNVGo6KHJWrh9ylhBy+5EI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                    "]]}]}, {}, {}, {}, {}}, 
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwl1He8jXUcwPHjFkrICCGKymhPpURUaFkllTRoG5fIzqVQumWPVPa8lwbi
2kWZ92bvjCS7QlZJeH9f94+P9/f3nHOfczzP7zllmiY3aJUjkUh080+9pETi
HqXrM+sp3ML6nMx7OVVfaat1A6axMr/WcPM3vFwFtM16GeMDCrINn4m/Z8P4
G+7QPvN2FuJO7uSuOJd+037r3SzMPdzF3zlD95uraIS5na4wd+QqHuKVLKa7
VFwltNDxBRqrNtYPqbWStUBjHJ/PGvHd1VJzNNrxPDzKuTzCeSytLuarWEp/
mX/lnyzJwzzAP+K8etvcQs3V2booO/BnHuQcFTEf4CzOVHXNtn6Z+/kdZ+hB
vaQXNV0jvdZeWeZ9zNAb5jf1uuZaj1InvWU9jw/zEf1t3s1j7Mjv2YE/xPt5
PO4HT3CRapprqba6Wl+dlL2P1vAMl+g/rbVO4XXszf4coH5abj2QH3IwV3AQ
V3IIP+L1XMqzWmfuzvH60fy+PtCj6qlljq9nD5bhSe7hKV7Gcbyb1+i0eTH/
4bUsG+cz947vo17qE98hPsPxVH6ij9VXn8ZnOr6B/7M8y6mSKqiishwfykxO
VB8Ni+dLT+hJ5Yj9rIRuinN7z1auZl7m1F5drFs00PHtXM8vWUfrzF9wiX7S
JOsB+sV8qe7UHRrq2CRO1gRtiu/FIXFNuTGeC27gOA7m6HgmNEKjYo9pkOO3
sz+38RLdpluVK/axcmut14dzDT+Pe86b49pxCy/SKnMSN8f1Nd/IVG7i+Xgu
dE4b49rzhrg3nKDHzY/F/9ncg+9xNf+N/aEU82J256LYy/Ge2KfqHPtWXWKv
61211ztqp7ZaqFf1ml5RMzVVhmariWY5/wucyb3KjHOxGqvqATXW83HOuGfx
/KqR9XN6VtPjN0Mr4/PjXurb+H20nsYpcS+13Do5rmW8Hq/pKaVb38enNdW8
gq2Zj/nj2pqXsmXsP6WZ6yZl/+ZfAD6S1+s=
                    "]]}}], {}}, {
                  InsetBox["\<\"\[Mu] = \"\>", {-1.8, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["0.2`", {-1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {InsetBox[
                   SubscriptBox["C", "J"], {1.4, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["\<\"=\"\>", {1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["3.4`", {1.7, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {
                  {PointSize[0.05], PointBox[{-0.2, 0}]}, 
                  {PointSize[0.0125], PointBox[{0.8, 0}]}}, 
                 {PointSize[0.007], PointBox[{0.4463998339305619, 0}], 
                  PointBox[{1.2771956561278897`, 0}], 
                  PointBox[{-1.0806611991222994`, 0}], 
                  PointBox[
                   NCache[{0.3, Rational[1, 2] 3^Rational[1, 2]}, {0.3, 
                    0.8660254037844386}]], 
                  PointBox[
                   NCache[{0.3, Rational[-1, 2] 3^Rational[1, 2]}, {
                    0.3, -0.8660254037844386}]]}},
                AspectRatio->1,
                Axes->{False, False},
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                Frame->{{True, True}, {True, True}},
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLines->{None, None},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None, "TransparentPolygonMesh" -> 
                  True, "AxesInFront" -> True},
                PlotRange->{{-2, 2}, {-2, 2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.02], 
                   Scaled[0.02]}, {
                   Scaled[0.02], 
                   Scaled[0.02]}},
                Ticks->{Automatic, Automatic}], 162->
               GraphicsBox[{{GraphicsComplexBox[CompressedData["
1:eJyFWnt4jNf2VlqcEFV3o0KCmqLVqkF72i7NKJWiUy3VVKdaRWrcDiUGrVR7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                   "], {{
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[0.3], EdgeForm[None], 
                    GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxFmXn818MWxmcmRLRxoygVdYukfbGUpX0hKqJISruK7IS4iJItW3bRItlJ
5FqSLF3LtS/Zt8vl2vftnnfP8339/ji/cz7zmZnPfGfO85xz5td09LTBU0tK
6c34Uy103ZxSnZBDwx4Qun/I6rDbhv459JqQLcLePOSwsPuF7huyKux9QncK
6RByXzxfGDIyZEI8j2dOxsXzxiGbMI91jZCh8a566DohB4Z9QMhTrCepnTFb
Rlu9kDFhjw3ZKmS7kDNDOoV0C9k6pLbnaejxfLNBSC2/+1uWXT+kkd+zlsa8
C6kXsr3np88lIRM9x6AYu0tIl5BtPY4xl4ZM8vcvC5kcsg3P0e9Ir+Xv/h7j
WljzzZbWTULuD7k8ZBzfi7H1Qyawlqzf2ipkWshUr/HPkKM999Uh0z33NSHH
eO7jQo4N2SHkZa+heciUkB1DWoccb90m5ATrdiF7xHe7h7TlN4Ru771+O2Rd
yM4hvaO9UchJYT8YsiDk5JDdo223rDU/FHJzyAzvSx2fzUchC0NmhmwUfU8J
3SHkk5BFIWeEDI/2zqG7hzwSckvIqexXtDcOOS3sg0MfFLI27GGcUeienEPY
k/DVkImsh/WGnBsyizWG9GFvQ/4RdtOs7/QN6edv7hHS33rPkAHWe4UMtN47
ZB/rHiH7WrOGQda9QjaL+b8PfSBnFvZsf2uIv8d39or2llnrHOo2vnmA9UCP
H+hv9oi+rbO+87X7jcBXou18zz3MfVnX/zzv8CS/xo/w89tC5rpvHZ8T/lzH
+AaHfc0H4BFugA/AMNwA1sEyuD88ZNMkngDH4A1Mg/Panquuv8Ncm/u5wgs8
wxdbeM7x5hWwBseMTsIpfACeweqoJN7aKOkbrL2B523o31PLbfX9jUZ+x3e2
9TPfaOxnsH5EEjb/ncQF4Hx8Egc1TeKCxl7PVt5PsPq5z3RwEg+AvWYhL4Zc
kYS/Cv7B7DjbfAt8t/I8Fb4A42AObIJVuAFeAMPdsvB2VNivJ+EfzIM/+tLn
ryS+gCMeCJmfxB2vJXEHfAHW2/kbYAz/B3s1s3wX/wDbcABcAGbBNHiDA+CI
jkm8caL7gPuZIbuGPBqyOImzwfFZSbhaGnJ2Eq7Aezd/A26AA8DtOUlYB2+N
jXXwBu7BPHibZJyDNfDd22PBN9ju49/EufRNVdjul6qw3T9VYXtAqsI2zxVs
81zBNs8tjT++C9f09J7snYXn8/yNIfaHCp6Hpio88wyOh3nO/n4/xN8b5n49
szA/J4lD8LP9k/AOtg8OOT2JS7smccJwz/VYyLIkXoCHRvi7hzvmg8uxYY/M
wnM7x3lw83wSxsDXQM45C+f7hu5qTF6UFJ/BwTMhFyfhZ7nfgZn9svR2fo/f
N0nyfWzi1O1JGANfYIUYiA+DXTgL/N4RMs/PYH2S3zP+WM8Htom/YP/aJMy1
9vNkjwOvU72eO0Ou9POKpFjLe7AHVpp7XrACJq9y+04eB/5a+d10j+Pc5vrs
3vQ6iLf4Hv6/Z8h7Idclxd7rrcHhDUl4q8RdbPC4MuRGn/EYx038bVzYo4zJ
m5IwXImdp/qb+DY4wq8/SPIV/OTILJzuZgF3u/u74LWj18ja4YdPQ5YkxU1+
w9mee4n7d3PbOW5nrlme++6QW/3cPL7bzLGwkfeMfd7BPj7IfcEQeAYP+C84
2jn6XOA9xm+JPcSd30JeSPI5/A8/axLye5LfVHK6eT7fse6L3/4RclcSJ05y
3wY+5/mpKnfCL/HJqT57zh1fI/+r+Bd5IT6GX5PX4ZvHeO4WPs8FPiP2e5H3
aYP4LS8l+cqGYb/lvcev4XZ8sFq0l6znE/yec4F3b0jymYftB53tG3AxPIy/
4D/kWuRv+Bz+xvkv9Blxhot97o8n5QDRdb0fwd0V/13q8+dMlvlcyKmW2AfI
K+5JwsAsn2UlB7vbbeDsTu/l1d5/8HOBx3O+m2bNw/OokHuTOOvXpHpjpPfy
Yf9ezvx+7z04fcBnyJmv8LnXyIpJrBW+WW5fYP8e9PmAj5XeM/byEe/B8T6f
1h7/qPds46x8d4b375/eQ+Jjb8fX6t5Pcp8nknKq4mds8qBn/Y52ajFsarQn
k/Kuau6HTY5Ejca7DUKeTsq7Nkzibmxyouf8jnbqLGz4/F9J8bRLEi9gE+vI
q3nX1eOed/93kmqAnb0H+CqYeCUpzwEj4AkMjnEb78h/XrVNn/l+xsZ/3/K+
rvP8bf2Ndd5napk3knDQxu30AaPgeqLHvet2Yt83SfGP3/GBfws4+DBV+fvH
SfjDr/+T5Nf46WepKnYTZ8kZ/mt7sDXPxN8vbQ+2/sLty/yOdmIwMRoO+8r2
cGueid1g8f0kTH/j30Cc/s7PlZj9teej7VvPQ4z53u9/sH1Iku/8mOQz1Ozg
ubjtJ7d/7zHMj0+R0+NXv9jewJrnkda/2iaHhDfBLhgjz9zJ+i/b5M+/+6ze
S+I1zny6+8H7xEe4D5+C1+A3+JKctpq5jvkgIubMWc/MAT43cu1XPcuG38hd
a2XtA+0bOz4Sv2rkKuxukoXX7V0P9vF81d2f/dnM88y1zX7DSbWdG9/lNbEe
uInaqbr71vTY2rbpf4i/BU+ucn84lpyL2qmWNXcuYLZXVk5WqXnQ5EJgrJ7b
6INd021b2t4/K/eq1AxoYha5VX230Qe7qdsa2H7K62AN22TVM2AZzTNxD44j
/ydf2DaL7yq8xzP3A0NCD87qN8R94EPyEXJ6uOdlz9vQbdT5Xbw3db0/7NuI
rJx+rfvRp5nb+vq39/JescecK7kKNd2uWXkB/Zv7rFtk5dNgFt3COcls92NO
cEqeDX4/dz/ad8pqB787ZuUu+yVpnufYbul24h92L8/HeOInuQ41APk/59w+
yxdoI9chDqLbZMXGNm4/KOn+jZx8M/dp7XYwS2wAv0/aBt/0pabe1GthfXyf
+pd26tn29rea9rV29kn2uJn37XDPxTzET3IvuJ+aoIvnoc7FbpJ0h8a7LZNq
+c5ZtQO58+72ydEez1hqWNqJA638XLm32s3tnOcunrOL7Saer5v7EA+ob4kb
nEcP/17aqFfJl9B7ZuVQe7qdcayxk/cW/+3u/uzbXj5T4gR2b8/d0/vfwWPr
+Ux7eT/pu7fHclY93L+RMYD/Ewt6GzuLwU7Rfv8W9uP2579CP21fpRY+Iqse
HmObeFd5hhtnxBx9iuIhfADmm5oPeKYOqtRptP8Q+mGv4dMY921W7kiNyN0u
9zRvhNzic2SNS7LW+U7o24y1F6P9vaz8a2XoY4ridP/Qz9qftw37s6x8bUpW
TUI9X6lzupqXWDPrhTO5kyJvgsf7eE9oI84R48inuKvaxP62j89xtfsV++9A
t69x/2r2wUH2Y2JmP3+T9n3tb/gCPgGPNbTd3n4yxO3kXtx9cd81Oqve5rmj
19PBPjvIczbyWOYjdpP/sV74YqJ9jHsG7jtouzd+RPeieqVr6MVF650f+uqi
3OKG0C9k5RFXhX1RFl/tGvZtRdxwY+ibivKAy+L9kqL9WRR/BhRx7+Xx5/Yi
Prmy6Pw4u/NDzy3Kn/DNc4vO4vTQM4vyrTNDn1F07zs79HlFcZj5anvOWaHP
KboDPiv02UX52Xj7GzyzINouycpVPgn9RVEuOcV7Qo2DXzIGPiPfo/6ZYb8d
63moF9ffdySNm+yxHTyWPtTT49zOnnUo2rdR7s85fBhyT1YcXIAfFeUF+O8U
j51ke6KFd9RZM92PPnvEuLuzasdBRWfDuQwsOlfO9Kl4f0lR/YSfDrCv4lfc
sZKfvxDvj82qaYaFfUdWnH+Zvc+qRZ8L+6isWurCsNdk1evPZZ0rZ/pI2M2L
apg5oVdn5cbXFvkWfjU09LKsHGRe6JuL8pzZYbcuihE4Udsifpsb7W2K4mzv
0DOy7znC/jqL855HF+W1r4U+Pav2mknfrFj/e+idi/jz1rAXZsXKhUV+jA/v
HbpHUWx5IN6vyKoh8JdPs3ymZ9i9ijj/JH5rFte9ga9m1X+Ph/1rVn74atg/
ZtWaS8O+tSiPblV0NpzLWva4qAbYpujbfPfwsO/Nqnf7ht2vKG5cHHpW1l0J
Z/uk5/ky7GpFNcQz+GNR7OL/db9k3ReQm3HucMwFYCerJv8ILGZx6VBzDrno
FsYGuCAvIpcinlPfURMyH3GE2g++Zdxo+xU1IbGE+8217kcbcQZ+HmYfHG1+
A2t8q4bXeKDnmWH87GJ9mO0JHgPuRhqrjD3U62AsmBtlvPQ0D8KBn4deCVll
recgr3+EfyM5ds14X6vo7mBqtF2axWkvxp9lRbXQXfhUUa08HSxkxetbom2f
orr81WjbvCheTAv7iqzcmJjKvrE3b4XeoojPrwl7k6L6gLsJ7rjJk9l31tfd
bSO8TvRwt38V+qEs/zw59FZFufeWoT/Ium8aEfb7WfdN6PuK7A1Dry2qf0qR
P+FL/NN3SlG91TJ0l6J7p/Vxvsj/78vyV3wVX9uhyN+Iz/gWfoXPtijyW3il
QRG3dAq9ddF9F3x5QRZnHp+VB5ADXB9256Ia7c4snoKjngZHRfc908Bu0b3A
o6FPKKqNJ4WeWFQXfpOVl9yYtDcnZO0POLioCAvNQm9fdC9zWOhRRXcW8NN5
WRzF3Cd6/vX1n8+icbSdklVvHhH2uKL7i7FF58G3TsL/i+4B6xf9fn77oiye
hWObhv4u6/fCSV9m8dKaIp6FY1fxrSJ+mx76way7FvK7P7NyPDjv/CzeWx32
E0W166GhVxT9fwmuvTCLb9uH3a7o7v+xaPs5q96Cg+dk8fDyLK5kPeR3Nbyf
G4euXnQff0DoA4vudM7K4iD8oW7oOkV3cHDwK+ZhYsKbWXHhY9ZSdGdKLHo3
66zB0OtZOMKX7y/yZ/LH17JySHykqf2EHOGlrDzh6NBDimL4E1kxjPi1Kou7
4e3lRTGVeDo89MFF9xAdi2IVcQqs35yF97vgrqL7QfLZdVk5LTns7kV57ITQ
44vuPK4Fm0X3FGC0p+MIeNrRmIJjyJ/gmZ+y4hmxDM64s4g3Lg77mqI7nOvC
nlx0z0V8+CMrRswD00V3UvhjoyKf7BZ6ftb/W+Cbt7M4B666KYuvbs/KCcgH
4LOl5rTTsuLZAri2yIfwH+JMLoo1J2blDeCa2LvK/nl86OOK7nL+D+Dzev0=

                    "]], PolygonBox[CompressedData["
1:eJwtlnnwSFUcxe+7yJLIVCZpISQyLWo0FU01lWZqlLaxFaFIZJdKdmWXbNmy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                    "]]}]}, {}, {}, {}, {}}, 
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwl1He8jXUcwPHjkpCsUKiMUEZKyGgo7VIJhXZGpYErXKskN1TiXluU7HGN
a5XIureUPRMZcc2slgbN9/flj899f3+/c87znPOc59zyrTs27ZArkUj09adx
UiJRT9M0wno6Z+hBTbKuz5nK0FbrWXxID6uBZmuk/TksrG3mudzOoiyiZHOz
OAebcjq/1XHzDhbjTuZwF2doj05Y7+Yl3MuD3MfZutl8i8aYX1MJc3du5yGW
4mWqo9Iqo8/sL9ZHetn6dr2k9lqmD+1/ztv0ol6I12ic/fw8wSU8zqUsq17m
K3ilfjAf4jFeziM8yaP8VG3Nz6udelpfyhRu40EuUElzTjyfn6ih5ls/wQNc
xIW6VY+rlRboA49101bzfs5Ta/MiPhev4Vj1UJs4NhvxDp0yH+ZJduYSJnNp
XFue5hH+GNdHd5rv0t3qbV2Ob3AHf+dK/RHfsXUfVubbHMT39Z6+sB7M/kzj
lxzC1UznAF7NVfxTO81v8mNlxXWPc+seva4s+7uSzt/TFfgzj/IXFuB43sjy
+tW8imdYkVfpLXOfOEd8lljHsdTPfmq8/5jjfcV7Vqr973iWVXiN6qqqqulr
+0P5FSdooIZZD9e9uk//2DvGv1mDg7iPa3kRc8U9pYSu1xD7+7mRo3m/NphH
cU2cUxOtCzJvHEcXaJ1qa5jHJnOKJmhSPF9D47pyc/w2uInjmc5x8bvQGI2N
+0xp9mtxML9nHt2gmkqK+0m5td7jI+L8HBnfPa+L7597+R/X6N/4vVu/y2v5
DnfzL2bHtYvHYj+up6rH/RP3jLJ1znNWcwUrxf3Ab/gbl8c9b17Gnvwp7k+m
qLu6qJu6xuvVUZ30ijroVS3XM3pWT+ppPaXFOux4LZnJFpwb10Rb4pjMxws1
x7w5zsfinK9H9Ziaa1bcT9pk7hzfr2bqgHUGp8Rn0oZ4j/GdK9M8T0002fom
PqKp5o3xOXgxC2mLeX18Jg7XVPMDSef///8PLw7bMg==
                    "]]}}], {}}, {
                  InsetBox["\<\"\[Mu] = \"\>", {-1.8, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["0.2`", {-1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {InsetBox[
                   SubscriptBox["C", "J"], {1.4, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["\<\"=\"\>", {1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["3.3899999999999997`", {1.7, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {
                  {PointSize[0.05], PointBox[{-0.2, 0}]}, 
                  {PointSize[0.0125], PointBox[{0.8, 0}]}}, 
                 {PointSize[0.007], PointBox[{0.4463998339305619, 0}], 
                  PointBox[{1.2771956561278897`, 0}], 
                  PointBox[{-1.0806611991222994`, 0}], 
                  PointBox[
                   NCache[{0.3, Rational[1, 2] 3^Rational[1, 2]}, {0.3, 
                    0.8660254037844386}]], 
                  PointBox[
                   NCache[{0.3, Rational[-1, 2] 3^Rational[1, 2]}, {
                    0.3, -0.8660254037844386}]]}},
                AspectRatio->1,
                Axes->{False, False},
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                Frame->{{True, True}, {True, True}},
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLines->{None, None},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None, "TransparentPolygonMesh" -> 
                  True, "AxesInFront" -> True},
                PlotRange->{{-2, 2}, {-2, 2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.02], 
                   Scaled[0.02]}, {
                   Scaled[0.02], 
                   Scaled[0.02]}},
                Ticks->{Automatic, Automatic}], 163->
               GraphicsBox[{{GraphicsComplexBox[CompressedData["
1:eJyFWntUlNXaRzK85Hgrs8jUzAuimcfjdDqF36NClmQ4EWdpZpPWSc0xr6Si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                   "], {{
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[0.3], EdgeForm[None], 
                    GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxNmXf811UVxu+9ipgLFFE0FBBBCgdKuBJBAQFFMFQQMBDEmWnuNHOmmHvv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                    "]], PolygonBox[CompressedData["
1:eJwtlncUz1UYxu+9pRBKQ0kpp+ToSJJD8xzJSUPCaZeMZFRWkS2bVEpWOFmR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                    "]]}]}, {}, {}, {}, {}}, 
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwl1He8TnUcwPHHTaFSMtIQSUo0kJKGBjLSIitKWWV1rbKKi7Ips0TI3nuX
mb2zN9kjilDK6P19+eNz39/f797nOc85zzk3Z43kcp+kSiQS7fwomZRIPKlh
6mE9nKVUWoU0QiM1WqNURq/pKY1RT68Zyxu02jyOa3gjU6uu+U0O5hscwvU6
aF7Hm7iBe7iRQ7VZh6w3MQ23cC+3coQKm59RL3N9pTM3ivflbqbnrcqr23S7
ptqfov6qY/28aquWZquf/Vl8TjVVQ9PV1/5V/aYZ1gc4k5nU1JyRT+hxPab9
9u5gBu01H+Y+TlZ184f6QE2sb2Ey13FXXDvdbN7JafGZ9azGWlfijjgHTlYR
VVQFTVJvv4svda15O8foPfNEVuME9lFjvR+v4QssqkPmfTzIhpzGBnH+8Z48
zP08EueuF80v6WU1s87Mz7iRpzhXv+tX6+a8l1+wIzvpK8237sw27MoF7MKF
7Ma2zMZ5PK1N5hb8Tj+bP41j6pU4hn6K+4YteSez6pg5PwuooL61zscs8fc6
bj2PJ3g371Irc8swjqfP1Tqy3yY+V5yL2iklfm9/C88wO+/To8qh+7XYfncu
4gClqEc8Nyqm4jpn7wDPMhe/5A7+wmu6GPef9QXmjmvIXVzB3iyh5eZe8Rot
0ffxgPM/LuW/XMZH1M08hEM1SIP1g7raH8iVcZ3jPTRAXeK5ieunPvGsxHOh
zvbzsCN38hIf5kP623yE/8Rx9bV5Kb+J758PsgO38zyX6C9ts27PB5Ku/3/a
yj/jO1f7uDbxuriuyhn3TdwzcT/pD3+ziHN4T9wj3MCTnK2m5llsxqNswhlM
ZmM10lzVU319pLr6ON5T76qqKmu811XhHr7D0SzPUXEOWmNuyCu6rJFaba8B
03Ki3lY5vaXh8bxoVRw/rpN+1G7rYRwUz7ZWxOeK66nx5gkqq4HWT/P1+C7N
K+NzMxWTtMq8nHXifoz3Nr+adP3////wR9cl
                    "]]}}], {}}, {
                  InsetBox["\<\"\[Mu] = \"\>", {-1.8, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["0.2`", {-1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {InsetBox[
                   SubscriptBox["C", "J"], {1.4, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["\<\"=\"\>", {1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["3.38`", {1.7, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {
                  {PointSize[0.05], PointBox[{-0.2, 0}]}, 
                  {PointSize[0.0125], PointBox[{0.8, 0}]}}, 
                 {PointSize[0.007], PointBox[{0.4463998339305619, 0}], 
                  PointBox[{1.2771956561278897`, 0}], 
                  PointBox[{-1.0806611991222994`, 0}], 
                  PointBox[
                   NCache[{0.3, Rational[1, 2] 3^Rational[1, 2]}, {0.3, 
                    0.8660254037844386}]], 
                  PointBox[
                   NCache[{0.3, Rational[-1, 2] 3^Rational[1, 2]}, {
                    0.3, -0.8660254037844386}]]}},
                AspectRatio->1,
                Axes->{False, False},
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                Frame->{{True, True}, {True, True}},
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLines->{None, None},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None, "TransparentPolygonMesh" -> 
                  True, "AxesInFront" -> True},
                PlotRange->{{-2, 2}, {-2, 2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.02], 
                   Scaled[0.02]}, {
                   Scaled[0.02], 
                   Scaled[0.02]}},
                Ticks->{Automatic, Automatic}], 164->
               GraphicsBox[{{GraphicsComplexBox[CompressedData["
1:eJyFWnt4zFf6j7i00gZr3TruWWxcVkJNi+LdmjRVdRmW1apOSkW1oaxSjY1L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                   "], {{
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[0.3], EdgeForm[None], 
                    GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxNmXnA11MWxu+9ocVSUpR2aVGpNy0ipdCmRdoU2bIlIrJmqWzZJVtkyRJq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                    "]], PolygonBox[CompressedData["
1:eJwtlnmwj1Ucxs85liSk7ozJ1BSpGWVkpltNkWmaRtqVynLJVoQM2ZmWW9ZL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                    "]]}]}, {}, {}, {}, {}}, 
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwl1Xe8jXUcwPHjIkSJlFlSFFoiMipEKaOhkLJSIXvPbGVfO8ouZK/SLSOb
ZO+tZRcVGlTy/r788b6f7+931nPOc55z8zVsVb1lqkQi8b4/pZISiQKMoKf1
SC1NGe5lFL3sj9bHeYL7GENv+x/on/o1Y80r9W/+oi7l7Q3Tcjpc13DYvFov
s5a91ut0BBs5Yr1Br/AN+6w3xWtRyFyYfub6/MubcT972/V/rpLHOkEqPrH+
mJrmGjzMK7zMXOYxh9k8RHVeYgYDPO439vCp9Sxmkpa37aXRfNxFXnbbS61J
7DQf1V06kWnm6XE8bLP+L44r6fp5mKoPMsH8nG7VKTqZBxhv/axu0Uk6kfup
xDPxON5zW8P4DM2b9SNeME/R5+O5tD9v8aL1VC2ij7DPvF/3xnnTaVonjlfr
6X49oAfic6CouRiP0sj6Bm2i3+pRncMxNlu/ozdpfOlaaxtasci6bczaXhdr
O/1MO2hr7aSfa0ftQud4vPXNsc+SuD8pfMHvbpvLFnNTTa8ZOGS+W+8hPwOt
79B0cRzx2izksP2MeiPNzI20cZzr+J5YN9Hm2jRuj/fGfOvm2kK36nd6i2bm
TrKQNY7Pftc4Zh0U751u1u9SnBL8ZO+g/qi3aUfdqV/qBU5xyPqkZo/PRHfr
cu2lj7HM3FN/jutSB+tFzrHS+hddpbnpbk7WYXE/hjIkjsn+QB0U38+4DuhP
N/v94rtGb/rSh672c8X50V16VnNqDk7Hd0HP6FK6m7/SHtpJb9cOukNPaArH
2W7dXrNpO92mP+hCWpgXaEtdEe+fW+N5WRqfF9+7fZnO1kxxHnWTHtFZ8bth
nhnXgx6Ma0dnxO+KvkGDeA1e43VqUZtX45xTlWpUZpLHVdEd+rR+qBV1XFwT
bIjn1F85z1jWx2voP3GtmsdTgTHWT+nouA/rzPW0LyPjt8h6lA6N88iaOD7t
w7h4bZ6M82hdUMuSbF6rdfQSf7CC1fH+4lww3Fwy6fr/hGtFYtVm
                    "]]}}], {}}, {
                  InsetBox["\<\"\[Mu] = \"\>", {-1.8, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["0.2`", {-1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {InsetBox[
                   SubscriptBox["C", "J"], {1.4, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["\<\"=\"\>", {1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["3.37`", {1.7, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {
                  {PointSize[0.05], PointBox[{-0.2, 0}]}, 
                  {PointSize[0.0125], PointBox[{0.8, 0}]}}, 
                 {PointSize[0.007], PointBox[{0.4463998339305619, 0}], 
                  PointBox[{1.2771956561278897`, 0}], 
                  PointBox[{-1.0806611991222994`, 0}], 
                  PointBox[
                   NCache[{0.3, Rational[1, 2] 3^Rational[1, 2]}, {0.3, 
                    0.8660254037844386}]], 
                  PointBox[
                   NCache[{0.3, Rational[-1, 2] 3^Rational[1, 2]}, {
                    0.3, -0.8660254037844386}]]}},
                AspectRatio->1,
                Axes->{False, False},
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                Frame->{{True, True}, {True, True}},
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLines->{None, None},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None, "TransparentPolygonMesh" -> 
                  True, "AxesInFront" -> True},
                PlotRange->{{-2, 2}, {-2, 2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.02], 
                   Scaled[0.02]}, {
                   Scaled[0.02], 
                   Scaled[0.02]}},
                Ticks->{Automatic, Automatic}], 165->
               GraphicsBox[{{GraphicsComplexBox[CompressedData["
1:eJyFWmtYlNUWJlNTkvJW6mCK9yk1zeNQmrnRMSvKRNMsO03iUQ85mpmVjZrX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                   "], {{
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[0.3], EdgeForm[None], 
                    GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxNmXm8l9MWxvfeGSoVKTIUlaJZkyRKqYQmlUqFlCKRqQwZT5Ihc8isiEum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                    "]], PolygonBox[CompressedData["
1:eJwtlgnUl0MYxWemEkWrjmQrSVkOEYcOWeOQPRLa0yKlpHRKC+3aJe37vu8l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                    "]]}]}, {}, {}, {}, {}}, 
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwl1Xecz3UcwPGfU5EGGqSJkqa0S6nsZKY0cVzHHdJZGWVT1tl7zzoSbWVm
ZJ19skIoNM0GKfR8P/zx9Hp/Pl+P+06nWEpGnTdyJRKJPv7ol5RILNTjdKKv
dVme4HYG0Nn+QH2Sp7iDQXSxP1hP6SKGmBfraf6hAdn2lmomd5mHM4JRjORf
+8sYbV6uY+KcupK95hX6H6vYZb1ah3K3uRT30ND6LKlssF6vuTTBDSRRglu4
mcmOb9IXeIhJ1nV1q87SD3iQ53mO93nHsT/4lizrmczgIprYu1CLU4yibLF3
geZms3mf5sR9Mt38HtNYZ32OqeaeOkXvi+djrqFrdXJcI/fGM7Ourtk6USdQ
mmo8w3h6OPYa681rdATj+c56nPaiMRutN+kEnjVP1Dq6TevrFK2nU+Nd6vb4
uXHtmhLPJX4mm81pmkebao7u0Rl8zxbrZppf48NrEeV1PrLO0AxtpR9rS/1E
W2tLbaufahttx5u0si6gn/MFn/Elc/nTsZnxrszN9WLNxy7zrVqS23jX+kbN
G+eLc8T52W3/Ur0krjGeVbxjUuPbsE7TFtpUZ2m6fqjzdZ9+pXt1nhbkJq7g
yrhe++3jerV33CMd4h60jD7GwXhuekALxT3rjrg//Yul5l/0a/1Zl+g1dDB3
0QXaWefrUY7Ev2v+5hgrHFvFSq7n7bgW7UOveC7xvfOW/R7xXdKV7nSjo/1r
9ToOm7/R37WILk86/3tlmT7OvPi9or/qfv0tng8d47xxDtpbF473qtv1J53L
IbZZt9WrtY1u1R91Ds3Ms7W5LmYRV7GQ/fYX6A96uV5GuvlRfYSHybLeyR7z
Dm2k0zVZp2nD+D6Zwyu8you8zEvxzuP81Gasv19Tx2gt3aC7daM+oPcz3FxV
U7Q7JxjGOnuN9AxjzeN4miHWVXRwPGPWmpO1GwPj2q0Hab/4Flgd16hdGWou
R3nuZBhL7K/RelpR+2sFrUwl6lufpL85M+n8/w3/AyM92AQ=
                    "]]}}], {}}, {
                  InsetBox["\<\"\[Mu] = \"\>", {-1.8, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["0.2`", {-1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {InsetBox[
                   SubscriptBox["C", "J"], {1.4, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["\<\"=\"\>", {1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["3.36`", {1.7, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {
                  {PointSize[0.05], PointBox[{-0.2, 0}]}, 
                  {PointSize[0.0125], PointBox[{0.8, 0}]}}, 
                 {PointSize[0.007], PointBox[{0.4463998339305619, 0}], 
                  PointBox[{1.2771956561278897`, 0}], 
                  PointBox[{-1.0806611991222994`, 0}], 
                  PointBox[
                   NCache[{0.3, Rational[1, 2] 3^Rational[1, 2]}, {0.3, 
                    0.8660254037844386}]], 
                  PointBox[
                   NCache[{0.3, Rational[-1, 2] 3^Rational[1, 2]}, {
                    0.3, -0.8660254037844386}]]}},
                AspectRatio->1,
                Axes->{False, False},
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                Frame->{{True, True}, {True, True}},
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLines->{None, None},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None, "TransparentPolygonMesh" -> 
                  True, "AxesInFront" -> True},
                PlotRange->{{-2, 2}, {-2, 2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.02], 
                   Scaled[0.02]}, {
                   Scaled[0.02], 
                   Scaled[0.02]}},
                Ticks->{Automatic, Automatic}], 166->
               GraphicsBox[{{GraphicsComplexBox[CompressedData["
1:eJx1Wnt4zNfWdjnuHari0lHaqjJSh4oER7Gcb0qJNuaoHj5l0GqlSQlRKmmK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                   "], {{
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[0.3], EdgeForm[None], 
                    GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxNmXf819Mex885yQhFJaKp0I7SUpFKJYoiq6wiZGSEaKiQdY2SHcooZItU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                    "]], PolygonBox[CompressedData["
1:eJwtlgnQj1UYxe+9lkRaDCmaoklSKW2jRfs2bbJnV/nsy1cSQsLY6UOyL1ki
ZMuWtbIUUUKikCgiFVNaiNLvzHlnvvPdc+7zvvN/732e59xb9vncGu1TCOF9
kB+MjSE8xsQoeC5ohK6K/h4+HkxFz0Cfx9hJ7zEORJ+GFwFXwCcydwD+OegM
fwYMg78LVsE38ExFxhLo+YwHwSz4MdAGnkv8OLwmmIX+CcyFHwEtiOWgu8MP
g2roxuiJ8B/AQPitzA2G54DT6OfAVPgy0Aq+nng5xifQexnXosswvoY+ydgA
jIUvBfXhZYlvgVcCn6EfQe+BF4LXhjdhnIQ+BIpqb8CH8I/AFmJPor+Dnwtv
Dp/J2A39NpiJ3oWeDF8BmqJnoLvCpwnwRsxNgXcB/6BPRX+L3rmL2Eb0cPgu
sBM+jbki0Tm6Fz4BnAMfQfxH7S/gL/QBLSHriF+p70TfBK8NLwPfBgbBb2Nu
CLwZ6IpuBqYH56Q5fA3xyxkfQA9jvAO9A/4VWI8ehY6M+cAQUBk9VLkEk1Qv
oC38zeBc1kQfDM5pLXgN0DF4biTxB9Ej4e3BaPTD6N3BORmvvKL3Be+5cqEa
Uu0oJ0fgO6JreQ54I9sj7Y2+YQT6vuRvaQc2RK9Ja1ENvwyvAwbBZwevdTh6
Z/CaS6EvBZvgm8FRYvPQFzL2RD+regWvKBfBtdkkmatG86J7Rr3SCnSEH1YN
B+dEtTAbFI2uiTLJPadeU40eY7466AdfABbCexP/C54PPA1/CnQI7unJxOuh
39LawHT9VnLt6RsbqPayXtczQ9F5oGlwj1Uj9guYr2fVg+pNrTm4p5WbMei9
wTlqi26TXGtHwQBiQ6PXuggMJzYsuXdVc68n77n2+j9QV98a/a3quXfgOcm9
pJ6RmclT5CW/6h34+cm9WDnYq5YxdybYs36HD2buX/h74Obk39RvbVf9w3vy
TMPgd4agK4H+we+MgHcifhaupvoY3Vt7iqzA+Gf0M4otVr3BL0nuJb0j72mR
9Y48aLxqg7FgdM+qN7/NvEk9+jM4JO/M9ngR4/HoXP8NruP5G8AX8PrBzy5E
F8/eOSOvQRdmXK4elTcm98IEsE+1h74gumana2+T906eMgl8CcYFnxl74JuI
38jYI9hb52S1Lo8dh75MOQ9ek7x/NWPj4DPgbvRYUAD+dXAtdUf/EVxTr8K7
JXuV5pbJD+Rt6rWstrUHWrtq/CI9C07CPwHF4H3BKfhGcGeyhxfKeraweh1e
GqxGr0Lfn9z7musAfxHUQv8GXpIXJfPaoLPyn8xPgC7KXzKvo2+O9kB530L0
GGKlQWt4fuaWwKtGn70lM69cx5iiPXMC2AbGEN8PRquX0eWDn9mMXhF9llbJ
vPib6LNCnjxAtZp8NmsPlKvd0Wefcqa97xL9LcrB4+hx0Wf/aDBF/ZZcG6qZ
h+Cjor1Xd4Ry6KvBWpd4WKpaBVuDPag8sWvAen0v6MG/F6K53qkLL5K891pT
T+13tFfpnf3wuap7+AzlNNpj5a06Q4rDS4ABwTVVAX5tcu61p/Li/tFnmTy5
ALogmBmc00/V/8pD8Bl6QHtBfGXwM7PgZ6PPZnluTtZD6h3dQRpG3zF0t1BP
rMxyUiXzjO1Zz6hXdKeoFe058hp5+prMI+QNeeCDaE+UF+qMqQk/kdWO1lgv
+o6iu4lqolfmORWyntDeq+ZV68qBzs46yXcTnaHyrj480yjYw7TWBaBY9JoX
RHuovFN3sOXRPVcqe2dxVrMlM4+7XX4ZfZbrTH40+c6ju448X7VeJfluopqX
F9yT3OvyBOW2dfJZoByrd5cw1ze4hxerv5N7SR42H34V6KVej75rbo2u1QPB
Z1v15Lugzrh5xNol147emSt/Sr5byuMuht+S7PU600aqlqNzoZpohm6ZfNfU
na1i8pmns04eez26R7TX6ptboWdnXqg7kva2W/S3ao91N1FPq5d1R/kfB9uD
qw==
                    "]]}]}, {}, {}, {}, {}}, 
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwl1He8TnUcwPHnXpFklFky2xmhQsnWHsoekVwrslOUvUfLXiVCVkZmKHvP
rBZFoSgKUfZ4f1/++Nz39/e7zz3PPec558mf0qZq66REItHTj87JicRc/qE2
etf6Ht2rTOqmtva78z7dr1vUQ+3s9+TfnKde5vk8oX9URV/ZWxR/r8zmvuqn
Aeqvk/EaDTQv5qA4Nr/WFvNSntI32mC9jH2VxZxV2VTN+rTOaK1G2lvDUfyf
aXmWtXWzOZ2GxzFZQXk0zLo8N/NTjlNuDbUux0/0sd6xHstcKqsyGqNO9kfz
DpXW49pobys38T2NMK/mcK7ifxpmfptDeZsGmYtzJYdwsHJooPUjXMGP+KGy
62E9pA/0lt/V1FLzcg6I12p9vJ4dVSuurfUGDtZj5iEsxa18iqP4JEfzaW7n
C3H+fD6uBXdqmbkOz+kVLbfeFddPu7XCuh4vqqEaWL+mV/V57DGFjTiFKZzK
xmzEppzGJnxdzdTY+pImmD/TeH1nPZFHuUcrzfVZmS/pRVXRy/He9quxuqqq
pmqoQdwfcby4RpzAOvH/xrnFe7EuJ3IKv+ekOA9N1mXrm3iFGZlB6TXd+s94
ruI81NzeDN7Ju7TPvJl7mcTmcQ9zJv/SbPN+fsFZsa9UeiOeV37J1pzDwzqk
Ljqm3+O59LsF8VzqRsWD3ynu47hf1DHuP7Wy/yY7qK3aq51a2k/NNDponsvf
eEO8tzqb5/BuzTa34gFu46+cpRZxnPif1cI6OT5PruEvcW76WavjM2aCTbmK
P3Gy6pknsX5cv7iuumo9jT9wKn/kBZ2Pz0r57eVTXo2z3qFN5m/5HMfyGY7h
s9zGJziSFTmClbiFj8YzxhJ8nyW5jhu5njl5u/qbi8U9xQ46on5aEvcc/43v
gjiGiqqPdRH2jtdocdyX8VkkXf9+Xmfdi121QAutK7O9epsfUAHdGsfSQvuL
4r5nIXZjQT6owvEMWB+Pe8TcNfn69/81Qw3LQQ==
                    "]]}}], {}}, {
                  InsetBox["\<\"\[Mu] = \"\>", {-1.8, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["0.2`", {-1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {InsetBox[
                   SubscriptBox["C", "J"], {1.4, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["\<\"=\"\>", {1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["3.3499999999999996`", {1.7, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {
                  {PointSize[0.05], PointBox[{-0.2, 0}]}, 
                  {PointSize[0.0125], PointBox[{0.8, 0}]}}, 
                 {PointSize[0.007], PointBox[{0.4463998339305619, 0}], 
                  PointBox[{1.2771956561278897`, 0}], 
                  PointBox[{-1.0806611991222994`, 0}], 
                  PointBox[
                   NCache[{0.3, Rational[1, 2] 3^Rational[1, 2]}, {0.3, 
                    0.8660254037844386}]], 
                  PointBox[
                   NCache[{0.3, Rational[-1, 2] 3^Rational[1, 2]}, {
                    0.3, -0.8660254037844386}]]}},
                AspectRatio->1,
                Axes->{False, False},
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                Frame->{{True, True}, {True, True}},
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLines->{None, None},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None, "TransparentPolygonMesh" -> 
                  True, "AxesInFront" -> True},
                PlotRange->{{-2, 2}, {-2, 2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.02], 
                   Scaled[0.02]}, {
                   Scaled[0.02], 
                   Scaled[0.02]}},
                Ticks->{Automatic, Automatic}], 167->
               GraphicsBox[{{GraphicsComplexBox[CompressedData["
1:eJx1WXtY1NXWNvMomZNmnszJVCRtRFOzqCxtiah5CR09lmY2mX56qLFjkZdG
PYZWqChKiWV+ftqoeLwkmLe8oAu8EINAqOAACnIZEAUThos3cr7OrN49z7N9
8g/38/Lbl3dd9lprr/GfOmvc9KZNmjTZ8cd//x1vHWkZHek+wud+XjfOUFbP
iYIJOH1/9ydinUU8b8rNiMRIN/dslXrVFZStMNYDYz1wR5mv8CnZT+H50z44
GhR7ReGX2/5ocZp/U+MS+a4w+ACDDzD4AIMPMPgAgw8w+AD3lZH+ipc+gh8w
+AGDHzD4AYMfMPgBgx8w+AFDj7qedF7AOA8Y5wHjPGCc91d+odtF9xPdTrrf
6HbT/Ui3o+5Xul11PWIdsD5CXmDI+1d+ottF1xv0AAy5gSEnMPjpPID1Efz+
ym91P9HtCH7A4AcMfsDgp+tF5wGsjzj/U7GbOh8Y5wPjfGCcD4zzgXG+vl+m
xDO1H/BVL07jp7371vEZwQRc4sX56vsz3tHFad5zq5Wf4/s5ma/W53jxNcL8
AsFqPewDnCIj6fNwLr4Dw/+B9RH8gSEvcBPvv+OJwJBfP0/XA/YBT3yHPMDQ
B3Bn2Vdh6AcYfqKfB566nXA+zgFvnIO/Y8Q6fNfngQ8w5Ncx1sE+ulzA0BMw
5ACGPwJjf/CAfLrd9Xm6nbqIntT5wJAfGHLp85H/MV+vB/T7oMdpfMf9BNb9
Hrz1vKT7Mf6O+4a/434DQ5+6P2M9ztPlwL7QNzDkgV4hDzDije6v4AUMXsDY
F+fpeV/3Zz1/6f6s5zF8Bz9g3C/dn/W6TPdvPb/hO/QEDLl1f9bzpe7PiNfY
H/6I/XX/RPyGPnT/xnfIhe/zveeU8OiD7x0wW2oZGGPf1q88bQm5ypFenk5O
9q7Pome9eisk4Jvv9+1kM9RTlmC+K1jNB8728ijjH1qufsOUUKNG/B3jQNmf
23l5nlI8sR++g9884UdYD35YFy4jYT9gnJ8u69T6DfJ3tX6k6EfJB3n1OAyM
+PBXcRF+BX/HiHoFuPzYwl88nhtKTp0X9sV9w77AsCvsh/nwd8wHxnzoD+fp
GPoCT8Rd8AcG/yUzLtbH26sIPOAPsBswzgGGncALeoDdsH+U7K/0AztiHfwF
34GhD9wj8AfGvrA7cD/xI8UfcoGvrm/4BfYHxn6PH/3veTvV/hu95+9UfoN7
jPXAmA+/BsY9gfzgqY/QNzD4A8POwNAf5kH/JrELgbe+D+6LHgeBEe+wDvcN
5wNDb4hfwIhvsLteB0IP2E/Fuz/jMPQMOeBf+r2EfiG3et/8eR8hP7B6z/yJ
oW/4B+IxMPgBgx8wzkdeAcY58AP1DtHiBvINMPQD/eI82Af6wHzwgD2Rj4CR
f4AhLzD0ibwL/oWiT1W/6aN6v/0ZRzAf+oK9sB9GvW7U4xT2xXfsi/X4jnX4
Dh56HQP7I37Br+An4KnHH+gN33FvoH/9nmEd7Ivvet4ATx1DPszHPQSGH2Ae
zh0c7d5mrTh/X/3rPrHvddMsX93Y7IHddY5d9UquzKGWPM/leuXvZ7vdW5iY
Usd50261smXc30c60f9ylWuOm8c+958iD9fc18/Je+jTWc4sF9+JTC3wvFer
eDQOvBvuzCpROLHJ4L6WT311VNrCR4tcB64qnsDgif30fokpLdgv1plH2F+v
P/Edf5+ROPh1U4Kvb5HaJaWDLdqp/HjGiLjDQbG5BH56n+nwIqdfQnGxul+X
6MSixJRSVU+2Xn6hiy26VPnfxNeWF3uomKAvnAv96n27yKg2dnOhrw8x++M3
NpkLbyj7Ip5in/yFm08GVfn6B1OD7z5pC21Q5/de0mVtpKWBVjX78YjZksT7
Vz71QEJwA3vWHvK3GfZRp/zQHpZpDfxScXebPfY3NWb3friPJaCWl40dPdvZ
poRLnow+b4wqVuPu4OVR9sT99Fvp3EPmjcXc9oO5p4Jmuyl6i+lre2MRd9hT
SSZnBU+KS3c7jl7gO7PmPG/ZUkTH1wbuM2/M5m0v/mttZL9yOj/9eFDI7Qsc
3i12lT3cTSdem/K8JaGIwtsHPh57s4ZsZzPLXHPKaXZ421Rjywq+k7v5jmOU
m1wvHkg3fpjDnT8qyPN8V09thhQ2S/DPpjTxZ9oQMtZmX1hI4+LztlqfqKfA
pyI6WrYU8M//E5dhLKnjdSPH/C2huJSm7Fpx0/FwHbetuNQs9mQlfXCmdbZx
UA23uDmgd0j/Si46x2HuO9Xc7/DyHOOH1dxq75C2toxKnr/ZfsNVVk1Dvm0y
wNS6kl8ec/u2Y5cvrw34R+Zw06+1/OXGmja26Es8l4Jq4/0LudCx96B5Ywnf
fflk69jvynhFuwfyXAcKePi5yjhzp3Q2p6ye5r5WyqGZmQNCbm/mYZ3vHjA3
L+W/37oy2Wn+lZa+fbsu3r+AT1nf3m0dXk2F3+YUuw7ksp/x2njD2jpuEfhk
uaMyg6u/7j3VvbeOY1ZecBhb/uLrT8t94KiPRyUGtfP1P6a2HHErPriSG289
+IqpTzoPuZyxzbyxkkN73OtmCUnlcaNmnjZGXaVLFzN+j/fPVX47R+4L+3Vt
2stysY53eu/XVoX7CaYcOvm+M6aK08YsG2Uo28HA4wQT+IYLX4I8V3t45SHw
6SN8CHwLhS817T50v/leLb/R1XMwqF0+Qb8LRL8E/unCn8ojHUnGwCra2zW6
m+WLXII+s0SfdHDZzH6W/jX0qLU2wGLNow+Pxb1jOF3N7dL92tkyrhHseUHs
SbvezHvcFpTHX76d0NsyoZRgz+FiTzp3tv9Oc7yD888+9onTVUqw72tiX4q5
7Wx0PFxDg5/bftIYdY3gf5fE/6jRG/9KOWpE6jR3Wi2dD3h5vHt9laoH4N/7
xL8J/j1Z/JsWBexomvB+GYVHTCjwbKqlQYX73jEcy1L9E9TV3z6RM8TUukHV
sU1m/O0jZ98GPnDweoAto1j1CQrD+kTbB5Sq/Jr19P+GOfdU3Pf7yCqJZ8pf
Fko8Y/BHvhz5gvHemu9uqDgIuSzrHvncPqCSm5d/eddxpua+PuS9CUkT3Ouv
qXt37tkdv69xXlZ5xCXxWdVl7SU+c3mHlF+CYpNUXIe8bXa3SgiKLWRXcq9t
1ol19/VNxy07EmJKuKDy85R3l7ayGX719f3/vF+R1WkjTQnnVL8lIszeyZbh
67f4LXc+GDvBVy/iO+I2vgODj963Gix8VH0wWPgQ7rfenzkh+iHw0/szTUR+
Zcezks8J8Q31COyh1+kNYg+CPWF32PMtsSe93N6VbIyqVHY+GuMeY5h+5b7+
ym9SvxD8D++LD9tmdrP94b96f/wb8V8lT+N0r/+qPJ4h9Q3Bf7Hf+tiIfzrN
Dt7QOOKlkA4NjPu2Su4bN5xJuu044+bAoKBbjl2+eDxP4jEhf0yX/EHfzQ8d
YVp6nj96bH6g5XA9nx1yp9jjSaIT41uUu95s4ID32wWb+qSS3xftO9oGNjDy
F+qxrjMr7sUvvsIproNdbf9280zJf1R9ZVSLhGQ31y15wrOmxQ1qlJHzI8pG
mVq7efjWoWMNceXcZsOGb62mY3SzeuJhc6dilY9HSj4m5PcIye8E+bqKfIQ8
ny8jYb8bsh/hvEFyHqFu6CMjgR9GyHNC5CHIUyXyKH19IPpS9coeqVeUfdaJ
fQj6PC76JOizmehTvT/nLug8P3FGg/LbxuCs5KC6Wj7klzoo5LDvdw7E944S
33lRqK2b7brv9w3E55ESn/nc6YJ/uufX0IavnJPc+RUqj/aybG6e4F+q4um2
3qduOipLVV/BtfuZHdbtJXxrRtjixGFudS93PjlsQ+Q4N8Uumd7FllHKoz29
utiu16p9kd8mS35T9zrpmdPL7Ik5Sr7q12d2tBkuqPdU/Nzeow3Tc/nd2zGn
g7JrVDzCvZsyO++8x5OrzsO+qF9mS/1CH+d8/h/rulo+vKrXMyH9LxP2w/yp
P0acM3Z1k3FF2TDDV5cI8oHXuu1fLk580U3ZC3ZXuHJcBP2DJ+qrZlJf0bY3
+h81P1LNFcFnt5qPVxHsgfmovwZI/aXsNKRLdYy9o0/O+DtLeloC6hXPZ2e8
sdUaVk/3vHlhHy+hf9c6JjTwrDXDdwfFbmLUw1i/V9bzNx13zbU3XuYZm/qu
i9xcx6g/A6T+ZNRhWf86c8X1Zr3S43NyHkfM+aKzLTSbPivoMdT0x/2uLN6z
OjI8j9YFD/6H4at6Rr36ltSrXOOtewqo5YbxCxO71ys/HS7yMerhe1IPc83v
r/6fNewqN2na5qGE5BqG/qpFf4x6erHU0wx7XBJ7MOzrEPvyiPy1IYbphRwx
ZOanzpgSnrJoxPrI8PM8+LTfiaDsUl7jeHq4qc9+vhPa09/2bqmq39Okfmf4
Q6D4A6/qET3PvvAGPb1y+Dvu9bmc2GJ6L8sW3+9z/MnSTOPUOk6ak/aW4avz
HHdoWIPjZB0vSJ6/01qRzPNMJcMN0yvV/IePTL7qeKyK+03K+Nl8L5nxjnPK
yEV7vi91HXBSx8f7r4kMd/Kg+APtY9sXU1dPWYXrQDZPmnp8pX1hKe1/7+IW
6/YcnjRxdIqx5VXyPztoXmLzXEZ9mCT1IQccemarudN1Smne9AlbdC4XXL/y
vjvf11f+KaLvRY+zjl8K/2KuM2sPA9/9xIupcG14hmdTlZrf/ffOScaoKh49
NrnCYf2RgS+YvZigH+Qx6ONd0QdBX3tFXwT9YD700070o/x/r8QL9e7FCH09
IvoivNf2yHuNMsL6fpzY/BK1P3I93TgyR93rEok3BP22E/0S9Bsn+iW8907L
e496ee9FGb2YlGVxr7+g7vUmiVcEezwq9iDo/5DoX9UTYyV+Efzr7+JfhPfo
V/IeJcTXlRJffb+DSbwm+Ptn4u80M2HKMFOfHP78yIJXQw6Xqvpio8Rzwn14
Re4DTVp2tHuIjflT99dvGeJKVf65JPGecF/ccl8I7+dyeT/TC/NG9rSExNGr
ky/ecfQsIeSXWMkvhPgzVeIPIZ7MlnhCiCexEk+UfW5JvqPCaTd7WB4sp/Gt
WvvbPvL1a8MlP6p4uEjiISEeGiUeEvoFwLcCT402zfqBeuQ9sjYyrEH1H2ZI
/4HX7Dr/qM2QzhU5z22x+jWoPv38x395IKG4nrH+WVnv+z20/vvNVksDD+r9
4nL7wjL+8pP4LGNgLaM+RF2KfnJKXXmWsWWtqv+T3qYRptW1/MJTn/cPyfP1
l/H+mSvvH4Y+Joo+VB1bKP0UHm979KWQ/uWqHz1w7g+XXfVXqddrg3da/dwq
bw167JEY+4YabrvGOsGddk31CWdMqPwpqK6Kp0xICQ7pUc2od1Eno3+XOSZz
U+Q4Xx8yWfpLfPxGgtm9vlD1r/G+XCnvS4Z/LhX/ZLwvS+R9yfDHBeKPDP8K
Ef9S+p4i/Snu9d00s6HbL5TqvP21NfUyD1nRa5E98Yz6PQb3v7vcf9Vnmy39
NMZ9Hib3WekT8Xhl69RvIvf6+uU475CcR3iPYV/0y9OT/TrETigi8EHfGvmu
8QFvvlP9wOPSnyT4T4T4j6qzEsU/CP6B/jrsaxL7Et6zeI+gz7ptx8MBtlC3
ilcDxP4E+6Mfj3ogXeoB1S9sIv1Xwv1wyf1Q/Ur0r5D/m0v+p+atHOkeTzrd
WRwzP7F7A297vnGSoVsxx5zpt8I+uY4RRw4GVPcP+b6OI9c/edmzyc1DI9ps
s4a51Lsls2BNd1toER9dcaTK0fMaV3jj0zmFcwXTxCnZFzxjrnDE/qKTxg/z
CetTZD1NC9z+iTPmPHXIu9bOFppP8PfJ4u/01siHfgqafZ1yzW8Gh3xQrfg3
CH/VX/GX/grjvBg5j8M67+luG1hNEVeOL7B3vM5ZxWFznB/X8Opj1+ckplRw
1JVj6yLH1fFp26Y46/ZshX8WTJi/VOYT9vtM9lP8Lgk/hjw9RB6lv4GiP4K+
V4q+6f8BY0Gq1Q==
                   "], {{
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[0.3], EdgeForm[None], 
                    GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxNmXe8V8URxXcWBGwgggUEBEGkI4iKIlJERFBAir1BRBELGHtUhMReUEFF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                    "]], PolygonBox[CompressedData["
1:eJwtlnkUjkUYxWemZKdsKW3SeiqdFpGthKjIFiH7ErLve/adhFSWrOGQI1lS
kq0jbaSUrSRJpbKnUOh3z/3+uN/cOzPf+8488zx33qItOtfulEII74LLwZIY
Qm/wE3wyqAqvxITT8LmgG/p69AvwlmAbejsYBtdzFvCzDl0FXox2IfoN2vzo
4tLgG7AWPVHPYPwT9HL4RfAAeij6KPwPzUG3RK+CF6T9R+8Cx9A7QAn4F2A1
vC6YD+8E3oePA93hN/KMSfBWoAx6J3gP3ljvg38ZvX/t4SJ8DPgL/i04pFiA
mvBlYJ/+C+bBN+od8Ko8fwG8F9iN3gXuCZ7TgLGG4L/gZzRjrDpYBN8JRsIr
MD5HsQVPRwdyF0150DT6DBT7r0ELxpqBEfALWiNjj4Hp8HWgst6F7hF8Zopd
rei1K4Y94Y3ACvjzoBTzK6NnwU+AcujH0bPhp8DD8B1gjfYCKsDPga+C96ix
5slr0ZzO8Ab0vaN8ot0K6gJtayhYDnmQOX/Cc8FnwifTDkQXoX0OlAcvoz/X
Oxh/EX0E/iu4HT0Q5KBvavC7ykWftd7ZN3qOxtqBQej70K/BO+jM4a9Gr0U5
0xbdBmSHXwKPKrbRZ6EYFEO/hZ4C/xkURndJ3tvY4FyaC0YH59Rs+BzGi2Zy
vj/tXXonvH1w7B+Jri2dwUx4B8Yvo82BnkHbDh2j15QXXhI+Cr4X3Ixehs4J
DgXn7kNgZKaG68M/jc7tG8B5+L/RudM9ODcuROeecqQ6z3sJ3Qe+EKyHz6Cv
MG1/dMfoPWuvTXW+6GvQ45XLyld4Nfr6ws+ASloPfce1N3Ad/Ey0VxwIXntx
+n4L3oPOukjymM68InxU9FpVE7WVP/Sd17tUQ5mcKZLxmC6016InwJuDovA+
mdgcBJ+ptqPXshK8Av8YvA0/B4ZEe468Rjl5KdoDVPuqwbMZz5HXKOef1N7R
vYNrvopiE137b4I98Cei+fpgr1oBXg/2LOXGHHTD4BxpLy8Fzwaf+Z3wO5Jz
Vx4rL9aetBd58kn0CbANvh3cm1xTuTI1Iu/rFV3b8sBujHdNPjudmbx2Ghge
7Lk9GOuefJaK4Uj4cLAYfiXzBqv+5OHo3MpJeGvaOsHPyJfsEfKG71Sj8F+U
g4o9uJXxfiAbfYfROZI9W169GxRAl8rk/vdgVvSdobtCMTlGezzaCxqpvhk7
hW4Dz5p5V7vo/+qdAxhvonVGe4Qut46gfnCNTQIjkve2mb5q8BrJuasamEr/
M+izwTlXEz6Rvn7Bnq274QMwP/iOGC8vUIzg+ekvDS+f7J1d5SfRHi1vngbG
MjYO5Mt43hj46OTcVt8V8KxgS7BnllB8k725M1hKZ1etIdiTrmIsf3LstccJ
jD2VXMvK0QPoCegCtB+pxuBZwBB4IeWNYpHsLfWCx+qAv4Pn1E6+g3X3qq8P
fFH03a01ZEPnTD5L5cSH0d8AxTIx09k3jj4r5cB05SbYF+xpw+Gr5Tn6b/Dd
vzI6VvoGuJ//D472btXQafhtybnUFsyLzjnlmjy4CWP1or9FFMO7IQOivVd3
wBH472BMcA1ugbeKjoU84Sbm94j+VpBnK9duSfZ+5ZxqrwP4IbgGyyafuc76
ZHCsW0TngmI+MPoO090lzyuNLojeH7yGKeha6CXBOaTYHAZbg2Oku7lM8rN1
R+vub5X8raRvgKvhZaO9XmuqLy9RTgd/c6xhbEiy96mGldvyQHmfcrwXuiE6
i3IP9EQfjfZS9elbTXM0pm+2DbT7waZgjyiUXKOqTe1pL3xQsldsCJ47DJ03
8588yTmnXNsTfHflTua6wzZlalS1qZgM1d2YfBflob9/cg7o7LNnYtU6+e5W
zPSu5tFz9c7F0Z4pr9Q34I/wg2BpcIw2R9eIakN9FaM9XN6tnNTdtjezF91x
a6O/ATcGe8Cq6BxW7uobrGRyzapWdQfqLq0R/S2nO/V/A716QA==
                    "]]}]}, {}, {}, {}, {}}, 
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwl1Hecz3UcwPHfnZ2RRFRKR0pFKhr2OKs7KdewImSLQ0hGHHf2niGRrU0o
IVlpEIpsbZX2Lqk83w9/PL3e78/d/db3+5PSMTOjd1IikRjknweTE4k5uov7
aWPPSz6+sLfTB/Qh3aPv8yTT7FV0L7dR2F6EQhTlQm53PkPnaRe+pLO9C93o
yn5n8+lu7kmPOLc/zXLzAv2AhSyyL9IefM03nKY6JfzsEn4w/xjvg9pc7qw0
v8dj6h/ajyvMg/U6rcBv5se51jyMobSzD9Ff9RotH39D2/hd/UWv1nI8Z16h
z2tfBplX6GO6XA8w0NxaB+j32ofLzMu0vz7Kd+ZMLjUvjdeqffnW3ItS5j5k
0spei1nmJRoXdWB8VvYBcW2pw2z7s/FaSEk+f93L6ot6Y7xfraRPaGV9Watq
llbRkfoKc8x19SD14z6wr9Vs1jHXnqqHuZPG9vHaSCdoE03TNJ0Yv6OTNF3T
9S6drE31bprR1H6E4eYR8Rp51Z6l7+p65pkbxH0Y9xy3Uo07aOi8htakOrWp
RSPndTUnPiMdrfW0sabqmHiPOlbP8E98B+I90CAel7Pmf2kfr517nE3RJE1m
s3mZbtLj8XOesk/X9xgfn0s8F+PiuTjpPCO+i+ZZep/O1LfYSSemOsvDvWTE
c/Kw8+YsMO/Qz/ks/p5Wcd/F95iWtIi/df4Jn7Kdyc626cdMMnfUiZqbGfHY
+qau0q06jZz43Mhmi/0Eo8wddKTmYqr5DebHNdVjNCNh/1//YxwbWersdT3K
a6y0b9BDfBTXh7/5iz/juVjDEr+3Wm+Je0Rv0uF6s76kFeP7rNfrEL1BX9Cr
tL9eGd89LaMrdbGu0p/5iUcoGfeQtuQdejLTWQ39kGeCfbF+xSm6UzzuQ20R
1z4ey96bXnSzX6QXUyzuWfs+OsTnT3s6xbXl7fh+Md1cVQtoZ82vBbkg7nv7
btqaZyed/7/9HOAot04=
                    "]]}}], {}}, {
                  InsetBox["\<\"\[Mu] = \"\>", {-1.8, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["0.2`", {-1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {InsetBox[
                   SubscriptBox["C", "J"], {1.4, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["\<\"=\"\>", {1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["3.34`", {1.7, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {
                  {PointSize[0.05], PointBox[{-0.2, 0}]}, 
                  {PointSize[0.0125], PointBox[{0.8, 0}]}}, 
                 {PointSize[0.007], PointBox[{0.4463998339305619, 0}], 
                  PointBox[{1.2771956561278897`, 0}], 
                  PointBox[{-1.0806611991222994`, 0}], 
                  PointBox[
                   NCache[{0.3, Rational[1, 2] 3^Rational[1, 2]}, {0.3, 
                    0.8660254037844386}]], 
                  PointBox[
                   NCache[{0.3, Rational[-1, 2] 3^Rational[1, 2]}, {
                    0.3, -0.8660254037844386}]]}},
                AspectRatio->1,
                Axes->{False, False},
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                Frame->{{True, True}, {True, True}},
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLines->{None, None},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None, "TransparentPolygonMesh" -> 
                  True, "AxesInFront" -> True},
                PlotRange->{{-2, 2}, {-2, 2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.02], 
                   Scaled[0.02]}, {
                   Scaled[0.02], 
                   Scaled[0.02]}},
                Ticks->{Automatic, Automatic}], 168->
               GraphicsBox[{{GraphicsComplexBox[CompressedData["
1:eJx1WnlYlNUaRy1Lb5R13RrNFs3GFTNHc31N7lXEbfTRKw/aZIFGkWmE2qC5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                   "], {{
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[0.3], EdgeForm[None], 
                    GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxNmXn8V2MWx5/zhERJaV8UlVLGWqi0CSkVMtkSRbKLsWXJliwzhuyRnRj7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                    "]], PolygonBox[CompressedData["
1:eJwtlnmUiFUYxu+9oeyOIamTkzqVFCVCOkSlaJHsIjSasQwzhiwTIqZBsnSQ
JVNE5RQttmghR9q06KSk7YRKCgklWer3eOaP53zPe99vud+7PO+tnZnXITeF
EF4DpcDKGMLnYAN8MbgFvg28DR8FroS/B1bDHwG9ebgX6AoPrN8APgNvYc4H
xfCtYB18GqgH3wxWwTuDBfB+4HX4FPAufEv0u7WvIngLyFL4CL0D3pO1lfDq
XJeDMeBN7HmgIfwjsBbeE3wD3wnaw5eDcfBGvONpeD5oiv0xeAM+F9yJ7w5w
N/xEcCxeBYuCY1KM73Hs0fCaXO/Cbpd8r77RlbWW4Bn4NlComOBfAh8uP3wj
ay/DT4FP4Z+AesHfuBn/FOyj8MOgG7w1eE57Aavhk8GR4LVD8D+jfcPAEvhA
sB7+BMiFd9I/wLOCc9MKPBuco3F872FwW/A32+N7Jzp2tUAmvAz+nYql8g9v
ztpC+O+gAfx9sAbeHYyEX8o9c+A5YBl2Hexf4RXgF8MLknld1hbq28oxvEbJ
uzqzdjL4nZnw+0E31QO+J0GfZF6OtaFcz03+1+zgXDaLrgXl9Hr4AdVkcIyr
c+/z2OXBbuzy2DmgtOKK3ZFrYzAd/mHwv9bHvz/4nxV75Ui5UQ7uwb4uunZf
UUxUG+A35RZczr0PYe+D7w3ORRMwMzgnqtW5oCi4ZtdEx0SxKMDuAu8EJgbH
ZBjrNbFnwfuD27HbYh+Ht9N+4DNZGx/cY9/Bu7N2Gr4FXJKcA8X+Z9Uk/gux
Z8MHgqvh9cCQ4H/eoBqPZ1r7zDuvwdcCoxh+QJqAfRGoExzTxWAI2BX8j3Pg
9yVrQ9lg7agPCoM1pCW+Sdgjg3u8Ofaj0b2unmmVrEHSnkPB36qdvHd9sye8
R/K79Y9tontUvamabqbYRfeean66tAysgP8DZuCfDsYFrx3GNwH8Af8CHBSP
7uWhilFyzpVr1Uxd7LFcc7EXgE3q7WguTc3G3w+UitbI/7ieAl3gX4JeCqz+
OXitILpmVCvqmf3RNaVaUg3PhvcGXwU/o1iejn6XYrpd2snzlbluxL4Afn5y
rQxQzln/CWxVr4Cy+HZj91CtgMrY+7Az4T8E90KlZK6eUG6rYf8YnGNpQ1/W
vg3WiMHYgzQT4I+BPLgGTG/4VJAFfwBkBMdE2p8XrU2aATnwKsl71R76iydr
j57RXvdE96b2PBU+EX8V6Zb2zPV76Qj8AzAJX1Fyb1RV3MBU7GpcN7F2Inom
aRZtD/b1wM6Ivudf1S/oiG9CsHbPiubS8MnS6+R3ayYM02yJnnXS4BnwNqwd
C+7RK+BXJWunauZG+E3Jta0eKIRPAC8E/1NK1lhp6w7FFPsv7DHBe1Stroqe
1apZ9W6D5N5UD0/D1xp7WfAz0qYXpaPBGqW9qSfUC9qjZmvb6FmpGTsAXjE5
d32Ccz0fTArOecR3VvLepNHH8Z2MjqViptm8IvosoBktLXwpetZKE/9Wn+qf
gntwPPxoifZVKqnle6O5anqM9BQ8hb+i+hCMTe41remskY99dvSZ4zL4qOhZ
pH/eCz+PtT3wfqCh5l/0WUCatja6h9Q7ykFj/OOje19nhluTzyA6e2jPmvVN
sA8Gz/ymyTNZs1hrGdiDsfsGa6x6Jz969qiHamGPiNZezcz+8ArJvaOeGQ7v
zNo50k/VATgSrU2amdICaby0XZqgWdEt+WyhmXFMuQWbgzW8tLQoeXaqRwax
WBV7RvAepQ1Z6qFgjSiHr1H0WUBr2dEzU7NSPX6t9pasHaqJB+G/RM9i7Xle
dE+qFzXjhuDfFV1LZbguBSO1n+iZtihao6RN2lON5Bjo35Uz5bZD9LPK8Q7w
tWo6+Mw2IjnHyq3eub6k59XruqeDtCD6bKmY6Gw7OrmWdMZdF60p0hL1zP93
YmxK
                    "]]}]}, {}, {}, {}, {}}, 
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwl1HecjwUcwPHfXUtJJEUqQqlkhUh2OKOzzlbWZYSsCJU9G86Rke7sXSHa
A9mispo0aRmVVZEG7+/LH+/7fL/PPfe73++557ki6X3T+iQlEonhvjRNTiSm
6Doa0cR+Ws/wFWn2xtpcN+sWnmOy/U7dSmn+5xz/0SFe3PfLxLk6TTvyNW3t
7XiQB/jAsem0N3ekA53s3bQ7D9GVLmx3/GHtwWWk2y+Nc/QFpprLaQ69nIPm
H+K9U5GrHMvNYfNcPaK9yGMeqDdoQQ6ZB3C9eZEO1lY6SH/RApqfx2hpH6g/
66NcZ16gi3Wh9ozXMs+J7+ts/ZD+5jTtpwe0B7nMs7Sv9uH7+Lxcac7W3voI
38X1Iae5Fz1pZr87rqU5S7vH6zAvXktbUIkZ9vnxe8ln7q/X6hIdojdThMIU
oyiPs8z3b49Zb9Mn9GWeN9+jH3EvM+3LdSgr4u9ir6K7qBXn2MdoZR2rVfQ+
rabjtKqO1+paW2vqBK0R51GLOvbdPGkeGu+FV+zDdIOuJMtcVUvoML1DS8Y9
S7W4Z+P+pBR3UZbqjpdPvvBclNMRWkFrxP2jI+Ma6yj9nWO0jvcY1zauA8fN
J2hDXbIde12forb5aa0Trx2/h0/s9Zltnqgb49w4L65HfPa4HnzmeEMamDPj
Z3SSrmUNmbHzl7meppARz1n8DHPM7+l+9pFKo3i2aUgq9wfHv+BL3mWiY+/o
5zwbz6w+o39qRnxG81u6VN+OcxgTf1tG86b9U0bFc68j9Y94Dd5glr2e7iWF
tpziJKN5jUXOeVX3sIol9tW6k4/jXuI3fuVo3Be8xELnvajFdYjeooP1Vl2q
hXSQ3hjPst6ki/Ua7a1Xx/OmeXWuLtB5+hM/0pUrHKugTVlPF6Y5Vl53xPPB
fPtM/ZZvuMR+cdxz5ibMoJM9nc7BnqQXkRz3p30bLeP/EC1oQ2ved3wqU+L+
1rO052/+5R9KsYlmzpmcdOF//nmj+rdv
                    "]]}}], {}}, {
                  InsetBox["\<\"\[Mu] = \"\>", {-1.8, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["0.2`", {-1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {InsetBox[
                   SubscriptBox["C", "J"], {1.4, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["\<\"=\"\>", {1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["3.33`", {1.7, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {
                  {PointSize[0.05], PointBox[{-0.2, 0}]}, 
                  {PointSize[0.0125], PointBox[{0.8, 0}]}}, 
                 {PointSize[0.007], PointBox[{0.4463998339305619, 0}], 
                  PointBox[{1.2771956561278897`, 0}], 
                  PointBox[{-1.0806611991222994`, 0}], 
                  PointBox[
                   NCache[{0.3, Rational[1, 2] 3^Rational[1, 2]}, {0.3, 
                    0.8660254037844386}]], 
                  PointBox[
                   NCache[{0.3, Rational[-1, 2] 3^Rational[1, 2]}, {
                    0.3, -0.8660254037844386}]]}},
                AspectRatio->1,
                Axes->{False, False},
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                Frame->{{True, True}, {True, True}},
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLines->{None, None},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None, "TransparentPolygonMesh" -> 
                  True, "AxesInFront" -> True},
                PlotRange->{{-2, 2}, {-2, 2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.02], 
                   Scaled[0.02]}, {
                   Scaled[0.02], 
                   Scaled[0.02]}},
                Ticks->{Automatic, Automatic}], 169->
               GraphicsBox[{{GraphicsComplexBox[CompressedData["
1:eJx1WXtc1FUWNy0rN3wklhKZmkukaUSOpFlHnbIVU8lcNatRS8ocUzMyh3XT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                   "], {{
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[0.3], EdgeForm[None], 
                    GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxNmXfcVsURhXcWK6BIkSIIH1UQ7F0kWAALir2LYu+iiIKKir3G3rAgVuxd
YxdNLBgSjbFGo8aCPfZeyDye8/7e/DHfzN27d/fe3XPOzL5f793Gb3FQLaXs
n39apf9H2pZpm6fdnXZC2mZpWxTdb5PWIUppn7Zpxi3pe6X9JeO27jNfWru0
BdIWTFvMfqG0RXx//rRF7em3ZI7xS/qn0rZLa53WKW1xx8zb2Z55utgzXld7
xutmz/xL2DN/d/v2af1zrpfTv5S2dMYD03bIeKnQnL3STk3byfOfnjbW85+R
trPnPzNtF8/fx/MxT1/7Hmnj/E4tab0d0292Wk/eJe28tL08xj5pe3uMPdJ2
9/ucm7anx+iU79kxbbeM3057y+PsmzYgbWDa+2nv8U18Q/bdz+0fpM1NG5Q2
J21w2jJpD6ZdBA7SPkm7NO3AtM/SLksbn3ao+66UtrLjZdMeTrsy7QCvaXev
M+vKmvKda6Ytl7Z82sLZ9lj6a9Ime6xhaUN9f4W0texXTPuD+6yStk7aammr
p61rv0bacN9fNW1te/qt5/vMP8Keeb5M+8LzXJd2hN/hSM83Km19x4y9gT1j
b2jPu2xkz7uMtmfOtvmN33nOG9KmeLzu2X60x/s8bVLa4Wk3ph3j8W5OO9bj
tTe34Ak8g4vw5bgijsI3+AoX4RV83aqIb1zDi7alyTeuty3ic2s/z/02Hred
+zV4y/VTjuFvv3yHvubq9kVc7eix4Eqn0uTq4qXJ1c6lydUupcnVrqXJ1W6l
yVWuDyrCDPv3o9d9TBEve3mus9J2LU3O4eHRjo57eFx40+Jx+/j62SIe9ivi
EzyCP/BmoGP4B7fA8LtFPISrcAoeLZ32tyIuDSniD7yAV5cUcYhvgE9wCHzD
p4OL8H152iFFOOc5cA6/DnAMv+DWxCJ8z0g7rAjfVxVhB5xP8nqt7vnW9Lox
31BfN3g11GOD7WEed7ivJ7gP7zOrNDna4NVwjwvG1y1NXq3n91jH/Rr85PoL
92Hex4v41uAZnBhVmhxbvzQ5tkFpcmzD0uQY1985Zt5FQnw7KuM/F/ENjsE1
cLNJEbfGeJxvi/h2rL99or/v/iJNH1fEBbgGD8A2fAHXcA6+wa1Wvia+J+14
9+MZOAhftiniG2Pcm3ZSEWdKvtu8dFu7bRv3GRy6D7ZvLeIY/Lov7eSiPDUo
+/zL8SlFWAfnzxTxgWu4t5PHuS3tNF/Dw7G+Dw93dhs83MVt3bwGtP3RcYu/
E51BS84vyj9wBC7CEzgCr/Z0f3i2l9tuTzvb/f5UlNt4Do7u7b4XFvGnkZOI
wT/83sd9LyjKc/Dz4iKe0Gdlx+wn+Id3YP+RtGmlyQ18gxfwcQUbfATzz6Vd
UcRJ/AS3P592ta+75vp3CeXD6UUezk4twgz1FJrQJ6QLaCWaSU6Er5P8Lt+k
XVuUe+ACnBjmb5nsMa91TPv17gNf4AYYhy/wAXyD7W7mwQjfm+L+d6bd5H7w
5lg/d0tRLgHLYPd4x3wHuaSB5ROL8Pxb2ouliWM8uKWOAp9g9dUiXILJCOGP
emqsfQObpxkDYJAaCxyCQWoscNgqn60hToLps4wBMASW0OVxRffB6gNFeG0p
wuA5jsEXNRYYAztgF9zOn2PPF01Nx4NVaiVwBsY+KsIlmASP1Ejg7aEi/BHf
UaT14A58TStNDKL7Dayh+w2sofvgqoEzYmqi6aWp/+h+Q59mFGlUF2MKfvy9
CGfkHTByjZ8FI2gsmHmiCDdgoHVI0xuYu9Z9wMhM91kshJWGPuLBSbtsXzSa
2ooHX+AJXKGtPxTVLuALHIEtsAQu0LKO3v/bvP9owO3ez2lex+U8550eG629
q0h3phadScAmmormglk0Em0Fj28UaSXaSJ4kR5KXwAX6Pq4IF2ClxXv4sNcb
Xj7iPWTPH/y/PX/Ie83+PFrEedb1ca/3TK/1KO/DY6XJ31nenyeLarlcxt81
lJg8wxmKe+jG00X1FlxbzDG68U/fo52zEvHCaT2dCxp1DB5e/LWovunnPsRL
FmlSb2MILUPTyPerer1Wcx9wRW1DXcR5g3HIVy/5fbo7huMn+v14N/QAfdjG
9192H/TgtSIev170zrzPK+7Twf5V95/tPj3tX/eevu493sHf92+Pgza8WZQr
+P63/O0DHC9l/7bj/zim79m+7u+2d9wHe680z1TEg+zfd4zN9f3ergnRCs5Z
HzlmLT/2es71Pdo/dMwY6MSnRTqBhlMzjSzyXzpGJ/5bmjUa96ipvnKftbyf
Xzmm7Ws/Sz6gZqJe+t7xxvZcj7b/wTG5hNqJPPOT4zH2XFNTwb+fi7gOTslz
YONXx+ATPJHzyHfkkxeK8klf1z/0R7/RebQfjray5g8IndXnOYY44ASdRrfR
ePi6YEg/ZqUtFOIftfr81na0f4GQxpNz0UF4CXfbhLSSdaCGZE2OcjzCfhG3
o3loIHpJndnOekg9iW6iW+gUZ7YGv4nDvoNj6iZ41cBmR/OLsxVrR03YOXTG
aGCGGIyhO+SAZeypRYb4fmef8+f43hBjpJu/pUeoJt7E+0jM/i4R6jPSfZdw
DcH9Hj6vsp/oDnv6tGP2/HeOhjj4rOPZ/nbOq406mrjatzhG81p8vuUbe/t7
5zgebN/H7Wg89QcaQ+1AHUn9MM942tq+n+Nlc5ITw2etjE8O5dvf0u8e0qhF
sv2IUH15ccZXhMZeJePTQrl39YzPCOnjVMav4vM16e8P5b9xGe9UhdEL0l8S
0sUZGd8V4uW0jK8J6U3XjI8M1SNLZty9SlNa0k/xPl6e8c2h/MO5YEgohw50
zG8r36D/zh9bZP+LQ3x8Iv2FoZxJ/qU+QzM3zD7rV3F9O4/LmPulX7BKT69L
f2goPy+a8SEhzH4Ab6o09sL0K4dy7w0ZXxfKq7wTY3byey7t8cdkn42qtOPa
0DP03zL9VlU6sn363bx3ozPe1FjdPOPHjRnG2NjjbJd+hyrObJv+SeNzy9D1
7/oT2lf29KaML6vK7WuG9oO9GJv+aWvL6+CiCuOs62bVaxt6D95h0/zztbnM
nu/sfd+b9QvVs9PRm6q69krwVVXXXhX6rZV65IWMR5t3e2Tb7lX18ry0lUI1
zp7Z9kaodj4k4x5Veenw9JOqtO9g1iGkcTPT2lXVuO3TT6jKZzfA66q6dnzG
B1TVQPCX82RP79cg44Rc3N9rcm76R60J0/O5tUP17hj0o0obz0u/rPG2GftW
lS/Yk2neF/Z2l6r9Zb13rRp/zfQbhGs18Bmqd5nz9Kp552Q8zJo2O/0zoTrv
sfSzQjXiMuyR9+XGfO6+UF12fsbLhc45q6bfynp1UbavEqpN2JMZoX1pXbVn
7NfCVXvJPu7Gb+RVNcvM9HeE6kEwtVYIV72r1pp1/iX9itaBK7J9eKje7Fa1
T+zR4hlfH8pRHaq4AS8mZty3qkYYGfp+vv259M+HatDl8/56obMEGNnfOPkV
7lrfwOOBxuQZ2f+Uqnz2BToUOgdcn22XhXTirPRrV9UNQ8zlpYyLgcYJfENj
yQksNrl5nnUYzLxkP8D4GeJn0YGe1gh0e++QjqAhX7IGodx6WLbdFsrp7Cd8
Y0+3Tv9Q6FzBHu7jfRyR7fd6r0/K+O5QbY5+vGIN+TH9uFDt8WD6B0JnlcND
PIEj72U8KVRXvJn+oFBNMjf95NA58kP4FtLAG9MfHdLqyTnGI6EzzOUhbIEr
3gss8m5ggdwAHi4K4RJMvsyahWqKF0O8glPvpn8nVMtvzz5W1T1j086sqkV2
Sfs29DsUGjC+SgfIS6+FctNn6XcM/bbxefqdQr9nrISGV9WUbdK3raqhWbON
vW7zZdv8VbX7qPQjq+qds9N/FTojgqnTjCswtU4VruDKniG+kG9/NSYR0ag+
J2TbvlX136sh7UA34Ot35iz55+pQDvop/c+hOvIcMFt17vok449DZ+IJobxF
/85V+8feHRXKu+Rccn6XqrzfKX3HqpqRPNyrKhf3JA9W1efHZ//+VWd6eHlM
iJtLZzy4qnYHC+Rv8IBGDqjSyYFodtX/VX7I9u9D/2dbJtuGVP2PBc1bo0r3
4PSKVbw+NVSLUIdQv3waqmFOCtU0xCeEah3qnHUzXq7qt4ZRGa9a9TsC+rpW
lcaemfHQqrr8D+mHVf0v4vRQrUOds176davq5VOrcAkm306/bei3Rjh0ThWP
JobqBmqGW0N5gm+/NKQvaMtxVboDNk6AB1X19z0h3sJZtGeq9Yda40NzbZNQ
vQWej63KneTNO0NajA5T75CHpvJdofqJ2umWkP6ivUeST6rOCUenn1L1/6iN
QrXa1dnnfxIf+WI=
                    "]], PolygonBox[CompressedData["
1:eJwtlnmwj1Ucxs852SVGKpnUaCoRbUT2IbS4VLaSsnWvra5ruRfZSvZ9LQpl
GZpsUaKSsrRqJC3KaBGZsk+WFG2fx/P745nz+Z5z3vO+55zv8lbqlte6Twoh
rEOF0JYYwlb0DKz+e+HP0SZ4EKoBfxA9/yHUCN6B3oXnoAXwk2gDPAENY5Fx
2O/DxWnXoJ3oPeyX0EJ4O3oLnoImwXV5ZhFcgG7Vs+h1uA36An4NDQheYzM8
G90fPOdmeBt6I3gPK+CRaCP8vN7B2o9hX4JKo/roM/QOY8+hjnBTtADeqT3A
tXlmIZyP2sKt0bPweZTF+GLsq2hbYs/TWaBV8Njgs2qTPFdn9jjcjr7VcKR9
GbsZbTXs8rSNsKfSnsL+XXvAflpzgvv0rg2MDw9+ZyftB5UNWjCEynBj2hcx
j6Cp2J2w18JlaJeiPPQ29nQ0AH5YZwpno4/gjjzzL/xm8N0213cG3/Gj8H3a
s+5CZw5PQSeD+x7h2Q7aI/wPqgY3YXwefAwtgQvQz/A0NJfxOtjXweVo6+nb
6buctmrw3TSMvjvdUQP4iHwy+MxWw4OZvwZ+QWcCV0QH4cryWbggeawocweh
ssl7z9Ez2n/ytxZH/eF+yc/uD/6WV5nTO/ib9K0H5DPB31yM8ezkuxwvf6et
hD07+Bndde3oWNCd66zrRu9dZ36t7hf7EPyr1kw+A+39MDqkWIzmHYo5+E40
Ff5E0nlF+9p6VDP6DnV3HdBg+DLWnAn3QPXhyfQNDI6xFvAi+ipE+9gc2nbY
K4N9fJZiA62A/0RD4CsZnwX3kg/B07SH4DlHGT8WHTv9gmPxNjQqOCazmNsi
OVbOBftqVeyjwT5bB54YHfuKuWuwr0ZVgu+0MXwXOg0/hWrB46NjUz46JRND
ih35ZIPkHKbcdQLdnbwn7eVscC5RDJbP5JTb4THR3z5f78Aenpy7luhM4JHJ
716KjtN/IjoW+qN79L7ktbPQCHgX45vhEtGx2BItD47Jw9F3rLuVTxdm/k+K
QXgPStjdsb+Dd6Mu8N9oNNw2+GzPoS+Dz3hEtE/Jl35DVyiWku++Z3DslcHe
FxyDd2AXSn7XOHSxnqWvK/xjsK+VTGb5XB/sEtiT4M5aU2srxwT3KffnR+cS
1QDlwh7RvqicuF+xj7YHx1BPuAjP74UrBu99X7Rv6wx6wZ9G+/b3qC9cKnkv
+sa5+lb0VfCZ5ESfmc7qWzRZvkDfsOCcvx5NR1uxX1GMMt5ez6CL0NnomqNa
s0s+q7XRFngZ+gPujB6ER6IJ8r/kuy5F/0blqugxxVCz5Bys3HsGeyy8Lnot
fUN37BzlcHhicK1cG10bVTN76eyjz1rfGJWbadtjfx2cq1WoxcrZ30TXONW2
bdj14IbJvq+Yz6b/v+jarTVUe3UG2rtqcBW4enKuzkOLo3O0cnM37OvhG5Nr
S67uW7U6unarpuTCxZP3Ip+4QbUyeu7c4Fq8MvpfQTVZuW95dO1VDpwJN02+
G92ZfHVgdC6Wz+pfZGByLtc/iWr/DNW/6H+AM4rt6LvTHZ2EmyefvXKU5laP
F0rlhWdUS3dnzko19SBcjjkHdDeoZnKMK7aP647k+8l3PTQ4d87IsHLoHsUq
ahUc4y0Zb5Wc69R3CzyK8b7BNbE0dv/M2SqnboJXRZ+ValoFxodG51rVFP2b
1Ej+Fv2jjJa/JucqrdkZ7iKfiK7Becl70l6K0J5Hf0XnDuUM+fYo5pTM+Lhi
aS/6OGRiKjnnKddpTlG4VnSs/hAcu4pRxaZiWLHdO3pMMa7cNT86tyiHPRFd
M1Ur5fNd4W7Jsap/mKHJOVe5tpj8HG4TXZv1Tct0dsl7UU27FNYPbOHoOztF
exp96CMIDzDWOvpfVn1NknOycrFqiHLzkOR3bcYeAOcn507VHK3dQTky+h25
2L9E/zuo76bkmFGsqIb9DwJXcNY=
                    "]]}]}, {}, {}, {}, {}}, 
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwl1He8zmUYwOH3HCJElIQoQkohs2SvsjKOUVY2qVCypUhky957Z0VRlMym
HVpGGSGjRdF23R9/XOd7P897zjue9/c7edt2S+malEgkXvbjMt9SPzmRSNEG
ulW3MYnx1kV0O8X4i7/5k9b8Q3Em+r2p2obDNLFuqE/oRzqNJ83NaEpb61ba
mhY8RUs+ieeIx0lFB+tk7agzmWwupan1Br4zfx+vw8NksHcTZ8wL9aw+T0Zz
X71ds3Ha3IfbzIvjd+K9aTf9QbPqrXSN92vdRU9pb24xL9Sluij+hufM8/RZ
nauf84y5iXbWYxqHnt48R5/WThyN5yadebZ2jM/MkXgubjS3px2NrR9iinlW
vCY9WGT9Ypwvj8RZWy/QnmQ299Is2p0XyEVu7uAu7oy/pwf5kq9fF3frK/om
M8zldCcV4nuwXq6DWMEs64q6m0cpbT1MS+nweM/6mJbREfE96ch4r1pDy+ko
LasVKE9N6z30MvemJ6viO9NNupLZ5kp6j76qBfReClLZupDez30U5gGq2C+q
g7WIvqYPatW4jnVIXOc6VC9wkeZUo4T9kvxk/pkW1GKuvbU6mormMVpJB8YZ
8oV1beaZx+mHjIgz4PU4ozgvDtqvS434/HFmTLDeyAbesB7Lb3HOWj1eK+4d
68dZYH5Pv+HruKdj315dalGH2tSz/xV1mG/9rn7JofgMcR/qKP1Vx8dnN6/T
Zbo+3gdDze/oEH1bDzA4zjO+Cwbxi72xVI7zjbOPa4v99vpp/7gnGcBLcRb2
17DE/JbuZR+rmROfV3dRnvOc40cGkt/jZXW6LtMB5Inn1by6VHPGa2p27ac5
dIneHPeGZor7I86EqeYyepITHI/7mbT2S2ujuIdJY91ZP+PTeH0W25uhH9CJ
SXHd6MdxLZkTJPGfdTv+pT3/xzXGDhp6vBEpTLFurO/rZCaYi+oftOJ3rnIl
rmU2s4WJjItrXxtQz3wp6fr//GveZLkO
                    "]]}}], {}}, {
                  InsetBox["\<\"\[Mu] = \"\>", {-1.8, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["0.2`", {-1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {InsetBox[
                   SubscriptBox["C", "J"], {1.4, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["\<\"=\"\>", {1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["3.3200000000000003`", {1.7, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {
                  {PointSize[0.05], PointBox[{-0.2, 0}]}, 
                  {PointSize[0.0125], PointBox[{0.8, 0}]}}, 
                 {PointSize[0.007], PointBox[{0.4463998339305619, 0}], 
                  PointBox[{1.2771956561278897`, 0}], 
                  PointBox[{-1.0806611991222994`, 0}], 
                  PointBox[
                   NCache[{0.3, Rational[1, 2] 3^Rational[1, 2]}, {0.3, 
                    0.8660254037844386}]], 
                  PointBox[
                   NCache[{0.3, Rational[-1, 2] 3^Rational[1, 2]}, {
                    0.3, -0.8660254037844386}]]}},
                AspectRatio->1,
                Axes->{False, False},
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                Frame->{{True, True}, {True, True}},
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLines->{None, None},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None, "TransparentPolygonMesh" -> 
                  True, "AxesInFront" -> True},
                PlotRange->{{-2, 2}, {-2, 2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.02], 
                   Scaled[0.02]}, {
                   Scaled[0.02], 
                   Scaled[0.02]}},
                Ticks->{Automatic, Automatic}], 170->
               GraphicsBox[{{GraphicsComplexBox[CompressedData["
1:eJx1WntY1NXWNvOSHCeMsHTKC6k1Xkq/jqNp6ioxMjMdyQtHPaSRWodMj5dy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                   "], {{
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[0.3], EdgeForm[None], 
                    GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxNmXnc11MWx++9ifZFyyNKm0pp1a5F0SppIVlLhSI7kb3sRqisxcgWEdnX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                    "]], PolygonBox[CompressedData["
1:eJwtlgmQ12Mcxt/3LbGkFNIgNIwUGscwJUUUonRttY6lXZ26j93usl2rKN2H
ipQSqRTRMSklHXSMOxKii6TQSEk+zzz/mX3m/Xx/7/t/9z2+x1s5v1uzrimE
sByVRHtjCK+iQfCb6A94E3oRfg/NhZ/kB8fhLHQ33JBvE+D96AC8H10JF6G/
4I/RTHglmgN30Td4IGoPP4wmwWUzXJ85DwR/uxW+BVWF96CKcA/G7IC3oZfg
l1FTuAT6Hq6FBsBvoBqMvw+7GvwTOgI3QVPgZegc+p+L7tuICrELUBX4W/QQ
fXWw98Hj0V1wbdQp+FsR/ddiPwvnoXuxS2JvgK9BP2DPRv3hheh2+kZj71Vf
8Nqm8K1MZo0zaD9Dr8DHUAc4G02HN6MP4YnoIDwVTYAbJHM3NBS7qv4H/BSq
lbwHrf1nrQ97DHbn4DtrDdeNvqt5Wg/956EuwXdwFVxI/5fwF+gB7PHR/0tn
eBP2zcl3ozMbFb1H7e1HdAf8PN86wi+gD+BZfCtH2xU7n/YeNBJeh66nr1ry
2tugQfBG+qfBZ9AiuA/6Ch6m+6F/Enb34DFae+nks9IeCuSL2M/Aj6PL5Ozo
UZqdOiP5GyqG5+t+4UuT+4agyfJJ7F/hw6gh3JxvPeBDqC9cOXktuehyuLfu
EP4U7YLXRO/9NbQaXiT/om2PXUx7m84Ibod2K1ZQY/h1+ZDWHu2LuzSH9q4Y
hQfrTuH50bxI562x0b9tjr6D96B+3nYYAd8on4fbBp/N0+hE8BkVy2bMArik
7i3ZR+QbGjNPvoDmBueIUfJ91DfYZ0/Rd1JnBs9GLeTL9F+oc5YPRcesYnWO
fgN/Hs2KkVaam/EVaRthj6Wthz0x2Ge1tpzoubXGlvBxtEq+i3ZoLsZXoC3A
rhmdE5QLdAbyvcbYNwT74GD0dfTdt0YH5ZeMOQkvRj3gs5Jj+xTqCbeJ5n8V
b9hFyoFwzPw2j/af4DmGYQ9P7ustn4TPRPuKxlRJnlNz7UYj4Y70J50Rqh2d
Q5Q7WqIB8FuZeDmbtibj70yObcXYUuUH7Czlaezu8BJ4BLxEMQivy+Tbd9CD
9DdK9mXF0Dj6NqDJ8LvBcymnKZdpztHYNWj5C6Wic2Hd5NyvnKhYHp+8Nq1x
BHx+8l1oT73gUigf+7T2A/dD4+D/0O/Klcn8tnKAcgEqD/8dHDurGFM9OIbe
RwOTY0tz5MlfUYvgGiVf2smYwmCfkm/IZ+QrFTJnMSO59uhMzk3OOco1m9BH
0TlAsa8cnEPfI+jPYB+flOxD8p3StENkJ/v6b6hZck5XLj+qPUTfse52NXaT
5JhTrB3B7qNYSs6dqnnL5TfJZ6WcrlqxIjpXqGa0x+6AtgefUXM4O/l/ySdb
ab/JsaQ1t4XbJZ+lzki5bUr0WpXjdFYnMmvTmZWhv2ny2hTj5RTLaEtwze3M
2EuSa3k2ulrnl/E95ZgG0TVXtXYsuh8+hJbCY4J94bpk35dP1Il+g+jtkYN+
ic6ZypX6zeLoGFVsyqeVW6ZnYks5RrV1ZfTcqrGKlf6KmWB//ASeilYEv0n0
llgQnev1pjgWXaNUm/Qm0lvlNFob/GY5rLOK3ot8cG10TCmWlKNUG+TD8l3V
iPXw0ei5FFPbot9EegvNQlui31h6W81Am6NjULGnN1d19jcyOlerRgyJrgmq
Bd8ohpXbo2NbbxC9fS6mf2vwG0hJPybXVtW8znCn5Fo4NLi2L4xm1fhe0TVM
tasSKgEntD74TTON/u3Ra1fOVS3WG0FvA9XkmZkcodygGqaz3hq9N5257mJ4
dG3XnZRl7AVoTXBOUe3cF13LVEPLJ9c01TL5XL3omFOs6Y3ZjjYr+e2mnF4B
vijZF3UGufAT0W9V3aHeTopxxbbeUI/BudG1UWu4AqiUvHftuXv0m1NvTcWY
al+36FysGqha3DPaV1WTl0Xfke5Gb4r/AVZyeME=
                    "]]}]}, {}, {}, {}, {}}, 
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwl1Hecz3UcwPHfHQrRIC1KVFK0tIyIzDtCh2xCqMjZoxRZ2UW6jDurrOLO
HtlK02oa7UIZhXZkPN8Pfzy93u+Pc+P7/ZwS7dPTuiUlEokB/rg0OZH4X1tq
a22l3+i3ZDHGXkG/oxJF7FdwOV3tV+oDOlZn69OcprW9jbbRH/R12prb8Rjx
DXTUTrTncTrwk/PO+gRX091+lfbQ+bxkflCv0aIkSIrP4ewhJpgn8qx5Mc8w
jKGUcX4rFzLEfouu0N7aUXvpBZTmZnrG9+W8h+bhBXMpXaYLdXnS+WfY3Zyj
6Zqtv9AtftZ4HnpW+1PCvDB+Dl2k/bje3Fff4k262rtwxtyH4uaneDKem70a
L5sX6M8cpAaTnD2ve+hATV51tlQHcaN5sN4UX48+3Mld3MHdlKMf/bmfUT7+
Ph2ta3jNXFsPcZi1LHL2th7lV9Yx2VmK/kZD6tgnaO14N5qij+h0fVdfIb/5
ObaaZ2ia1tVJmqoPU49G9mPxXuMdM4AN9oG6V9czxZyqFXWsVog7SiXq2qvE
HaIy1agan9t5dR0X90jHx3ONr6tTdWPcPTYxzZ5JZ3P9eNbmWlxEgbi7zhoz
0/xevIf4OHOGNtBB8a74w96EWeYpui/uqXlYvKu4o3Hn+Nt5cxqZG8ezYZr9
Mz5llH0kF8dzpSEvxr3xd814w/yJnuJk/K7HubPmNKEpj9LC+X80jd9X+y79
l38YEXdQh2tBppp3Mjv+rf4V750dcZedbdc/+Zgc+7a4P3wU99z+of7O+2Tb
P4h7zTsssG/R45xgM1nOGuiRuE90Ip+zvIwxl493oBm6WkdyTzwHvVdX6e06
QsvqcL1NV+oNcfe0pA7UJXEnzdU1t+Yimeu4Nu6L87b0opi9tx5gP3OZ52ye
7qYn4+1V9Md4F/Ex9jn6JemMi7uo38edYY59ln7OF/F7Er8TdOEyf1eYQlS0
f8XXZDLaWXltRQvzJcnn/38/B5ZNugw=
                    "]]}}], {}}, {
                  InsetBox["\<\"\[Mu] = \"\>", {-1.8, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["0.2`", {-1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {InsetBox[
                   SubscriptBox["C", "J"], {1.4, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["\<\"=\"\>", {1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["3.31`", {1.7, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {
                  {PointSize[0.05], PointBox[{-0.2, 0}]}, 
                  {PointSize[0.0125], PointBox[{0.8, 0}]}}, 
                 {PointSize[0.007], PointBox[{0.4463998339305619, 0}], 
                  PointBox[{1.2771956561278897`, 0}], 
                  PointBox[{-1.0806611991222994`, 0}], 
                  PointBox[
                   NCache[{0.3, Rational[1, 2] 3^Rational[1, 2]}, {0.3, 
                    0.8660254037844386}]], 
                  PointBox[
                   NCache[{0.3, Rational[-1, 2] 3^Rational[1, 2]}, {
                    0.3, -0.8660254037844386}]]}},
                AspectRatio->1,
                Axes->{False, False},
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                Frame->{{True, True}, {True, True}},
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLines->{None, None},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None, "TransparentPolygonMesh" -> 
                  True, "AxesInFront" -> True},
                PlotRange->{{-2, 2}, {-2, 2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.02], 
                   Scaled[0.02]}, {
                   Scaled[0.02], 
                   Scaled[0.02]}},
                Ticks->{Automatic, Automatic}], 171->
               GraphicsBox[{{GraphicsComplexBox[CompressedData["
1:eJx1Wnt4zFf6R9waEn4qLkHc06lWWe1oS3i10ZZQTS3S2poiWDVN3dnRuFSY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                   "], {{
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[0.3], EdgeForm[None], 
                    GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxNmXXcl1USxe9cAUEQMEAFpSSUEFGkBF4QAUXFLlYU7G7sQFHsVkQRUXHt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                    "]], PolygonBox[CompressedData["
1:eJwtlnmUzlUcxu+9qpNKRftytIiUaN/r1IlCg7I1RAaDsk6WYzfGNspOEZks
ZSdbCukoSqLSIiQ7JSUOWUI4fZ6e+eN5f89zv+/7e+/9rvempjm12qUQwnxw
DjgYQ5gLesJngacxVgJl4VvAn9iqgm7waWAV/EvQAl4BPMV3KyZ/twzIgDfE
Pgy+M5jXYG1X8NoM9EzwHLwIuB9bHXQp+EZwL7oW+gr4T/pPeA5rB+Da90fo
vmADvC/4Cz4LdIVPB/3g9yXbGoKH4A8m720T+Bj7a+BneD4YA6+NfQS8JbgM
Ppy1rfAvQF30NaAVfDf4Fls99B7tHZxF/wDGwBeBofAnsL8Ozwb1dBb0Kvht
oDg8P/qsK8Ah+HyQC58NntFe0Nvh24IPvQE9VmcHk9GN0eXgF/I8BZqAN9Dz
QGXsVZJ/qxi+jC2iFyu24BX0dHQJnhnoqsl71N52gAPw6qAXfCa4EvvIaNtq
8Cb8eflI7wId0c3BePh7oETyGXW2lcG5cwt6bXAO/YKehr6UZ0d0C3hz0Bne
RZr1qehiPCuhJ/GcEm1bAhpgy0a3g/8KBqMHJb+rANwD7xOdO+vBO/CXWNsL
/x28CC9gra3OAjLR49Btgn24Dr6QtVsL126H94CvU+zB2ugYyPet0VnwRsl7
1X8MhH8X/e5/QDn0Hcm/LQ6+j96T9jIa1MI2Ojr35NMK6N7KKX0XfA5fwFpp
ns3QpeGlVCPBPs1j/W50nnwT/NvD0bmkd9yA7UawDM5yWMZHAbooz6zgWngg
uTZUE3XRb6PP41kSPYDnENAUPhc8ju0x0CR4rTO2m9E1g2tasZvMWofgGObp
PMpZ/RfowNpVybmkHL4Wfl2yL1Rjyr2y6K+DczA32ifyxfWgKPwC8Am8Prg8
uWZVq6qxXeplIFO5A3aqd4E68ImqQcUWvBD8HxcplmA5/FPlIN8tg+4e7GP5
tgs4HOzjQdgfTT6LfJCJPgbel6+De5NyULmnHlUe3it6r73lI3T15NpRTzyO
bVRhbAcH+34gulFwDMaDq1lbE9xzxsIXRce6CM+J6mVgXHCNj8B+LqgGPwN6
wpdg7x+8x73wbeAsfIp8AD+tnIePAj+q14APgnvaV/C3lIPBPVK9aUX0XtWj
zkTXhGpB79gR3ePV2ycE9+7p6IPBPVy99TMwKLjHjsReOTo39aHa/jd6PqnG
J6iWtQf4h8F7+yZ6r9rjang+73gXPjTYV6pB1Z581lWxAT3gM8Al2B4Bm4Nz
srF6NTgB36ccU24nc+Xwk/Bh0b1cey6Jbgb+CO5Z6g0Lo2OrHjEAW7/kvRwP
Pkv/ZK4z1dd8TO5d6kHZej84FfzO4fCt0bE7Hez7NWBkcAyeVWyTZ6tm8NRo
H8p31YN9vT96VsvnQ5N7pHrjSZDgQ5L5UtCgcIZodgzRmbG1T+5Vh8AJbCej
beVBd2w56L/hR0BG9MzQrJCPa0TfKXSXUA2q12sGafao5x+Nfod+OwdUi57h
mt2qUc2mLehOwTNKvUo1ptpSz5oTHVPFUjVaRb1UMyO4B3Xj++cnz37tUXeL
Ysm1rTtGS9Ve8uzbD7LUG5Jnu3z8MDwXHAvOEdWKYqJYqGZ0N1ENqvZ0Rzki
XxT2yj5gefQM1OzTHeBVdG0wILhn7YuOmWKlPffiuxcn9+KjwbnQKbo2lROt
0K2T96qa1mzSHUR3D82ozdEzUrNRM1izYmV0rDQz2qLbRN+dNAM2qdCS7xLq
GXfB70zureqB66PvNLrLqOY2Rtfg/7WnmoTXjD7rZNBR+03OFfXUxYUxVmzV
c2bDt0f3At3R5kX3ZPVi3TkXRPfsScF3oKXRM0ezRj5TLNpH+0Yx2Q3fE313
U4/snLwn7UU9+rfoO6rupuoJqm3dUXQ3UY0rt4ok575y7D9wUHq2
                    "]]}]}, {}, {}, {}, {}}, 
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwl1Hecz3UcwPGfo0hUlMoohIYIUSQayLginV0UF9lOZM/Idbg46+zMkiiz
ZTSsBg2jTYMoiiJklZ7vhz+eXu/P5+c37vP7fn8lU9NSeuRIJBJp/imRlEhc
THe6WffQg/oyaeZF+juHaEBpe2UoRT/rGzVZJ+pS7c9rTLJ+UA/TkJutb+Em
Blr31mfoSS+e5k/7ffRWylGWQfZWkm1+WMvrEL1E88bzzU2Ybn5HR5HJWGra
q8EVjLG+W9fpcB3G5VTnLobGZ/DYEL2M0ea1zDK30BM8x2Drt3WQvqXHGZh0
4SwHaB5GmqvoG7pc39QR3G5+Vitrik7T1XFmmpvh5kpxrvQlvqRHmGpepX9z
jGbMsPe87mUfzZlpb41mcKe5GlXjPalFbe7nAeowgnrUpy5ZnvcBs82t9GR8
r2xkhb0NeorTbOJFe4/pGdrRwnp6fBadoZ/Fd2f+VFvqTL02Pjefm+drqj6q
s7SVto7X5Enrs3Hm5lFxpnxona6/6H42syWuNZLtPxTXXLyGdaO4XmjIZOvG
2kZTdEqcq2bHtaOP6xz9KM6aj5lr/YQ21WYUpghFaW9/gX4RZ0Wb+L/xOmRw
3t5TvGSep6lajHa0jWuL3vY7sND8bbxfzPG68Vx7Hbg+3ivOgnFxv3jsAHsY
b71bs/Qiupi7aFc60plOUfu5YtZF+r3m1CQyeYGxcX9wHfM9/l3c//E6mkPn
6DcsM38dPxz6pa7Wr+I6YBevW+/U/9jOKusdcZ2zLX4XrLfqOf7lE+bFmeg/
cR3Qi2vsXc0EcwNtqYX0Kq5kvPX7LDW/p/fF+eg98ffovbpel+i7WlALkG6+
Q5tqfs3HpVSkAo3td2cot1kP06P8Ffcxr9pboT/H7wBTrBvpkfjbWWy9TH9i
AJPjmtQ/4rm8Yr1Ef+DHWMdz6EPJuOf1hrgf9Vd+i2uICXGfale6mYsnXfjd
/h9jE7nW
                    "]]}}], {}}, {
                  InsetBox["\<\"\[Mu] = \"\>", {-1.8, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["0.2`", {-1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {InsetBox[
                   SubscriptBox["C", "J"], {1.4, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["\<\"=\"\>", {1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["3.3`", {1.7, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {
                  {PointSize[0.05], PointBox[{-0.2, 0}]}, 
                  {PointSize[0.0125], PointBox[{0.8, 0}]}}, 
                 {PointSize[0.007], PointBox[{0.4463998339305619, 0}], 
                  PointBox[{1.2771956561278897`, 0}], 
                  PointBox[{-1.0806611991222994`, 0}], 
                  PointBox[
                   NCache[{0.3, Rational[1, 2] 3^Rational[1, 2]}, {0.3, 
                    0.8660254037844386}]], 
                  PointBox[
                   NCache[{0.3, Rational[-1, 2] 3^Rational[1, 2]}, {
                    0.3, -0.8660254037844386}]]}},
                AspectRatio->1,
                Axes->{False, False},
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                Frame->{{True, True}, {True, True}},
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLines->{None, None},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None, "TransparentPolygonMesh" -> 
                  True, "AxesInFront" -> True},
                PlotRange->{{-2, 2}, {-2, 2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.02], 
                   Scaled[0.02]}, {
                   Scaled[0.02], 
                   Scaled[0.02]}},
                Ticks->{Automatic, Automatic}], 172->
               GraphicsBox[{{GraphicsComplexBox[CompressedData["
1:eJx1Wnl4zNf6j6VpmwpKbHPTNNZOKXLDlKtx32osuX64odQea1O9qaWEGIII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                   "], {{
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[0.3], EdgeForm[None], 
                    GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxNmXe8V8URxXeXIiKIiBSBR+9VykMQqQpYMPYAioigKFgQhGBvGLvBhooF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                    "]], PolygonBox[CompressedData["
1:eJwtlnmUj1UYx++9SU77vpxWIRLt+36iLCU0KMoylmxTSCEGMRrbZIaISBHZ
mylZD6XEkZCiVIRGJFFaLNnO6fM9398f39/7ee59f+9773Of5S3fussTz6cQ
wgeoDPo4hlDMQHmurbFrwcPhn+HtaDc8HfWCZ6BBzH+J/Tp8EB2Bv0Zj4fko
i/ki7PbwCHQedgF2KbwK1cauk/zsyugRuDHz18Db0HNwGzQenopuYL4P9kZ4
A1oJT2asHNeO2NXg6mg9fDbqyHg9NBB+Fy2CB6HN8GB0KvcOxP4B/gT9Ae9D
lwf/R2s5i3uWB6/pOriH9hj8jkbw6YwtgyuiB5PHxD+h1XAJYxW4dsJ+Ch6T
4VGoP3w7Y3nw0xI8jrHOwT69A7sB9tXBa7wb+y5UCf4R7WFuNuoLz0a74IdR
b3g6+g2ug/rBs9B4uDn/3605lOCT0GKtTT6Dh0X7fgVaDL/FWFmuLbD7wX1R
S3goegC+H7WCs1EN7rtKMQG/jBrq7PSOjE+ncM3B/hOOwWdxZ/JedCZaeyXs
tcF7GIA9JPrZxeg9eJrOVGtHZ/JzBvos+IzOSd6D1r4SbeXenqgJPBm9AFdW
DGltqCpcRTEHr0Pl4StR/eA9yHfXJs/JhyfDZdASeCnqxvwVyXvVmk5LjinF
kmKiB/xS8tkOQu24/yhaANdETeBzk9daBeVi34I9AG6GHoJroK0hc+bKpWjf
9UTfyR/yAddu2F9wbYq9C74VHcZei8bAH8mn0Tmk3LlU/oZrJuee3rEl2sfy
7TuoA9Bee9Be0ETlWzQvREOYG5z87gnKGZ0F8wXBNeUA3DI61ku0JsUP9iat
Hd2I3Qv7yeCcfgy7GfZr8A50G/bj2OcH/0dnPTQ6t3Tm8xTb6PvgHFoGf4ra
wtVRW+1HZ8K1hnIYrph89oqxlnCL5DnlRD733Zcc24rpS+BstAfuqhxkvhD7
OHwCXQY/i/YG+2hYsk/ki8PyMdwW/a7YQ3O0djQpOGcPqXZmatfI4LW+Hf0u
rXkc9tzoWNChd5Wv0d/BMTuVsV+jc30/GgtfwPzq4BgoB9+LtgTn7HLm87Cn
BJ+RavsSNCy4xiv2K6A1wTnQCs5Hh4J90Ea+Sd6b9qRaWIJeCa6Jo+AVqAj+
MPhsdOY6a52R1qaeoV6hNXaB1YBUq7WnznDH5NjeF1w78lSzgmvISNSIscLg
ntIcuzH2zuB3NoEvRB2CxxoofnRG8C+okPsbJvcijSnW6ifPKebWRNdI1cbR
wb2lBXbV4B6j2iWfy9eqYaqNWaoBwTWyV3LOK9f/QX3gU5Jr57/KCe7pntyL
lOM71QuS9zpNz1S9Sv7vHHQPnIsOBJ+huHP0szSm3qKcV65XyNQC1RjVFtUE
9fKlXKsF9/QC+Zvrf9hH0PWqXdG1X2fYHZ6FcuGZaBu8PbpX6gxKo3NMuaUY
qh39TaBvgSztWWtDw4PfqdhRD1fvVgy9CT/DWE5wjxsBd1GOwkdR0+iaoVqh
Z9SM9pF80wDlqBYkfzvoTGZGr1lrVU1fGN0z1Cvyg2uHcihkaoh6adnk2q2e
2knnH32vemDdmOmpwT1jBrw5uhbqm6dWdE9VL5WPLuJZFyfHimJufvQZ6uxe
Da5te1H/4Bp3HD6BJupd6Gb+e1NyLVZP2cTcMbQo+J4d0TVHtUY+apfsM/lK
NWckXJT8LNWk3vCC6He/rz0m+1C+U06PhldF15q5il94o3wU3JMmwOvRG/A8
nUFyDVPtUswcy8SQYkdrfBSul1yrVXP/Uu2O/nZUTfk8uiaoFihnv43uIeod
+qbLhg9G9wrFxLroNWpt6llfRfcw9S6t6ZvoNWpt+sasm9xD1TtL0Ybob1B9
e2pPqrUvRsfmpOBc3R/tG+VscfQ3wuTgM/offht3tA==
                    "]]}]}, {}, {}, {}, {}}, 
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwl1He8zWUcwPFzL0pGg2wNKSN7hEgl2VEZya5LZI+MbBkhQsnKKmQnsnel
hUplVyhlJDNlVfT+vvzxvp/n+5x7X+f8fuf33Dwpnet2SkokEl38aJucSMzS
/bThGr8ymw5em6NHOUIV7rOXj3vpZs6vVfVNXaAvsZDx5mp6nBoUNN9PAXqY
u2hXOtKZTpyw300LU4RC9LT3AROta2lR7a3Jmop21k8yxXq1vsIIhvOIvYe5
iVfNFXWdDtD+pOUhKtCP9l7rqzcyzHot06zr6RkG0ce8SnvrSj1NL+uX47PG
tZHEQPtldLm+ryvifSkd760PaB2drB9qd03E57AupUvjXmpbrc0k62V6ipM8
zdv2huhBDlGXqfbW6FDKWZfnwfg8PEZlKlGFxxlEdWrE98Uof7ee6dYN9Syv
s5El9jbon5xnEzPsNdK/aMGz5gnaUCfq1vj+rL/URjpJs+hQtlnP0ue0iU7W
xjpFm+rz+jeDrT+O71Y/0SH6s/7CZj5iDLXs1+YJGsdzoU/FfWZs3DNtovV0
XNwvfUPra1OdqVviWeZT3jE30wb6DFnJRnZS4ozo9vgeaGbdgubx7HDJXive
s56hKZojrimuN57HePbtt2SO9a6457wb78uL9tqQm9a8wJg4K147zD7GxueP
a+GquTX/8h9743uzv0f/YXScMR2luWhFS0byGiMYTk5m+r3dzI331StxDtjJ
Ynvf62W+ZZn5u3ju2MEi8zd6ka9Yav5a3+ILFpo/1wuM57O45rhvei6eHzpw
u73MjLauGfdfM+lt3Bqf2VxVG+gtejMZ43rMj2p9zaDpScdgc9l4HvQGTUNq
SlIinpm453G+KWbuq8XjXOsfcYZZYF6iB+LMM8FcU3+P62a+ebH+FOc5rjnO
lh5jXjDP1x/4MZ6NuMdJ1/8P3+G1rnpnnFG9W/NwF3m5J86r/d9oZ90++fr/
7v8Bn2G5Fw==
                    "]]}}], {}}, {
                  InsetBox["\<\"\[Mu] = \"\>", {-1.8, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["0.2`", {-1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {InsetBox[
                   SubscriptBox["C", "J"], {1.4, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["\<\"=\"\>", {1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["3.29`", {1.7, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {
                  {PointSize[0.05], PointBox[{-0.2, 0}]}, 
                  {PointSize[0.0125], PointBox[{0.8, 0}]}}, 
                 {PointSize[0.007], PointBox[{0.4463998339305619, 0}], 
                  PointBox[{1.2771956561278897`, 0}], 
                  PointBox[{-1.0806611991222994`, 0}], 
                  PointBox[
                   NCache[{0.3, Rational[1, 2] 3^Rational[1, 2]}, {0.3, 
                    0.8660254037844386}]], 
                  PointBox[
                   NCache[{0.3, Rational[-1, 2] 3^Rational[1, 2]}, {
                    0.3, -0.8660254037844386}]]}},
                AspectRatio->1,
                Axes->{False, False},
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                Frame->{{True, True}, {True, True}},
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLines->{None, None},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None, "TransparentPolygonMesh" -> 
                  True, "AxesInFront" -> True},
                PlotRange->{{-2, 2}, {-2, 2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.02], 
                   Scaled[0.02]}, {
                   Scaled[0.02], 
                   Scaled[0.02]}},
                Ticks->{Automatic, Automatic}], 173->
               GraphicsBox[{{GraphicsComplexBox[CompressedData["
1:eJx1WXl4zNf6p1XayNDaylTR3MiNpZZc8Usr7UuCaivkUqQtYymqptfWFGMp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                   "], {{
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[0.3], EdgeForm[None], 
                    GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxVmWe4VsUVhWcGRBBQaUov0otUqQqCCGIXEANRATEgWGj2Boq9CyoiKipi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                    "]], PolygonBox[CompressedData["
1:eJwtlnmwl1MYx885uIQhMWhEezdl3/el0V7kVkpJe9Hutum2a9+UEu2b9lU1
EY0kFRGl0qJVJUm0iYzR+Hx9f3985/0857zvec/yPM95ijZpn9MuhRA+Qhej
NjGEJugteApaAO9DE+A8VBe+kg9Ww6VQC+yqqAe8HA2Gn6J/IPwSuhweRttO
+BNUCbsOdongtp/h6qgXPBP1hR/inb5wHfQwnENbEfi74G/z0bYqeIxn4PJo
B1wc1aB/LPZ5uAB6MLlNvBm9AGfRthIuhlZg90Fbgv/5E1wFdYdnaM7q5/0T
cLb2CftR7G2au/YM7h89tw/RHPgImg5noQfo7x39729RL/h+2vpoLugo9vzo
vX0P1YJ/RXPgQsH/Xo39W/AcKmMPx94N70Ln4O/RaPh9tAZeyDvZPBtg3w33
hDfBX6Nm2C3QAbgdqkBfNvYXcFfUEc5N3vs3UGm4FKoa/M4tcCFUGf4c9Yj+
h8YuqPPAvjm5rzMaJF9A7eGx6Af6p2JnRbcd5jkLdYKnaQ/gmagizCMM4N3N
wAj4d1QP+x3s5vBw7Sm8mLaymbYG8Hi4RfA3xbGLoirwevQVfROxL+LZTP4E
j5LPw0NQc3gabfl4VsC+XWOjavBGVJH225L5dfQl9iLsMpkxLkn2CfmCfKwm
7e9i/wPfhK5IjgnFgmLoJP0vR69lHupH33rsQfB87TG8DjWEy6JL6R+qM4c/
Rp/Bs2m7jmcZ7G941sfeC9+D9kbvqfZyvOZPXwVUMjhm2tLRFL0NT0Wz4T3R
7+pMmsF/oqXw0+gP+ToaCS9WvDFWPezBOlv5CHwGLYDvQOXhYsl73wXV1tjY
kWdh7MuS16S1KKYH0v4I9tbgGCuXHLOKVa15FTyOtgvyBa0R7kZbzWAfvzX5
jP4/G+WIZB+Xb29AhZPnpLmsQz2xe6D6wTlrv75FOfBEdABehmrDk9DjvPtY
cq7RHIfB7eg/BZ9GVyf7rHx1LboRboMOwbmKUd7tkDyWckBLeDA6CR+UDybH
jGJFbZ2TY1KxeCTYlwYwxovBPqVctzw6lyjn3YDdCv0Iv4aOK7aSv52Nrodf
Sf5Xh+BYLpK8F4rps/KFTGwMk49pP+g/Ch9DryavWWvVP5Q7leOU25RDx0Xv
gdYuHxya/E/9S3u0gf7+2JODfVy5pUzyWSnHKFZLJp+VYrag9hcdhjsq5pPX
qLWdQU/A3dFxeDvKk28l+8Yvwb42JPouipnYb8CzdHAOkC8p5yrXyqcaYzfU
HsL75AP0NUrmRWiC4hW7ZXCO6QuPyORa5WjlNsWMYiUrk0tmRM9dOaUWdg5q
jL0nOHbXaszgGFYs1UzuU0wpl3+aie3sTK5TjCu2lfPmJ985umtKRO9Fq+i1
a090drqzdFfpDJWrFKOKTeWsKdF3gu6C1mikfD05F2qOTeFrk/v2B9cGTZJZ
NcIseGl0bsvP8zz6O7oWqIES/U8mn41i7C6dl/YB7o0awaejc532tHL0nTAN
fhZVir6TZ8Dd1Mb31ZNrjzWaM31XJbPO9Bq4AHpTc0f/0n9BPhf8z/vouzf5
rlohf1ZiTOYiqHlyTlQu1B25JdoHdPYac3J0jaTaSD5yKDpHKzfLpz+IjjnF
Wr/g3HQM9QzOUbnaq+S7UXfcSux+aG7wHE9E50jlRrV1gudFr306qhZdM6hW
UI5S7aUaSrWTarDFcB6aFVxTHdS3ybGrnDEaeyMaGpyjt8Jj0cLgnL4tOscr
t49Sm2JXbfA57UFyTlMuU5tqw87RZ6UasbXiAZ0Nznltk8fQt4rhSby7PXrs
JehO+rpE+4pqrrrYY6LPTnOcCu9CY4LvoLkZn5ev607eET2mxlINpLVsis5d
WlNX3cXRZ6Gaamd0zaRaSWMqt8uH82dyvPZuSbRvag8Vm6ei72bF6HO8+3zy
Xac7+a/omkG1wjKdT3LNqFpRNVoV7KrJtZru3N3y7eh3dedqr9pH5zLt2aLo
O0h3j3zmP3CTg4Y=
                    "]]}]}, {}, {}, {}, {}}, 
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwl1He8j2UYwOHfORVpEJFVRkRGidA0IpKRkZWVvXOUrLLJyoyssmf2yMxK
SaGlMqNoUEZoEIrr/vjj8n3u5wy/932f9+RunlKrU1IikYh/ZiUnEvP0EN8z
mzm8TDZfe0Wz69N6j+bgbnKRkwr279U85OY+8lLRfn69n3wUpADP2C+sD1CI
LuYFLLSerz/zKu8xxl4l/YXKFDF30we1u17kX1pTheNUY5yvL9XXWMZ483P6
kL6uV/iP/6nJBPvrdCCnqMNke8P0Kb2BodZldaP21l4kU4bS8XtpH/+nJjHE
+gMmWdfWkwygu3mtdtM1+ntcr3XXuBdxv7lsrz+PWr+vi3S19qOkdV99RGvo
27oqnpde0j6UsF6unbWt/sBK5ppX6G88z0TzG/ojPa03aA9dr0/oYH1cS/Ek
feIcxDOnfDzLeM7xeahMFZ5lhJ+rqpviM+vmuB4dqVtZbL1Fz/Ah88zb9Cx/
0IQG9iboCzpRv2Cp9efaUCdpuvj8fGn9rr6ojXWyNtIp8bu0qZ6L52u9PZ6D
fqKD9Kge4yM+ZhTV7deM+0uDuFfxDKnF6Dgf2lDr6Ritq2P1U5ZY79DzvMVn
TLHXSOvrOL1D05OBZuap+pW+Q9PYi2thqrkjzYO5BXcyk4xMs99SW9OKl8wt
mGZ9QGdwgVaxtjdLUzQrneL743roHNetWehIh3hWpNgfoZnjbNOON5Ov/90Y
rnfF+aJNvB/xvsS5j3NDpvicvu8g061b6j+xZn+83/b26d98x3Lz3niOfMsC
8zf6F1/He2zeE+ed3cw379I/4/1mZ9w/e431dJwbOpDW3u3x/lON+vZu01u5
Ja7HXEnraRq9mdQMN5fTuppKb+JGBpkfi7Og7UhYX9Xi+jDVrdvQi6Lm3lpM
e+qJOPvMMS/RI/G+xTkxV9VfWchs8yI9TFfGxnulP8U7nHT9b/Y1Xdu4Vw==

                    "]]}}], {}}, {
                  InsetBox["\<\"\[Mu] = \"\>", {-1.8, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["0.2`", {-1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {InsetBox[
                   SubscriptBox["C", "J"], {1.4, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["\<\"=\"\>", {1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["3.2800000000000002`", {1.7, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {
                  {PointSize[0.05], PointBox[{-0.2, 0}]}, 
                  {PointSize[0.0125], PointBox[{0.8, 0}]}}, 
                 {PointSize[0.007], PointBox[{0.4463998339305619, 0}], 
                  PointBox[{1.2771956561278897`, 0}], 
                  PointBox[{-1.0806611991222994`, 0}], 
                  PointBox[
                   NCache[{0.3, Rational[1, 2] 3^Rational[1, 2]}, {0.3, 
                    0.8660254037844386}]], 
                  PointBox[
                   NCache[{0.3, Rational[-1, 2] 3^Rational[1, 2]}, {
                    0.3, -0.8660254037844386}]]}},
                AspectRatio->1,
                Axes->{False, False},
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                Frame->{{True, True}, {True, True}},
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLines->{None, None},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None, "TransparentPolygonMesh" -> 
                  True, "AxesInFront" -> True},
                PlotRange->{{-2, 2}, {-2, 2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.02], 
                   Scaled[0.02]}, {
                   Scaled[0.02], 
                   Scaled[0.02]}},
                Ticks->{Automatic, Automatic}], 174->
               GraphicsBox[{{GraphicsComplexBox[CompressedData["
1:eJyFWXtU1FUeJ8VH1igZpk7mo9CdXF9pmEvmV6UUycdEhGac8QkHHV2NVRMf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                   "], {{
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[0.3], EdgeForm[None], 
                    GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxNmXecV8UVxWcGqS5IEZbmsgtSRBHQpcgiCyKIHcGCWCgWoiIIVhSVKK49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                    "]], PolygonBox[CompressedData["
1:eJwtlnmUl1MYx++9ki1yyjn2aNEpQtmPY03TJu3baDXtpWWmfdO0pyjpFG2a
ykSrSioiLbSpkEJp0yZETiRyHD7fvvPHd97Pc+/7e+d9732e731KZnWv3y2F
EFaiQmhzDCGfgXJc2xA3gCfC7eBxKIO4GtoFt0SD4IGoGzwJ7eXeqcQXRY9N
4zoDdYWXos/gecyXL3jmx1zziK/i2px4in6POsOLUV3mXip4lxfRPPhNxspw
rUncBs5CjeBctInxs2ghXAGtgXswfwQui26FqzDWB16PmsJFGFsD34ZOE/8a
zSM1xlwGcV94I1oHz2bsaq7liI9xnYt6wjNRPnwcvQEXRifg6mgAPAs1hydr
wbneyaUx18LE78ElURPiy4hXw6XRduIdqD1cCd3I3FPEvbV26Bz8OXoZXoIa
wqe0xroX/QXvRq/Ay9AP8NuoP5yHOsKt0QR4OqrB8zOJx8Bfob7EnxCPhheg
DfBG/QYujzrBz6FX4RnoJFwLDYLnoEv5/SVoVfA3dYWfR8/CI1Aj7p1E/C9c
Ap0hbhGda/PRfjhHz4RfQwfgXqgO/Dp6Fx7P788G58AV8OXog+A9fV/vRnwe
zkQXw4XQiuA1/475tvHCdlzYw6eBg9HPLopmw3NQhrcsDOXPPfx+m3JZ+Uc8
jbgw1yrEq7jemzx3QPVDPJH4HHwDqq29Ij4DF0N1iCsSb4GLo23EDYn3wBXR
YHhfdG19jaoT10zeG+3BSuYGo7fgYeiX6DXVWmrsW3gmWh68R+3hw6gJfAv6
Hu7E8w6qFtDR6D3W3k5Dh+BlqAE8FVWLznnluvbkb/i8vhF+XHsSnVPKJdXw
/Og91N4p54qqdlTTcFt9U3SOKjf1jH+i11RrqXf+T4ue/G31UJXkmlYtf4m+
UG6jRcE1MIz5a1A2/HPwWi/Xmgav+djkPdbentYz4R/lKcFr8md0jao29cyW
8B/Rud9BNRHtafIy1czOaM+SV+mb9uhb0TvBNdeb//ebag4+rneOrlnV6ng0
XPUQ/a6n0AoxyleuqR6ja0q1NFB7xv03o+rwOnQX3J/5zfAm9Ajxo2gnXCrY
K0ok3yvPqEx8PfFauJdyEr5Onh481o35a5PnlPOt4NvlAfBe7TH8mPw3+H/c
IS9HdYPv6ae1Ix4SvOby2tLEG4I99+Fkz5PX7Qiu1VHysOCafZJ4dCzYWzQ9
2mPkLTpD7mf+vuRvUw3WjPa0vGBPWCAvlkcHe27VaA+W9/ZDi+E+aG6wR1Xi
WfWja2Eruju5RlWbWtPK8tvkd9E3yzuGRN8rD3ki2bPl1fqG4fBDyd7WLNj7
RkZ/qzzwU7hfcm3JU5vBQ9FPqlV0pfYTnYA/QpOix8TyhOLyTvQN3CM415sn
/1Y5XwxumuwV3ZVj/H4LGht8JrbQuyXn2hTUMdmz5FX7UbvkMzUX3hecayWT
z0rlnHKzbfKccrQL3IGxQ/Bh1Jk4JnutxpRbNyWfVcqxbHlV9F7ojJS3zGK+
SIHHqHZ2RdeGaqgecxOivULfsB7+PfpsaIUqMN832hsGq0Z1lkbXjs7AB5Lf
Ue+2XTkRXTOqFXluKbhs8tleIzg3lkQ/SzmyKNoz5BXKceXWwuhaVI4l5h5M
frbOtNXRa6q1lKeq9nsSHwv2gKrJniAvUA/VC85J7jV0j9ZiafRZoTVRb7Q2
utdQj6TeQ2ugb1cPol5NPY96HfVs6q10hujsUI+lXkk9iXqRMgVnUW601+tM
ylQ+o5PBOSXurJoKHtPZqjNKZ5PO2BeSc0y5pXuUu13kocE5nJuco8pNjZXT
vdG9mnoonfUjomtDZ756oa3RvWQo8GJ5jrxGnjyOuHZy75elnCBunXwWyWOy
4THRvePR4F7vw2g+Enz2qydSL3ShB4BrMbY7uMeZFV0TqoWc4LM8L5p1pj+j
8yL5f+s36m2zos869biTUePks0E92oDknk29mmq4THKOKbfkgf8DxGl4Sg==

                    "]]}]}, {}, {}, {}, {}}, 
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwl1He4z2UYwOHfUQpRmZUVWdkkKqKIiKyTRGQme2REGZ1kFZIVMjMilcrI
qGQ3jDLKpqJQyQpl38/lj/t83uc94/qO93fytuqa3CUpkUi082VqqkRitu7l
ed5jJp3J5nvxg3doFb1Ls3MnOcnBY/Zz693kIi95qGo/n+bnHgpSgGr279Wu
Wki76fvMtp6jv/Micxls73H9gxoMNc/XHnzIMPMTepQnGW7+WF9iASPMtbWY
9tYrXI0bN9fTUfq59uc4TzPW3iB9SG/gdesHdUU8E+1EKh6gHB1p63sdNImB
1ssZY91A/6Yfbc1L9AVdrH/F87ZuQ2tacdleXxbxlrmultJXtIS+rCW1jo7U
hdpSL2kfilt/oi3i7+pBPmO6+VP9k6cYbU7RX2lvvUzb6VIto6/pfVqW++MM
8DAVqcAjVIp3GOcizgCVGer3quoX2k2/jHepw/RrZliv1FOsirNmXq1nOM1z
cX32RmuyjtGNcT6sv9cGOlYzxLOI58Im82bGxfszj9eG2kz/pbf1ujgTuj6e
k/6mh1jDWt6M82W/ZpwnGsd5irNDLYab6+izWk9HaF0dqd8wx3qDno33xrdx
PfaaaH0dpbfqbdxOc/M7uiXKJCabJyZd/0y2YIJ5u77LlGCeHO8r3jkTzbt0
KhdpHT9rb4Y206xMj2ca5znOcZxd80DNQtO4vnjXcYbtp2jmuMe4f16lg/0B
molGPEN/9sSZ1r5kZJp5d9xHnGP9nwvsZJa9n/U/djDP/FPcH9uYad6q5/mB
ueYf9W3O0ZTx9r7TN6hmXT3+L9CLk/Z6aE+685X5BP/QiPT2biEdQ8yPxn1o
Wk3DzQw2l9eGepOm5sZ4BubSmhyfW36J5xHXZq++HqO5dRGKUjiuyd5Hcabi
7OgB9tMzrj/OmB6J58A08we6j+4MiXvTw/Hckq7/b74Ge4KzXw==
                    "]]}}], {}}, {
                  InsetBox["\<\"\[Mu] = \"\>", {-1.8, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["0.2`", {-1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {InsetBox[
                   SubscriptBox["C", "J"], {1.4, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["\<\"=\"\>", {1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["3.27`", {1.7, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {
                  {PointSize[0.05], PointBox[{-0.2, 0}]}, 
                  {PointSize[0.0125], PointBox[{0.8, 0}]}}, 
                 {PointSize[0.007], PointBox[{0.4463998339305619, 0}], 
                  PointBox[{1.2771956561278897`, 0}], 
                  PointBox[{-1.0806611991222994`, 0}], 
                  PointBox[
                   NCache[{0.3, Rational[1, 2] 3^Rational[1, 2]}, {0.3, 
                    0.8660254037844386}]], 
                  PointBox[
                   NCache[{0.3, Rational[-1, 2] 3^Rational[1, 2]}, {
                    0.3, -0.8660254037844386}]]}},
                AspectRatio->1,
                Axes->{False, False},
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                Frame->{{True, True}, {True, True}},
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLines->{None, None},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None, "TransparentPolygonMesh" -> 
                  True, "AxesInFront" -> True},
                PlotRange->{{-2, 2}, {-2, 2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.02], 
                   Scaled[0.02]}, {
                   Scaled[0.02], 
                   Scaled[0.02]}},
                Ticks->{Automatic, Automatic}], 175->
               GraphicsBox[{{GraphicsComplexBox[CompressedData["
1:eJyFWnt4jNe6D9LSEOoWTG2km3b2Lqoq6lJ9S3AecRvqVnubko0TmaoILVOp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                   "], {{
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[0.3], EdgeForm[None], 
                    GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxFmXe8V8URxXdWBQUBBXzSBUWKgFIFARUEu2DBgh3sBZFijwUR7GLvWLDG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                    "]], PolygonBox[CompressedData["
1:eJwtlnfU11Mcx++9kuSPjJCQ0hCKsp0jT+NJRWl4qKfytNMpbW0tqSSpKG3t
aNI4Rhpo73VaGlJZkRERzonX2/t3zvN+vu/3vd/f/X7uvZ9VomXnBp1SCGE5
yAfqxxAKMLACXhJ8gO6APgIvA86ifwSl4S8D/fijaD4H1INfythSeAlQEz0U
fQZ+NfgDvR2MhC8AW+HnwXz4A2AzfAtoC68ITsFngT7waeBy1hqE3izbQE/0
QfRY+C4wHf4VmALPD07Cq4G+8KngVt6vjO4FXwP6w+9nbAi8CTiNrgFe1Frg
MfgR8Ba8EHgk+Yx0NrLhUXQW2AIvBWoxVw69Dn4NWIaugN4APwDe1VrofDyL
oLvCP4UPg88Df8L3gNfhi0EV5quBbfA8cIK5aaA7fLLOmLlbQC34atAMngee
hg8ES7Q2+mzwWOXkO9VdbgXXo68FNeAfg/bMFUa/AK+u/aFvRH8C7wHKwsuA
evC1YJz2AzrCF+kd/RZ0Cr6TA8yNQf8TPJaFLp5sa0+wCT1da/Jsg64LH5nh
r4J18LcZK8WzFboSz+uSbZWNteHDMnOvgGflC4xdhGfrTuG3Jdu6FxxiPg/w
9/8ZToFMjd6rxsbw703QPtgnW8Mbg1HwiYoR1roEvB/s45fB8yfHj2JmFe9O
QhfkWRbdgOfD6GXyPfClbAW3B995Q63N/AV4efALulH03ueCjfB6zO+EVwj+
1kDGNmVitg28ic4YPgk8mByDij29swa+FjQP/uadyTGpWPxcgP8G3oGXA3cw
3yN67jNQBz6CsZ/hRUE7+HOgcXDM1FUso8/Di4F+6LvR64N9/iZ4UX0z2IdW
aG/oc/Bc3aHOAj0AniOfg+cwNhy+Hdyc7DPylVWgSLJPyhdXak34RMYK8GyK
/oJnF1A3OGY7wmeC3sE54Ydom2XrbNAqOUYVm/tBX+1POQR+EvRBXwm6BI/1
ghcCnXWXiil4b3ACvht8p7NG74PPAm3hLRg7BD8cfJZ9dcfBZ9oiOWYVq/qN
1mobvbbWHAW/Qjk22AdkyzPJ35JN25ifjC7Ms7X8KXkPsn2PYoLx9brD4DtW
rN+QfHaKed1NseSz1R0pl5RMzo3KKdprTnJu1Z6vgjdKXrtrsG3dwPFgG9uo
mCTfrfZ8b/IZaO8bg+/+SeWUYB9QrKxGNwuOmVrKRaAlekewL9RM5vIJ5c75
jNUPzqHyvQHRuVs+qFjaEJ0rFVPKBZPR3YJzQvfkGqPaIpuVm5qis4Jz1Gh4
A/lAcA2allxTVEuKqy6g2/E8hT4dnJsUQ4od5ahJIJexccHfnABfGB07+XlW
le+AY8E5Xb67MpMr5MPPo1/K+PLR4Nr7YTRXDdZdq2aqVurOv4nOccptM4Nz
qXKGcoVy6gKtxdiE4Bgbin48OVfqjO+BV0zOTYrZRdE2y9an0BF+X/LdKeaP
y8/QB4N9+I3oHKncqJw5PjonKRepJjSHHwMN5VtgqWIxOvYGg7+jc7Zy9RLZ
BC+YXNvVY1xA/wVGB9/RftkX/a5y3tFom2Wr9jgbfhiMD+4ZqkbXTNXK2qB6
dE+hXkI5Yg68s2pMcI+QHd0DqPb3U8zId8CM4J7g6+gartqtsScyd6Cz1x6r
RPcc6jWUc96LzgnKBYPA9/Az0VwxcBH+b/RZyKfvYu/lk89KNUa146Hk3kI1
ZF90j6DeQGfSLzkmFYvySe29U/RedQalmeugOw/uecbCd4HX4AtBz+icr1yv
nmUeegj62+Aar95tcXRuVg+nXkI9jnob9RR6Vz2SeiP9ZkZ0zBTPfHN5dI5V
bpXP1IGPyOQq5aQdqgc60+CeULHxU3QvqRjZG22zbFVPtDu651CvoZqsu5sb
fVe6w1z4ueheSjGcLfuSa0lz8Ht0zVWt1Td3Rvek6kV1JspFv0bXXuWkSvx2
cHSvpB5Psd0/OfYV4/8BbUptwg==
                    "]]}]}, {}, {}, {}, {}}, 
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwl1Hecz3UcwPHfnUSlSKmIMorKzCqizJDLOBXKFtmXFbLO3hlF3J1Ne6Oh
CEUaVCijKKOpQcgez/fDH0+vz+f9vfP4fb/fz++KdEhL7ZWUSCQ6++e55ERi
nu6gDZlk0ZVrXOum12p1vU6vJx/5uYF7zW/UghTgJgpxn3lhLcLNFKMoNcxv
1e56i/bQBcy1nq976clChpnV1H3UJt1+iaaxlBH2dfQA9Rht/6L24RdeYpbZ
y9qXs5zjPA8wzrW3dSAHacwks2FaWZMZal1JV2gXfYIkKlKBzrR3rZMmGGK9
nInWjfQP/uQtOpi9qb/TLn6PtrThjNkA3mCsfQMtpU/pHdpfS2p9HaOva2s9
rf243foVbRX/p/7Iazxv/6r+xoNMsH9a9/C49TLtqO9oOR2sZbU8d9KVqqSa
V9G7uSfORbz7eM9xNhjheg19V7vre9pDR+qHzLZeqf/yEXPsV+lhDtEinr/Z
JG2kk/Uz5ltv0CY6Ra/QPvRlo/3nPENT+6maqi31P3pbr9Enda3+FPfKaj6O
80Id1+6nLg/Z149nTz3GxDnRhzVFx2pDHaefMM96nR5hPJ8y2eyReNY6QXPp
lXxpnaFf6DGm8SwzzGbEu+DRuBf7b+J7GWc3fsZ+ZpwvHmOq/XfxXjkVZ4Dp
Zhnx+5qXOdYt4+zGeaSL/WC9mhY0jzMQZ9l8kOaJzxz3ycDki38XBmjueCY0
i3PIdvP+2o+rmG3/fdyLdSs9wUm2kWW2VY/zLQvtt8Rn5Wsy7Tfr/3zFAvtN
8b3hKM2ZYrZeR1HTuja1SOMfs176vvbUD/Rv/qJZfNe43Pwy0q2raVPNqTm4
lOH2d2kTza6XkI0ylCYlvqfsjucU79isof4a78K6BLdRnN5mL8RnjfOkP7Ar
zh4j43zpfhYx036x7ox7YHjcl/7M3KSLf5MvAO+8sAM=
                    "]]}}], {}}, {
                  InsetBox["\<\"\[Mu] = \"\>", {-1.8, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["0.2`", {-1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {InsetBox[
                   SubscriptBox["C", "J"], {1.4, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["\<\"=\"\>", {1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["3.26`", {1.7, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {
                  {PointSize[0.05], PointBox[{-0.2, 0}]}, 
                  {PointSize[0.0125], PointBox[{0.8, 0}]}}, 
                 {PointSize[0.007], PointBox[{0.4463998339305619, 0}], 
                  PointBox[{1.2771956561278897`, 0}], 
                  PointBox[{-1.0806611991222994`, 0}], 
                  PointBox[
                   NCache[{0.3, Rational[1, 2] 3^Rational[1, 2]}, {0.3, 
                    0.8660254037844386}]], 
                  PointBox[
                   NCache[{0.3, Rational[-1, 2] 3^Rational[1, 2]}, {
                    0.3, -0.8660254037844386}]]}},
                AspectRatio->1,
                Axes->{False, False},
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                Frame->{{True, True}, {True, True}},
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLines->{None, None},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None, "TransparentPolygonMesh" -> 
                  True, "AxesInFront" -> True},
                PlotRange->{{-2, 2}, {-2, 2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.02], 
                   Scaled[0.02]}, {
                   Scaled[0.02], 
                   Scaled[0.02]}},
                Ticks->{Automatic, Automatic}], 176->
               GraphicsBox[{{GraphicsComplexBox[CompressedData["
1:eJyVWXt4zNfWTrWNnugodenpVF1LB0GaYzR82K1xcESYoqjLuDQcMYijIeJo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                   "], {{
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[0.3], EdgeForm[None], 
                    GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxNmXn8l1MWx+952hVFe1op7XspjChRYVKyZAnVEFmSLWUblH2LbNkaWcdO
kj3bDGYMJgzGzgxjMI19HT7vzuf7av74/M753uc+97nPOZ+z3OfXZdqsnQ+r
SikH608dyQeEI4RthdUC1xoJDwlHCtsJjwhHCWOEHYQGQjPhc+G/wmhhsTBH
GCes43VYv4lQV6gn9I5SeglNhPW9TkNhpZ+5gfCV8KUwXvhaaCy0EFpaZ71J
/r2h8KSf11xo5evrCq0t1wN63hfe83HCxJLPv0qYK+zotet4r/00vxIOkn68
sLP3cKAwQxgi/FbYXeggrBKeFtoIrwoThLbCVKG7MFA4SdhNaM97au3/SW4i
7CFMFjoLbwpThK7crzk/S+7D/dIHCC2E/kJPjQ0WBkWuvblwgNBHGIrUeF/J
Tb2/VrZHI43/U3IZ+5C+obBcekfJDsIK6Vt4v4OEX1nyrCG6PlhoJfzgNXmX
a4VThb2E0LVhkiNKztnQftpaGC5sJoy0ZM/1I583qiQHt7MPDhZm+vkLhUOF
rYQLhEO8/kXCLK83uyR/4dw04YySNoK/Y+zT7UvyFM7BWbje0PfAn0Z+dmP/
5p4m/g1f0eEw/IXjcOvXJeOhqdeFU3BspXXWv1A4zDbgHYbZFvB2Az+3se0E
x5pG8nViWctjbL2jdfi8S0mOdSoZK3AbvnXRfZ0j+bikJHcn+f4O9tfT1lnr
tZJ83VW4tSQPu5Tk574l+XSHfbuxsFSYX5KjTbwu+75N2FPYiHm6d6NILp9u
f/QQ9i8ZDwNK8hiOERtwnFjoXTLem9v+5JuxtvkA8x4ufliSw9NLchY+Yk84
P9R7htNwnxggjuHlliX5vsI++L1wXskYh9fEErys8R5ezrA+2PfgvxH2X82f
+H20fQ2f4SPchr+jvE4nja8b+T61GOD+F0vyG3781VyB03ASPtcxiAv4uI7W
2MbXB3ptnnWjcHbJHMC8Mbbb+prfTNhb+rHmEPxZVDIe2PsVwjElefyt8E3J
fLdJ5Bh8hssTrbf2OuS6a4R5ZS0XkZ3NCXgHn0+wTi64RzjFXPlJ+LFkToSP
5FL4CefHeZ/fleRmW6872c+5WDjZv1kPfq7hnvWuvs5z4PPRXrN+ydyHP3t6
3hTfxzvN9XsNi+QqNoZPxAJc6qrxlsJ+0s+xveHcdcJpJe/p43H4PDSS/zyr
m/TWwm+sEw/EArVkhvd0iXCuf8Mt8h586+taxLPg40z7Hi7MNh9uKFmfWO9S
4XzPu7lkPuW+rUtyjbXh4CyP1dP6dSNz65klY6uX8JywoGQNaqDrh/u+BbZb
N9t1jv0F74hbuHe57V7f/j/efIBT8A3uPV6yHsOvK0tylHVeER4ta7k1r8YB
7eFEyY4l+UJNhTPUygXez2T7vov9f4q5QQxRD4iPZ0vWb3gHX079Py7MNx+m
2qfd7XdyGXnsnZJ5kOcRo9QtYvQFzbm2yji83nbsZS6cbT7MtF/ICzeV5NBQ
+/tc++g/wmcl6xs+P89z8NWF9he8oBaOsD8X2qefCp943uFeY6Ttvcg2n2Nb
Y2f4comfD0cu9R6J2SX2G/3JxbYrOeOykvkO3y62//EbvVQthq4uGUfUxyvs
838LH3uv9B73SfYrWcuusZ+fLzlOrH1UktNDbOul9g9xc539c3vJ2oN/37Pd
e3mv1LNOtvGN9gM2vtl2xg+32Bd7eh04c7fXZU36pXu9Jtfv9BzkXdbhFz3Q
XsYdvpf7yDW1Xm2Z34X3W+537OH+i9ryF9/DfDj+u5I8x/83mQP3l6xf2I28
SO0mLl7wNcbp5dD7l+TmgyW5/1jJeCPWiIOHS8Yr/cfKkvWLOCPuxnvsMc9/
wjr9CrnwLO+fOv2k10A+5Tl/tN7c8g8ehxP0H9SQZ6x3tOQ38fgn6x0tn/U4
Mf1n++oM26un97XS6w+zfYZ7j897n6y/ymsuEf5WMh/RL70kuVNJ+bJ1eEb/
Qj6Bm6/YNvRLr5esRRNs/86Wr1n/u3X885bXIbfQF/F7b/vqH/YROfadkhzH
/++W5NtL3nMbr/O27+X6e54Dl94v6Xf4RV8Ex6Zb7+XrH3gO8gXrXP/Q8/9l
fbrlRx6nJyGnkE/IJeQl8hB9C/G80NfIOeShNpE9ymrr9NkSa+Tn1uEZ1+HM
aF9jrHtkz0EvS91HtivJRXrctp6D3tRjX1mnf6Z3hI/fWG9hyW94uLP1Fpbf
erz2PNb/3no7y+/tR/pczjP0NT9ab2/Jb3qbdu61ar0skl5gN89pb/mT5xef
75jbMzIXhOswcoTXZA48/Nn3UIvr+Hy6pe9Fp99F1nGvUFuLOdT1ul4TWc/j
9BD0rPSQ1Hf0UR5r4F62ofVRntPQfQD8IT/CsXutLzMnyPPUqMbmA35HNnb/
2tv9ML0BkvMVPQNnCnR6QGxJ/8oZeazn1bNdm3kc33FWamfZ1PpG9kU3z+c8
gy+aR+rcS45o5Z6fno4zSe2sjj7I3GxjPnMf95P/9vM9a+a7J6Q3oLejxyOu
h7jfG+CxVh6f6L02s03a2D74t633vNrX6OvIZ5xb+vm928VaPrQz35Z7zjDL
9p7P+aijn0uuaO96s8LXajbo4DnkJeZznXw33nGB7TvZX+Qichl5jX6MHFrL
n+jkrAV+F7h6oucx5037ppvfBZ2cRm9Fj1Wza1fbk+sbe84qr0MOpwegh67Z
u5vtTJ9BDiEnnCnj3RzZj7SQ3rLKPcyB+1XWpPmSW0X2NTtJX+g1h0k/IvL9
H5M8zX5foPEbInuo06WPiuxxukq/0nFxMnyuskcYK3mG3+sZyQW2yfYaPyvy
bPCG5Gyvs0jjL0X2KdcQx46XSzT+amTPwlmgT6w93/Yxt/FRb8cSuZFc+YXt
0d02gdcDzO1NrWNn5EDrXOOsTc8yPPIsxNmY3NLPz+2m/cz03hjrW9uP5xzk
9Tn/9Pd+uUYPQ17qYa520TpXROaKTyXvjuw9z4y0EfaZKH2HKjkyCTtV2Vuf
CxeqrFl7STavMsdj422rtPPXrF1l73h6pD/wxQWR/sbXU5hbZU+wWOOvRebL
SaxXZa3bVXKXKuvh7lX6G1+Plzw/sqY+xH1Vnh8exvaR+pOSs6o8S+wt/WrH
+4OR32Cp60MlD43Mc7dI7lFlL3K25D2RMUQfRY9Fzdpf4wcIb0ifLtm6yjoz
o8prjD+l+96NfO53cLPKvrlzle/JOx4ovU2VZylsv2+V9p8meW9kL3Mf/qzy
vDRGcrsqexbySA/7vZe5R35opOsNq+yDz5e8P/J8NZuYqrJ/eSLSH/hilMZO
iTxnYL+Hbbe6fJ+uso/Hz53s61MlR0SeP/bEllXWsnFVcgWe7IjvIvvEbyV3
jewHF1bJIfjztuRxkeePczQ+1vrxku9E1v3V7N17m4CNI3PPc5Ecgj+LNX5p
5PnpcumLIs9VS6W/Etm/XyT9We/haOnHVNn/XU5cVXkO2URy88jz/AXkJ++f
M+WLkWfIidJfjzz7HSn9qCr7u80iuQWv3tOf9yPPaVdF8vVw+6qn/bUELkee
jW6X/DiybsLTp8wZeHFiJDfg1wmRHONb2XDnhGHWyb3E39zIGGTOEI9fqfHr
I8+g1BquUXPHmTdwhpyFTt2vvE/yREvnpRa+h2fSqxwp+VHkOXO41+RZ5Iuh
zmOtvQee2Up7GOM42kZySmQ+PE3jIyPPr7dJ3hr5PYI4uMu5aJnk1Cr7/h2k
fxLZv62IjA3ioqmuN6vyTEi+Yw89y1ob0VM8IvlNZO8xteT4AO93U+95nuRn
kWe/AR7vb/7CIfjzciS34NXWkTWJenRIZB4hhzSQrF/lOXYDyfWrPNf2l+xX
5f92box8f96dRuPnyG+iA6UPqvJ8SGxNjoyvIdIHV/m/oJ00Ni3yO8k6GhsX
edZG7mN9bpW5hjzzpcYeiDwHwd95VXL4WMnnI88f0yUfj+ypRkfWb2r3UZH1
m9q9BbETeR4lr3zl3AI3l5uf2Hil7TySvBV5pvwevkd+I5gv+WhkX/F55Pvw
LtRh6jq1mLgnNxH7J7NOld9mRmCzyDPurMgegv6BGP3RcfqT5IWR3y+WRuYs
8tUP0neJ7PmJlTsdL7tH1n7q/pb4vcrvaPDxLXOyj8b6Vnme3yOyJ6AfGC65
WZXnduJ4e8cyfKd+wPmDsWuV36vIMT2qzDO9JHtW/h+gxm+K7HmoRddGcukA
nl9lT99Ocmrkd9wDJU+q8kz4dGRuJa/OIG6qPBNOiKwB+Ihehr6BnoHcTI4j
v5HjGzvPbyM5uspz/qrIPEWOui4yj5BDPpB+WOT3xVp/s+b/epF5nBz+pvQ7
InvtyyJzNPn54sgcTX6mRq3nOvULDpTQsw==
                    "]], PolygonBox[CompressedData["
1:eJwtlnm0T1UYhvfe0aQSVq2i0k2rSaVpVZIhUyKKzOM1hhtXmYdMWUJJhZB5
CsmUNBGhCBmSoSIRQoZKaUmpntf7++O55/3O3uf+ztn7+95vZ7XIrdUxhRA+
gDzwWwzhSXgBPQ36ossyoR+6HrxNXJ94G/oq+Ji4PfEe9I3QnLgGDEQvhk/R
kxkvxPUm4p+4zoBu6PFQgLELYD76XWjB2EXEC9DF4BTxH9H/W+/0O/pk9Ngg
yEZXhwHo0XAIXRF6oidCB/7Xsui50+Ee4rvgUfQn8DBjdyfrztAQ/SCsQO+A
h9BdmbMKvRJKEj8ANYLn1EUPgF/QI4PX6mnYHbxmjdGNoBa6D1Tif5UiXo0u
CJWJyxCvRReCclpr7q1Hr4PXidcRN0UHrv/A31Cc8CVox3jb5L3pD+8z9grx
Wb0btEK3TNZ6nyvQV0Jf9BPBv/Vh9LP6zaro4YyfQReGvPo+7i1Ez4PH0Y9w
bwP6OrgUXTB5726AqYwfgHHo82ESejzj+eK51w+N+DOW+EKu5YnbKy+In0VX
0PcSj4a26LfgDc2HHPQc6MXcnvAM+lX4lrExxHmj792KLoV+TrkJRYl7wBF0
S7gXXZrxLujlcGdyDmjvl+mdk79Z36qc/JexLdFrPQsuZ6wZcRZ6kfZTuQQb
g/foS8Y2Qit0CdigemB8C/oA7CNuCTejB8Mq9GrIDr63CX02+tsPQ32tB8+f
x7U0cWuuDWAEeoz2F11Pe6a1gv/Q25UDqlXoxLOfRf/WDLgsec+0V6qx2tE5
FjI5dTW6cHLtNoRL0PmTv1U5sIJ5k4gLcG1MfAe6OFRGLw1e+9uTtfagdHLO
K9fXqN6Iu0frz2Et+gzMRP8IB9HloDv6TajG/KHELdAvwonoHFTuTYW9GmPO
LnQd5QxxJ5gQ/D+yGXuP+DvlCtQi7gNH0V9BX9Ur48fQx6G5apn4+uBnjqKb
cG8negr0RmdBB/TP0CV5j7W3+4O9cCnxD8GeqN9qEz1Xv9kmuSZVi/KIJozt
loeh88O18hs4iP5I35CcE8qFQ6rxaI+QN6gG5WX3JeeyPE17USI5l7Un/eUP
PHMi2KOKqNZgH3qJ9j95DfTtW6FbtOfJ6+RRs4mHEJ8K9rwp8nbik+iK8Lxy
CToGr2GP6D0+t7fKafRtybVYSe+kubA3uGZy0IMyuaQ1mxDtqfLSTtAA3SXa
q7YH95650Vo9SF7VJ3rv5VmvqX9xr3VwDY4nrpnsFdqzbsk1qtrUGl9D3Dl5
79QDVWs7GW8XXHPy0mpciwR7qrymYaYW5TnrNQc2Ew8L9raJ0e8ujzsS3VPU
SyarJpJzXrmuPWia3CPUG5Rjw5TfxEOCc17eOTnaG+Wha+RFsCl4jmpxeXRv
VU2q167k2iy45w6Bx5JrJ1s1k+zR8uaiXCcSz4/2+vzy9ugeqt7ZAzZH56By
Tx6qtQnJ3qI1GhPtSfIiefT+6BxRboyFgdE9Wr25AYyK9ix5lTx+MbpXdC2r
J6n2fo2eqxrcgR4Js4M9bVt0T1AvkOfprKEzy7TgM0dT1R7U1vcFr5VyXrmu
NSurtY9+t6rBXjEr+lvlGYejzzg620yCOeoN0VpnivLRZxidXVSzVTJ7rL3V
b26N7hnqFS9DR/R06BrcExdFe8oU1Q4syOyB1r4mcZloD5T36Zkl0R4m75LH
HSM+Hv2scnJEtGfIK9RjviEeB3ODe0Q+xi5OXot3gs9KFVQDwWemismeL6/X
vcGMn47OZeXQsOQzis4mp4Nrv2R0L5cH9CMuBrnBHiOvqBDtZfIMjdVJ9hbN
kVc8ley98oy6zP0rujepZnXWmge9g89ce9DfZ9ZG93ahc6P3bpTWGP0FDA3u
IQuj31nvqjNXSj5z6KyhNVGtquZV66pZ9fI8yWuTBbegc6K9SmeS6sTDo88O
+o37dfYgrhJ8hpCX/Rl9ttwbnKtfR++9cnZadM0VzTwzM/ob9O46A/8PXWV5
cA==
                    "]]}]}, {}, {}, {}, {}}, 
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwl1GmclWMYwOEzIylRWpAlilSkQohW00KJVNpMs6iZkamZagzaJKa9JBFD
iyTKUihbC4XsW6WitNCCsmvfdd2/Plzzf+7nzJlzzvs+Z6r17Nexb1Iikcjz
IxazGJ6cSDTVX7iBkebZ2p85jDKn6G+0ZKz5ZS1kB6/Qzd6reofeq5X0TM7i
JvN4fVMH8ze3kGLvoXhNHaYLeZdc891U5kFzM+1FDneRTRZnM9Tj7/CodVv9
k79YQKa9+foH6dYZpNGdigyy/wbjrG/UpjpQG+sAbaKttJHerw31Pp3HXDaz
ideZ7rHX9HduZoL5Af2ZntZv6536lvbQf/TfuPY0NxfF49xKC3NLzuFcethr
x3+0Z6K9RbqXPSymt70l2kdH6DKetV6q+/mAGeYP435ygM48Ye/LuH6cb10Y
94+v4jV1olaJzx3XgK/N3/AYt5knxXvSLnowzoz1x9pPP9EtZPERyxlNa4+N
0TbaQdvq2LhuOi7OhnaM19BP4+xwnnUB9/CZ+RCP8DmT7N0e104n6AV6YdxL
VpgH6Ld6lMd5kmfsTdZsujLZvEaf4mmmmIs1J8507JvXxfNIjjMUv6fT4/la
nWnWXfThONdxhs3D9GI60ynOc5xl+0P1onjf8VnjrMTZtj9EqzHVuoP+GN+Z
OKtUZYp5PcXWqZqk3eIz6Q+a0P91LbOsv497zGqeM3+nx1jJ8+ZVeoTDdIrr
Y+8LHUmr+O7Gd4O+7LOXr+9pnr6vu9kVZyHOOaXtl6Isp1OB8pxCSU6O6+P3
TtNynEGmuYSeRBlOpY29DH6KaxL32l5r3Umq9XVcT4M4E/ZeYox1C01nIwVx
3uw11195gWnmF3VDnFFGmJvpVrbFNaIo/ramxXeIqeYZmssl1r21hjbUWtpH
a+plXEoj8+Vah9rUoy6N7V+pV3EFV1OfJvavTT7xP/kazY97w0zrmbo96cT/
6uNm5LIZ
                    "]]}}], {}}, {
                  InsetBox["\<\"\[Mu] = \"\>", {-1.8, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["0.2`", {-1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {InsetBox[
                   SubscriptBox["C", "J"], {1.4, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["\<\"=\"\>", {1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["3.25`", {1.7, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {
                  {PointSize[0.05], PointBox[{-0.2, 0}]}, 
                  {PointSize[0.0125], PointBox[{0.8, 0}]}}, 
                 {PointSize[0.007], PointBox[{0.4463998339305619, 0}], 
                  PointBox[{1.2771956561278897`, 0}], 
                  PointBox[{-1.0806611991222994`, 0}], 
                  PointBox[
                   NCache[{0.3, Rational[1, 2] 3^Rational[1, 2]}, {0.3, 
                    0.8660254037844386}]], 
                  PointBox[
                   NCache[{0.3, Rational[-1, 2] 3^Rational[1, 2]}, {
                    0.3, -0.8660254037844386}]]}},
                AspectRatio->1,
                Axes->{False, False},
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                Frame->{{True, True}, {True, True}},
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLines->{None, None},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None, "TransparentPolygonMesh" -> 
                  True, "AxesInFront" -> True},
                PlotRange->{{-2, 2}, {-2, 2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.02], 
                   Scaled[0.02]}, {
                   Scaled[0.02], 
                   Scaled[0.02]}},
                Ticks->{Automatic, Automatic}], 177->
               GraphicsBox[{{GraphicsComplexBox[CompressedData["
1:eJyVWXl4zNf6d6O2yFyhUUxtsaRTSwUNXcIpUUvam46lom46duUOYgvGvg5X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                   "], {{
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[0.3], EdgeForm[None], 
                    GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxNmXn8l1MWx+95SmlPqdC+aU9KRCpKya5lECNrhGgQaUyJauwlsss6Y4kk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                    "]], PolygonBox[CompressedData["
1:eJwtlnmU11MYxu+9CHE4wjnJ0qqIY42UCtWURKZN+zbto6lmWmcqibZBm2ra
k0pClpMW21EKRVqkRYrSaS+ciHRw8nnOM388v+/z3Ht/d3nvu9zyWf2a9U0h
hPfBhaBVDGEneBx+JXiZzpnoHPXzbQhq0LYRPQK8iK6P7grPAjXhV4HWwWNe
oX8HmAgfADrBm4Jx8Mngb/hmMB6+EGTw32noLfDN4Av4l9Fz3wlGwmsx5ll4
e/A5ui56E/woWIvujz4ErwqaoSejI9/a6M58m4NC+BTQBD6B/vPw27TH5Dk1
1xHwM7wFbTvhs0BL+B1gSHBb22KbyBaTtCd4I/AMfBl4GH4X4z+BlwIn0I3B
SPgc8BH8Y9ARXgXsEY/mo8AH8Jn8/wq+ldEz4KuK+eXFfR/y7RA85hFwL21r
0VeDrvAs0AI+DJylfyMYo7sBfbS36LXmgdnoOegS8Bv49kL3BG3RP4F7ks+k
s6zRnaD76ww6C7gbnRfd9yn4E34m2rZac7HunzE74KXBet09+Bo+GtxK3wPo
XJ0dXIbOBNvhb+m+4E8m+yvDwo/8PAgGwqcF730fmBp8hkqMrS6fgK8CZdH3
o/vBV4DxyTaTrc6Cl+CTQA/4fFCS/pPoivA3ZAP4/Ghfnh48VwXGrAyes2V0
zChW6qIVXGvgB+VLGoP+I9o31fYCuj76evi/ujN0TvLYd0BFeHmQEbzGDMUm
ekJwTBbKF+XT8HOKKa0PesNfBRvgf0Wf5QRozvhmoEnwHVwCvzT5bEt1Z4wd
C76CPw/y4fcl+07L4FjaSlvP4JgaI59LHttZ/g4fHc2fk33QBYphxTKohh6M
Xg9fB36DrwT74XPBfvhDYLDOGpxLSiXHknLKLfDKoAF8NWgg3y6ObeUMrbUc
DA9eczt8OtgqW4MixWsyz1bMwDuAPcE2yaC/OnoD/CbQHd4t+eya893oO9Nd
Kaa0d9lQttMZVkfHqGJTMaNclQ0OBOesFfKt5FiqBH5Bn4rmygkDomNIsaMY
zo2OMcWWcshj8OHgV/i38sloH5bvNgWDom0s25YNjp3ZtPUNjqFW6KeSx+aD
YfDrwNPai+6csXWS7045aW50TlAuaCibwLsr5wfPqdi9hrb3gmNYviMflu/K
h7Yov4IFwTl+BH1lQB/dfXBt6K2cGVwjCujrgj4JP6U5o3OWctVYcDv9PYr3
ohyhuTdF92mNb6JjQL6vGqPctAQMDc5R8r2D0blcPlgIv5Y5lwfXkEeT96C1
twX7WtXkXCSfy4eXTvYd7XGWcjn6NLxe8N1kRdtSd6Ra9Bn6cHBNykWPQ3cJ
blMsnYuufYop3UWj5LV1J4r9m5Nzl3KA1qoWnfu0pnxbNVO1Uj6+G70LZAaf
+TvVomRbK2cslK3QZ+BPBN9F42Rf0p0MSq65qrXHwI3ocsm5Unc+LDqmFcuK
kSHwoeB48JkGJ+cc5Rq1ybYDk+eSjXvRNw/kBefoKdE1WbVYOWti9BtBbwPl
4JrwH5TTgn1kb7TNZWu1dYuuEaoNqglL0UXoksU2eJtvO/Tu4BhfpFgAM4Nz
zIHomqRapDbZpk7020c2Ogw/AgqCc3RvxV50rlJMy/fzkt8KioFs+R4YBC8C
b8IPKYaC59DeXkeXCd5jvegcrtytNr0d9EbQ20BviGPw46AVvByoFZ0jlRu1
ht4iOdF3qTfJgug9aG3VxH+ia5Jq0SLQnvFHo3Pb98G2WRbNZaMO8i3algTX
vG3oqdH/1ZupU/KetJd9oLPiFewNrkEdFfvRfWrLhP8e/bbQG3F49JtJbyWd
6WLGlwAVgte8AJ6Sc9fi4LfZuui3nt5oNaJrvmq9fKh2dE1WLdabtR38PHgt
eE7ZvjVz7Aq+g1Ho09FvDb2Z2iTnROVCjWlD33/Ra5cHF6mWJ3PNqbdEleTa
ozfF/xy1bmU=
                    "]]}]}, {}, {}, {}, {}}, 
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwl1Hecz3UcwPHfXSUlIyqVrUJklJ09UnadnZmVfSiZcWWPlBIyWjKzCpWZ
IqMlq4XKbGeULTzfD388vT7v9x2P+32/H5evfWpKr6REItHdHx3JkJxIPMp0
5zQtrbm1k+bSvOShjDm/3kU+7uFuytoX1EIUoDD3Us7+Pu2sRfRJncl05xm6
jy7M4jm78rqfCgw3v6ndeIsR5or6M1UYbZ6t8UF+4R0es2tECqnmjJqJ1iw2
t9RF2kp/1Yco6zxYy+ggfZ/36GTuSBYGmkvrMu2g7cnMAPNSxjnX1CMc5V0e
t1uoh2nu3IJmNOUmnrZfwBjnalpSn9L7ta8+oFW1hPbR4tpb5zKH7/iW+Uzx
tXl6iBqMNffX72nn/ARtWGJuq7/p7zxLOfOQ+Hl5mPLmB7mZrLSyq80f1GW8
3XL9m79YQWe7LvF+GWr+kKnOH+hxPmKaeVW8Z07QkIl2G+MZcEt87ngGbDJX
17F6azwr+vGZeXM87/ic5vFaM+6unqSH81rtruv0B9qwmjU8TyVfG66VtZ5W
1RFxp3SkVtP6OkHX6yiyOfekFx+bU/Vf3UBv50+0j47W2zR7PP+4HzzDFvvT
8W/yIq/YTYx3EXc2duYv9SVeZrJ5Urw7GjHJ/E38PS7QJL7PbprW1xxMda6n
u3Sodoj3q3dSlzrxnuPu2g/WO6jNI3Hv447YD9TbmRJ3QXfoLN2pr8b/F+fJ
Wksb63lS4uc2b9dznOUrZtp9rS/wBa+ZP9czbGWGeZue4j8axPfafappVHAe
phW1G135x3yMlaQ338CN/GmuQ2uSzAmuJ118PruWXOYS19ldSy3nFvzPRa6x
S6a6c3P6USrenx7kAI3NTSgW98FcVHvo23FPnCtrM/YkXf3dOtKukv7E6/EM
zW/obrrGfYz/a/oje+MZMcyulDaNZ+LckJzJV39PXwG7aq9S
                    "]]}}], {}}, {
                  InsetBox["\<\"\[Mu] = \"\>", {-1.8, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["0.2`", {-1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {InsetBox[
                   SubscriptBox["C", "J"], {1.4, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["\<\"=\"\>", {1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["3.24`", {1.7, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {
                  {PointSize[0.05], PointBox[{-0.2, 0}]}, 
                  {PointSize[0.0125], PointBox[{0.8, 0}]}}, 
                 {PointSize[0.007], PointBox[{0.4463998339305619, 0}], 
                  PointBox[{1.2771956561278897`, 0}], 
                  PointBox[{-1.0806611991222994`, 0}], 
                  PointBox[
                   NCache[{0.3, Rational[1, 2] 3^Rational[1, 2]}, {0.3, 
                    0.8660254037844386}]], 
                  PointBox[
                   NCache[{0.3, Rational[-1, 2] 3^Rational[1, 2]}, {
                    0.3, -0.8660254037844386}]]}},
                AspectRatio->1,
                Axes->{False, False},
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                Frame->{{True, True}, {True, True}},
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLines->{None, None},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None, "TransparentPolygonMesh" -> 
                  True, "AxesInFront" -> True},
                PlotRange->{{-2, 2}, {-2, 2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.02], 
                   Scaled[0.02]}, {
                   Scaled[0.02], 
                   Scaled[0.02]}},
                Ticks->{Automatic, Automatic}], 178->
               GraphicsBox[{{GraphicsComplexBox[CompressedData["
1:eJyVWXlU01f2t9gyjiW41G0iUwerNq07Q6zF5c0YWy1uca2lGq0VRk1H0eIS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                   "], {{
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[0.3], EdgeForm[None], 
                    GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxNmXecV9URxe88iigCLiywiMAi1ZVYKIpYgiiCIliCDUSKghJFxRajEsWC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                    "]], PolygonBox[CompressedData["
1:eJwtlncYjlUYxs/zStpdKQ1KRmkoNIWkbDIuZO+RPSsr2QpZ2Q00pFKp0LgQ
ZcWVFSkrWakuDe2p9Lu7vz/u6/s957zv+533nOe5n7dohz4Ne2cppdfQKWh8
pNQUTYQ7okPwYdQYLoKacnET1BAehD5n7gAaCBdC9ZlbQDwAnoHmwV3QNPh+
VBa+lmtWwOej14lbEO+Cr0Dt4HcYGwbPRtvhJuiq5LGl8HiuycdvCeJK/B5B
M+Eh6Cbm2qA98FB0q+7VM+H86Evio+H/egi9Bb+NWiX/R0O4InoQnoBawXm4
/zn4ZT2feDeaCt+X/N93hZ+lNdwTXpPWMh+9AO8P74X2qJqu5Xm/wiVRCbi7
1qC1oLHwo+G9fxzlY/60zM9qkvzft4T3Umt4AF6EBsPva41irv8p+Yyaw81Q
o+RrKjBfing1XBhdBpdmrLfOAl1MXIq4F7wIfQo/gfrCU1BdeBTXnIAra4+I
J6PO8FNojc6O+d/h9uh64guJX4V76swzj4lfQUvgcYzl5bcZ8UVwAVQt+Z5P
GL8R9YMno4y5ysTF4WfQpcQFUfVcDr/BXGSe241WEJcnXg9/pvVk3jPt1Xuo
GXw3ehiehJ6Et+gMkt/5msw5pNxZrnt0L2oLl0a/wD+H90LPqA2P4J4/4Yqo
ONyNsaXwYrQKvp2xjaqd5FqrhUYn19xIuBzz65LXrLMolPnddCZl4WGMtYGH
o6eVy4wtgT9STsF9GVsFr0Sr4e/DuXQQXc18z/C7LFNNwtdlrmXliM6uZjg3
dYYn4L/R5fAcnTHcAT2WfCYVMv+Hnv0B6k7cnPgQfBh1Iz4LdUke26v9Jt4O
T0dnag4dgBeiOnAxnVHyNf3hm7nnXPgY+jp8xjrbWao35hujnXADvUNmzyqi
3FENEC8M8//XEB8M5/4OdCXxS2HWGfUP54hyQzXSEf5WngXvQ+PgdaoB5Qrq
Ea5h1a48phXcMnMuy9N6hfdcey3PK0c8iPg4XBANCHuOvEYe2zVzjim3tCdn
EN+L9sMvos6Zc0i5o7HKmfdce70FjZVXhZ+dJ1er0/ntnlyzm3R2aDP8SPJa
+oX3TmuSd5QPe7k8ZKr8LfO1OsNK8BTGNsEfojuJ64RzXWPytnfl6cke14F4
eXjv9qLTidtn5gVoGnPViccnr3Fg5h6h3vCd1gjfwVi75JqTF9dG25I9eZnq
Da2FR6CazNXK7NUMpz3hGlFtqAdNYG4W8alwgZz3LM71kry52hsVzmXV4HD4
tszPVs0Nlf9mrj31jNFwJ8ZqwyeTe9ObxC2Te9RK1TbaoNpGPZlvQXwE/gLN
Dee4crsOmkHch/gruEpy7nXK7F3KwSHEx8LP0n/UgL8J90rt0fqwJ8uL5Skb
wjmrXB2D1sLH5enJOay1KceUW1rjDZl7jnrNGvRD2NPl5bpnIvxj+FmdUOLa
k8TFwHnKYfivMMujG8F/oLnJ13wM79Q7Jp9BmbDHy9s1Jm+ZE+6t8hh5Qefw
3sgTxoQ9Q14hD50fznnlej3i1tq7sDfoG6AB/FvYu4qif+F/wqw1yas3ht9F
nq1cUo4qN5VTg8PfFPqWUE7rrHeFe6HOvGM4B3T28ijVlmpEtaEa20ysD6yj
yTm+jXhrbq39k8+6ZDhXdeby7n1hb5SHn8f8BZl7ZdXkXlc4c69Wz+sBn426
JueUuEpmL9DYOeqlaCvcLbm3XpK5t6vHTgr3QPU+9fCqmXNUual76sF1Uf3k
b7oicFuur5H8zTA7XFMFcmPqne1RreQeugNuHc5ljelb59nwu+ubJz/3tgm/
Ww+tOdwz1SvV03plfgetXXvYJ9zj1NvUk54Pe4a8QmuUN8wMP0seoW+5Mplz
Wd90/wGVZlvu
                    "]]}]}, {}, {}, {}, {}}, 
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwl1He4zmUYwPHXSUklMpJRqJDM7DTs7HVCiHDsvYXsPZLRUkahkhUtZKRh
ZpRddtGgoomsfO7LH5/zfe7nva5zfuM5b56UHsndUyUSibZ+NOeGpESiJi9b
99RCmlGf0Ts0M5kobL5Ts5KFbNxFEfs5NCfZuYe7KWo/t7bUXNpKX2WS9Su6
h73MoJe9YrqP4vQxz9QUZtHXXEK/pRT9zXO0A9/xBvfb66j3aSfNq+9qAz2u
j1DEup8W1r66lCU0NTfhJvqYC+lifUobcyO9zYsYaF1Oj3KMBdS3944eoZ71
21pX65CaeOBv8ax1GX1Qu+kD2lULaGnNr100n3bWubzJ1+xkPuN8Nk8P8zAD
zL30GxpaNyKZheYn9Xv9If42Rc39NZnHKGZ+iDTcTEN75TlBRQbZe09/4keW
0cxec55mgPkDxlu/r6f4kAnmj/Q5TvMEQ+yt01HcYt2O9nxqflRH663aId4j
682fMSau1TxWH9dq+iutrFdqS12lu2jMx6xgMCV9NiTOjFbWMjpUS+swLatV
4jr1Ex1OWuvWpLDa3EZ/07a6RsvpiHj2OjLOlX6uZ+LdMJHR9ibE+aEGw8wb
4+zzQtyTebI2oRYjzFv1H/6mDiPtvajVND3T4znqdu0ez1+76e1UjfuIs0Qz
+100XdwzleIs0dR+J72NafF+9SudrNt0arx76ylaQWvrX9SM52Leos/zJ5ti
bW9zvHs2xH2bv9Sz/MEXDLVXXX+narwT89o4VxS3Hqgl4ruGFvxs/oXlpDIn
xfVbn4xrohEX+Y+Ez/6PMxHnnAuc5ypX4kzRgHP8y2UuxTunPj0o6Hf01EMc
jHcR9829cTbNeeKc6mz6WZfUenEm4hwnXf8OPcB+XmOsvdd1B63pHf9fupsW
vBR/115BrUt16xpkSLr+XXwNVuenew==
                    "]]}}], {}}, {
                  InsetBox["\<\"\[Mu] = \"\>", {-1.8, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["0.2`", {-1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {InsetBox[
                   SubscriptBox["C", "J"], {1.4, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["\<\"=\"\>", {1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["3.23`", {1.7, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {
                  {PointSize[0.05], PointBox[{-0.2, 0}]}, 
                  {PointSize[0.0125], PointBox[{0.8, 0}]}}, 
                 {PointSize[0.007], PointBox[{0.4463998339305619, 0}], 
                  PointBox[{1.2771956561278897`, 0}], 
                  PointBox[{-1.0806611991222994`, 0}], 
                  PointBox[
                   NCache[{0.3, Rational[1, 2] 3^Rational[1, 2]}, {0.3, 
                    0.8660254037844386}]], 
                  PointBox[
                   NCache[{0.3, Rational[-1, 2] 3^Rational[1, 2]}, {
                    0.3, -0.8660254037844386}]]}},
                AspectRatio->1,
                Axes->{False, False},
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                Frame->{{True, True}, {True, True}},
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLines->{None, None},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None, "TransparentPolygonMesh" -> 
                  True, "AxesInFront" -> True},
                PlotRange->{{-2, 2}, {-2, 2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.02], 
                   Scaled[0.02]}, {
                   Scaled[0.02], 
                   Scaled[0.02]}},
                Ticks->{Automatic, Automatic}], 179->
               GraphicsBox[{{GraphicsComplexBox[CompressedData["
1:eJyFWXlc1NUWN7WeqfOeH/c3mhmlb3JFbHq59I6JoeE2KqWZjblmUqiIC8TD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                   "], {{
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[0.3], EdgeForm[None], 
                    GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxNWXuc12MWfs9LU9PUTFNNDV00NRGVSKkm3ZNbJSoVRSUViay0JKJVEete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                    "]], PolygonBox[CompressedData["
1:eJwtlnm0T1Ucxc/3RnOxNFk0UJEGMialhPci8zxneKZHMiZDiFBmZShRerVI
CoVCEWWpkEgJqaw0qZSVZK1Wmj577ffHXr+9z7n3/s65Z3/395bNG9RqYJZS
WgWKgAmRUjMwDZ4HnoPvA7PhzUAn+DwwBD4TNOTmxejhyddcjO6KbgQfBmrC
D4DH4a3B7fAvwBPw0eAV+GTuOYPfa9HL+G2L3gu/GnyMzkHvhJcEVdBXotfC
S4B+6CVgJPxNsBL+KPNF+S2HnsxvczAd3hs0htcCo+BTwTPwiVz/H7wJOIg+
Dp6CXwWqwssyvx5+EViDrobeAt8H/kAfDq91EfgKPhC0g88Bh+Cf6xnJY3vD
e9JehoK/4KfD76INKM+zK4CN8PbgReZOgoVaK3gZPon54LeD9qy9oE/Cu4Nf
0b+AJ5P3UJm5B9H3wseCj+AVwWD4DLAHXjm8llngeviF3LMcPgC0RRdH3w/P
AQ3QY9F/wu8CZ2q9jN2ntYK+6D4gH/4YmKjzCL/7+cnXnsP8suR7zoWfDeon
j52XeQ3675dANXmNsaPw0uASeHfGVso7YBS8KmObk89EZ52rM00+8yuY64Fe
A18NLkeXBI3hr4JjzP0c3ovumQPfBqbAB4Fcrl0Q9rJqpBG6dOZ7d8kj8J7M
r4O/Acpk9qi8qbEvw2eos5Pnc+APcc0p1QKogx6BPqF3D4agb0KPgXfUGaIv
Ra9IroF8eQ09At5KQJ8Ci+FLwQ2ZPSTvbALXZK4R1caG5NquDyYk1/g6+HrQ
FV5Re4DX4J6t8P3gQ/QueVpnnbz2LeieyXuYG84EZYE8pbNSZigrdGaqfb0z
vStlwD3w/aphPRtchi4Ic53pMHSN8FkfA10zr0lr+Qx0Rn+LrgD/FHRCrw7z
T8Df8I6ZeQFoCm+SuZZ3653rvMAh+Ad6H/DmmedagN7wlsoonZ08omxj7Di8
C/gX3Q19AL4EVIdvYOwg/B0wHr4RjIfPk4dVp5nPQmeq/26hTEheQ56yB90n
eayXwhj0TV7DHZnXpLVsl/+4dns4S8uAHsx9rxpIXkN99Ex0f/iO5KxYXpit
yozr0G3AnuSMmcZYncy12i95r7ULs1N7roW+O+zV98BU+G2MTUpes7y7NuxV
eVhZVC/sZWWSsmJ6+NnKjO6ZPSev6R3+o2zKfLYvJHtZe9Da5em6el5mbzOV
tqo2wfvJa7hVaw+vbRuYgp4V9mrxwt6yQh5N7jHt0e0yZ6d6zOuqR/Au/OHk
XrAIXSq5J6iXrEJ3Tu4pyprR4bNW5oyAV2FsXHLGjoN3Yawh/DR4DT4SvJ18
zTh4Ta7pllxzlcIZrOxVTx2q/Ax78SdQTtkb7g3qWXXhR8Dc5GeoFrpk7kWq
iWHor8N70Z43hz0pLz6S7JUfwr1dnhkOr5S5N2iP3cIZq2xV5siLtTPXijx5
i7yEfiu5hr8J14hqQ2vaFM58Zb0yRr1oAHg6uSdNgv8YXosy5MZwT1IvUsYc
1drDvUw11BG+O5zFeqfyrnqseqs8rCwvlTmbleljwjWq2lSGqXcuDfdm9dAm
8N/AguSe/Dv8RLiWNKazUoYUJJ+ZvCGPypvyiLwnz8lr8mDn8JnrrIuBEvIX
Y7nJPbN/OIOVvXpnvcI9Q71C3xR54R6l3qRvmhnofPRhnbXeCfzm8LOPJM+V
D9eCrimqekbUS6559dLzM/dO9dQi8LMy92ZdMz/8TD1L32g7lSXh/2oAZodr
qHjhHgJ+Z+bsUU9vqfxSRib3oMGZv5H0bfSd3olqMfwt9QB4PpzpynLdo97a
Ifxf6rGtmWuVuZfpG656uAbkfdXgs+H/0LObao3Ko8xc35zy1o7wt5w8pl6/
MPzf6vnFuPaCzN8u+qb5H4GMWMQ=
                    "]]}]}, {}, {}, {}, {}}, 
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwl1He4jmUcwPHXQWREWlZWUbKijIjsLTkoGeGEEA7KFk5msiqrtIyizDSM
hl1RiEi2BqJhNIwin9/lj4/v/btfnPO89309hVNSk3ulSyQSXfyRzN/USkok
Jmo3vUMzagvNoJm4hjvN12oWMpONrBS3f53mIDstzTn1Ls2lD+v1+ohOZpz1
JP2Kr5lCd3sldCul6GF+SVszlZ7m0rqdu0k1T9cdfENt8wy9WdvrTdpBb9E3
tYF+pxW43bq73qbddB5zaW5O5rx1V4pYz9Fm+hDnrJ9gNk+Zy+tu7qGP+Q3d
xbfUN7+u9bQu/1h35jV6m8tpYe2kBfVxLaRltYCm6K3aUV/hZT5nE68y0mez
dCf30jfp6nl+wYPWTWlEExrzvf0/+J3f4vtlM424j6L+Tk+9wEX+pQr7OcDb
/Mlb/MUh5tMyzjXOmN7mdxll/Y4eZiGjzYviO+MI1Rlo7wMdwiXamR/jQ+vy
OlQv0z7OkY+sV/BMnKF5mFbUGvoDP7KUfvbu1yYsZox5iT4d98q6n5bWqnGP
tL+W0QFaVqtpf10WvyP/8ai5Ne9Zt9GftK0uj7PXQVpOB8dZ6ErtqEf1GM8y
wpwWZ0MtBps/iXOM35E082htSh2Gmtfqr5yMexTPbu/5+P40ifHWD+iGuJdx
/qSLZ4jnozPNfNZJE/G9UCXuWtxn+yn6vz5HZet1Ol7X6zgqWY+N+xF3WE9Q
O87MvCbOmV/4NP4Pe5/Fc/IxY82r9TjDWcUgezX15/i9GWB+P+4uJaz7aEld
oK3ivRLvEIrFuyfeS/FO4qDP4wU23DpV97E3noHGnOYUZzkTz0FDvuTJuAv+
XUXdE/vW+chPbvKShzrM9PmNcS/1Bm2n0+JnW5fRBnEfGGZuG/eEbbwQZ27v
Rd0YzxI/11xSt9CcCXSNZ9P61IjvhvRJV9/JVwAuUKaW
                    "]]}}], {}}, {
                  InsetBox["\<\"\[Mu] = \"\>", {-1.8, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["0.2`", {-1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {InsetBox[
                   SubscriptBox["C", "J"], {1.4, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["\<\"=\"\>", {1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["3.2199999999999998`", {1.7, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {
                  {PointSize[0.05], PointBox[{-0.2, 0}]}, 
                  {PointSize[0.0125], PointBox[{0.8, 0}]}}, 
                 {PointSize[0.007], PointBox[{0.4463998339305619, 0}], 
                  PointBox[{1.2771956561278897`, 0}], 
                  PointBox[{-1.0806611991222994`, 0}], 
                  PointBox[
                   NCache[{0.3, Rational[1, 2] 3^Rational[1, 2]}, {0.3, 
                    0.8660254037844386}]], 
                  PointBox[
                   NCache[{0.3, Rational[-1, 2] 3^Rational[1, 2]}, {
                    0.3, -0.8660254037844386}]]}},
                AspectRatio->1,
                Axes->{False, False},
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                Frame->{{True, True}, {True, True}},
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLines->{None, None},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None, "TransparentPolygonMesh" -> 
                  True, "AxesInFront" -> True},
                PlotRange->{{-2, 2}, {-2, 2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.02], 
                   Scaled[0.02]}, {
                   Scaled[0.02], 
                   Scaled[0.02]}},
                Ticks->{Automatic, Automatic}], 180->
               GraphicsBox[{{GraphicsComplexBox[CompressedData["
1:eJyFWnt4zFf6d1trMaERZaeqVaRT94ZxW/ZF3KpEim5SP8Zlq0VcU7eJFPVj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                   "], {{
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[0.3], EdgeForm[None], 
                    GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxNmXe8V8URxXcuiDTpRZD2KAaQDgqIARUJKiqKDRVBQESFCHaxo2IDFOwN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                    "]], PolygonBox[CompressedData["
1:eJwtlnmwj1Ucxs856WpXWq8iFNqmULJlV9ZruQjlWq59z6VSdC3dkRY3hYpK
igrZt1C0IEKjphFRIaWakZQWM5I+zzy/P575fZ73vL/zvu853+VUyB+eOyyF
EFahEmgkpgD1gB/SNTihxvALaCg8BOXBo1AWPCCGMAueiWrAZyXfm4824Cfh
T8P3oV74s/G9g+dsA1+E5sCfoRmM56MXg+9ZDz/O+Em4M6oAX4uWwsvQTsZ3
oKvg/qgkY33xTYPf6WL8UPxc+A20B16OOsCPodKMD8e/Db+FLsXXw5cOvvYw
XI5rS+CWmgM/Fv8L3Bzdgf8PTde36Zvg8YyfgMuiDvj6+M1wfdQKbpn830Ho
OcY3Ra/1JvQUPAV1gwvREPhCrTF8DyoFX5DMWrOljBfjs/i9Dr+Y3574PXBF
FJL3RHsxAy2Eu3DtS7g8GoPfjR6A26NX4PMYnw1v0zM1L3558Jrfj2+PCuDR
KAcuYvwUXE1rir9Fawrnas/gSmgF/AVaw/jt+PXwN6gd/gn8Gbg2WoD/XmsI
f47ehdeiTvDN6AD8XfRa6h1+hx+Njt8pqApz3YhWwm3RrXAh4x2D3+k3xQrX
FsJPopX4Z/HZmXsm8FsVv0bPRn9EP0NzFyuG4TZohGIDZXPv5cmxoTk/Zaw2
6gs/ov2Gv4qOtXvRZrgF9++Am6Gf8APRy/Ck4Ni7hPF5wTHYBF8WvxgupxjC
X4afr1hFreG50bE0FjXQs7h2FL4arcDfhl8NV0LnwoO59hr8KuoSvcfa28lo
FVwt+dv3oRb4E9HfXkVzMvYgfhH8DuqE74haK1aD1+JKtCCTL+fAdbm/VPA3
bofvis7VMagy4+VRm+AYGcVYmeS5clBDfCH+GFxGOYofhz8e/MxrknNOuaZ3
0lwVk2uD5nw/OqeUS9qzffB+1BWuqv3k3q6oXXBOXJ8cg4o9xfz5+DfxO4PX
7IrkmqVapW/srlqJdgfP0Ss5p5RLe4NzcUk0Kyfz8N2Sc1P/uSE5R5Qbitkc
cfRe65nt9W6qefAuVB1epxyA16KX4NFcOxJc86bhR+EPKxbQoOQcUu58iwYk
56Bybz96JjqnlcuqOX8pHpPvfR4NTl4zrZWemYvvkPwurdBWxrahPnCWcoqx
PtHPLsHvR8ovtBE/Ek2FayWzeohyf2N0b1ANaKLegd8Kf4KOwI2TuQj9iG+E
3wJPRH31PFQZ/hqtVr9A64Jr2nHVvuSxp4N7SevoWFZPUSw1is4VxZRq9/zo
2FMNb5r8jfo2vdOw6J6iXqIcVa7NU04H55xitSB6bRSzd+KL8RsUi8pxuEZy
LVBNqwnnRtc+3aNapJxVrmZnavuy6FqqGl8vZXoG/uPgXqSaoFqgnqRe2za6
FqvnNsA3RNNgLofmcLPkXNquNYrugep9qil/KjeTY2OqYgD+Nbo2qF4ejO6J
yu1xWh/4UDQrRo9G11jdq//8AB+O7jXj0Wz4Z9X84J42ObqmqpYqJ0/BPVBD
5U7wXk+PZu25ev+xzPuoZvWE/43uvfqPavfE6NxQDT8Dn1bMBPfoCfr+6F75
d/De7YqundrDmtE1XLVbMZ0XHXOKNa1hnegaptrVD82E+6kHBdf811VPk9dW
NV5nk7uTe6nOKDrbKKYVyzrj6L+zoufSHJ11f2b9dObYq7HkWqwYVy4pphRL
yimdZfRN+hadaYqic1i5qx6rXNCeai+VE7W5Vwe+A/AH6CZ4dHSvHKY9is4Z
5Yp6xknVa+75MGTOhNE9QLVfPUlrG5PPFlrj4clnRJ0N9Yx/GK+T/KzuiqdM
DCt2dSYaoXrItYPwoeBevij6XdTTt0T3TPXKgYrX5Dk1l/5TN3kO/VfvqLPe
nOh7debrHV2TVItK4gdF90D1Pp1x+kefYXV2VY9S7awenSuqoYpV9Wj1ZsWs
am2tzFyquTr7vBd9NtUZ6H/y5mSt
                    "]]}]}, {}, {}, {}, {}}, 
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwl1Hecz3UcwPHfSRqikKhEEskqe8UZDVlx7mRfRxHKJs6WjLqujDIalNFW
adptlYwK0ZCd1bI3z/fDH897vd/f+z4ev7vv93NXvHPvlF5JiUSisy8d2UX9
HInEVB2olfUU6ZzkAU5ThbOc4wxJ7k1Q1XyR5iQHGfaLtZoO0ueSLnzWbhrY
G/K8+U5dqd8yjcfs1fU7ajLEPkO7MpNMey39njsYan9Bf2AVd9lf1Mu1h16m
PTW3ztNm+qM25AbzIL1eB2oRbaCj9HVtrft1ANeZX9M0TWWfuT/zGWmvr+tI
Zrh9rq5lDU3tc7SJNmavuS+vMsxeV6/WPppfe2sBraP5NF7UVfqozmYWX/MV
97r+it6tjbiH1fZ6jDD3029IMbfiPlrSgp/i+bONrfHsKer6/fEcmWz+Wydp
m/gMSphv5g3zdnayg595kza+1462DLF30nTa05EOrHf9nThT5gWaoUN1A40Z
Y/9IH+cw3ewP87G5so7VI3SPd8wn5k95Is6nfZxW1Sa6kV94n9HxfLQt75Jt
fy/eAWXNw7VcPEetoCO0vI7UD3jGvFBv01H6X5xpcxce4kE2xVnVD7Wijtbb
dYxW0kXaU3/V35jIk/YJ2o7m8XvYl8Z1nuYpe5a2pyUT7Cv0T7bQirquTdY6
Okm/5Is4o3EGOB5/L1qbvvEe7H30mNbSmnHO4uzFOeMRjvres9Qwfxazfh7P
gWrmbK2uKfoHLRhvXx4/M8sYF2dOf6cZY+1L4j4Wxzu2N9XNcZY5xEH+J5O3
4xm45y0to4P1Fr2V0nFWKUkpbuQmilOMf9x7gH8pbL+WghTiGpqTlyu5In5n
9+XRlzRLX9Y9/BVnjUvj+WnrOJPkinOpl8T71+kMNtfQNLrE+41zEX8HTGGA
vZKmkmyux4mkC/+DzwOixKkL
                    "]]}}], {}}, {
                  InsetBox["\<\"\[Mu] = \"\>", {-1.8, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["0.2`", {-1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {InsetBox[
                   SubscriptBox["C", "J"], {1.4, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["\<\"=\"\>", {1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["3.21`", {1.7, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {
                  {PointSize[0.05], PointBox[{-0.2, 0}]}, 
                  {PointSize[0.0125], PointBox[{0.8, 0}]}}, 
                 {PointSize[0.007], PointBox[{0.4463998339305619, 0}], 
                  PointBox[{1.2771956561278897`, 0}], 
                  PointBox[{-1.0806611991222994`, 0}], 
                  PointBox[
                   NCache[{0.3, Rational[1, 2] 3^Rational[1, 2]}, {0.3, 
                    0.8660254037844386}]], 
                  PointBox[
                   NCache[{0.3, Rational[-1, 2] 3^Rational[1, 2]}, {
                    0.3, -0.8660254037844386}]]}},
                AspectRatio->1,
                Axes->{False, False},
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                Frame->{{True, True}, {True, True}},
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLines->{None, None},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None, "TransparentPolygonMesh" -> 
                  True, "AxesInFront" -> True},
                PlotRange->{{-2, 2}, {-2, 2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.02], 
                   Scaled[0.02]}, {
                   Scaled[0.02], 
                   Scaled[0.02]}},
                Ticks->{Automatic, Automatic}], 181->
               GraphicsBox[{{GraphicsComplexBox[CompressedData["
1:eJyFWXl0k1UWLwgFgYwIlSUwLIoYFlmqYbBTe8FKlUIhYpHFElooi0SBYTkl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                   "], {{
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[0.3], EdgeForm[None], 
                    GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxNWXeYV9URvXOBpcnCwgIKsrAUJaCoEIqIdERAEASUIlIMWAELGAWVomRB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                    "]], PolygonBox[CompressedData["
1:eJwtlnnwj1UYxe9zK9KmaBclg0ZZCpVkTfyKCNn3n33PvmaEhKRSKA1CIlQK
WRqaCpMWIYXUtEg1lUnStM/0OXP8ceZ7zr3v933vfe7znOeWLRzaakhOKa0F
Z4ItkVIVUAgfBerBx/DACfiN4CH0a+B++NugH3N9QafksfPhxcBd8BfBbp59
D7SBV9MYfBIYCx+UzB8E7ZPHtsHngd7w0aARvCbvewdeF8xBtwUj4d3BI/Da
zL8LLwI2oa8Pz40Af+ndYD58Hijk2R6gA3yI9qS9oI/CS4FT6OtAV/hccBZz
VdEl4MvACnglxrbAPwYv6HvorfBPQEv0n6AbvCE4m7lq6JJ6FqyGj2PsJLwt
KAovDM+tANegm4E9ii2Yz1xPsDI5JsvgFZjfAC+fvLYz0EuS11gbfQzMglcE
SxRf5v+Dl0teSxH08uQ1LUbfi94Lv1Y5AO8e3utScCX6MvAKfB2owdxw9A/w
0qAnfF04lm+C6ug+4Ah8KPiWuaNgZvKa3oBvBZcn59jT8GE8fwx+N6iJvhj9
MrwM+BfdCTwLfwY0Za40eDU5RsuZm6qc47clemA4hordPaAzOqF78tNY+QS/
I/vdeuco5iuiN8JfB1+iz8vO3WmKMXz46XcPAP/AK4Pi8AVgJrwVeDL5zIvz
/IVgtWIHJsIHq2b0X+UEfDxjp+C1kmMzBKxPjlEBc02yY9FXMWGufrhWhmnN
8ANgIvxDcAPPjtcaFFtwBN4hvLYp4ArmS2WfXTNwAbwX82uS17gSPpqx4/DW
ChW8K2OL4YvAJehLs2Ohmp4YXpPWopouk/0NvVtnMkDz2WvTWAn5A2MvJXtM
H/hF2XtrCg6hH8iOzQQwGd1UOZbsCSWzc065pnf8LS8BjZJrehi8XPbZtAC7
0EuV0/AxyV7xGOiRTnuG1hb2kkOgAboheB/eRPmSXdOq5QOgY3bNq9b364zR
a8P/PQjqo+tln7Xe0QreEjRPrinVeoOwd6rmJ6DvQ9fTXsDt6DpgYXJNNIaH
agj+Afhe+Z+9ljmgXzimiqVq5KrsmCvWqtFu4TPU2ckTzoHfmf2uVWAQvBLP
FIV/Bb5TvmTvbXay18iT5EXynHbw9tm1UUH5Fu4R6g2KqXJ3EeifnMPy4tno
3cmerNqUZ8mrip322gX8FiR7bo3snqJe8pb2AJ8CtsMHq0aYn4XeBd+pmgx7
jLxFPUdetDCcS/Kkb+CtGdsHnwFGwGuFve+nZK+pHvZ6ec5t2lu4d+gbn8Fv
zf7WZK0fXS17LeoZ8tLnwrkmT62KrpJdy9u0hnBNqhYfB4fRt6B3wCeBrvAu
2b1wU7IXrAn3AnnC8/AxYDN8oPKX+TbZsdee5FWjw/+VZ6nXnpt9tqrPjao1
cDi5hvozVx4tG/wC3Az5SD0IfjUYCt8R/pZyVl5QN9w75Anyrq/B9GQPawE/
Aboo97Ue+EnwRPLYb/BfQYPksU9VS/LkZM/6GX48HAutSWtVTamWtOay8EFh
71ZO7YfvC691fHLubA/fDZRDe5R74b1rT/JinaHOTp48MpwTygX1TNVWl3Av
UI0p1qoB5b5iXge+M+wd8tRx4TPVWarHjw3XpGpRd4Ae4Z65NLmnHgx7mrxM
e27OXEG4tyqGvdA/ojsq15K9Sjmq3JRnKfcrZ+eSakBevTe8d3n2w+Ez1VnK
Qx4N17RqWZ6o2tscvvuoBvWtm7J7s76ps/k9fLfRGbUOe5K8SJ7QMdxz1Wvl
SRvg68Pe2Cs5l2egOyfn9B/y2vBdR3emX+DNw7mhZ9RLngr/Vz1lLvxzMDW5
J7cL39F0N1NPnR72BHmB7nx6Vj1NvUz/6a1eE46d7hi6m64K9y7dUf8Hq9tO
yQ==
                    "]]}]}, {}, {}, {}, {}}, 
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwl0llTTgEYwPHzJtlLwn0XWiTZs1aWFhekUJFCKXvFrQszzZhICaH4FoYR
pdIXkHQlog9gKaSy/97p4jf/53nmvO+cixNfUVtYEwqC4CGfDG9IjwiCq3pG
E/QLe/lMPqMk8pVvjDHOd5KYYB8/KGCSZM76v2tayBAb7ZtoNG/WJ3qdLeYm
fUoHKZx3u6FFtFBjX6HPWEmt/aZ20clW+zb+mA/zm1L+sst9Jy/M61lsPqWL
9KTG6Tq9qA90t77XamLN9zVPcxk2V9HOBfta7WU1dfY27aGbu9S73dNKZpkr
dLau0ig9rpF6TGdqms7Qoxqh5XqHVh7ziO3uO8ggi0yeu68hxryQaE7YX/Ga
AQbpYwP9vOQ0Szy7lHTzFR3RD8w3L2AO85hLNjmEKPPMP46EPyj7Lb2st/Ud
bznEL1LJpZgpSvjJQZo553fLNYf9XLIf0D00hN/Tvkyzw+9v/hia/n7/AxrJ
U3I=
                    "]], LineBox[CompressedData["
1:eJwl0mlTzWEYwOG/voQlpIVEttSMLbS8oBSKChVCGcnRviBL6ktEsoRI0kxf
IGvknaW3sqYv4XrGi2t+9/2cM2fO/zknsSZWcmFBFEXjLIyLokVscbBUz2mB
9usnvvCZSYqcf9UZrpgv02D+RrF5j+7XlzrAAXMJB4nZX7GDFvsDbecXR+xH
GTKv0Q79zTFzJQ/Na7VT/5Bu7tJWzdbXvOEuzc626l7ucN0+qBdJMjdqsm7T
ldqkKdqs9+kx39NV2qKzlJoPUcZh3jor1wpW02pP1TZN02qqmLK/D3dFd7iv
cLfspsM+HM7Dd+QahUzwjONeH9ET+lHzyTL3aab26jgvOGuvY958k83mWs6w
z35a/2qGbuIUY/YaPclceG42mkfDZ+hzvcE68wbWk2efJpcu+1O9yhM67Tn6
gV3ht7U/1ks8os2+U9+xnZ/84Dvhz3g73IH33NJEPa8JWq8rwnNQyDKWs5h4
lsT9/w//AwkRU/w=
                    "]]}}], {}}, {
                  InsetBox["\<\"\[Mu] = \"\>", {-1.8, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["0.2`", {-1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {InsetBox[
                   SubscriptBox["C", "J"], {1.4, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["\<\"=\"\>", {1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["3.2`", {1.7, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {
                  {PointSize[0.05], PointBox[{-0.2, 0}]}, 
                  {PointSize[0.0125], PointBox[{0.8, 0}]}}, 
                 {PointSize[0.007], PointBox[{0.4463998339305619, 0}], 
                  PointBox[{1.2771956561278897`, 0}], 
                  PointBox[{-1.0806611991222994`, 0}], 
                  PointBox[
                   NCache[{0.3, Rational[1, 2] 3^Rational[1, 2]}, {0.3, 
                    0.8660254037844386}]], 
                  PointBox[
                   NCache[{0.3, Rational[-1, 2] 3^Rational[1, 2]}, {
                    0.3, -0.8660254037844386}]]}},
                AspectRatio->1,
                Axes->{False, False},
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                Frame->{{True, True}, {True, True}},
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLines->{None, None},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None, "TransparentPolygonMesh" -> 
                  True, "AxesInFront" -> True},
                PlotRange->{{-2, 2}, {-2, 2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.02], 
                   Scaled[0.02]}, {
                   Scaled[0.02], 
                   Scaled[0.02]}},
                Ticks->{Automatic, Automatic}], 182->
               GraphicsBox[{{GraphicsComplexBox[CompressedData["
1:eJx1WntYlNXW9wYphR+fx8xGBTM0Uo+aRh1NXdaYISlnMpP00JhKmuIF8Rbm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                   "], {{
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[0.3], EdgeForm[None], 
                    GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxNWHn8T1UaPu+1bz8/yw8/W5Ts2QnZl0Ii2yCFZJIUZYqQJltUlEqNmhpU
06oVlRpLm5pomUo7NUq0SCFCNM8zz+PDH8/3fe+555577vs+73K+NUdN6D8+
SynVw08ByPeAd4EzgJKRUglgF/QDwH5gGvAfoChQBiiO+wUhS3B+kl4IWAQU
A8oClwFDgY7Ad8AaYDrwAfA+0AlYzLWAcsAyoAJQBcg7Ye3zga5ALsfx3vJA
KeAjXHf33IuBAcDpwL1+tjzwCVARqApkeGYh5K1+D9cuBZwJdAHygYnAaKAn
vwPziwK7oR8CDgIzgMIYKwTcCP17YDkwC9gHbAX6AF8AnwO9gN+Bw8AcYAtw
KtAIeBQYCfSg/bBePchmQH+gH9ACWAk0BloB3wDn+tnmSfPrA98CTfztra03
9fO83wDYCDzv59r4fjPv7QagNjAGGOg1/gS0T+LGu/Y/fT8Y6GB/v29O0C/k
yC77ntwhP4qbD2X87HTbvJCfL2k/rTFHSpkPZb3OHfZ9N8/Ls0/p/872K3lQ
wc9ebZ7Qj5cAg/yt5AP5xf1cAQxP4g35Q85VTuJJFfOC/Kjq9S8CzgZqmBe9
gVr251z7hn6eYX+QI7ttd3Jnlu1/jrlQ1zxoZB6QL+TEacDkJN6dAhxJ4lcT
r9vc/iLvyJWmfkcL3+trne866ue5P3KGHGrptehb8oScaeX9P287NTMv2nje
piTekIs/JOUG+jHw/p8g29G30HNC/itobtC/Y4EL7I+E+39AzAfOS/JdDjAV
mJIUL0uB65Pi8GVgvefN9xqlgQ/NBfJtD/CL/XFhUgxVBz4FzkrHcwj9TM6M
sm2r+5097ccJSfFPzhTAPn+2v0uH/EXbr7D/6LuvbGva+Rq/m2t+DWxLik/G
zWDb46qkeKZvdgI7kvIU7TvQvmhhGze3bRl7BeyHQZ57KfBnv5s2HmI7X26b
5tgXQ63TjsP8Xa/ZH4ylK22L6rbl+bYn7TTctupq3+XbriM9n3YdYdsydivY
xq8nxUmNpDx/HVDY+xpvP/JbL/b39vW38LuH+hty/K1j/L0X2Df53uNY72t1
Umy3sV3H2XYj/W3V7dvJ1um3vyT5kt890fcnJeWLfO/lKu+nq8dL236TPGey
/c01y4Z8TP+uS6pzHb0uucX43WedHGPMMH8yp11rHUukmUl546SkOst7me03
3f59KylOGCM3+14h259zmPfqeR3mg0Nel754Oim3M8/MTspFNZM4TL2h9zjV
e+b+R3vPj3kd7u17P38y8Lh1rsMcxlzW2O+Z43fluj4yXigLW38GmJdUa25K
ym91kvLVPOu0P2OenGziOcxJz/oZzqHxFiT1D0NsF9qE7+EcvmuB1ylt/RbP
vzOpJrHG/DMp11dL6gtut36bryvZZ4vsQ9psue223s9W9H2uyzr3N+tlfX+h
1+TYXZ5zd1KdK2f9Hs//u685zlhckhSPrH2sYaxf91kv7zXu9rNLfK+879+X
jte8xf4O5rmlSbnhkaT+g/H9IHB/Ulwvs86aWMHXeR57wOMj/EwVjy+zTns+
lFQ7b/U1dfJjrv35hG1ILpFrTyXl8H/bx/TvG0lcIU+YE1mfWJvo2xX2L9dk
XSMHX/Ccth5blVTvVvmade45X7fyXD7DHMLeY21S/HJstcen+x7jizH3r6Sc
ttbjhf0dTybx4UU/39Zz1nlN5r71STwpEupBef1qUp3r7HHq5Nt43+vsfW70
moxF5tkaSbG2wfbZYHtRZ7/EXM98+aZtSnvO83Udv/MVv6uf16eN30mq98fG
Nvm9lG9bH+d5nEN+/SOJY+wL2CMWteRZgvltmq+ps3azVyT/9yb1E7xmX8A+
Mtfj1ItYfmCdz25Oqlebfc112LOx3pN7Hyf1c+TnMuvk7X+T8l1D+4DPVPB9
PtPda3CcXP3M19TZm32ZlHvZ47GnZz6c4euTPJfPsDb+mtSTsJ/bZkl+9vL8
ep7DdWt5bers/WZ5nw0suW/WScYt+2rG8blel2uyf2MvQT5vT+rzyPmV1htZ
bj/hua/9rh1+nrW4ifXGJ+ybcwZ4HueQ76zrhT220++9zuOMFcYC6wTjmn0h
+0PWstken2V/0+/kyY/Wi3juLs//wffIKfKWeYPcLumek30RuUHedLL99tme
7NvYv9VIqoW7bU/O3+v3F3OPx/o1xc/28bfTd6xfva3Xstzj8V/sP46TAwf9
HvJ8v3211XO2eOyAv2uXr6lf63E+dz3wG/BX7/eg98+9kue5tsle24r3D3nO
TOvcC3MCz3KswYet027zbatc2/JIOl5Xqdfx+GHPp82PnjD3qOdwDQYybc7+
lH1qO69TyOeRnzxOH7HuMddVOmFPje2f3d7/Aq853+Psv+mX9X6WNYTr8rzD
/M++orTPP7ThS7Yn60LhY+dxyO9CufAcyG4hLhXDxMtDvu0LfVmo7+sY+g+E
sZwPWTnTuv8/U4ZyRgGMjQ3xqwv0Oe6zD0EeBh6mHyG72yadMGdGqDfpB7kt
1H9UwXjVTLXkIMb2h2pkjv/PYK3peOzaNihiG9JmPE82MJdK+HzNsWK22yxf
U8/zuYx9dTn/n1PAPmIscQ3mpdLuzXi/pOfQn7m2c0HbvJ7n5nr+h5BTQnni
AcirQ3lmKeTEUEyVwrdOCNXyktDHh3rSStA/DtWF2tCfC/VIdaG/E8qlp0J/
K5Tz6bd77bviGC+RqW8oA9kylPdyoF8R6iG4r4e8t1yMl81U+ytCTg/V6k6Q
p2XKV+9Bb5gpV3HsxdD4p5Bn2qefQ/Zw3/8R5LTQeeUyyKKZ+oDN0KeGzjrd
MHZz6ByzFbJX6Ny2EHJYph5qO/Q6mfpO8qK6uVEN8olQviV/rzOHH4fsEjoL
Ml7o9932L88kx/5zoWTPSI7yTEhO9cCad4TOSZUh24TyyVHIi0J94KuQr4TO
OqMgD4T6udqQv9lHXcnh0NmuK+TyUF/QOuRX+rQ5ftaE6gjf09vvehCydeZ+
gnwJ9ee3h3xPvzeBbJqprxmM8R9DffMWrh86V3/GuAzloa8g8x1rkyEnhc6F
vbFGo9D5r0Jof9xbM4w3z9QP0Q+3hXwxAnJfqMcdSruG+vLzMOeWUD8+DHJP
qO8ZTt+GeurHIB8NnUvLYf41oX6T3FxrfuZh/JHQ+Za+KudYK2GdPmMO4H9b
zDmUeY7fzr7OcW7I89zi9jvPoYybCx07nFPG89tDbgrVl/Z+N987EPu5KXTG
HRDiInn4CeSbofz6LbkcOi/8GuIubXUKnv0mdE56GvKZUN+6A/JGr9kYc4pk
6vfPhmwQ+o9gLmTNTD1oLeirQj1bfYxlmc6dgyAXhf5b6Qm9XujsPj+UF5gT
XoC+OnS2rx/K48zh5XH/4dB/Dc1CuZ55/uWkXLoesnooPhmbhSAvDZ1rud9x
oT1zL2NC++FeItN+WAfuCdWCaiEek8OXhOoEx/+AfiR0xuJ3F8z07b+Hagbr
RftMeYQ5ZHQoDhmD3HvbTPtnXmnp3NImU85lTiPXOmTi2xmZ8g5zTpVQfWLc
k2vtMvGN8cGaxBi5IRTDjN8WzDeh3vi10PfwWxpCdg79J/AU5JOh/ziYk2aG
8tJZoZxITq2EXBH6b5X+PNk+ZR5t5BzLHM88whzC3NAklB/4/qbew3rI10P/
v/SBnB3qN1hb7g/Vlw2Qb4T+s2Dt7WB7roM8PXROeZZ7yFQ3WZOZx5nDB2eK
B8ZCY8iX/I2M0RaOU8bKRs8hx/ub55zb0PMXhPICc8KgUJwwRsh9xhX5P4R+
yNTb3RniNPlTN5SLmYeZz74M5bS7Qlwnz3dBHxL6L6FnqH6wdvzM94b+J7gy
lOOY31pBLgn9V8S8+EUoN74NuTPUYy4OxSF5+D8moKvf
                    "]], PolygonBox[CompressedData["
1:eJwtlnmwz1UYxs97kqY9KtVNuJcWZQ1tF9Fylaibay+FhNC9qDCSkGSIwlAo
hFTI0ko1iRDalGk0RiOZJpU2bZqpqc/Tc//4zDzvOed3vt/vOe/7vL/CvhWd
ynNKaTFUge8jpW4wBz0baqOvZcFn6GrwIPE4aInW74rRtaAX+i5ozWAr6IIe
CIXM/Qzz0adCH/TvcDu6HfyB7gvL0M/CDHRvWJq85mT2GkbcEf0y1EH/AE+g
q8N6aWiPvif5pS7QHsgXoD76dRiO7gv3okdCJ2k4F92O3+xB14QRxFfD4OQ1
jdDrwnvrHRajS1l/AF0Ky7QX8UF0GTQlvpF4P7oBXIG+PHuuv76B+WlwG3oo
FKFLmN+NLoA/w++kd9GZHEH/FT6bc2AheiuMRu/QN6NXwCD0TXAofGe6K93h
degvdKfoVvCV3g/aoKfDXPTRPH+F7gpaoouhM3oADGa+KvFK9ItwFfHFcGfy
M6swN5D4BvQd0ER3xdg+dEMYrzmYiu4O7dFfhnVr2I++Ofwu0+AAugxmoh/X
nuh/4Xl9C5wfvmPdrcYuQj8ZfvYW+AV9CyxAPw3NtT9rvka3gMPhnFQuas0q
9NnQAz0E5qFvZf1Rld80XTEsTL6zX5W7sKSyZhagT2L9S+jt+qbwO+rdnoOf
wjmrXJ0HE3Q/rH8bXRWeIu5KfBjdAS4lPoP4DeUOjCFeHq6l9fAbul44V/QO
vVSLsAhdopwNn6HObgb8qG8LP3su1MuuWdXqZpiPPoGxNaoFnRnxicRr0e9B
Z+JvdKa6++Raagj9kmvqEp0l61+T1v2gz8vOVd1hV+V6+N0qknNjkXIwOUem
htdoTh5Sgt6jsWSP2a774Tdvoccme9GjjF2T7Em19Kzss9Sab8PfqG+blVxb
j8nDkmusiLhu9tmcCR+Hc0i5MyHZC2aGvUmeUJ/4QliOrg0rVYvwUbJH1GHu
EeJN6I3wEHp1OJc2wER0W9bsSq65scRXEu9EF+u+0UsZ+xD9AVxGvCF89xpT
rmhP7aWcKVSuhd9dz1yLngzvosuTvUh3oruQJym3dMe6W+VYI+LG2bVcBPcz
d3p2rcuzRxOflu1V8gB5XbNwLcvzqhNXy66lV+ET5poQb0VPghrZOatcXQef
yi8Y24aeDE2zc0y5pd+01/mGz3Yv7Ap7vrx+ChRk9xz1mjehrryD4Ah6HPRA
d9Oa5LFtzJ+VvXYMdA/3NPUy9Ywy5jqGz/4QHE98bHbtrU7O7eOytXK8Bbp5
tpevSvaSJWHvl6cMQu+EickeKq+QB8l75Bk9wzWo2lMPfCbcg9R75KGqXX2T
vkU1/L5yoTLWNzXgeW3Cd6Vn7EZ/Hv42WaF6jXqAvH+/9kTPCfe6YaphdGM9
I7ln1ESvCedKT3hYv4W7kz1QtfJKuDepZmaF99RevZO9XDWpWpSnD1euZfci
1fQU4o0wItkztPek8LP0jGBtv7CX94Ed6O/CtaqaPojuEvYancE/6L/DXipP
1d7vwH3Jz9iC3qycSR4bEK5p1bJqVrVXQHxMcg2qlw0J36V6mv5ryNPl5frP
odpWTaoWVeMV4RxW7soTVbs1wmevGm6W3QPk/crxoeEcVu6qJ+yVl4R7rzyt
QzgHlXt6J9WuPETeoRoeRXxKdm3JUx8I15RqST2hPFxzqjV5dlvVPoxMvuNN
6P4wKnlMenb4rDX2/3+l7FrTf6bScA9W79UZ7kNfH+7N+s+gXqj/CIXJPfE/
frsu5Q==
                    "]]}]}, {}, {}, {}, {}}, 
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwl0llXT1EYB+CTD4GoP80+gqSlhAoN/oYkQ/oAfAOl0mzqO7hUMl1rLa1V
qW5NERlSMmWo7nre5eJZv3e/Z5999jln57RcTl/KSJLkDi8U42RuSpJttKrb
OMhLDvGKLcxSyWuqeMNW5qjmLYd5F+tRZr2r8ggTbDfOIkU2d/Xa2aHukMMM
xTz2612TdXRREffKe4zQw069bpkj78tcmcdHdZoPHOcTRfqFPFYXssY6/2hh
lYJ4P3MG5S45Iy/yl1s06d2WzfzmAn/I51E8P76XOTflQx5wnTN6N+RZfsU6
rMS++RnX+U4jP+K9+MZpvtLAcnyn+C/WGoi9ykm5xGLswbhEpjig7penOM85
9pIXa7rWSAOlxlM8Y5ovnOQzJ1igN2pz++QoTxjjKdnsoZ73HGOeWjopjzMl
izka/8K4JvbHFfYZb5a74xypn2f8P48bYqVSpg==
                    "]], LineBox[CompressedData["
1:eJwl0tkzlXEcx/HnHGRrD1270nGK1MkWRW4qWpipq64qWlGKNv4KVEq2Tgu6
V1rM1ExdpsQfU5TXb7p4zfvzPceMeTyKz3e3dcWiKEqzZqzymz8coiR8GY+i
XXpUB7WdhxxzJ3SOPeS588ml0z3KWfupbtTwi36w167gmb1Ju/Un++z9jNmb
9YYuscW+qS1apm95xyOO+6xUD5MImziX3N9J2o+1WZOaqZc1Q6/oE87ZI5ql
V3WR3XZDeC6d1zItJ5tr7g16XXP0ACk+uCs4ad/SWY6E5+KUzyb1Nnfoo4k3
vKDK92mt1oVws9Me0CLt1xmmw3tx17NiP6DQfq11epBl+z4F9iut1Rp+2fd4
SZu7UnfoXd2q29kWnsf9iRSt7ufayxSnwzvSj+E9csI9oT1U2uP6lW+U8z78
LWnkC5/pYJgzfn5IY3pR/3KBf7H//4vrZbVE1Q==
                    "]]}}], {}}, {
                  InsetBox["\<\"\[Mu] = \"\>", {-1.8, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["0.2`", {-1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {InsetBox[
                   SubscriptBox["C", "J"], {1.4, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["\<\"=\"\>", {1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["3.19`", {1.7, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {
                  {PointSize[0.05], PointBox[{-0.2, 0}]}, 
                  {PointSize[0.0125], PointBox[{0.8, 0}]}}, 
                 {PointSize[0.007], PointBox[{0.4463998339305619, 0}], 
                  PointBox[{1.2771956561278897`, 0}], 
                  PointBox[{-1.0806611991222994`, 0}], 
                  PointBox[
                   NCache[{0.3, Rational[1, 2] 3^Rational[1, 2]}, {0.3, 
                    0.8660254037844386}]], 
                  PointBox[
                   NCache[{0.3, Rational[-1, 2] 3^Rational[1, 2]}, {
                    0.3, -0.8660254037844386}]]}},
                AspectRatio->1,
                Axes->{False, False},
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                Frame->{{True, True}, {True, True}},
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLines->{None, None},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None, "TransparentPolygonMesh" -> 
                  True, "AxesInFront" -> True},
                PlotRange->{{-2, 2}, {-2, 2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.02], 
                   Scaled[0.02]}, {
                   Scaled[0.02], 
                   Scaled[0.02]}},
                Ticks->{Automatic, Automatic}], 183->
               GraphicsBox[{{GraphicsComplexBox[CompressedData["
1:eJx1WXl001Xa7kAtfIVCZ6SAGWQTJCwKo8QBRnlxgsjXjyUiM0CFqGU5SKnF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                   "], {{
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[0.3], EdgeForm[None], 
                    GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxNWXm8z1UaPu/Xdu3XvlwTsl2MpVxb1CiqIW00oQYTaSphtEwkRYiKVJQa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                    "]], PolygonBox[CompressedData["
1:eJwllnmUlnMUx+99dUo6mZMWKRkz2jBZW2hqxjIphJQUQkqLlhltSpIkLceJ
LMmSrZIlS8kphWydkiVLkghZTs7h2Mm+fL59//jMfO7zvM/7/pb7u/cpGVTT
u7oQEbdDLbgpI1px4WX8bCjCy7g2DF8Dj+MPwXh8IpTgnfnMFrwdXEo8F4bi
T8BUvIr7u/HT4XrirsTb8F6wP3F74s34gdCWOIif5F9nmJcek8bSG67Gv4HF
+m04Gj8EBuPDoQ3+NyzDO2oM+BIYi0+CXfgBcDH+ABzObx0GfcNjboO3hj6a
C8zhs5XEO8LXehFPhoH4aLgLPwgG4dVwKJ9tC+fgQ7Su3BsHF+KjNAd8FUzD
F0FffDVMD8+pFC/n+a14GXxN3Ce9dpfAMHw4dPEyxQDNJb02l8MF+I3ptTgL
GuJb4RZ8P603D01Jf9damIafyLVdeE9oTHws8et4Mzie+CmYqrWAa/BfYCne
Ckbge/P5lXhtmE78m3IEXwf98GdgRviZ3/Hz4Az8YY0JP4bnN+ENYALxgvRa
dQvnXgMYEM7BCrwazscvg5X4u5ozXgUn4afCKfhIaIRvh/laC40Zr+D3tuMd
lGNaG40Jr4TZyifuvxg+A03xI7lWGt6jdfgLMAVXqrbnz0twbnhPluMH6zvw
ybAMfxSK8HEwJj1GjU1zasT3N4Qe4RwdnZ6j5qYxXZnOOeWacvaxdE4rl6+A
o/BHYEL4Nxenz6jO5pjw2jfn+58N74HmNktjDs+xBfGvxK3x53QGia9Nu55p
SbwofRb1TBlx3fTc12sPdTbTY9EYfsC/T+fuEvgW/y7tWsMi/FYYEd7DZukz
pLOjM1WM3w014RyZkc5x5bbO+Gv4JjgBvwHewjdDC3wufKi9hzvwBcqRdA4r
d/vDG/ib6c82hePwjel7FbAFPxluxufBe+kcVW7q2gf4tvRZug0+x7+A+8Jj
WKN6wBo9j8+Ez9I1TrXtfuiBt9OcwznaE/8ULsK7Q0d8PfTDu8JC/Co4Lbwm
E1UL4N7wM5/gTdJn9R74WJ9N+0IYj3eHO8M1aKfOXnosGvMO/GnlZHhMH6XP
jM6K1rC44DOts6w5lRCXFpzbZ8IReH3u18E3hn9Le6C1129WpddUa6kapLFr
jBqb5lCP5+en92I17ENck/ZVWmPtvWpIOGfqc3/fgnNbY1btGak5hGtQ3YLP
tM6yrn2Jf5Wu9Tpj76R7mnqZakY34vfTe6kaMTSd48rtchhC/J/OVLgnbcA7
pXNFe/QK3iG9V6oBA/E/dObDPahcucr37Qyv0VLiB9O1QD1Ue9uJ+2+H91hz
1Rpo7ppzJfGr6VxXDRmVXnOttc5Af+K1MDtcc9VbVOP31PZw7a5FvCJcw9Wr
r0vvnXq2eu+kdO6pB6sWj03XUtVk9SL1FPUS9ST1CvUA1X71DM2tS3qtNEf1
9pbpdwH1eNXameler5qrXqoerd6snqpeo5qvWq+e05i4ScG9sTi8Ns3TrjUa
jP+b7q3q2XsV3BPVC5fDCnnBrhpdB69dcG/SGqjW7U6fTdU89e6ftCfhHq61
VI9Sb9Kaau/1TqN3GeXAX/if6d6hPf4Z/zHdO/d8B/5P+t1B7wB699E7S0n4
Heh/ZZISBg==
                    "]]}]}, {}, {}, {}, {}}, 
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwl0lk3VlEYB/Dz0kBCpnLrUpRQJEMJTXTjI3RhyNRg6GsUGW7cWLGWVheh
W1ODlDJUCqnwRfz26uK3/s+z1373fs45b869rsbOWBRFo8wpXhMXF0XxNKtb
KGaeiyxwgrdcYpES3pHEB0p5z2WWOMk557XKMqY4oj/KcY7x1Np9EtRtMlFe
kc9IoUDfIasIA1/Qp8p+BngQ5rLWFeaQz8O9ckV+4TOrfCXN+ojMZp8D/nGX
Pc6EZ7XniUyXb2QDf+mlxlqfrGeXO/zhNMNkhXdmT48cYpDHXLfWLW+yzQ12
yGSLOjb5xU8y+EEt38K9fA8zUeSsR/KUnJYbrJOqzw/PSKH6YbiX29wK34Hf
zFDNGtdItjeFMfUrJhjnBS+ZDHeRx1U+8ollKmnnvN8ny7OUh3P1FWFWmsjX
J8pcYurZ2P//3CEEAkRB
                    "]], LineBox[CompressedData["
1:eJwl0lkz1mEYB+C/vkKkbEW2mBEHlaKaZjpOtoRQqlOO0WJpL3FM1nHATBNH
LZZvQ5vsW6XS9YyDa36/+37+7zLP+6Y2Npc1xURRNMxVpZXTB6IoQfaRwjob
rHGNdi555qHcpIqPJNol0aEnyy25zafwPuajdOo7XGean1RzNpzLft7Qxhm7
RJlHnH6Ir3oZ74k335OF4XPld8r5RgUPuOzsvlykkg8ctjspj8gBmSCX5DI/
WGWFY/ZDMo0ivVa+poDjFNs9kjdooJ5eeshw9iw8J5/KdDkqs8Nl63flHnfo
5hW59jnM6bf5x0tO2GUzqzfylxdk2WUyo9/iORfNWfIPN/nFLr/JZCR8Ny54
7oms4zHnzelymFTOmbtkTZj1NCb1qXAvDIbfmHwmGKeUt7xjjFivOUiJvsAV
5vnC53D/nHLeErP/3/sPvZBLfQ==
                    "]]}}], {}}, {
                  InsetBox["\<\"\[Mu] = \"\>", {-1.8, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["0.2`", {-1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {InsetBox[
                   SubscriptBox["C", "J"], {1.4, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["\<\"=\"\>", {1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["3.1799999999999997`", {1.7, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {
                  {PointSize[0.05], PointBox[{-0.2, 0}]}, 
                  {PointSize[0.0125], PointBox[{0.8, 0}]}}, 
                 {PointSize[0.007], PointBox[{0.4463998339305619, 0}], 
                  PointBox[{1.2771956561278897`, 0}], 
                  PointBox[{-1.0806611991222994`, 0}], 
                  PointBox[
                   NCache[{0.3, Rational[1, 2] 3^Rational[1, 2]}, {0.3, 
                    0.8660254037844386}]], 
                  PointBox[
                   NCache[{0.3, Rational[-1, 2] 3^Rational[1, 2]}, {
                    0.3, -0.8660254037844386}]]}},
                AspectRatio->1,
                Axes->{False, False},
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                Frame->{{True, True}, {True, True}},
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLines->{None, None},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None, "TransparentPolygonMesh" -> 
                  True, "AxesInFront" -> True},
                PlotRange->{{-2, 2}, {-2, 2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.02], 
                   Scaled[0.02]}, {
                   Scaled[0.02], 
                   Scaled[0.02]}},
                Ticks->{Automatic, Automatic}], 184->
               GraphicsBox[{{GraphicsComplexBox[CompressedData["
1:eJx1WXlYlOUW56qpoVih14UMd53U0soxy/R0HW+ZKE3mctvQrMgaTcN10NTU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                   "], {{
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[0.3], EdgeForm[None], 
                    GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxNWHm8z1UaPu/XekWufXctV7iyXDfSJGlmQhITw4gxJqQdSUaZpixZrtRt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                    "]], PolygonBox[CompressedData["
1:eJwllnmwj2UYht/nl0iyJhqFTjUhZkJkH0SKmDgosnSSJUvnSMmuIw7TGMmS
SpY5lmQde0UqkhBJIqWZLK20GSotg+vu/uPi+n7f9n7P+ywnq09edm4mpTQH
isCBSOk/2Ib3gC/xlrAIL4R6eAtojT8DA/A74Cm8G+TijWAh3gtq4a+EzzWC
a/DKvPAAXhqyOC4BPfE8+AJvCAvw+bAOnw65+AQ4ipeCssnXLAhfo3PD4TD+
OZTB58LNcuiND4W+Wi/vP44XTX7WEXgt+Zkl8c+05uRnrMdnwJP4c9AH/wM2
41fqG/AqPO8gfj0M4/huWIw/AqPwtrBc90I5ri0LnfBBUB6/FrLxwTCFa2tx
fCz5muMcn4QVeDsYh9fm/Em8LXzC8T5ogs+Gb/AO4XN9oQLXXged8SHwEudm
wwN4R+iJTw2fWwcb8Q0wCS+A2/Hd8BDeELpoL8P3joc7wzmjXGkBP+DZcD++
GqrjH8KDeAOoiv8M65VLiilek/UdxTvAonDMFetR0Eq5FY7l64of/jUswyvB
sfA1OrcUDoZzTLn1MozWORiLvw/L8ErQX7GE5fgbUC35t/H497AK3wlV8NWQ
j9eGG/AarPeIvg2+Ui6G9141slgejv1o+BSvH16LauxF/GnISc6pJYoV3IeP
0TfIoU1yDBPvGhnOnXeht2KhZ+L8l8byzylYid8Ef+H7w7nwFtyG74CuyfcM
Dtewalc1d4vyg+Mb8UNwNT5Xa8Sb6/UZx1Cxew+24lfx2wf4dL0jvEat7Xl4
m+PI+NqpUAwvCln4DjjB+Ss43p6c08p1xVixVc7/Ge4Z6hVvwt+qTaigdyev
Td+ob9MaS3P/mnAu7YG7wjFXrFXDDfBD4V6gGp8WjqGW/URyLxoSzl31pC14
kYzXOg0ucDww/O4tcBG/pJxJjpl6wWPhtaonKJcrh3NDOf0jPhPa42vgN/wX
6IJvgOIZ55xyTTFVbWtPtZeq8RIc36oawndpfzjeFq4V/TYH/zX8rGHJuZkf
7hXK0VXhZ+jeZ5N7s3qseqt6dA7+ezgWWtNm/CxsxKck94LO4bWrJ6h39uO4
cXIP/Rb/LpwL2uN3wj1AtT8DHsZ/Cvc69bjz+Llw79Q7zoR7kHrPWuiBnw73
QvUs9VLNoMLknto6XPOqdfWAV5U70AzvDp3Ca9C7VcP/hmeMZotmmvZiFgxI
3pPmeN3w7NBMa4wvDM+ulnCPagUexUfChHAPVO/TM1bgm8K9Uj1kYjjmivVA
aBKeQZo9reDecM2oVpRD87QX4XPK8ZrhPVDsZybP1sfD36YZWyy859rrptAx
nLPKVfUA9fYy7NHe5B6v2aOaVC1qBrXDxyhnk3uiYvePYpYcw4rhHqneqGuG
KrYwInmGjgj3DPUK9ai94TVpLbOSZ2FeOHb/z0TVf3jW7leN4h+Hr1UODQrX
mGpLa+gfvkfXaqaVwgvCtb0bhof3RHuRAy/gdcK9Sn8jlA/3YPVe7dnk8DN0
r2Kyk+Nq4VmknlgYnimaJfrGj/Aa4VmnmdUebxOeRerR6l3q2erV26FXOIeV
u5ppJTk/Kbz3+VpDeE+1l5qhlwFglBsi
                    "]]}]}, {}, {}, {}, {}}, 
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwl0tsyUFEYB/CNlFDiRkRohiLHUjoJ1RN4AJVyiqK8hsNdogOeoOmmrpOz
CJVTXgElIdVMvz0ufvNf31rf2rNm7ZVV21r9KCIIgl7WDO7wnQ46qeE22bwn
hyGiGOY0HzjDCAcYI5dR8hgnmuTIILgrz/KWH2yyxU96qOUX99gmn2fEkGJ/
gyyikVT1YdlLMXs8YJcmfvOc17zgJdcosO+qPMUxMtRtspxBkljlFt+4STuP
Oa/3ibzBMlWskMgACZzU0yqv0M9DzpkLL/oyi1xiiaMsUMZnvvKFI8xzkVku
MEc86b7VIv/xLjwTn/jLH7KII01fsyylkuuUmKsIz8Mr3tBNV7jGCeuxso8d
ppnhI4XUc1zPQZnJ/fB/qOvCe2WCKSY5xFPW2YjYf1//Acd3SYQ=
                    "]], LineBox[CompressedData["
1:eJwl0lkzlQEYwPH3UBGKOAmlkJQ0jS8hsiQi+40PkJuyFC0qwk1ZbrpEJdI0
lpmi6IsoabN9Bvqd6eI3/+d53nNm3jNzslvbqm+FgiB4SZGhnZyoIAjrBGl8
p4JvXKOHQp/p1p9cZ4kDbgeJ4RC/3H6zTKz9MPfNf6jiM3+p5rxn6fqKEjo4
63Y8UvbYZ41iPkZe2vNOzdVUPaddepVPhOxR3DW/ppR75Lmd0DdkcMH+QN8y
xQemWWSBeW6wyTAjnOKi7z3SGuqpY4xRkjzr06P6VBP1vZ5hlxZ2aGaIQVIj
v5ev5ia2GSDslsKquZEtnpHsdowVcwP9XLKf1llucsT+RBP0sb4j3pyrcfpF
a+mlwJ6pM5wk3/5QK1lngx9Eu09qGZfN5XqFceZ4wXNukxV5d83WO6H//7F/
JBFCWw==
                    "]]}}], {}}, {
                  InsetBox["\<\"\[Mu] = \"\>", {-1.8, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["0.2`", {-1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {InsetBox[
                   SubscriptBox["C", "J"], {1.4, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["\<\"=\"\>", {1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["3.17`", {1.7, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {
                  {PointSize[0.05], PointBox[{-0.2, 0}]}, 
                  {PointSize[0.0125], PointBox[{0.8, 0}]}}, 
                 {PointSize[0.007], PointBox[{0.4463998339305619, 0}], 
                  PointBox[{1.2771956561278897`, 0}], 
                  PointBox[{-1.0806611991222994`, 0}], 
                  PointBox[
                   NCache[{0.3, Rational[1, 2] 3^Rational[1, 2]}, {0.3, 
                    0.8660254037844386}]], 
                  PointBox[
                   NCache[{0.3, Rational[-1, 2] 3^Rational[1, 2]}, {
                    0.3, -0.8660254037844386}]]}},
                AspectRatio->1,
                Axes->{False, False},
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                Frame->{{True, True}, {True, True}},
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLines->{None, None},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None, "TransparentPolygonMesh" -> 
                  True, "AxesInFront" -> True},
                PlotRange->{{-2, 2}, {-2, 2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.02], 
                   Scaled[0.02]}, {
                   Scaled[0.02], 
                   Scaled[0.02]}},
                Ticks->{Automatic, Automatic}], 185->
               GraphicsBox[{{GraphicsComplexBox[CompressedData["
1:eJx1WXlc1NUWxywtdbR0XN7UAzUfTm6YOWaZnWJ8aGg2ktpiTalp5riUuY32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                   "], {{
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[0.3], EdgeForm[None], 
                    GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxNWHmcz3Ue/rzHMblnGBE7jhwtIZOionKEaklZpFY5t+gQXRq3dluRbrab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                    "]], PolygonBox[CompressedData["
1:eJwtlXmwzmUYhp/ni5OxpM1JIU6rZppSKrKEGloUOnZF5lCW5BBJphXJlqSS
FpOylGgZbUjpFCnRDCXRvk22mEo1Wui65z5/XOdc7/f93t/3Ls/9viVl5aXD
CxExHapAWUacCzPwXvAR3gwexGfCSPxzeAJ/EdbjVeAo/H54H18LR+JToRzf
Ao/jjWA1vg8W4z1gI34hPII/DPXwhJ74DVDAazDA5XhtqE+7CHrjg2Ad/kH6
tzSGm/QuKMeXQlW8Jv1X4nVhFu0joJ+ehQ/xc9Jj1xpswA9PP6s5H0ffjrQ7
4Wtgb3qMGpvm0AW/Gs7H+Rc9+VOfPpvwIjgrPWfNtS1sxj+Fx/DL4WR8GXQN
v6Ma/jHMxk8Ir80g6BNeo534W3AvvhC64sthQuX+dcd/hvmauz5jLIdBZ3wA
HJuek+ZyNozTXGmvCz/zF+2GUILfCWPwYr6vwK+EbbQvhSvwJ+FtfBW0DI+p
iGerQhd8oPaU71pD+3CfTfjFcFl4D0bgJ/L81vBnc2g/Cqfj/WG2aintI1QT
eHOYFV6Tu9J7oLW/Hhog82CUakk1gdfh/avxxlBM+3ja6/GmcF66plRLl2jN
8buhjfYehuEXwRz8WoE3oP8WvBb8TvvG9HfPw0N4W60RPhxOxV+DbngzeAdv
ApPx+1Rj+Mz0WNWnDj4XbsabwLv4e+lnlamKdCaUBb1jMP4ADAvPeTI+JT2X
YvhJ+5uuhbHwRzojysYSaMhcRqdrYRs8l56T5jJOmcX/Tmf9JLULrjnV2g74
BP8TXgjX9GJ8f/rdt0MJz/dJr9VumJSuYdXuENiD706P9VnojVejz+vhmjoI
E/hsMP9bhde+r2oqvAe1adfQHuKrwrWkM6dRuKaUxV60W4Qz+Sv+m2os3Edn
nc4AZV9n3g78DJ1J+IJwrdyhjIdrRrU0Kp1d1dQ3+LfwlGoJfsC/g1L86XC2
tKfaS2XsX2ULXsJfVobSn8lHwmf4VtVgOIPKco/0WOZXrsX36XdrTb5O17Rq
eR5chX+RzroyuB2/Bzric6EU/zGdFY1xaTrTyvJ46IR/mc6u5vwV3jn9bs1x
gbKbftcYOJCuEdWGxqxs6s7QXaGMrsDfhInhPWiJD4FrwjXbKl1zqjXtibKm
GlLtKHNn4r/omfCeH6qsIdWOMqraU+aUNdWgzqpj0lmv0JrhU9NZHg2N8UXp
LOjMbK9aT591uqMG4hco0+E75mjVanquOpPa6Legb/iOmZE+s3VWq09T1VL6
7mwH1ylbMDR8p1VP30G6e7QGqcu34NpZBtP47pn0WNWnQ3qPtDe6c1emM6Es
aE3/UfbSZ7Nqqh++K50lrVmL9B2ru1V3iu7CAemx6U68DT+U/u1Xwndt//Rd
pTu3VvoM1tmrOSub/4XvNmV0aDqDyp7O+FvSZ4rOEtVct/SZobOiueacPhN0
Fihjr9I+JX026g68NZ0JZaEMDmqv0q4z8Q38tPS7dKaOxwsFj1139P+/CPxn

                    "]]}]}, {}, {}, {}, {}}, 
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwl0sdOFlEYBuD5QRFF9mBJ/AUBqSqi6FVQRVB62+kdoIkNBVy5N5FE1ii9
KEWKoNwD0pu6R8BnwuLJe87JeyaZbyba8LjkUSQIgncsW5SwShtPKKKYy/SS
wif29ftkKp+5Qj//nA/KNAZIp4xLMUFQKofI4CNrJLHOc8rZ4B6bXOUBUXer
5AsectG+WmazRw3b7LLDK97TzmsKOOfOTXmBOBLtm+Qt3hLPEnf5yR1aaQ7f
WbdFFrLIbX5wii5OclanUebTSX04M2cN8gbfuc4CJ5hjnm/MMkMsU0wzwTUm
iSHBs+rkX3rI5St/+M15IpzRq5V5dPCBbt6EHzmcA0/J4bTukeOX1luM84Ux
sqgM56JzoJNsXRHOz/6+zGSYUUY41Hkmf7ESOf6X/gMHREeT
                    "]], LineBox[CompressedData["
1:eJwl0ukylmEYB/DnFZqi3vL2JtMk73EU0WbXTIfgU5ZCdvGBE1CWFGkyw4ws
1ZkgWmjRKWRrj989Pvzmf133XNezzZOqbbp9LxZF0RiXFHWcTIui43Io1Kxw
lWWu0Uy+mSb5jhvM8YOL/OQ9H5jnFwX8poWP3GSBdUpJuF5cjlBIPXFnWeFe
fGeLJS4zyzYNnDKXLU/LRlnES3bY5S6jXCG8bI65E/Jx2OWM/r58whhTPA1z
zDBNGRv00x7e006bnAj75Oor5QBp6m65T0wd8TzMsMk3vnCLr5wlz0yfPCrf
yBo+00umswxeq6v5xAPSnR3hlbqKHs7pk3KSCv7TxT86ecZfUvxhkXI6wnPY
Tcjx8C1J6lvldd6yxip7DFPMeTMl8hEPOcYFXnCHwdjhf3UAYzxGTQ==
                    "]]}}], {}}, {
                  InsetBox["\<\"\[Mu] = \"\>", {-1.8, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["0.2`", {-1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {InsetBox[
                   SubscriptBox["C", "J"], {1.4, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["\<\"=\"\>", {1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["3.16`", {1.7, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {
                  {PointSize[0.05], PointBox[{-0.2, 0}]}, 
                  {PointSize[0.0125], PointBox[{0.8, 0}]}}, 
                 {PointSize[0.007], PointBox[{0.4463998339305619, 0}], 
                  PointBox[{1.2771956561278897`, 0}], 
                  PointBox[{-1.0806611991222994`, 0}], 
                  PointBox[
                   NCache[{0.3, Rational[1, 2] 3^Rational[1, 2]}, {0.3, 
                    0.8660254037844386}]], 
                  PointBox[
                   NCache[{0.3, Rational[-1, 2] 3^Rational[1, 2]}, {
                    0.3, -0.8660254037844386}]]}},
                AspectRatio->1,
                Axes->{False, False},
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                Frame->{{True, True}, {True, True}},
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLines->{None, None},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None, "TransparentPolygonMesh" -> 
                  True, "AxesInFront" -> True},
                PlotRange->{{-2, 2}, {-2, 2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.02], 
                   Scaled[0.02]}, {
                   Scaled[0.02], 
                   Scaled[0.02]}},
                Ticks->{Automatic, Automatic}], 186->
               GraphicsBox[{{GraphicsComplexBox[CompressedData["
1:eJx1WHtc1FUWN3wuimvW+piP4iPTMbXUwkSNo45ZGdpkFsW6mJqGToGZRGiG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                   "], {{
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[0.3], EdgeForm[None], 
                    GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxNWHmcz3Ue/rxnyjFjZ4ywiHWFlTErk7KhXLEhFdMpJSGyGSUspUjHNtW2
Obp2kyTd5WgSKTlKOtxH01JMzkiqbdvatPs8+zxe/PG83p/v5/c538/7+vwa
DizuMyIjpfRdpJQJ2QZAM1UCDgBfAu8Ce4DdwA3ArqSxWcBKYAZQDEzwvKrA
EOAKoAswEagM5AEneV42UALUAOoARUAHIAeo7t+rAPOBecBZQDnwIbAauMPr
VAPu9pzaQCnQ0fvMBSoCucAXQGegE/AGsBDoCmwFtgA3AhuAxcAfgL3AKUBL
oAz4BBgFLAIaAM2B/cA+YBwwFLgSOBf4BzAGaAisBd4GmgLLvF4hMADoDbQG
pgEtgNOAl4FHgQKgP9DTe7X2mHz/xrM1AXoBpwKtgIuAMwDy2c5c8v6fAmM9
7l3rLdNcVjLf1wHdzNduc1zZnOZ6nR3A50l80y6KzdM86zrHXFf1uiXmpLp5
a5/Ed7b7jtrCSeZxtfurmN88n6HUHNcCzk6yk19bz7zbaPNax+v3Ac70HT8x
J9T/QvNM3Z2XxH/jJP5HWZ/bzGcLr9vcfNMuyP1vk+y6O1A/if+95uVRc9vS
nLayztcl2UGPJFso8F7DzHEvn6nAc5eZ73yfg23axnafj1y+kmQr5wODgAvN
N/VwqXWxCvi9uRsIXGzdfQa8Zx31TfItcjfY3xyzE/gAaOs12nkdctXRfH1t
HfLsXawX6uQyf58MXG79/waY5fORo34ew/ELgHN8hmt9fo57IckuOfZpz2/v
ed28/nLgAuuI6G1dtbFOaNubgU3AcPPRy7xe5TZ5egtYkuRvw33mZsATSX6V
Yb1Qh7S9NcDHSXbwjPVbZN1cYv3QF2mLmb5fke84Jcn+GnvNvu7/k7ll3Njg
e1M/jLEjgROBEUl+y3td7zvw/J2tu04++5U+P/VxtXVS5HN28L37Ww/U3wDr
j/412GPOtS7oOxWt00rmdKh//6PHNDPvQ8wPzzXM+9B2Bnl+P3PKMTcl+WNd
c3VNOpZ7eEf6/i2+M/sZNxhzGB/+4vmcu8djyNGt1tUJSXbJ9Zu4r9j9m31u
+uPNSb5fz7qgz9NGvjJ/5K7M42jDf02K7Q287ijrZ4znsn+rz8Y1H/Rctpcm
+WuB9yDX9G/GPMY++sX4pPjTyL+xzTiw37/RZm5LisuMs3+zjqifhzyGc2mD
dyXZ4QTPybVOJ1rHk9zOs5yUjsVuziHnk5NicTXLyR5/l9vVvPbtXp99d3oM
78W4zZgxHXg4yVbvAf6cFM/v9nctS34zZ9zrb7YfAO5LimmUJelYrC/xPlk+
X2WPud9zH/Hep1mf06x76mmK9fmidUe90S6mJtnGs+avnudN9/mn+5trbkyK
A8wNV3s/9j+WlA9Ot+R3oeXjbl9j/sgd/ePvSX5AW2bcoT3TZplvafNPus04
QJt6LskmKZ93m777VFJMYaycZT0dTKqB+L3Da7V1P2NrzSSbneP7zvH963ns
TI8vsX6pW/r3S0lxhLyVmmvaOHNTgeUr1sOrbvP39Un5iXXDAkvaD3MR64kc
j2G7gteiHltavuw1X/P8XEt+M9a+7vPU8hrzvU6pf+uYlLtYExyNE2zXPe5M
Oe57w/1LzDPjxCUgrVaG/GyRf2NtQHtgrcC4zRzLeivTfW8m1ZaMA6wDfud5
b3luT39z/aYe08RyqXVA/pkPaAOsE5j/WqdjdUO+x75jPS93f6H7lnpf9q9I
iv0r/F3oMy72eUZ6L9og65d1njvX3DE+HPA9GVfPdJv3fd9jqHPWjKwlqliu
dnuVx7G+yLKuGOPLPe5XSXl7rfVBPdPXGiTVkx8l2fhH/ub47h5T3/uwv4Z1
uNbn5+9rvA5rKubdRj7Pep/5A5+7rfWx0fszf20wj6w9WYM29JobvS9jCHPM
cO/JO/Tw9ybfZZPHsJ+2t8Vcj/a6jFHMr6xf6df0za3HjWWbvjnKY5q6vcX9
jA9lx/1e5nUW+/w851jvxfPP893nWh/b/TvzzzbrZ6zbLSy3u5962mFdzfA3
+aUtsNakbYyxrni/Jz2eY5nn+d5g3GZsYozqZP2XH8dhufnt7DE1PWan+zmf
bxba0aGk/L3Lba6fYbnH7RFuc/+R8OVTQrXP+ZD1Qzb5EmTDUEy6GHJ3KLaM
g2wROksB5NuhfJOBhb9PWqcp+uaG8iLjxKWhWFEV7VM9Nx/yzVAubAa5KJQ7
X4T8Z1LdNAvtLiE/ZZw+aD3x/XXAumUdfjgpl3X1N9vPYl7dkF/uti52WTeH
rIej35nW60Hr9gz3Z5hH7kX/nI316oR+HwFZHMpjCyEXhGqImpCHQ3b1BOTX
If7Zt8r9hyC/CtX4n0PuDN1vM+SWUC58DLIsFIe+5T6hXD0D8puQneZCfhqK
h5Q3u70DcmzoLuWQfYHZvC/kF6GavSfktlBu6wPZOBRP5kO+GqprXoBsYHvI
hDKKQm+AjZDrQvl8OfURij20kcdtJ+Rkn7mYbf64fgWsc3nonXPYfB19Q1Iy
lo/z3HzL/V7nEcx7OBRjzoG8KRTns7HmwFDdPyGUn2hvtdE/PFSbVIXsFYpv
a7lGqO4fDXlRyI9qQO4J5bs1kNd77tYQ3+S6PeSHoTopC+tXCL1nfgJeD9V+
OZAbQjmaRvRN0jtqDvq+TXoXfecz8TwXhM7BM/wIzAvVol0h14dqpi8hD4Tr
HsgLQzFnJW08FJNvgPyv/aUj5MehuvN7yH+F6pXqkNNC78cbIQeH4vD7Idui
Xd0LeVXorTMTskMoP1/LPb3XJshuoZrtKfp06L2115yyrii2r9JPx5vHcfYl
9meb38OeR9tpYvu5DLJ5qFa5A/KK0BsrM8QTORoE+WAor/0AeV3o7bUX8p3Q
O6ki9J/hub8At4Xqoiz+Hsr1eRhzeuhdTR/qYT/aB7k/VA/2hzwYqjUrY/wJ
1k/FkP3R9mgvtDnazHjqPOm9PJV6tT9S95Osf+p1iHXbPWQrtJPpaD8Qelee
CLki9P/ClJBt0a4egjw79A6mDrKtB96pku9FG//Fdk4fHWA//Sm0Ftd5j/4d
etuR25Xml3Y0y7Z0JMTx//9fgOwXirU/OC4wJqxG31mht8TPkMNCNS91kBfS
Q4Tsj3evHYqnjKWTQ7+xv00opvCc94V0QT3cAnnE+iS3rcwvebvT3C2DbB16
t9DPngv5Gn30Hvsp7Zr8kTvGs1tD519K/YXeW0sgW4beYUfMJfd9mrYTenPS
p58J8UWuKvucjEP3h+zhdnIaeq/R7v6TZHuMfxNDMZD/Pc+0DZwcylvMWczJ
zKnMp4zlU20/7UJxh3fZjvZnoTcPc3XvUL5+HrJe6P8A5sDzvCZzO2M64/lr
oVjDOMN8ztzMvFwY8gfqs1GoDuCaPyfFbp6Zvki/ok8x75WGch/t8d+2yR95
39CbZ2jIP+mb/wMPFYey
                    "]], PolygonBox[CompressedData["
1:eJwtlnnQllMYh+/7UwktsrVqVIMYKkIq02Zpk+pLRKVVi6iUaUoLqSSFMGWp
pkxKiaJJ0mKZhooklGUowqCQoZ226ze/949rvut87/Oe5zzn/O77eWv0HlI8
uCgipkAJmJYRU+FivBtUwRdCMX4NLMMvgofwcbASfxvG4xXgsOZhwhX8LQ+r
NBdMxCdAR/xsPt+Ml4WljH+BBfitMAYfDRXxznAzfhbXb8RLQS/Gm+BpfAm8
ha+AM8NrKI2X4fo1eG14k/Hy9Fp1TSt8MYwpPO8kvCTcifeDx/FT088+ANrg
38FcvKT2BP8AnsJfgR74RzAdvwA+xPfCq3hXuBGfr2fCZ8HD2juogt8OJ2Bt
ev8rwzq8DkzDp+oavDZMwm+Dd9Pf0bW65h3G/xX2Xnvcj3FZnn8d3hb2M96X
9u4wF/8YnsEfhDPwclz/Pl5Xz8B4CTTGG8KlOi/og7eAMtp7uAevBz/rfKB3
+AxX45fBY/hk2IBvhJF4DZ05Xp77rcfrw//aV8Yr+VspPNehwtlrzpmMr4Nn
8XuhQXqPtbet9Nz4UGgSzswa/HhhLq3hwnTGlK2m8EY6o8qmMnyc8TG4Be8J
j+L14Sa8P6zHr4aW4YxMxq+AG/DWMAw/CsvwduG9bZz+THs8EZ8AVcNz9sTP
4Xm3hOfcD8P5X9/wnmuvjxayoT3X2TRNz60zKkpnVlntArvwH+E8fD6cy/V9
02e5NVxrxdrDcM39qbOB6vhiGIHvgJfwu2En/jp0Cv/vD7x7+tpF8L2+C9fi
88K12S6dFdXo7nSNqDYW6nyVT7gKXxruDZ3TZ6EeMRvfk577Afg0nTFlayb8
iv8GT+LVVEP47+m5h4X3UjWo2tOejsRHpbOqPfkC/xJeCK9hSLomVYu94Hn8
G5iDD9YZ4V+nP+sAX+Hb0j47nN37GLcPZ1i1dnq616jm1Hv6pLOpHlSa8Snp
ta+Cz9M1oOy/qMzyeft0L9xVyML29L2Uia3KWvpaPUMLfAv0CGdWvalt+izU
owbhzeG58DUV8X/TvbKm9qTIPVC9bydcj3+Wzr6eKfD34Ilwj+qafgatXZk/
zHgA3BXuAY3SPUW9RD25RLqHqnfeoUylM6kstoHxjB9JZ1c18beym+4NI+A0
rT1d63oHXYKPTfe+ZvCt+ke6Fw8NZ3lK+l7KdEOdZXou9eR66cwoK8rQX+ka
V22rRw/Ej6SzqRo+X1lJz613hGqhJjQK18SV6cwqq3oHVEpnSNlRjz+Y7rnq
ta/BP+kz0N6rB3bCf0jX6ss6QzzZn+XheyiLLaFjOJPqjV3Sz64eOR0/kJ57
YPisN8OM8Jlfnu7B6r16p9RNv1P0LtGZ1sJ/St9bPUHvFr2j9W7WO0Zr2Rd+
12pN/dP31L105h3SmVVW1QMWMK6c/m2gNS/Cq0KD8G+GT/D702evHq61NkvX
ttbcOp1JZVHfORDuSepF6uknAQLd+j8=
                    "]]}]}, {}, {}, {}, {}}, 
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwl0tk2l2EUB+DvLzk1tFamkEoZcxWFBiKFUxeAtcxT3AMH1WllKFFUaNBN
NKDMXABJpvB8y8Gzfvvd397vf1hfZm19RV0kCIJ+vilu8pOwWc8NnpHEY2Yp
CheigmBTvFAn85wUBtjSH5KpDHKBEs7bKZbDpPGEOWKZp4lb/OI2v0nnHol2
y2Qz5ZxzrpCXWeU+S6ywTCt9tNFOHnF2csNdDn3HGOcadS894W/iK4V84Toz
HHv0WRbwkXw+caT/SB7Is+6qVufQzcPwP9OrktlMcY1p9s1/kJNM8J537Om/
leOMcZU37OpHu+uBeoOnZDHKOmsk8M/cGXOV6i46+a/XIXdkvGzgClHm/uq1
qBdY5DWXGCGTUiLm/piLU98JP8f5rszgJRd5xbaZRvmdH5HTd+kEUWBKxw==

                    "]], LineBox[CompressedData["
1:eJwl0usyV2EUB+D9d05izJTGx+6gKKdUOlyBjyWnlIiaugOVipKY8v8gxysp
ChVF7gFFFEUiPO/48Mxvrz1rrXn3nvdY7Z3y27EoiuLc93CZ1IQoSpCtJDPK
KUYooJrDeqrkGMX0sUIOPxlngn5+cZRVavhACQN85DTp9qXIx5zgCmneJcoj
zDHPG47TywLfqOAtebzmO4tcZYkntFHJATuTZHv4Tg6qa+UznvKKjtBHnB5K
+cRdrofzmKmTnWGeTPU5eY9tGthki390hx6+Mss0l5jhEFnmm+Uuw1zkC03s
8J8hLvCZRnLN3JLnmaSMKTLo4ix/uckG9bzgD+v8Zo1BznAjnMXOdPk8/Puw
S31NFvGOQt6zzA8ekU+2vpPyIQ+IhfvBS1pi+/dqD4lCS6U=
                    "]]}}], {}}, {
                  InsetBox["\<\"\[Mu] = \"\>", {-1.8, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["0.2`", {-1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {InsetBox[
                   SubscriptBox["C", "J"], {1.4, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["\<\"=\"\>", {1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["3.15`", {1.7, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {
                  {PointSize[0.05], PointBox[{-0.2, 0}]}, 
                  {PointSize[0.0125], PointBox[{0.8, 0}]}}, 
                 {PointSize[0.007], PointBox[{0.4463998339305619, 0}], 
                  PointBox[{1.2771956561278897`, 0}], 
                  PointBox[{-1.0806611991222994`, 0}], 
                  PointBox[
                   NCache[{0.3, Rational[1, 2] 3^Rational[1, 2]}, {0.3, 
                    0.8660254037844386}]], 
                  PointBox[
                   NCache[{0.3, Rational[-1, 2] 3^Rational[1, 2]}, {
                    0.3, -0.8660254037844386}]]}},
                AspectRatio->1,
                Axes->{False, False},
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                Frame->{{True, True}, {True, True}},
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLines->{None, None},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None, "TransparentPolygonMesh" -> 
                  True, "AxesInFront" -> True},
                PlotRange->{{-2, 2}, {-2, 2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.02], 
                   Scaled[0.02]}, {
                   Scaled[0.02], 
                   Scaled[0.02]}},
                Ticks->{Automatic, Automatic}], 187->
               GraphicsBox[{{GraphicsComplexBox[CompressedData["
1:eJx1WHt4jGcWj4RoY1OXYplaSpVZt5I2ihWnjFriNrIoVoO41rBIkUa1btuh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                   "], {{
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[0.3], EdgeForm[None], 
                    GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxNWHuUz2Uefj9DuRu3MhHNDEYuGaLCKpfISkkUjUlhSFKUJEUq3RFZSqQL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                    "]], PolygonBox[CompressedData["
1:eJwtlXns13Mcx9/PpDFFJSWtiBYqlVLkCB2okH7FYpXkyKLfj0RoUSvpQDlC
InTLHJFjGGLumiOGsllFslJzj2Eezz0/fzz2eby/38/xfr9fx7vtmLqa2nql
lBlQHxaqlJ1cW8DtsJrxkzAObwO78SOVe9fDIHyT78H7wCr8CbgSbw3j8ZYw
D6+DrXA24/O59oRhdjgHbwUn4wfDXfi50BQfDIPwE+EUfAXciQ+GR/HlcIf/
K5n7A8p6vIa1+OGwEH8QZuL7w434JNgGtzG+gesAqIf/wvU8qIW2jJ+HYXg/
6IU/ArPxpbASf0z5tue0GxYznlOypmX4nmotnuMIxq/CInw4LFHW4Ofnwl/w
MuOHuHIpf8IPyEtcu8Ai/GEYg7eEF/2fsrauXiPeTIndTPgG3wx9S9awB+8E
jfBP/W74lvFTXJvDODvcjV8N3+O/cW0Ha2C+/4MpeBPYjrdWYr8WpuJd4Sx8
ItyPL1DePR064zvgjZI53IM3hqn4rXAvvr16t3/ryPhN7zHeAI7GX3cM8L1L
cnEyTKjy9zvnLeObuB4A/1QxdmxHwX/wo3MQRld7O0CJrfd4jmOrPDsZjsCv
h2tLYvKCEhPHwjk117mn3NsYLlW+4XdfDL9Xe+S96Qg1+BDneDWHV/B20L+k
Jrz3raB3SQwGKjnhXPA9fZSYOBanwUb8M8WHwBb8pyo3noF5riVlbo6Z974L
HF8Sg1qlRl2b18CvUKe4Y77T71bmvs4xwqcpsT0BbsYbQHf8TDhK6RHuDf7t
QvwiqME7ldRedxhYUoPHKDnpXDzOe4aPghH4SK/Bc4FTnSvwtnNf+fbjzgHX
svLtbl4Tvq/yrsXwFr4OepTk0Gj8EiUXvAdDnZtwUsmeO7c6KM86x7rh/1bf
8pz7Mh4OF5Ss6UD8PiW33XOaKDntXJ4GByk16VqcBV8oMXOsVsGh+LN+h2ul
5N2fK//5G1/jXym1vdp7rsTYsfWcJ+H1lbWfUdJb2ivuHuNe9rSyd+5pn3iv
Yb6/7RpReqJ7oWtml/Ncmatz9GNcyr0+A9wreiq92D3jI8cGVuIrnAPKmryW
oSWxmuEaqvLFvXZHVRvuue71Y+GKkp6/Dz7SOVNS02vwP6rcWQAblGLwWeQz
poWfhctKerLPmt7K2eAzx734Z67jS3qy97qN8i7v+VVKz6+t7nEvX6r0Yvfk
1/C/S3qN5/Sucga49y+BY5Wcda665x2GP6es3T33fe8VLMeXwS2OX0kvuw4+
UM5An32+Zz98inI2Ome9Nx8qe+s9cm00VJ51jXjt7ynv9h5MV2rUe+09P12p
Ydeua+gQpce7tzsH9lLOJJ9F7nHrlTPcZ7djejn+jrJWnzn98S+VXPSZ30PJ
eee6z+j/Aftv9Yc=
                    "]]}]}, {}, {}, {}, {}}, 
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwl0kdSFlEUgNGfIihRgiyAAkmS4x4oQGBMxjGOyCo5SY4qKwEJCuyDHCQU
MhWQ4lgMTn3v3b7do05q/lDTGhQIBMZZc3hDGX/dVzWZNoKpZZ1U9ti306Eh
tBNKJwfm3RpGFy9I54Y0enhJHRvc2d/UCjLYIpOfhJPNH7KoJIff5BJNI008
+M4xw/+f67W+p4VH9wsOnEupoZprsxVN5Buv+c6V+VdNYJFllrg0r9Jz3dcS
4nlHEbcUE8c8sSxwZn9W55hihmlOzSd0kjG+MM6J+ai+YoQYCingn2e72swQ
AwzSSz995HFBPg3UE8VnDr1/z1vnX+ywTQQfieQTR3bK9QcpQc//xxO6yUVr

                    "]], LineBox[CompressedData["
1:eJwl0tky1mEcwPH3dRFJIVxF1lDEOLNkO2tG2d/EZbgDUXZF9nIDIvtaaDkQ
MpN5kyw50+cdB5/5PvOb53nmP///P/FxqLAxGAgEWnlhUcUHZkimnWieMMtH
UpijmBJS+cFvd3ToiYa1njqi+Gs2rCM8o4ksjsiklHN7fmocBXwhhy122KaS
S/ve6xSTJPGOf+aHms93Wkhkgjy+8ZVmEhgnN/K8POQOo8QzxoX7yrWCB3zm
PmVs8okN1nlOLNkccObsIz3VkEZecgMxZPCLdPro5xXddNLFS3rp4dgde5rG
TZ4yzwL3WGSA11SzFPmgLPOGQWpYIcgqawxxi1recpt9/jhepDe4yy5hsyum
rduC1//Kf4qmUhM=
                    "]]}}], {}}, {
                  InsetBox["\<\"\[Mu] = \"\>", {-1.8, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["0.2`", {-1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {InsetBox[
                   SubscriptBox["C", "J"], {1.4, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["\<\"=\"\>", {1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["3.1399999999999997`", {1.7, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {
                  {PointSize[0.05], PointBox[{-0.2, 0}]}, 
                  {PointSize[0.0125], PointBox[{0.8, 0}]}}, 
                 {PointSize[0.007], PointBox[{0.4463998339305619, 0}], 
                  PointBox[{1.2771956561278897`, 0}], 
                  PointBox[{-1.0806611991222994`, 0}], 
                  PointBox[
                   NCache[{0.3, Rational[1, 2] 3^Rational[1, 2]}, {0.3, 
                    0.8660254037844386}]], 
                  PointBox[
                   NCache[{0.3, Rational[-1, 2] 3^Rational[1, 2]}, {
                    0.3, -0.8660254037844386}]]}},
                AspectRatio->1,
                Axes->{False, False},
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                Frame->{{True, True}, {True, True}},
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLines->{None, None},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None, "TransparentPolygonMesh" -> 
                  True, "AxesInFront" -> True},
                PlotRange->{{-2, 2}, {-2, 2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.02], 
                   Scaled[0.02]}, {
                   Scaled[0.02], 
                   Scaled[0.02]}},
                Ticks->{Automatic, Automatic}], 188->
               GraphicsBox[{{GraphicsComplexBox[CompressedData["
1:eJx1WHt8zFcWj1RTDUlTj2BKRGlNNciSQTV6+mkoIjQUtbEdaaysGq9Saqxu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                   "], {{
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[0.3], EdgeForm[None], 
                    GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxNmHnQ11UVxu8BwlcU2QSFV+B9eRFQdhVFFAUFUSoQEVMUFFmVLQF3UNQS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                    "]], PolygonBox[CompressedData["
1:eJwtlWmwiGUYht+HbMnWZA9jGElZk11zcLJmO/adkxoVhyT7XshWdmWPbFnH
PhiUHzX9aKYf1FSjmqmMZZTKNCXVdbu/H9c89/ut77O+NfPH5xUUSinNgQdE
pLQKnkO3hhXo5WG9HD5Df4+tBAegGevuMBSdBzXQz0B/dEe4Cu+zfg9bHyqj
20I/9LNwGdqzHoh9Gq7BLtabsZi0ICwWY96CbugG0BM9GD5A74SN6AbwBHo1
vI3uDpcgh/UAbBO4Am+yXoitoG/q2zA282kZ+nloJQ0Lw+/oWe3hMdZLYKn+
DTvCPsq3TcmxaAq9k2OyF10BtqG3whrtLYun9rgdXTb8rnz4AZaG/90N+qN3
wxb0aPmDbgKPo0/CN/Ap633Y8nATvoWu8DLM5d7X2LIwHwpYVw/nZhrUQt/D
vgFdZFnPD39rAXwFfViPxJaGG/AldIKX4FHufQHH0Q/BLPTscD3pnxXR+2E7
uojqDP1Ptpd5We4rhWtBNfA5+kHIQR9Ojt1YmJocQ+XyYWifnNM24ZpRmeja
TMQMKJPV9EX0x9AO3Vc+KPZh/a58QVcJ7/0T+BV+hB7wOpTj3hiYnFyT8rWa
cpzs80/ZnrVX5WSKng3Haha8ih4HzdDTYSp6Wvie9rgBXRzaoFfAJPUSNEfP
yGL9Wlgr5p2UO6iY5Xhb2Cf5sj65tlaGe1U19i/khnPbAjqjC0HL5H/2Q9dX
jaHzYTj6COxI7onz6HPh3toL38Ei9UDyHtai18EE1QL8DTVZd8aOSJ4FfyX3
tmbCYdaHsnjoGfk6LFyr8lmxGh+uTT0zCD04XGuK+Sn0LWy15H+ul+8wMbum
2fJncq9rxlQN51i5bayeQP+GbQQdVLOaNZoZ8iW51x4J31PP5YdzdD83ylk4
5oq1ZloJdGPohR6SPDtGh2tHM6Qo+snwLBoEZ9Bn4R10dagTnqmapcrJQenw
XtUzEZ6Bmn2K+X/qm3Bvaobdy3pKvaQePo3+Jfu2YnJCuVeNo3epZtF1w3on
FAv7KN+0p03oF6AteqXyFvZRvmmmtQzHTLHqkxy7krAmOYbqnY3hd9VDPdA9
w2dDPX1DvReutWFwAf1RuLZyoBR6a/jb6tl66CIwKvlMktY39K6uFUaPgILk
mSxfu4Znp3zOC9ekanE4PBWeoZqd8vFu9ozujYQ/YADrF7FToHz4mnQu3E6e
yZrFmgn697FwLLWHo+Ez4v7ZAL/DK+F3VXMnwz2jXtmd/WtP+GzQPxuGa0a1
ojPuDgxkPSZ5BjYKn4E6+1RzH6KvJ89WPbOF9c9ZrJWTIeqN8OxRP+msqB2e
BToz/ge01N+4
                    "]]}]}, {}, {}, {}, {}}, 
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwl0kVSHWEUgNH3lhDcnV0ECgkwhyqcCaMQNFgI7uwkwWERSBgBIbhkjEzw
4JxXGZz67n+7ugfdnVrbXNwUDAQCo6wbwvnIqfMP/cBnLp1L9ScRLLFl90Wv
tE6vtV7/6LJGcmMu00mmiKKBW/tynebMPKO5RDPLPHPcuRavu8SRTwKbJPLP
9Qqt5Ny8S5u5nWpquLA7Ys2cSRGF/LWb0CBjoZfAOCeh96FvOqQjDHPsXKCH
+kszeDV/0jT2SOfFbkCfdVAPtE/76aaXHvbtu/Q7HXyjM/Qc+xJ90mJ91FRN
YZEFqmilha800kzoYybxm2SyeXD/qu5onsawQSxZ3Nuv6LbmaFjw/7/wDjJ2
SP8=
                    "]], LineBox[CompressedData["
1:eJwl0rdSFkAUBtAfJEn0FWhAkYwooaBFMgy0ZKSDx5AkUQyoIOkBQJSg5I7U
gM4ADVkbwEfgzFCc+e58c3e32fjG9qq2oEAg8JpOQy2zfCORLh5QxxzfecwP
XlLEE7Y5dUe37KGJZv7rLvhk/kwLr8jiN5mUcGlnT0ZSwBrrLLPKChX8szcl
p5ngEZP81Y/LOL4SSz55bLJBKzGMkcMxuUTzhShGuXJXmSznBX94TinPOCKb
h2RwQDrFpHJIGmEks89ThnhLLwP00c8bQhjkzNs7MolQKqmmhhTmGeYd9Sxw
48yifM8HGljiVv9T/uIj4TQyQgS7nNsplMEksMWJ7poZc0fQ/b+4A/sxRLk=

                    "]]}}], {}}, {
                  InsetBox["\<\"\[Mu] = \"\>", {-1.8, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["0.2`", {-1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {InsetBox[
                   SubscriptBox["C", "J"], {1.4, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["\<\"=\"\>", {1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["3.13`", {1.7, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {
                  {PointSize[0.05], PointBox[{-0.2, 0}]}, 
                  {PointSize[0.0125], PointBox[{0.8, 0}]}}, 
                 {PointSize[0.007], PointBox[{0.4463998339305619, 0}], 
                  PointBox[{1.2771956561278897`, 0}], 
                  PointBox[{-1.0806611991222994`, 0}], 
                  PointBox[
                   NCache[{0.3, Rational[1, 2] 3^Rational[1, 2]}, {0.3, 
                    0.8660254037844386}]], 
                  PointBox[
                   NCache[{0.3, Rational[-1, 2] 3^Rational[1, 2]}, {
                    0.3, -0.8660254037844386}]]}},
                AspectRatio->1,
                Axes->{False, False},
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                Frame->{{True, True}, {True, True}},
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLines->{None, None},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None, "TransparentPolygonMesh" -> 
                  True, "AxesInFront" -> True},
                PlotRange->{{-2, 2}, {-2, 2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.02], 
                   Scaled[0.02]}, {
                   Scaled[0.02], 
                   Scaled[0.02]}},
                Ticks->{Automatic, Automatic}], 189->
               GraphicsBox[{{GraphicsComplexBox[CompressedData["
1:eJx1WHtU1HUWJ18ZiRrrCyqxMh1Tk8WQ8sBedTTNY0mmUWbkumoirZqmOPi2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                   "], {{
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[0.3], EdgeForm[None], 
                    GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxNl3mU12UVxt+ryACyiYKCso0IyKpgiIZsKaKJEJKEioiAIoNsw6JiAuIC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                    "]], PolygonBox[CompressedData["
1:eJw1lWfI1mUUxs9xpKGmZi5MKiVyZaI5kyhtuMcbjrLXzFVuMXOUZmZkjtyZ
e9AwizC/RF8KCsQvVgaFA7QsQy0cYDjKot/Fdffhx32d//M893Puc65z/+8a
O6NiepWImAvV4Df4EfrDdHg0I1rBEPQzsBD9N+tyWAbNiLvBSPTj0BDdFUbo
t3AH+hrr69APWhK/BivR2+EILCBeqt/CD/AZ8W7W2+Bh9EPQqOR0HsYT92Zt
D+fgBAyG+dCLz/5h7QYPwMvEL6X3egO+h4HEE1nrwDfQnfgp1g7QU99N516p
PdDfsj4GT0Mn4i9hr3KD/ehP03o4vICeBbegF8MM9ExYFH52GCYTL2TtA7ei
e8Ao9Faohe6c3uudklsd6BXOsS66Xvrs6lsX9K+sGf7OL7CZYBNrO/UQPS19
VuXQBP0V7NN/wRT0MOgSzklnnUi84P8zoyvTte0Op5QX8QbWNvA7nIRh8KQ8
oNygAv0svIperBqgG8sH6T2111vwStoDDYun+qXPoNzHwjziuVAXvQROlxqq
dtPgOT6bAB3DOa9GV0v3fhXsS+eo3HbCT/AFzz5gbQWz0S+me6X/qI++IN+E
PfYnTEp7u7POnJ4JzcLQsBdOlVrIE//CSHkgisfTPVOvNus36B2wBT0V1qVz
VG5rYAT6XdgWrtl76ZnRrOjZEH2W3muyzpT2kLyjPQ8Vz8qrj4Rn6U7NZHim
bka/DevCPayObps+yxioir4HBqFHQwv058opPFPSx0ov9exG+E7QXbACPkTv
gaboHcpJuWkGi0f13zVhfTiHjeifWVuHnx3UrKe9+XXpVQ3dAeGeybtNoVPY
wwfQ7dK93B++C9YQrw7fCWvRo6Fn+Nmm9IxptjbKg+hVMA/dHEalPSTv6NkK
9EqYg74dlqGXw2x0s9Lr99NnVc/vS9dUtdQMXIUBxOPDd47uwjlpL+tOvAgN
0r3SHXAdHkzflerZheKZqcWT2usK64Twnh2Jb0rPimbw3nRNVAuduQq6P4zT
rKjHqn3aa6pph/TMalafgD7ovmmtnrROe0Je0Dugt3KFAeEev4lO6BH2zB/F
o/Kmev4XzE/fvbrjP0GfLbVWTT8i3puu5fNhkyyFgeE9dTcNT7+LdEftRu9K
z2JfqJ3uqXqpO+8oLEp7Ue8M1ap5+ruq2XFYkr57dAa9uy6z3h9+h92drplq
pRxUu0Hp3FTDxmmPypu6c/SuuxR+d+idV6Hape8mefRj9JniHXnmu/A7prL8
53/Hz8zc
                    "]]}]}, {}, {}, {}, {}}, 
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwl0ccynXEcx+FzLkAvUcO5CUS3ZwZJXIBO9N65DhLlFkhZKhtm9Jrsw0rv
deExFs98fv/vu3xDla3lLcFAIDDGvCOcDP57j+sElRx7l+p3fhBBJCf2Kj3V
al3VWY3izF2mk0wRTTbn9hidY82doxtaq3XUcOn9QZeJJ48EFknkyvdy/cyh
e4tG9ze+UsGRbZ8/7hBFFPLPNqovOqzPOqJ/dUiftF8HGeDAu0D39Lem8+jO
14+skMaDrUf76GXXu0u7aaeTDnbsrdpGE28/oJlte4nea7HeaaqmMMM0X7i1
1+uNNmgSSySTxbX9l25qrsayQByZXNh/6rp+0rDg+79/BdXBRQI=
                    "]], LineBox[CompressedData["
1:eJwl0kdOlVEYBuB7QZqwCVB6B9mAVCHBhIk0aQuALcAFpfcmUwWkSJuBbQKY
yA7oZUDbA+UhDJ68b77vnJzkzx/f0lbVGgwEAiE6lA98Y5ZXhLi3q5ZzzLPA
dwop4jVbHDjXKbuo5yM3ZseM6KM00Egmu2RQwqkzf2QUEzQxzhhr3Nqf8FvP
I5JyLsxmZBxfiKWAN2ywTjMvyecv5+5MyxgmiWaKM/My+Y5c/pFDKVnskU0E
6eyQRjEp/CeVcJLZJokegnzmwRufnj443RyqP2UiYVRQyXuWWKSXPmpY5sqd
H7KfAWpZ4dp8VQ4yRB3DvOAXR/Zv5Z1MkJvs65d81duDz//AIzXZQPU=
                    "]]}}], {}}, {
                  InsetBox["\<\"\[Mu] = \"\>", {-1.8, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["0.2`", {-1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {InsetBox[
                   SubscriptBox["C", "J"], {1.4, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["\<\"=\"\>", {1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["3.12`", {1.7, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {
                  {PointSize[0.05], PointBox[{-0.2, 0}]}, 
                  {PointSize[0.0125], PointBox[{0.8, 0}]}}, 
                 {PointSize[0.007], PointBox[{0.4463998339305619, 0}], 
                  PointBox[{1.2771956561278897`, 0}], 
                  PointBox[{-1.0806611991222994`, 0}], 
                  PointBox[
                   NCache[{0.3, Rational[1, 2] 3^Rational[1, 2]}, {0.3, 
                    0.8660254037844386}]], 
                  PointBox[
                   NCache[{0.3, Rational[-1, 2] 3^Rational[1, 2]}, {
                    0.3, -0.8660254037844386}]]}},
                AspectRatio->1,
                Axes->{False, False},
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                Frame->{{True, True}, {True, True}},
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLines->{None, None},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None, "TransparentPolygonMesh" -> 
                  True, "AxesInFront" -> True},
                PlotRange->{{-2, 2}, {-2, 2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.02], 
                   Scaled[0.02]}, {
                   Scaled[0.02], 
                   Scaled[0.02]}},
                Ticks->{Automatic, Automatic}], 190->
               GraphicsBox[{{GraphicsComplexBox[CompressedData["
1:eJx1WHtUlNUWR3wsM7lSKulEmGI6ofkgudeQ2nnHW2aiE5kS11DzkTmaLnrI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                   "], {{
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[0.3], EdgeForm[None], 
                    GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxNl3m011UVxe8BBGR+IIkM8h4CTx+DRoCIJEgEQpqAlWTKLHPgzCQK5oAG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                    "]], PolygonBox[CompressedData["
1:eJwtlVeMlkUUhucAAZEqgnQRBaUsvfdVQJC+FBVhkayQzdKWXgRReqRKFaWI
gshGCYqEuDGCIUbv9hYbCUSlc6H0hCDPm/e7eHae+ff/v2/mzDlnmhYUj55V
LqW0HCrAokhpIVTHl8BQvAsMxsfB0/hPUIpXgd7474z9YDi0Yv4YjMJfgnMw
ivkbjNWgMf4LlOEdoBN+n7EdDIKxzPvBSHwSrMTLw0p8BVyAU8y/ZKwN4/Vs
yMU7wnl4h/kyxprwl37H/F3GOvAj3gF64sdgMb4kvNcaMAGfCFPxzvAM/gOU
4F30Gf5A606OyVzmc8J7WwTF4WfotwugMv44dFXs4AT+L2MjmA4nmf+nuMBM
uAJn+Ow4Ywt9hk8Px2p+cqxnhF0xvwGfMN/OmANP4UUwF98Jf8Nq5qv0P3gL
nwKz8W7wnmITjqVyoC4+DebhH8I1+Ij5Bp0tLMOXhmO1FG7BZXgZhsClLMaK
bUtojq+D1VonXIe9zLcwtoZ52ks4dsq5QXg7GICPgefxb+AzvD7Uw3vBMK0L
+uANoC8+Am7CRXgxeY8D+V/LcC7mwTC8O7yCv6oY43k6M3wi/JE9c0R2xiPD
OalcHA/3tA7mfZLX8Bp+GHbjU+DzcAwVu116B34o7AXwMf4EbMY3QYnWFj6b
vfBFeI/am555BH82/L89cDB8xjrbHTBOsQn7ZPgqHHPFej+8iR+FA3iRzlRn
B+vx9/Wd8JnoLLbpHeEz11lrjQeYf6ocxxnSPv48Gf7uVmgYrmHVrs6gFD+b
ffew3hHOOeXamuTabRquJdXwafwf5R0cTa6188m1q5pTr2gU7jVlWW1Uh97J
NTJJvSC810LIx5+Dfck1/DPeJlxL3yum+NUsNxWDNczXhn+rNWzS2YRrUTW6
Ad8YrtWGsAX/AIqTa1a9sEm496gnFuBb9czk72wL9wDVvj77WrURzmWdSZ1w
zBSrNsm5/gIcTM754fhoyFeuKcfxh1kuvg4DwjmtXFbPzQ33bPVq9dAh4R6h
3jAWvlVvCe9Fz+wWrgHlvmqiPV5V70yuwdbhGlLt9Ie7Wc4r19Uj7mQ5rtxW
z+mIVwu/Sz3hdpajyk3lUM/wnrXXofAb9Ai77oDvwj1FveQQbNfZq2aTa1qx
WR/OJcWoQviOWJHc4yqGc165rp5TKRxDxU41rsR8O9y7dEe0DeeIckPvKFRt
wbrkHPs/i7lirTtMd8fgcG/SHfJr8h2ou089QbmnmlWtKgdrh2tGtaIe3Syc
88p13QmKdU44top5OXx5uBfrzqoZrlnVqnrwqvCdprtMd+KOcMwUK625VrjH
qLeox/4Js8J3US48AkZj10c=
                    "]]}]}, {}, {}, {}, {}}, 
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwl0UcyZWEAhuF7sQU5XpaAQctMVaGUlppJj+QrpyuzELS4BKknVFkC3XIY
M5Ljowyees///ZNT54R+h6u7goFAIMIdPx0W+UMcrdzba3WJZeJp48Fepyus
kkA+j/ZE3eTQc4H+1w7tpJ1n51TdJ4Ui0tgjnRf39dpAI8fOXy8a5hdN3Nqa
NYs1MlmnjGt3cxrDDNHMcmWf1igmmGKSS3upXuhfDREkgx3O7eNfH4pRxohw
ZhrWEQYYYpBTe5/2000vPZzYq/RDK/RdK7WGYt6cS7ScXHJ4tW3rkRZqErsk
k82TfUv/6Q/NI5YNDmw3zHteoCX4/Z8/AT8PQBc=
                    "]], LineBox[CompressedData["
1:eJwl0ccuJlAYBuD/X+ijuwGJ3lkMe11Y+O31smNvr8+M3g17M3rdKQnhQnQS
7QI8icWT98t7vpyc5KS294V6g4FAoJ9BQzP/+E86Q4TTwgabbLNFORnskMko
w4zQQScf7r1l2hxDF90UcEk+VTzYOZdxzNHDLDMc8+n8njNzCbHU8aJbkyn8
JZlVnvUrMoklElnmSb8oE5gnngUe9bXyTp7KYmqoppBrivhBHhfkUkk2V+QQ
SQX1lPGTUrJoJIIGQjSxxy5j/KKVfd6840D+5g9tHPKuP5LjTNDOJFNEEU0Y
aZxwY/+VdfNA8PuPvwCfAjt8
                    "]]}}], {}}, {
                  InsetBox["\<\"\[Mu] = \"\>", {-1.8, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["0.2`", {-1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {InsetBox[
                   SubscriptBox["C", "J"], {1.4, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["\<\"=\"\>", {1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["3.11`", {1.7, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {
                  {PointSize[0.05], PointBox[{-0.2, 0}]}, 
                  {PointSize[0.0125], PointBox[{0.8, 0}]}}, 
                 {PointSize[0.007], PointBox[{0.4463998339305619, 0}], 
                  PointBox[{1.2771956561278897`, 0}], 
                  PointBox[{-1.0806611991222994`, 0}], 
                  PointBox[
                   NCache[{0.3, Rational[1, 2] 3^Rational[1, 2]}, {0.3, 
                    0.8660254037844386}]], 
                  PointBox[
                   NCache[{0.3, Rational[-1, 2] 3^Rational[1, 2]}, {
                    0.3, -0.8660254037844386}]]}},
                AspectRatio->1,
                Axes->{False, False},
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                Frame->{{True, True}, {True, True}},
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLines->{None, None},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None, "TransparentPolygonMesh" -> 
                  True, "AxesInFront" -> True},
                PlotRange->{{-2, 2}, {-2, 2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.02], 
                   Scaled[0.02]}, {
                   Scaled[0.02], 
                   Scaled[0.02]}},
                Ticks->{Automatic, Automatic}], 191->
               GraphicsBox[{{GraphicsComplexBox[CompressedData["
1:eJx1WHtc1FUWRxMyckzL5+RHhQ0aE9MPOfhKj4WVUsFIlEItPlC3FdLWzQda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                   "], {{
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[0.3], EdgeForm[None], 
                    GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxNmHeQ19UVxd9dFXYpUkSDIHVBYEEhAiJCBAtSrCAqiFiAlV7sCBILCIoN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                    "]], PolygonBox[CompressedData["
1:eJwtlWmwj2UYxu+bNMpeWiwtGkm0kEJMEnGyhmwp5JCRcuykhVM0WesUIpWO
fWjCDKZpqk99bv1Q0zZl2lAzTWayDJXf5Xo+/M5z3c/7P+/z3OvbpnLmiKo6
EbEILoB9GXGU9X6ohZ9gDXsrWG+El9N70qvhU+jE3nDWXrAA/TVrc1gCx2E2
e0+zPgNz0XOgSXjvInRbGIS+Gxain4TF6MtgMXoJzEK3gh9hJfYLrO3hFvSt
6bN1/8/gJuxhrDfDVzAvfXZT6IvuCEPRD8MV6AHwCHoSXIluAd3QreVj+kyd
tRzuwr4W7kOP0xnounpn+MwP0b+ytpCWD9g74S2dBfege0MH9MBwrLpijyox
U+y/L8+Ug0t5tgiq0ZvgOziEvYv1BsUU/SxUoVvCU4o1PFHuMB/9T8mFYjoI
uws8gK4sufuctXc4h1XYM6BxqYnp6MdhYXivM7p+Olcj4D30v4oL7FEOFEvl
WLUCE9ATYQqaJRry533Yh24Aj6GnQaPwGQfTOVOudkA97EkwF/0K9EG3g8Ho
h+BLeBR7vmILh6EGe004xs+hv2HtLh32dTJ784rPPxQfdPd2MFO1lvZdNfoR
+uL0XT+Gl9CZrv1VYV8aQaewT1vRtXAv+g2YqljDbeE7TkFXqmbDd1Aur4Oe
4Zw+iB4Hs1UXqgn0NhgSfmdPdEvojx6rO6D/L7X5IryJ3RT6hmvqP+1jLwv3
TP90DSj3E2ED+kJYi34V6qR9lG+KoZKmM/RuzYD16ZwoFzVwB3oTrEePhC9K
jag2OsNQ9Gvpd0+DCvUOTAjnvEO6B9V76knFole6txQTzYY/w72sGXE99l/l
3aqBBukcKTeKqXpxP2wN9+R4zQp4vtTo3nSPq7ffhmo9S9eGev4a9AdwAH0n
DEMPT9eWctwk7bN8VYy7o7ekcz0aNqZnkmaRYqrY/My6Lhyjs3AVexXKNbyu
WKkny2+Wos+Us/vBEfi2aNXEOzz/PTwL1fO7sX8L9756XrPmctgcnjmDFXvl
NNyDl2gWwQadrRpCv5uOhWbsCvTy9GxRzRyDIdhTwz29LP2NqA3HtHG6Z9Wr
8mFtegao93WmYnl1urcU0z9KTagW1NPK1Scus/M5uz3d4+ptzahTqnvs8eEZ
rbusS9ee7jQwPXM1a/WbHukZr9k+RnFD/11qXTU3Ur6mfVdPbkf/Ep7N06F9
euZq1qrndqFPhnvxfEyxm8HGcAxPwKj0/1ZHmTXpWtDMaZPOuXKtb8Zm7G7p
b5ve0Trd0+pl1UQr9Olyd/X4OYE0zKU=
                    "]]}]}, {}, {}, {}, {}}, 
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwl0ccupmEYgOFf9D6cgQQrvYy9ZJDov1kPfr33IXEUeucUtIVZOITR25qd
Xvcusbhyv8/zvqvvSwsNBPvDAoHAJI0OVUwzQwRN3Lqr1lnmiKSZO/sanWeB
KBbJIZdotjjwLk+PtEVbCfFgjtd94igggX8k8ui+Vuuo58Tcpu008JsNUlkj
hXVKuPJ2XCcY48P8Vy/1p77rqv5ghWSKWebG3ZIGeXNO0l0unEf1VYd0hGHO
zQM6SC9fH7SPM/tu7aGDLjo5tS/XCn7xYi7TSgp5NhdpKZlk8GS3o8earzHs
EUs69/bbeqhZmk04m/y3u2bK+U/Y93/+BI2eO4U=
                    "]], LineBox[CompressedData["
1:eJwl0TdOnFEUgNEZtkDODBSkDZCDoDElEmBSwwKgZsg5hyWYnAyuDBIgvA6T
kYgbIKeDKI6+++6d5teEWtqqW4OBQCDML0MUC2SSRSTt3LvX6CKX5iXNJ5pl
Yljhwa1eG7g1HzJgftFGbSKVPVIo4sRtR990WJsZYpA/3Nkfs23OoJwyLuxm
NYJpgsxwbj/19VFM8GGc1DMd13cd0TFGOfUu1SP9q+mUUEwa/wjx6p6suyRR
SAIHJPLkXqAV5JJNDrH84NG9UqvY58p7VcN0UMsa1/br2kkXdWxwY/9bu+nh
J5tsEUc8z37Tq/308d87T+eYD37/x59JqUAL
                    "]]}}], {}}, {
                  InsetBox["\<\"\[Mu] = \"\>", {-1.8, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["0.2`", {-1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {InsetBox[
                   SubscriptBox["C", "J"], {1.4, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["\<\"=\"\>", {1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["3.0999999999999996`", {1.7, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {
                  {PointSize[0.05], PointBox[{-0.2, 0}]}, 
                  {PointSize[0.0125], PointBox[{0.8, 0}]}}, 
                 {PointSize[0.007], PointBox[{0.4463998339305619, 0}], 
                  PointBox[{1.2771956561278897`, 0}], 
                  PointBox[{-1.0806611991222994`, 0}], 
                  PointBox[
                   NCache[{0.3, Rational[1, 2] 3^Rational[1, 2]}, {0.3, 
                    0.8660254037844386}]], 
                  PointBox[
                   NCache[{0.3, Rational[-1, 2] 3^Rational[1, 2]}, {
                    0.3, -0.8660254037844386}]]}},
                AspectRatio->1,
                Axes->{False, False},
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                Frame->{{True, True}, {True, True}},
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLines->{None, None},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None, "TransparentPolygonMesh" -> 
                  True, "AxesInFront" -> True},
                PlotRange->{{-2, 2}, {-2, 2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.02], 
                   Scaled[0.02]}, {
                   Scaled[0.02], 
                   Scaled[0.02]}},
                Ticks->{Automatic, Automatic}], 192->
               GraphicsBox[{{GraphicsComplexBox[CompressedData["
1:eJx1WHtUlNUWR0tScYzIxEhNvT64aSVeMZeCuwQfoeHopTTD8XHVq00+whJB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                   "], {{
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[0.3], EdgeForm[None], 
                    GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxNV2dw11UQfEeABJUWlF4CIYIIiAhSBUQQpEgVsFASSlCU0O2goPSiWGkS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                    "]], PolygonBox[CompressedData["
1:eJwtlUVsVVEURe8huLS4QyC4W3AtpcWKu0ODS3HX4u4UCYTgAwghwIwxFgaQ
YAGC+wASJDiUtXPuYP27z39695FXOX1634wcIYQ5kBNewR1IgSkwzkIYCwno
WfAQVhFnstaC0ehRUAg9A+7CGeLDrDWgJvoaawfoBcWJS0BzdHnog+5r/qxm
kIGeDvPRJSABvQu2oXdAXvQ5OIUuAGPQ6ebP1jtORX9iXRD8HouJT8I+dFdo
ii4PXdADoSW6BdRGd9Oe0DmhPbo3vIZ78VgPaMyxRlAanQq3oJ72oL3BTflG
PJe1MDyGyrqGtSBMRk+CxOj5ePQEc2/13zN5RTws+DMMPQSmoTdANXQ2ax3o
CcX0rjA0+DWJ8gIWonfCXPQ8mIwuB/fhLPFR1upwwnyP2ps8ykVcCboH9+Aq
VDV/Vj24EnOqXLaDR7CWeE1wDx/ACuKlOg+aoEuae9UfiqAPwh50qaANhjAY
piLXKW/o26wtYBHMlDcwHl1GOUfXhT7oZLgBw4kzWJO0J3QN83dTPV+POVUu
lYMR2hs0Dn7NbPQcmIguG735ydo2uEcDiQfBSH/VsI+fLOiE3gW70fXNa3U7
bDLPmXK1Hg6hv8TazlIOzW+kva6FKuY5U67SgntT1PxceaTaL2R+b/WA9r4d
tgT3QPoJ6+bg/20hzgGb0Bthq7kn8kL/paI3mx9Lh0z0b+UMlusZxN2gSbxn
b/Qx2Bu8hk6hL0cvDgTv9YrQOnjPN9C55t70g4vo3Oa9eil47+aDhsF7+LR5
z6hXDsEF4ucx1xdhjfnM0axZDeeJy5rX7mlI0V7MvR4NK81rsGbc02riv/Ha
VdBJ55p7r5wWRu839145XY5eZj67lsA08x5Xb2umfNe78V9n1gHwC5aan6ua
r2B+jo5pxpQ27wHVvq5pjf7AOgQGy0Pip7EXxspD4hexFlXzbVXL5udqxiaZ
eyRvBsGb6IH2rh56G3Os3GpmfIYe5vfWTFCumpnPPuXsK7Qyv5dmSDlzj+Vt
SziCfhl8dqhHFhF/i8f0jciONaFa0Ewahn6vOgg+838En8GaveqpneiC5r2r
mXnc/Jugb4FqbL5ml3nv6xvxJ9aoajMTPuo9zGenZuy/mGPlVjOoDbojDI8e
p2nWmH871POabe+CzzLNuGTiOuazWdfkN69J1aJ6oIve3Xy2qGbzmNf0pbjH
27HmVeuaWf8BoaXAvw==
                    "]]}]}, {}, {}, {}, {}}, 
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwl0bVRRVEUQNH/ca8BZnBrAAlwiwhwdyenAdyhBiyAgBZwz4EQ1wpgMQRr
9rnn3uTNS+oarx0LBgKBCeoNJUwx/bekgQdjqc4wS5BGHu3LdI55QlgglTRC
2eTQu3Q91mZ91iZ90UjdJ4JMotgjmlf35VpBJWfOLdpKNTWsk8Aq8ayRy423
fx82zgjfzqN6rTn6pSsaxzKxZLPEvbtFreLTHKM7XJmH9UMHdIhBLp37tJ9u
eunhwr5Tu2ijg3bO7Qu0kDzenfO1iGKyOLW7I8n8ptt6ohkaxi7hJPJkv6VH
mqwp/Jg39EBvmTTXBf//8S9utTnw
                    "]], LineBox[CompressedData["
1:eJwl0UcyplEUgOHfCuScCguQ46RZALp/bMAC5JxT9xJaprUwQhWKhchhIG9A
zuVRBk+959x765t8abX1wbqQQCDQxV9DGOOkk0EoDdy4L9cJTs2TmkU4U0Qw
za27Xxrkyrz79W3zg1ZpNYmsk0AeB+5W9Vl7tIYnc7cusci1fZ8VcyrFFHHi
7I9+6Ii+62891mF900F91SE90gF90V7tp49De6Hu6bKmUEA+SWyRzKP7eF0j
jlxi2CSWHLLZ9u6MUnMkP7izl2gZG5zbZ7SRJiqY5cL5P22mhUrmuHT+X1tp
4yfzLBBFNPfetGsnHezYM3WUsZDvf/wJ4B1BNQ==
                    "]]}}], {}}, {
                  InsetBox["\<\"\[Mu] = \"\>", {-1.8, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["0.2`", {-1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {InsetBox[
                   SubscriptBox["C", "J"], {1.4, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["\<\"=\"\>", {1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["3.09`", {1.7, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {
                  {PointSize[0.05], PointBox[{-0.2, 0}]}, 
                  {PointSize[0.0125], PointBox[{0.8, 0}]}}, 
                 {PointSize[0.007], PointBox[{0.4463998339305619, 0}], 
                  PointBox[{1.2771956561278897`, 0}], 
                  PointBox[{-1.0806611991222994`, 0}], 
                  PointBox[
                   NCache[{0.3, Rational[1, 2] 3^Rational[1, 2]}, {0.3, 
                    0.8660254037844386}]], 
                  PointBox[
                   NCache[{0.3, Rational[-1, 2] 3^Rational[1, 2]}, {
                    0.3, -0.8660254037844386}]]}},
                AspectRatio->1,
                Axes->{False, False},
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                Frame->{{True, True}, {True, True}},
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLines->{None, None},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None, "TransparentPolygonMesh" -> 
                  True, "AxesInFront" -> True},
                PlotRange->{{-2, 2}, {-2, 2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.02], 
                   Scaled[0.02]}, {
                   Scaled[0.02], 
                   Scaled[0.02]}},
                Ticks->{Automatic, Automatic}], 193->
               GraphicsBox[{{GraphicsComplexBox[CompressedData["
1:eJx1WHl0k1UWpwwgwyHIiIpUDlIQiFAGLC0iAhcJgrIGRLaDYeegRRZlxCg7
UhUoFA0gqEBQEQu22qEIJXBlsTZtB0upjZRSumQpaSnpFxAQxg7m9vfi+TiT
f9755b1393eXL2rGgrGzGzZo0CAnokGDP9duzbMuu+MKeMm0GysdCRrfzGiW
mKBlKOwQTMBt5bzCuQc7P2JzlXKfBw5YXOYaBj1g0AMGPWDQAz4t9BR+e+Yr
R+NsPoVXC1Yr+AODHzD4AYMfMPgBg59+H3ywD4x9rNj/f3T1dCAvMOQFhrx6
usD6FfR7ir0I/gAGP2DwAwY/YPADBh89/TckHhR9YNAHBn3g8tB+EWeH+AQ4
XzABQx/gLqH7br4YOufnxwSr86CH/cuhNVvhX2Ql0MmRfYXBX4/BB/eBwQ//
gx8w6OM89AcGH5yHPYFBP1P0I8gDDDr6fbxP0Ne/L9gL/PT2QtxCDv370dsH
fgIGH9BD3IAeMOggnkAH+oCOXj/Ez9uhtZy9x5b+VFd3lRNCdF3c8/6+j1tM
l7l7iG4Jfdps0whjai0B7xbMBd9/PNbg8fC6OReup9irOS/EJ0/dXyL0FB/g
1wUT+BnlPOE+MOivFvqKTonIG36f9fyAcR/20dsL/gB9PT+937APf8D/wIiX
BqHfcQf2gbGPeMY+MPYRj/oVfgQ9yAcM/R4++uf/yTzq0NR0syXID4bunyZg
0EO84h4w9IQ/gWFf2AcY9tHvgx7k02Pc2xn6P1nZXf+ugRHXiJv+EocKIy5P
SPyo+NLnHf07gn76FfEG/+L9AOP9xIh9eZjYV/kD54FxHv7BeegPjHjAfWDc
hz9xHvoCQx74G/UEGPyAUV+AQU8fL8h/ueInQr6AX+Bf+AXxAAx/Ix9jH/zw
rlW9rsf6dwv/YF/5tR7jnSAekG/0dR96gR7iBfSAoR/+hz64B32AYV/Yab8h
4j27w8t/zNozUYv0KzmQT5GvkA+QD5Ff4X/YFxj2RDzg/cAO+vwH/Mf0nu2s
Bo+SB/wRb+AP+WAnVV/q9UL+BYa99H6DvPp6jn1zKM4qeMyRs1ed8ZWq/4E9
EM+wB+IV+7A39hE/2Ed86e9DHtyHfaCPPv/hf2DYBfSxr/yAfrL+f7wfFf/1
9lTvoz7fAEM++Av2Qf3GPvQFhjyQE/4EffAHBj3Ii/eC+9uWdT8WZytU9e3F
iH5DDJ7ie+aX0nyeq/0eUO8vZ8iJK+7rtVzCgwLObpXq/cfmV31pbldN+jkk
Y2gnj/sXr6L3advkjxJiwvNIdFUjq6NJeB6JcZctdRS6Fb/oXX6TIa5E2b2w
l+lD+5RSxV8/D0R2Xz/ZMLuMIA/28R68HQqmaBk+pT/yL/RX/VP9vYFbPuti
uhXu509Wn7nlPBXu57Oinvin5fOg6uc3rJ7d3vqfoJKn79JnJhieC9LWPT8u
dXgL+B+Zh2ZraRpv3RyTETe4Uq2N1n8WbVlTwDUiH//hefe2M+csFQ19fpO9
eTmnXE01aztKCGvTbydZHYVeGhvRujAyspTmJhsr3Nd9bBP70gPBOXecw8s4
ttMTrrrHfLQm5kUtxX6c3x/3Q4q53d33mWVtY2tdSn39u1c5OmsU0fVRr7Pq
IiflvVrj3lLLA7wDvjJbPuGNLbt9FZ8V5P1Hplq0okyKOKDN1NKCnHbbQ6an
y9R7zlvy6/aEtArSlrcbaGpTy4VfRN5wDndT54i8nQnlAT6TmNXDNMlPbt8I
v3N9Fc+9vavKmeOnhbKqeDl5cGGJ2+7no0naaMNsn6o/E7t+PU6bXE3J78z5
zrzTw981XNwg1b6Xxo/4+XzdLg/7e60/YLZk0fyu+xa5kio4K6vbQ7b3yunD
Z029jaNLFF4tmMYtsC90ZFbR7glPNkmdXkG4P0fuE+TDCvmLRX76dlar+1LL
yrnZ9NzO1u4BZb8NYj+CPWrEHsQv3fkhbl54HjlQfLmoru40Tw6saWVbEiTY
e53Ym5wVjZvZXB9T0rVd2xPygwT7/3d/yP60MOXOKOPoPLr0VPJX8SuD6v0v
vb2zaWpE+HtFrsSnel9JEp9qHtlSQP1NRzTWtg952nQrPA+hvkzrtKg2Jeoq
L5x2c6bLfOGeev/k3uYvazt83PTElXYWU67aRz91rn1mG2tieF4a9uS+U5Hr
/GzYejjKajil6ti0tz/+tW504T3z0pRHNgVS7JfU/Zea9s2PHBbuB4aea9TC
Glei8t0IOU+Fz37T2nqsUtVl3B8p9wn64J1DnydEH4I+2Ic+OaKPeu9dJV8R
9NH3pYNEX0I843/YG/UCdpgo9lZ2KJb8S3hviB/I+5b4W+m/Wfyp4rOFxCcX
F27ZEV9ZxAm/fB5r2u7jmu9L5zm8F2nevCVmLaOEVr5WNMuVl83tzS/XOtf7
qOT6h+XOqkt8eMyW/fHP1/Lq7YezI9cVUt6aXrecjwZ5+o3sT+P3naexY+7r
bzqvMfLJAMknPK7jjJzIrl5ulv/FfIe3mndvdDe3PeXj45s2PWMcXcXjx1mX
OLw+evBvjkjL5zWM/IX6MDZR2xtfeU7lw8HBb3pZ1pTy7/ZAYR35GPksSfIZ
Q36jyM9l6WeHGK8WUMoH+zPjYstU/jwuq9J/qejPTba1bWO9cjffr3ojw7y8
VN3fK/cJ+31kn5C3N8pKkE8T+Qj5HPUG9l8u9ifoh33Yq6HYi2CvQ2Ivgr2a
i72Ufw6Kf1R9MUh9IfgrV/xF8Nco8ZeqZ7Av4q/GW6k593tVPP4mmBND9MJr
0aiD8139PHym/bLepkQvo970k3rDE88tmqW9WsFpXVv1NjnD99bKSrifKfdV
35Am/QLhfrLcV+8B9U31F1IvaHnE1IDz0cp75vma4yU3ncODaj5F/lPzemrN
QfPOMPbO7ZFo71fB69849ltKVLWyA+rFPqkXan56vHH2y668EjUP1t4/PiI1
yku4j3OoX3ukftGBSQOjTZPu4tO92lq7e9W5dy4MOBBfGaDnes2vdqfn87eF
I1c6vBrnt9w2Ssv+mWOrjLecUUGOnmI7FXctjfvs7XmxLj3IZwf/XlZX9wP1
XjBpvOHH8Hy3QujxsK11Ew3PldOGTh8dNm+s5e9mjCxxp/vV/LEjrc3huMWX
6c7fj36QkF/Nxa9fbmO1+rhP9roqp8vPsC/mO8ifLPIr+94S/blg3rEv4o3p
fCxUt7xsbv/1JIPHzqvOnvG4/+XlzYkrH7JNSKPcMUf6mF4Ifx+IFXty25sn
q91rw/Ub/c5k6Xc4f+zAorqpHoopnjJam3xJnUd9B/904U/gbxX+al4pEX8T
+q186bdo21vX3nQl5dGUQZaelpnlBHshf8Ne18ReBPu+L/Yl9D8dpP9R8eiX
eFT+PSD+Jfi3p/iXIjveaJJae5JfO3dkkSsh/P0B/SX8Hyv+J7Nj0FBj6kHq
uyG+cerZv3xvkPgmxEeMxAftbr1opLHHWWo4Ou1k3OJgeF6U/pbRn1ikP2HI
s0jkYfQnNulPGPwHCH9Gf1Ih/QmDXxPhp+a5AdIfc0Ige5gxNV99n7gRzA46
u3mp6bIJsZaOAVWHn5d+nFekm36tW+FV3yvQX6nv4/XzWXGr6DY2U4C7T3/w
WWOPSjWvIU+ciSmb5mp5hSt3rlhhvxOuj5jXxh15v7kt3se357wyy9Uyh5cf
3rzWvsHHiI9ZEh9Knw4yf3DNi1VNbUvOq3ht9ELr4YZOfvqsc+Rkw5dljP4E
eQ3yDPONLYiMLOM9i37zO7tVqbk7UPBuVpwx/P0D9NH/o39Cv4N5b5CrQ2dr
YinhvXSQ96LmmzMyTxHk2yLyEfhj/od9UL/QXz4u8xvBPm+KfdT33tLGJ78x
p/gI/foo6dcJ7/+0vH/K98zoYrmbbzr1b3QrxeUn+Av9EeyTKf5Sev4k8yg1
msiLXXll6vvLoer+D1sTz3N19OCO1u4aRyRHP2N87wKZildUu/drnPTQzGap
EWUc7Rm82V4d4OlPrX9JK6qiFqWX19iXVnKPPSuMJutxevjr3ssce91qv4ns
K/qVQp9An4Q+IX4bSfwqP55Y9YLJeNVLGVu6/tu80825n7Qwmo7UMPBpwQT5
jCJf+Ht5l+VjDGu9tKDTwha2CV417/8P6MfIMA==
                   "], {{
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[0.3], EdgeForm[None], 
                    GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxNmHnQ11UVxu9BQFAKXhRUeAFZhDdEQAxZxFgkRRBCEBBNZRVQEAPFFJSU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                    "]], PolygonBox[CompressedData["
1:eJwtlWnQj2UUh88RSpayhBjLO6WUUUirSBleihZElsg+Kq+EIiVE9kKWQrI0
2k2ZKVt9wPChL4xPmTHF0BRNe9M6les3v/vD9d7X/fyf936e+9znnKdi9OT+
VdUi4mmoDl/BwYzYwdgGvoEnmU9hrAMf4xVQiQ+CZ/BZ6f9vBM3xZ2Emvh5+
hJPQF+6D6/ntHONl0AvuZd4P2pZ76uPtdQ2/A57Cp0M9fBo8h8+GifjlWhP/
VuvAEDgDy7i2gPFqOA2Lmc9lvAqm4H9pT/AEjGc+AXrjneELxULPZLwEOuA/
lGdpz/vSe9Je3gzv5d30XrWnOfgJxlsUG9jLfA9cic+GTvgN0K3E+6iey/z+
8LWZ+HHGhjADJjJ/FEbhqWv8+bf8ppjXY/44PIYvhwF4//RZDYe6+k1r4Evh
Cr0L3Iw305r4PJ2ZYgvz8U/Te7sHaqSvybvCKTjE/MPwnlrhO2Ez3hRuxC9N
n90D0EL3wut4Y+VU+pl6lmLeBb8d7gqfcVO8KwzAe8Jk/A+NMKnE6hhj93DM
FjFfmM7VOcpB/FbFILxmN71Lei3FVHutlj4L7flreJn54nAOXotfAA/hd4fX
Uo4pt7TmZrwBvIKvgk34G1CF11ZO4GcZ18Da8F50Ta49bcMfgY7lni34bVA3
vKZi1RI2hWN2Hd4QVpccV6xbw5ZwzOW94MHwtY/w/0sua43azJcrRuE9fo4P
hmH4AdUEvhu24SPgbfytdC2/Ch/g76VrdQNs1FnCCry97sHXpXP5JVidzknl
4rJwL2kHXcI9ZWm6JlWL8+FO5u+n1x4II/E16bXGhc+iLfQJn8kIxT699hh4
GF8JS8I1otysmc5V5egG1Wb6bPTOh/HvS67u1Dune4Z6xaJwrC5Ou2K2Kl1D
qh0940L8xXSuqac8j89N17pqaiz+CWwN96jP8CPh2t0OQ9LvoGfrDHbg35Xa
mAB90meisxgMw/Ee0ESx0XvivdO/KSY6u2Hp33SGX0JlujcPhf8Up/Ta6sk/
lxgqduoJv5SYK9bqIaq1xnpmuOaa4dvTufAa9Ew/Q2sr56qrN6RrRWesXFWN
qDaUs6Pxd9L/2wEGpXNQuac9/R6ucdW2aqiWzhJeCPfwf2BauverJ0/F/y5r
6R13pXuaepli/me4x6u365t1ouSYcks9WWtflM49PaMK/63kcneokz4zndU1
4W/Rr4ztwt+kgaq1LL0VOuI/lXt1j74tN6V7n74xTfD9ikG45uX6xujbomvn
AW9ozwU=
                    "]]}]}, {}, {}, {}, {}}, 
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwl0ccynmEYgOHfngSJKDsHEDNErzkDoy21f6f+el04BSVadFEPQrCylOgc
gLKT6G3GZSyuuZ/3fd6Zb/ElBkPFjWGBQKCPWkM5AwwSQR3/7Cp0iB98oJ7/
7it1mBHGGCWFb3zkN3+8S9UdffvYtTbojU7qFONM8JMMppmhiVvvQnqnX3SD
PXOrPmq1BlklgSVWWOY7J970aC9dvDh367HmawHxLBJHHgtc2P/SKp7NsbrJ
kblTn7RNO2jn0DlHc4lhns9kUci5fZJ+YpZo5sjmwK5UyyiihGL23Wfqrp7R
Yr7XZn3QdE0jki2i+MqV3br+1WS91HBdY9t8Sr+5Juz9v78CyoZEFQ==
                    "]], LineBox[CompressedData["
1:eJwl0UVOnlEUgOH/x2UJeHFJYAstWoEQBvgIH8EGoFDc2Qc1oMUZYUGWgNsE
3QHwEAZP3nvP+fJNbkpTV1VnMBAI9PHTIZ58bt1nNY5unt2b9Q93zn/1EwnM
kcg8L3at2kY7J+6bmk6QfkIYYI1VvnDhux2NYIgOwhlkg3WefHPOtnMeFZRz
YzajsUwRwzTX5pMazThRTHBlPqaRDDPKCJfm3/RMtzSXML6SzT45hJLFHpmU
cchnMlihgUYKOfK/e2qdqzmghkrq2OXBvl6LSGKBZEoo5tS+VBdJ4T8fKODR
7p/28J0WllgmlbS3B6aXH/RxbPRRf/E7+P72rzNpP04=
                    "]]}}], {}}, {
                  InsetBox["\<\"\[Mu] = \"\>", {-1.8, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["0.2`", {-1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {InsetBox[
                   SubscriptBox["C", "J"], {1.4, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["\<\"=\"\>", {1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["3.08`", {1.7, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {
                  {PointSize[0.05], PointBox[{-0.2, 0}]}, 
                  {PointSize[0.0125], PointBox[{0.8, 0}]}}, 
                 {PointSize[0.007], PointBox[{0.4463998339305619, 0}], 
                  PointBox[{1.2771956561278897`, 0}], 
                  PointBox[{-1.0806611991222994`, 0}], 
                  PointBox[
                   NCache[{0.3, Rational[1, 2] 3^Rational[1, 2]}, {0.3, 
                    0.8660254037844386}]], 
                  PointBox[
                   NCache[{0.3, Rational[-1, 2] 3^Rational[1, 2]}, {
                    0.3, -0.8660254037844386}]]}},
                AspectRatio->1,
                Axes->{False, False},
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                Frame->{{True, True}, {True, True}},
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLines->{None, None},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None, "TransparentPolygonMesh" -> 
                  True, "AxesInFront" -> True},
                PlotRange->{{-2, 2}, {-2, 2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.02], 
                   Scaled[0.02]}, {
                   Scaled[0.02], 
                   Scaled[0.02]}},
                Ticks->{Automatic, Automatic}], 194->
               GraphicsBox[{{GraphicsComplexBox[CompressedData["
1:eJx1WHtU1NUWxspuIZOVmjZ51SxpFiIaOl7ttZW5EVLpVNfQlNHKTEUz01IM
xTTHV6BeR0EjYkrykUqZQddG9lUQBV+kCIqKPGYYeUQw00NTm2y235m1fndd
/vmtb845+/Htx9mHB1+b+eIbtwQFBX3WLijor2/fkMMNTmMZz5342yKH1cOX
9wanWD17FXYIJuDusl/ho3tCu9kqqnnIvTssFeYWhjxgyAOGPGDIAy4UeQrP
f33q90abW2HoWyy/K/nAkA8M+cCQDwz52nXowTow1vHF+v87B/uAYR8w7NPK
AdZ+IX+A8EHgGxj6gKEPGPqAoQ8YerTyZ0u8lXxgyAeGfOBa/3oll/j1tPJJ
wQT8iH+/ky/4f29k7Adu8H9LFD4tX8K5I7KuMORrcU/BhPPA2IffoR8Y+oGh
D+fhLzD40sorEn8J9mgx6gn2aOtByxfyFfq0/GjzX8sH8ggYerAPeQB5wFjX
5o/WH8R/vv9by/X7kg75fD+x1S+nggd0fOxhi6mB+/nlVFFG8OrnDDltBJwl
mEv9ckvV/rlyXskFfkcwQb5B9hPOA+NcldgTqJ+b8oGxH/GDv0+Kfeo8eARG
viBewIhvkP8v34F1YKwjv7AOjHXkGeINjHwB1n4RJ+hDXIER3/u+/+v37Twy
d8K3ZouXO/vPFxIw+IA+8IH4AsP+srz0F3Uul+IXccJ+6IU/4B37YR/WgZHf
mf7ftxP0aOsaGHHCPujZL/mh8kfbJ7R1gHP4Yj/yA3JUfog+0uYH6gUY9QL/
sA6MdcQnVuJB8B8Y+YLzwDiPeGI/+jniC3nA6O/A8AfxA6+ID+KP+Kn6uYnB
N+pQ3X83sbbPaOsW9a69JxEH7EccYB/iB/u09Q0M/+En9oNP9AfkN/oN+hX4
BB+RwrfyH/HAOjDyGfFBnkIe7Ic82At7YB/sQT+FHysnn/tll71ZxQ/8QL/2
ftPOL/AX+uEv8gPr4A/riC/WEX/teejHefgHf5BviBcw9sEvbV0ifovFf4Wh
D/bgPO4vrMN+7X7owX7whfzE+kT3e6969KdV//8kZsV557fnVD9HHucaDJ9Y
T7Zxn50djupLDqr7/fqxEz0tBU0qP5DPp3oV3Z+YEph/Y36812EcFJh/R/VM
SXLc7grMD3kbjYacKlVf7WtzdiRsrVb6tPPo6qjsNz2bagj6sY58y3v294Gm
K27lH/oL/FP3/81z40ZW+dalBebJsCsjUu0ZgXmyQ/arEZYlXjVPrmntFGHJ
8Sp7knyz43R9vDRq0tJ06ztlvCj3i2bneg+XWT/4IsFQyJ+5fv3IPt7Lx5Lu
vl7cVEqx/+zzhGmsl3/dGD3UdKWMp2w31Dl/cav1OUmLU+1JtWwbPHOe/VoV
4ftzZco6a5Sbngp/ttW5tJpOpn8cnFNTzXOSfz6sX+mm/V/nfm627OMs57p5
jmg3dWpqP76i9CKVL3I9a+joofz4Lu/bky7wovhtp/Tz27hD38HVPp+dj79S
1OjM9rJhXWq7nHZFNGDZmMvFaV4Vz2n7ssfpDrYy4oJ6eXvkhe6Jx1wcer3n
f/Urm9nxWcgecw8ndQsacb34yI16W/BCrG59I30hX57hm/OY4acmYnNkmjXS
xbFn5y2xO7ZS/kZfu5z9Lq6MGvQfY9lhCn/r5B7zrjoO3T/oZc/8JjrePrNX
4s46gr4eoo+w/2HZT9CHb1Xx7lxzZi1ndcr4o7hDq/I/Sfwn2NtZ7KXQocHP
GE44KSpz6VTPylYCPyXCD4XNOdPqNGbRwpjhB4x7vAS+woUv1a9fvbLmoLEs
0G87Sv6o/F/xesrjphyvmm/Dl3XsYkvzsGfFfavs0wPzNe6Z+GlTdYkpLRw0
ofbtiiCn6leNPXw6W1q9qkfszxz9jFlndKt+dNvwGTvNVW41740YXB1qKXAH
3gEhrm3mqgZ+OnzmAoe1UN1vjfvedzqNFf8zj1+NGliuDw5gr2Dq8sOwuY7b
L6n7D/Zp780NYh/FVvQOTUwJvEdh77VhfnvV/DFc7FX194z0D4K92rmoUvwh
8In5B/pHC5+qz+B+gv54iZ/yY7f0PwL/2veEQeKn8m2z5BsfLXy5yDiphkt2
3DXctLaVzzyQmmv8VyXf8c2WUEudm4fEXJ3hiL5Avc+PH+V55SJlnOn8kf18
Hbf0z433POammIdeO6IPK6eo+vgrxbd6+dGp+VXOdyupas7KZme2h1HflVLf
vOaDW0JseW4aOeDpHOOcFkZ/SJL+wJD/q8jniQtHbLK+c0r1n9dWhS+0O45w
VsXXcx1Fbj5856ha34lqXvjd2qX2j9yM/rJV+gvnrjjxks54mjbODnveEFej
+tVm+Sr/IsU/ZV/uhpRDxj3V6vxaOU9Y3yXrBP3viX5Cv5wo9hL4DBI+Cf5g
Hf6kiz+EeBRJPJS+aOFL9e8k6d+K/6eEfwL/lcK/ui9Y7hvVL4/I/UdNveKu
FxdUc3ljfnDOsVZVR5Oln6r8/nDWrlJ9mFe9H7YFP9jJdqM/YN6ZVHa5fc4H
XvVe6Dx61iFjYeD99fKmsi0JU+o4ZkveKuvuJpXn6J/l0j/V+e6X3eMrzBfV
/D5x+NUHEp+vJ5zHPvTrPOnXCtdKXdPJS6tmVWSd4pFTb7/o+9LDMce+idK5
jvOBxTvidO29vHfUsike/df89unkLQnpXp52oN1zBt9+WpLcbYThxn0DfiqF
HzWfT5+3k0xj2/haSbzL+W29mleXr6973zHZxeXL1xz19fyRI08kJlTc7eaT
v43pYOt6iecPfsTi+b2ey1MO9zeNbeSFpQk/+CY0qnm2d9+Dj5qGNtCaWPOl
4i+buXTGlFM+aqDIg3dmmzOb1f2EvgV+pgg//Fu/rfpEXR7X3PN3na2rm39f
EJFltnzKG356c7BpYz0v7P9ISE67ryh1gfOsb13gvRcufPPmbR0eSny+liqS
l+gtBVXc+u+HnjQV19KQubdVOE9XMe73aLnf+Y67Vv9S3NdFRW9wN0tB4Pwh
OU84b5DzBL7UPH6TnxLhh8DPceGHwOdx4ZPg31nxj+Bfqvin5u+Rkm+EeWW6
zCs0rdPoQ8ayUipanTpGt7SWwD/sAf/LhX8C/2HCv8q7uyW/KeN8ZL4xqJ7i
Zq2636YL1MsiqReVf7GSf4T8y5f8I8xfmTJ/0Zq1d/WzmAIY8c2WeiPk63TJ
Vwq/GveDvmQ3GapDIizfBN6vE6UeCfmcLPms+IiW+Y72pnWe6ikppTv6fzzC
MM6r+kWEzJcMezAfdk5P7me5tVC9dzFvLJZ5g2FPuNjDkB8i8tV7ZpHMo4x5
JlrmGQaf44RPde++LvMvb3rrw6/MPerV+3nz5D8+TTgT+P/2kIEzT/iSz/HO
Tz8e76l0M+5vzB+o35beZeM9e92MfDgu+aDsS5P5nd87XzTAVHyWPjl42zRP
VDUP6tU221HfQNNHDXvUUlfDmCfQN/FuKX/p8xbnuzUqz8cWDM81V9XytceN
sbrsRvUex/29V94XBH3rRR9hvsE+vI++a35ioKWgmlB/uVJ/6r1wvcY/NxDs
nST2qjx/Qewh2IP3LPjLFv7U+2KYvI8I83CuzMOEfmKVfkKIh/b/fVOkX1LJ
/juv7XrwLEf2zsuw3uvhn7NSDujDzpHv/jGpdpuHI2xtXWxdb9TlwyFdbXPb
+B/7JvzNFlei4pWaEdbeltZEjz+9YqBp6CXusfz7UFMi06k+fyQ5ipxqf73s
J+wfKPuV/gjRT9B/VfRTqntfuvXFG/Ppj3Zd4owWDnlp2T22NCdndN++zhrp
VtgmWO3fIPsJ9s8X++lPly5PCQ==
                   "], {{
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[0.3], EdgeForm[None], 
                    GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxNV2dwFkQQ3SUQihACUgOEhBY6Su8KSJUeagxIlxp6R+m9V+kk9CIdsY84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                    "]], PolygonBox[CompressedData["
1:eJwtleVrFlAUh8/R2d2CitiYzELs7qmbNXXO7prdrRgYqFPEIf4bxgdBMVCw
sQvELlCxQNHnx7kfHs7vvHvfe+/JNZhWMHJRMTObDxnQ0s1uYAdBDozEHwWT
0dXhE3THn4bdApXRd7A1oQ8MxR8CFdALoAL6IbYEDIQW+M2hKXoAjEH/Tb9d
DBfhOJ+dwDaCs5CFvxBbEb5AeY+zukApdGsYjS6EyzAVfxW2IRSgr2EVY64+
w7+guGC4xW/bwBiLMzLQL7HLoS9Uwr+VYu8Nf2APn+3H1oDJ6Ekedy2DMui7
2MHQX/fiF4cO6NpwBo7iH7XI0Uz0LFiDbgzj0ONhKrqW7kDXhG6KG7LROVCA
rgaz0e+w62GdPsM/je0KQyzecinlWm+6CnP5zgZsE/gNdfCzsL1gBnq6R+71
pn+wH/9AqnEVdFXonPrlPNTHH4btCJ+hh87AboMp6DfYlbAC6uLX87irqkXu
m0K2RQ1GoId7/E0xnkoxKRbduQu9w6MWe+Ep/NSdME997BGjYtsM+/D3QqZF
zZqgHdrrLuUNvc4jtztSLDs9zlZMFdHfsTstZqKTcgGHLGr0NsWo2NRzOrsI
jlvc8T7VSLVRziegJ8ISi55Qbsp69IpyZMq9R28ehFdQEr+fRY42om8qD7A7
1U6fSauGq9X7UA69HZZ61ES12GoxW6Whk8WMHfOYMc1WkcXbz6XeUwwblCvN
WLozU2/3OGu8xWwt9tgFmrHD6JMRhh2BBZpd2GQx81v1XY/e3QPtlDuPt+br
ndIef2ulHHjMkGbnUOpFHa7cqCe1W3riz7TYMZqtH9iWFjOm2q31qK1quBt9
29LsQj/1knaS6gTfoK+H1sx9hScwx2KmnsNgj92mnfQxxaxYmylvHjtUu3Mo
5KJfYNta1LC/R8+qV+davLW2x3f15tdQ6LHLVKPO6C4euygzvUU5y09veqCz
8fMsZk67K99jF2mHjUaP9ditesMc9BWLXaOdMQ//g8WsqEZ5HjOtWVaP/ko9
ot5QD3TVLvLYpZ5y/wg7y6IGA/AHesSmHryfeka9ov8Zg9DPUm01s4+hj8cu
Vw16oe+lXOrMZfjXLXaNYtTubuwxu9rh/wH8q636
                    "]]}]}, {}, {}, {}, {}}, 
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwl0TVSZGEYhtHuHKjCnSpiAjxikMHdlsACaGSQngEGWwKawDJwWQAW4bYA
3IYh4lAET533++tmN7Mj1N4ZDAQCYf0wshXSrruLtyzmEXPYrR7duUt4zFz2
as/+xWjF6N49zWXGcoUzfOK58uw+9WtQA4pTWNWqUZUufPtPc/Yaa3nJAhZq
QpMa1bjGlKFt37SyTU1qUbO2vKcxXR/2X/5nKkd0YA8zX9f2u+btTTbyinVs
UL023Clc5SzfmMREZWnfHcVX/uaQ/ihZ697imaAXe5HPrGClfurMXc4HLvCR
EYzUiV3KU5bxkDeaspe4o68fXBT8/r+fLSQ+ng==
                    "]], LineBox[CompressedData["
1:eJwl0bVRRGEUgNFdXALoABaHAUKsjMUdFteNKAF3yJAZoBPcIqwA3EpAD0Nw
5rv3zoveH4pEw6PBQCAwxoThQ9P0Qsc1TDVlTHPpPqOZfJpndZ45bu0VWkkV
+/Z1jePB3KrttLFCPsfunfqiHfqsKbpDMjf2IzbNqRRRyLnbsI4wyLt9SM90
QN+0T1+1X0+1R3uJ0E0XJ+4FeqgbmsSTeVUTKaGUPB7dE3SbeOq5c6vROmr5
sm/pt6brlRZriB/zwt/PJpssDqw5mkuQNXbdrlk0N9BIOUssE0Ms975p0haa
2bNn6CRTwf/3/AW9FDkl
                    "]]}}], {}}, {
                  InsetBox["\<\"\[Mu] = \"\>", {-1.8, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["0.2`", {-1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {InsetBox[
                   SubscriptBox["C", "J"], {1.4, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["\<\"=\"\>", {1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["3.0700000000000003`", {1.7, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {
                  {PointSize[0.05], PointBox[{-0.2, 0}]}, 
                  {PointSize[0.0125], PointBox[{0.8, 0}]}}, 
                 {PointSize[0.007], PointBox[{0.4463998339305619, 0}], 
                  PointBox[{1.2771956561278897`, 0}], 
                  PointBox[{-1.0806611991222994`, 0}], 
                  PointBox[
                   NCache[{0.3, Rational[1, 2] 3^Rational[1, 2]}, {0.3, 
                    0.8660254037844386}]], 
                  PointBox[
                   NCache[{0.3, Rational[-1, 2] 3^Rational[1, 2]}, {
                    0.3, -0.8660254037844386}]]}},
                AspectRatio->1,
                Axes->{False, False},
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                Frame->{{True, True}, {True, True}},
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLines->{None, None},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None, "TransparentPolygonMesh" -> 
                  True, "AxesInFront" -> True},
                PlotRange->{{-2, 2}, {-2, 2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.02], 
                   Scaled[0.02]}, {
                   Scaled[0.02], 
                   Scaled[0.02]}},
                Ticks->{Automatic, Automatic}], 195->
               GraphicsBox[{{GraphicsComplexBox[CompressedData["
1:eJx1WHtUlNUWR0g0bMSrpjZqampNelV8TL7d6izN1y30Zol1x0e+LqOS+Lqw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                   "], {{
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[0.3], EdgeForm[None], 
                    GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxNV3lQl1UUvQ9EEBBMCAVUUNACEk1URElBc0NzLXNfUBR3UzP3lRDNLbcy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                    "]], PolygonBox[CompressedData["
1:eJwtlfePllUQhWd20YhodCEUC+CC0qSJitKUuioKC4uA0l1AZZFFQLqh6VIV
RQkSE8I/gSXBCARLFNQoKAoJQewaK9gSEn1Ozv3h+ebMd9/3lrkz81bXL6xr
rIiIJ6AZfAvHoBYGQvOM2AS70LvhPXgUfx0WE2P4+VAWlsCvcCX/jcduhLPw
MYyF/nA1Y9dAjZ6DfXA5/jhsZ3gXZuM/iW0PX8N3ZS9T4QHGJkI/9FKoR7+D
vRZWQzf8rjADPRO+gafwX8DeBjPQ0+Bm9HLYgT6ArYK90Aa/LYxAXxE+ZEIf
ZEvtCX0Ie5f2AqdhPP/1DT/zEwzCbwjHqAr9OnYoTIBL0zFU7AZpnnQMFbuF
sB/uw1+MbQFXodul9zIS1qAvYEfB5HDs3yhjuoMWjH9UYqtnxuLXwrxyxr/g
C5hY9vQzDGZ8vuIEv8Ei/M0lH3TWCen80JnvR9fBTSVnatAnsV1hGByG6enY
3gP/Qmv8SeGY/gKP4zdhK+EcfA512kfJlbdhdMmZ12Abz7+s2MGrJaaK5RDd
EfqV8q5ybkp6D1p7GdyLPzr97iI4pbG0VowvRlcrJxR3zYm+Ex5DV4fHmmBn
+JnV6JUwHP2c1lAuwg3oZ8vZVAPK/aYSy9+xW8IxbanYwHbFMqw/KO/qv8X4
n5W19U5H/P+wveFBxVyxh06KCyxFHy36mfBeP8G+GN7zyPQzGmuEh9GPwBp0
B3gaPTBdG3pnbroGVXtrYb5yJ52r68td/IntEr4T9YZL4KVwj9iMvj49t/7b
ns5p5fIeuCzdU9RL1GPWqxDStfU8zEH/WNbWHhekc1S5uSHcKxrSe1HPUK1X
wo5wzfdXb0rPNa/k3qr0XSkH++hu03PN1ZzoL8P9RHO8Ga5x1bZ61EPo78O9
ZRXcjj8A7g7XwFuKY/pubgnHplX6bhUj5caodOyVI7q7EbAgfIfK/fMll1UD
n0Jf3VG4Jo+XPWuv6inN0j1RvVA1cqv2ku4dqsHh6KElP7SGav3vcG2q5m9k
7Ei4tmdpD/id07mvHnoRuifUh3tmBfoMdkr4zNfhd0/31jY6I7pHeq7p4VxV
T91bcla9dhasCPdc9e6p6dpUzBvR74d7gc78Q4m5Yq1vwB3pb4S+DarJP8qa
WmsrnIAlaa0zz0zfie5Ca/5TclC51y1cuyvSWjXcO30mnWV2+Oy90lox0Nm/
Cn+7FINJuuv0t0f7P6i4pXuxvgH/A+4CvfI=
                    "]]}]}, {}, {}, {}, {}}, 
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwl0TVOBQEYhdF5LQnuJQ0FFHiFuzcsgQp/uG8Ab1gKLgtAKxx2gLs1nBeK
L+f+M8k0k9EebusLBUEwpE7jjlHcYwdvWcwT5rBHvbp3l/CUuYx8ZN8OM0YP
dj8fGcdYrdozfOWF3jTrXmM8NzjPD17qUwvuTdbxioVcVpEaVK9WHXu3oyX7
l+lM066dwlT92NP8ZjInNaUJjatAN959adHeZguv2chmNWnLncR1zvGdiUzQ
mI7co8xXrWo0okPPh5mnalWqShU6j/wDvjCTWcrWgftJA/YzB3nGUparTCvu
aHapO/T/H/8A8zY8Ng==
                    "]], LineBox[CompressedData["
1:eJwt0UcyhFEUgNG/ZcUK0GihUIUhzSKEljMtzahegByHQtmOnGbSWM7WIB1V
Bqe+e997sxeJT8YmQkEQJJgyfGmWnmmp5pDLt31NtzWse9qircS4tddqlDr2
7RuaxJ35kS3zg15wxKY9hSfzKy9cke0skxUyWKWEU3djOs4IH/ZRPdFhfdch
fdO4HmuRFpPOMmlEWOLS/aLW82xe0FQqqaKaQioop4xk5rn3vl276KCTNnro
5sB9n/bTyyADHDrP1wJ+zOu6o+fMmBtopIZZ5v4+hxDXxia90Wbd1Tyd5vP/
/34BUXM1zQ==
                    "]]}}], {}}, {
                  InsetBox["\<\"\[Mu] = \"\>", {-1.8, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["0.2`", {-1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {InsetBox[
                   SubscriptBox["C", "J"], {1.4, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["\<\"=\"\>", {1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["3.06`", {1.7, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {
                  {PointSize[0.05], PointBox[{-0.2, 0}]}, 
                  {PointSize[0.0125], PointBox[{0.8, 0}]}}, 
                 {PointSize[0.007], PointBox[{0.4463998339305619, 0}], 
                  PointBox[{1.2771956561278897`, 0}], 
                  PointBox[{-1.0806611991222994`, 0}], 
                  PointBox[
                   NCache[{0.3, Rational[1, 2] 3^Rational[1, 2]}, {0.3, 
                    0.8660254037844386}]], 
                  PointBox[
                   NCache[{0.3, Rational[-1, 2] 3^Rational[1, 2]}, {
                    0.3, -0.8660254037844386}]]}},
                AspectRatio->1,
                Axes->{False, False},
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                Frame->{{True, True}, {True, True}},
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLines->{None, None},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None, "TransparentPolygonMesh" -> 
                  True, "AxesInFront" -> True},
                PlotRange->{{-2, 2}, {-2, 2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.02], 
                   Scaled[0.02]}, {
                   Scaled[0.02], 
                   Scaled[0.02]}},
                Ticks->{Automatic, Automatic}], 196->
               GraphicsBox[{{GraphicsComplexBox[CompressedData["
1:eJx1WH10jGcWT9kTNk20xSqjqw0tY5EoglrcQ3btJi1mseEQL6W2iFarUY12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                   "], {{
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[0.3], EdgeForm[None], 
                    GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxNl2dsl1UUxs9htYW2QktLC0IpUESmLbRlFCkgAmWXvaQgIHvKkFGGluFC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                    "]], PolygonBox[CompressedData["
1:eJwtlflvkEUQhmcBETCCIJelHI0cgmg5KtQCsZSjByBQKAVpFcuVKrSV1iKC
KUG5VMCAiYa/gSMQNRwhgHKpEJBgVCIIQsCTgJqYSASel5kfnszMt9+3uzPz
7n5ZVbWlNc3MrA5awJRkNhky8BuhI34nGIPfFkrxr2LfhGUwjDgXFuP3hD/g
NEyHPFnGypK/mwnb4CHiUmwWXIATWhdy4DJ8BVMhF87BUZgM/aEl374Bm/E/
jLlmwnLzOQ/oW+Kl2G7wiSzxbOx4mIVfDs+afzMt+TfdIqdv4SxsjfVuwCO8
MwP7HHwKGcQvYJ+GQvy92AmwBPoQ94Yq/Ll6jl8Mg/HrI9f9MDFyLmBsD7Yk
eqC9foYtMt9zK+Jj2HYwDv6D2zBQ+4IujHdO3pux5nONI34t5myNfzzeLYRa
4n9jLuWgvZck35ty+BVeIl4VergOLxI3YZtDe/wOyWvRBm7CGSiHfPgLvoGZ
MBr+gUd5f5a5hnYoF2kCOwK64j+WvDfK8UH8g1jM/R5dggaCjdhn4Jos8SLs
WzHXzli7LLSyO2ohzYxnfCwMMq/Jw/jbQ5vT4Ae4A8VQaa7dP2Nv0vB36nvy
XqvmPfAb4QP8OeZafAC2mGtyCX5d8lq/DyPx58M61R4WaC/SCP76qPVv2LfN
a94mucal7alRu1fhPfMa3oXz6knseRljWcnPlvbwf+RUGRqSdhfCu+YaXoT/
ChSYzzlQWoYV+NXR61+wK817rm+PxF41h7St5mww13imtJY81wrz2nyJ3WRe
I2l5Fc8+jv004e8K7XykGhKfNL87VIN64h+x2eZr5BHPhTX4NfA6/pDkWtAa
Gvscu9r8nSr1CnrFM9X+C+xa8x7MI86Gx+OZcm2bXAvKeXjyO0p30+LQsu4E
3QXSdHfG+yY/2x3NezkqeW/V04T/k/pqfsa11ojke9eaOiu3zM+Gzkzz5JqS
lp5XHbT35L7u4K/hKWnAXPOzk58BaV896088QD2WtuB3rUP8Mvad8PvBPPNn
T+AfNj/bejaUOCd579XafN31ye8i9eDJ5DkrV62hs1SU/K7TmVKuP5vf1cpZ
2qpWjcw1dkV5Jf+X6E4+pX0k35t6pLtxEjSY35HNkuekXDaG1i+a/xuk+QrG
DpnfRarJROJ92CHmc6xN/s9Qv3SH/x2ak9a0p+/Nz4i0KE3uCw1XxBz3AKU4
toI=
                    "]]}]}, {}, {}, {}, {}}, 
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwl0TVSBFEYRtGeiADXiSkCCNBCB9kEAa6D6xDjGSwGZwF4hNsScNeYU0Vw
63z/67Czo7H68VAQBBNqNG4Yxy02sFRlyleLWnXrWzkPWcA2bdvtTNCd3cF7
JjFRy/Ykn3mqF025V5jMVU7znWf60Ix7jbP85LmudaFFbwu6sg+0oXn3L8PM
0qadwUz92GP8ZjpHNKphDalEl759ac5eZyrT9GYP8pUpHNC+3c9i1alWfdrz
3ssi1ahaPdr1HmWhTuwIj9nNJ+YwV3nacT+o035kF49YwSpVaskdzyY1h/7/
3R+GJzmf
                    "]], LineBox[CompressedData["
1:eJwt0VcyQ3EUwOEbbbACnRjM4M0C9Og12IAFSHQetcxkP9HLo7YAvbMHvXyZ
8fDN75zzf7s3PB6LToSCIIiTHt40Vw+1Ugso5N2+pCkt1g1d1hUuzN9c8sOq
26au6a9ecUfSfqvH7JKwh7g3P/HIKfluOSyQzSJhDryN6hhRXuwjuq/D+qwD
OsQge/ZyrSCLeTIpY44T77PawIN5RjOopY56Sqmhmqr0h2KaG2OLXmuzttHK
lj2iHbTTRSfb7j3aSzf99LHjXqKTTBHnyy1Pj/SDT85odDvXJl3XIo3x+v/v
/gDpvTb1
                    "]]}}], {}}, {
                  InsetBox["\<\"\[Mu] = \"\>", {-1.8, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["0.2`", {-1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {InsetBox[
                   SubscriptBox["C", "J"], {1.4, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["\<\"=\"\>", {1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["3.05`", {1.7, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {
                  {PointSize[0.05], PointBox[{-0.2, 0}]}, 
                  {PointSize[0.0125], PointBox[{0.8, 0}]}}, 
                 {PointSize[0.007], PointBox[{0.4463998339305619, 0}], 
                  PointBox[{1.2771956561278897`, 0}], 
                  PointBox[{-1.0806611991222994`, 0}], 
                  PointBox[
                   NCache[{0.3, Rational[1, 2] 3^Rational[1, 2]}, {0.3, 
                    0.8660254037844386}]], 
                  PointBox[
                   NCache[{0.3, Rational[-1, 2] 3^Rational[1, 2]}, {
                    0.3, -0.8660254037844386}]]}},
                AspectRatio->1,
                Axes->{False, False},
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                Frame->{{True, True}, {True, True}},
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLines->{None, None},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None, "TransparentPolygonMesh" -> 
                  True, "AxesInFront" -> True},
                PlotRange->{{-2, 2}, {-2, 2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.02], 
                   Scaled[0.02]}, {
                   Scaled[0.02], 
                   Scaled[0.02]}},
                Ticks->{Automatic, Automatic}], 197->
               GraphicsBox[{{GraphicsComplexBox[CompressedData["
1:eJxlWHlQk2cax2OdypiuraxiPFrdqhmPikdatdbHSrU7WjVlXWupZlhdLJrO
tuJB07HOVm1saT0bbVFWxB1dRa6RCh7YR8WDIFq8CCIghAAhUgyJJ9Otu83D
72Xnk3+++eV53+e+XgYs/CgqtmNISMiKDiEhv30fHQ/daPMf54SYh//It/k5
XzAB9+1W2Og2Xle4+IfB4XZnNY97Pt3sNDXzMKErDH7A4AcMfsBnhR9pz69d
tOSE0d6gzgPjPPCn8n2KDj2B8QV/3AN/YJwD1n7BN0L0JdgPDPuBIQ8Y8oAh
T3t/ufhb3QfGfeDGIL2Ii4J8fHw1iMsJ2CVY0YcE77u5Mvi7V8UP9BeETqDj
PjDkAYcE/37MB74odIIc6AMM/sDwq/Y8zmm/4A8M+TdEvvKPVg7osAcY9gDD
/8DgAwx9tfzOi/8UP2DYA4x4a8+jvkDXxgP1gfzTxg8Y+mvjo60X0OEvrf8h
B/KBQYeeoANDnrZutHzgP+iv9be2vrT+Qv4X530fpauro0+D2MXAaxffup+Z
2kQjgnyqKDl089uGrBYqCfIp4T2CGXTgeOFD9SdXX3jy5K7ilyj8uOeJ3+Sn
ccTvJ7xkjmxkg3xJi6/LPU4I2u9U+gFDDvgDgz/44Itz2t9xr0r0VfbBXpxD
/IFVfNr0gn3A8B8w4gGMfET+g/66+JOhD+INjPxAfgMj/1HfoAODbhP/qfhB
HvwP+4GhL+zGeWDwA8Z94NHB/DurMPRFPgIjH6Ev6MDa/g37kA+wB/UFDP/C
39Af+ani02avmk9tGPYBq3nVhmEfsJpfbVjNxzY5yE/kD/gj38AfGPfhD9gL
OuwFhr+08wT5Gyb6qvo6LfFS/sJ59BNg6It5Cv/vDuI0dR/2wL/wPzDkoR6h
P/QFRryAtfMJGPyQX+hHkIe+Cv6go17BH/bBv+CHeLhL7Xmm/v83X/4TWJu/
uIXvFS2ocx+pV/qCz6O/9+hof/dntY9Fldtj/DvrOD005+aTrLqn9qt5hdbe
9l7Vio7fYe+fFixMtk1xKT09fcNWOvfUKD7PZd8hg9Oj9L2640aN+4hHzeOU
E4OXOksaCPpq96XidWMeO/oEVHy3b35rgHVmQMmf8lW/ebpzfho+4utoXexp
/lD/SYGxc4BLTac9Dks6JXdYu9MWFeBZBW/kmqquUpq/bGNqhZ8PNneiyGM1
/Ie3v/rCNvout94b8UzWGy7O/tfHh0y/ergp/azdtq2UXTkNW2xnPPx2cvIO
i+EkZ6Tsmu8vb+DV35Q69KENVPT1sa5Zf63hzJmn5usGVRO+0z57eY/JnEUP
A0UBx7B6Gms+/61tYAN5u3V91XD7Z5ry3SKTbpCT0z8zfeAvaqElrROd7iNV
lP5mTpqlsIXWbzq90BlSwYeX2Gca+rTwmoykCZHj3Tx2fkWl+76Xm+I++dg5
0c3h5ugu9jteXjz0wDLnllpqLug5X/eFjyNW9p5kuN1I4+TL25o7DzSv89LS
sktzdPvcfLk2YZclroji5i4aYe7Rvq/5JH5c3GdTrnGOV+0POB8j50lfYz9s
tBfTN2tjX7ReqiXwXyj8CfLxhb7dRV+CPcPFHpU/PslPcr5TeU4/vVHVE+zz
in3KP5nin/b9S/KfKjKGHLQccKn+NNfdeYhVV6L2Mewb26/T65HH/BzWmvFF
6mqnmkeoP9/uNcm20e3vo1nxRRmWZ3wM/tp9rt8u3/r8aT7ODPolh9HfME/C
3h+VZaqqZ9iH+v/lNeN03T6v6oc3e19IM5kdyv9fhm4ZGWktf2pfO9U0cYy5
oH2f21y8PcUWX63Owy84f1TOq31sg5xX9TVd+gFBvnYf7yb6E/IDdOiv3Qt7
iz+U/7Xvm63if6Vfk/ib6oN9opAfdDbnmi77+ZeTKcvyX7lFI8dUDLIeqabm
eyso0ppKhrD4Damr6+l6FY0zjKyk+F5De9of/m/+lL1fYAy7xnv/PD/PNMnP
DUnTxkc+vk7eTs4we56fUW/ZUm+M+6vkPqNe/VKv3D9t54p82zHeHZvwa+bp
BkZ9P5H6ZugTIfqwb/mMWOcWL8WlGWrd9xs40/d8rDPbS9FJy761RTWw929r
Lur1pTSmpkPXLEd7/8iVr7L3VbGXx6Ve62n/rkb145KEsiTb4Vpa/eKrhcY5
7XST0An0FUInyBsm8gj964z0L4J9O8Q+gr5Roi/Bnhixh9A/ddI/lb93i79V
P46Tfqzi6Zd4EuJRL/FQeQr9J4V2qHpCtTy7e12UP/pnBn5LMA0eFXPQ8uXT
+2uFK2yDLapZ0dX8a6O7hc5V97e5HHduc2mvo+vzF/tUXU2X+qbPb01Kt3ie
3m+bf6x65JgRUPvImvOlO20DA+r9XX+haaMtvv19vT11YZyzxKP6TcfwkBRL
nEfdjxn/zpr8Lm51fn52QbRuagsVLZmx1K/P5sS//LHAODbAKeGbdHbnfp5w
ZdEA6+sBHtW8skQ/vYC2xRvjnZMD/CGN7W5/9xy5Rm4r0U8IKH4xwo8xb7Jl
3rAvO6nWfcTJrf129bTntc8X9CPHpuFDIsffZm/JYzL85OHoe+9N1cVW8qSQ
rb2slzxc63/hnDHsKg/++ORM3T4PX81LMhqyLnP+wI2DzOva7Zsn9lHjhTtp
lgNXqIv3vemGuy7V16rEX2oeoN9jHh+QeUzercm7bIddfLTS3tXeq1G9zzeK
fwn6ukRfgr6viL6EeV4u85w+io24oE8s49Gb5u62FHpUP2rtFYwPwb7+Yh/B
vh/EPsI+sE/2ASrr4Q636gqZdMvDrTM9Kl+8ki8qnjaJJyGer0g8CfvK97Kv
0OKX5oyKtB5UWO27km+E+G+S+BPiXyXxJ+w7+2XfoZaUoZnGsJ8ofEGfWH9o
QO1XJbJf8azcmO8thmJ2v7BwoDXDr95bPZesOmtc4Wfog30K8yJJ9jEG/77C
X70vpsl+xneTjy7P71JOv5btbXXM8Kv6K5f641UjfzdVt71S/b8K76FVn3e6
oc9t//9W2rIHXsewO7zD1+Nlc1atet8iP05Jfqh53Vv2T0a8J0i81XupXPZR
Rvzekvip99K/ZT/l4dXRo82RW3m99E3G/mOX/YeR389Kfiv7TbIf84jB39xx
G6+pPnXq2fQjxuvldMackG4prFb4uGC17yccvvJPW3wNQT76dsfDvzx0XMxR
exvebzlb/LN1se3/d9sr/iL4C+9/+Bv7EfwdL/4m9IcH0h/U/l4t7w1CvlRL
vhDi2yrxJexTmPewpy8PijCv81N5n43X9Ik1NMdzc6UzooVvHbg71fBRHd3L
vHZcn3iXKzyPatypHpo8eWeOMaSJO8amrnSaTlP3Zzffdwyr4/2XJl/WJ7rp
zUDGGPO6aoUnCqYPXhx3yNS/kcbMfvzYcchF4N8k/BX9NaEreeNEHv0Xwr6s
Rg==
                   "], {{
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[0.3], EdgeForm[None], 
                    GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxNV2dwVlUQ3QUTSiQkgZDEECCBkBAIJrRA6Ii00AxNei9J6KBEQCkqYFSa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                    "]], PolygonBox[CompressedData["
1:eJwtlOdviFEUh89tzSaqVmLUqFGrtHYVqdWq0tKlWlrV2qM1IkLsFRL/gxn7
g70/IAQJgpgxEgkxYsbenuOcD0/e333vOvesuPKq3MoIESmHatA7iPSEbuh5
sBuSGM/hmwGb4AOMhji4DqdhFCTDFTgJ2dAT3sJxqAtD4St8g1SIgrtwBnIh
Bbpz1x6+w2Gu7mMcHcy+CvgIm31tDgxibjAsRMfCFvgMedDPbdkHmW7TffgC
+W5Dl2Bv1LdVid3dK9jb1YZf8BsGQzQ8hp9Q6P+EtQHS/I0P4QeMgQluy1YY
6Dadh2OQBR1db4ch/q8/Zw2ABehm8A5OQAykw1/447bonqfwDBJ8TSR7d/Ed
BkXQjXEiJInF8DlcgnG+5gXUYH483zIoQT/xWI2FB3AWCvwN/ZhPgaZiNu7V
vGFcrLGDmuiYYLFqCDshIthZXWGH26i2qc9uwyeP5WJoFOwM3TsVLkKnYHsT
3PdFjFd7DIr1bBgk9m8yOhZ6odfCFPQp1+s0zxg3gTbo5Z4LBYxXeU6oPsp3
pdi/5oxbwHQL9f+7CiFe7M589QW09T3t0XmwAl0JtYLZoHeXis0d8bt1zWjG
jaEVeinM0LuC5fJ6eA+vYYNYjVUyt02sdja67yfAGrEYlKFLg+WK/muHzoFl
6NmQjR4FE8XurEBPUhvFfPbI79Cz9Y2ZwWKksVkkdtZht1XPzGI8Elqil2iO
oFOD5a7W5Dm4IJbrWhOtg/UQ7R2zxGr/nlitag/Q2MQHs1Vj1EBzIVguqI11
0PXUZrE3qO87BPO1xqA2OkptEsvROI11sLvURu1tyTBfrMdpbfQI1mu0Rjpr
rgXrBYnu+2nBYqExqI8+JNYr1YZy9WWwtdqjvov1AK19rZk05m7y7SvWM/sE
qxmtFbXhMlwV65Vag7fc5+rrSLgDI4L5Vu98A/s9F/XMDMRBXzsTXsI1KBHr
eS01t4LNaZ+vHqzmy8R6gK69Ida7dU868wd8reb8K89hzV316T/KVp34
                    "]]}]}, {}, {}, {}, {}}, 
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwt0ccyQwEUgOHrASxYRJsg+nvonejsbJEsPJC+1610XkDv8QJZCKKHLzMW
3/znnLu4M/dGxuPRWE4QBJM0GE41yTL19jClhGhixb1ZyyingBZW3Vs1pWe0
mc/1hWdmmXC71D2usu+0z+kr80zZb3WfD+745IBjpj0/0i0Widsf9ZcMS3zz
Q4Ixzx/0ixHzKMMMUcKh+z3ZD7Cgb7xzw6DbtaYZMG9qvxZTRy19bLhHtYga
qull3b1HC9k1V+mOdmk3ueSRz5r7Be3mTjrYtke0kgpm7E80mk/+/9UfSAg8
RA==
                    "]], LineBox[CompressedData["
1:eJwt0TdOA2EQgNE1OQmQgI6G0uSco4/gmmgyQiRxJnJoMXYNmGQ4AjkKOAIP
ieLpm39mu62KLUeXQkEQLDJsuNcvjij6OxDiwbiiG5qpW7qqL3pGtvlVczSl
V6ybL/WYPda83/SaW25I8sMnc+4LzFPIod2QRuhnkAEO7Hu1jy566GbfPl8L
+DDP6rvm6QwJ87RWkjZP6hRllFNBLqWUUEyMCS58X6vnWqP11LHt3ahNNNBC
Mzv2bdpOK510sGufpWOMM8qz3TdxHnnihLDbqVbrpmboCHf//+oXz7EyBA==

                    "]]}}], {}}, {
                  InsetBox["\<\"\[Mu] = \"\>", {-1.8, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["0.2`", {-1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {InsetBox[
                   SubscriptBox["C", "J"], {1.4, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["\<\"=\"\>", {1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["3.04`", {1.7, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {
                  {PointSize[0.05], PointBox[{-0.2, 0}]}, 
                  {PointSize[0.0125], PointBox[{0.8, 0}]}}, 
                 {PointSize[0.007], PointBox[{0.4463998339305619, 0}], 
                  PointBox[{1.2771956561278897`, 0}], 
                  PointBox[{-1.0806611991222994`, 0}], 
                  PointBox[
                   NCache[{0.3, Rational[1, 2] 3^Rational[1, 2]}, {0.3, 
                    0.8660254037844386}]], 
                  PointBox[
                   NCache[{0.3, Rational[-1, 2] 3^Rational[1, 2]}, {
                    0.3, -0.8660254037844386}]]}},
                AspectRatio->1,
                Axes->{False, False},
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                Frame->{{True, True}, {True, True}},
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLines->{None, None},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None, "TransparentPolygonMesh" -> 
                  True, "AxesInFront" -> True},
                PlotRange->{{-2, 2}, {-2, 2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.02], 
                   Scaled[0.02]}, {
                   Scaled[0.02], 
                   Scaled[0.02]}},
                Ticks->{Automatic, Automatic}], 198->
               GraphicsBox[{{GraphicsComplexBox[CompressedData["
1:eJxlWHlUlNcVJ4tLMSTGICiiRmzJ1H3DGGu8hmk8ES3bUSHUM1E0bggqGnFo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                   "], {{
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[0.3], EdgeForm[None], 
                    GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxNV3dsl1UUvY9NW0qhdIDQAbQC0jJl7yFDZe+9oSigOBFREBfIXgXcO3Gv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                    "]], PolygonBox[CompressedData["
1:eJwt1OdLl1EUwPF7zaKEtEVQVpa2HWmZFpalqampqblSKZSIqLBsEVE0bFF/
Qpum9aKiTXsPKtrRIqJFg6LI9voez3nx4Z7nd5/f89x7zrlPt+pphTUBzrkq
BOIejiEXg3ALI71zC23+E9YhATlowtxWxhQUYwfi+G024wgcwmiulzO2wjZE
cT2TMRWJxAnoSDwXLYnX2LtkDf25jkW002euxUeMQlecwQFZI3rhBZpxfxlj
Ja7iCLIRj0s4jCzE4jaOI8/2FMF/79rep+ALNmCI7APvbE+yl+F4jNOYjqH4
iz8IRrKtbZPFssZn6MM7ap3mpDfxRsYgTMNPPLJnjZH3MB+CccTjZY/Ep+ze
GhxFuNdchCGaOBJRTnMcJnOYRCx1DiXuixnEk2WfxIO95j5U9kmc5DWeh4f4
gUJU4B8c88MYQvAbrb2uLdhyuxNpluMYrz0hvTALX/ENSbbn+2hAvv223nIu
uU7EA5xAgdVAanXH5vIs95KTGqtBNnEHhBMvkj4h3mfxYuRyvZ9xCerQw+s9
MjcVz3EBpU57erPTHpfelj1L7s4zRjrNYRuu26La6Rm6iMvWW9KDOdLbiLB3
Ntga6mzPAcRPGZehyGmtnzAudVrzLK4zvdZWzmAhcb7X3luBQOICr3GJ9Axx
ESYQx6Ed8UGrlayxjOsSpBOvRCVxBToRr5K+I072Wnv57QPeYLXTM5TB3E3G
BZiP5lyXen1WOdoT75L3Ol3DSZx1ejalh9KY3ys5ddqTTb2e2UrLueSqp9da
SM4kF7+cngXJidS2u9ezKTU+57SnpZdrba3lXvcia5az0M9r78mZ6EzcBRNd
Yxs35l5qWGU1kG9NPOY4/eZ8d3oGKqwHZe+fnX77JActuDcIGU6/YVvkuV5r
KT0ygLieMcbpM1O53uP0LMoa3uOl029hJt5it61tIF5bjiW38o4U4us2J9/A
7Qj2+l/J+StcwVinZ1BqXey1F9Jt7prTb6Hcc8NqOt9qUm89VWJr/g+3SJ7N

                    "]]}]}, {}, {}, {}, {}}, 
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwt0TVSQ2EYhtHLAphAhcwgAQLsAocQoUiPTAqkgQXhbABLGoKnx90WQIO7
DKegOPP873fLG06PpUYLgiAYotljV2+Zp8muoJISWllwb9MqqimlnUX3Dr3X
PTq99/WRBybpdTvUNY7os6f0mWn67XNd550LPtggz6Dv25pllgH7Rn/5YY5v
it2LCHFtf/HJJSNuV7pFg/emNuqMvvLGGT1up/pC0jujCS2nnghxlt1jWkYd
tRy7DeuJrvJEoT2uSxzQZXcTZcUOa05rdELvaPHe+f8vf9LDO6g=
                    "]], LineBox[CompressedData["
1:eJwt0bkyQ3EUwOGLEMEoCI00Sjuxr68gYl8awZhR8FD2BGXQx84z2LexvAKf
GcU3v3POv7u3NrWWXM0LgmCFwHAn87quBbqpC/qopxSan7RIz/SCZfO5HpFm
yf6il9xwzTHfvDPjfY5ZSjlwG9Qh+hign333Hu2lk2662HOPaAlv5ml91WKd
ZIoJxolx5W1Ux6iimoxbWLe1XL/0k2cW7VvaqE000EIzO+5tGqeVDtrZdQ/p
CEkSPLh9cMiw/V7rNKc1Ws+JOaUbf59f87k1V2glUbL2Mv35/0e/r1Uv2w==

                    "]]}}], {}}, {
                  InsetBox["\<\"\[Mu] = \"\>", {-1.8, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["0.2`", {-1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {InsetBox[
                   SubscriptBox["C", "J"], {1.4, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["\<\"=\"\>", {1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["3.0300000000000002`", {1.7, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {
                  {PointSize[0.05], PointBox[{-0.2, 0}]}, 
                  {PointSize[0.0125], PointBox[{0.8, 0}]}}, 
                 {PointSize[0.007], PointBox[{0.4463998339305619, 0}], 
                  PointBox[{1.2771956561278897`, 0}], 
                  PointBox[{-1.0806611991222994`, 0}], 
                  PointBox[
                   NCache[{0.3, Rational[1, 2] 3^Rational[1, 2]}, {0.3, 
                    0.8660254037844386}]], 
                  PointBox[
                   NCache[{0.3, Rational[-1, 2] 3^Rational[1, 2]}, {
                    0.3, -0.8660254037844386}]]}},
                AspectRatio->1,
                Axes->{False, False},
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                Frame->{{True, True}, {True, True}},
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLines->{None, None},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None, "TransparentPolygonMesh" -> 
                  True, "AxesInFront" -> True},
                PlotRange->{{-2, 2}, {-2, 2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.02], 
                   Scaled[0.02]}, {
                   Scaled[0.02], 
                   Scaled[0.02]}},
                Ticks->{Automatic, Automatic}], 199->
               GraphicsBox[{{GraphicsComplexBox[CompressedData["
1:eJx1WHtQ1NcVRqsmKuurRgz1UR+YraSKD6ha9Fg2moqabBwTK9a1PlAUooSi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                   "], {{
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[0.3], EdgeForm[None], 
                    GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxNV3ds1VUY/S4FupBSWvoetdBBodVSmYUuoKwKFKUUSillidYiIOAEB0IZ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                    "]], PolygonBox[CompressedData["
1:eJwtlGWLllEQhs+xUGTtjtW1Xbu7a9d27URdERXdNbAT8R8oioqC+UHs7i4U
BcUuFAO7u6+bmQ/XO3Pec57nmbjnJI3MTMvIEkIYDtngM3yBppALLsFe6AwN
YEAM4Rm2FiyC13ARSkIK3IRDkAHNYR9U4JlG2LLwDpZBfUiFUuwlw0T8MXAV
PkFXj2E7vIRWUBB2wkZoD52gW7T/5C+A07ADOkJN5cB+TijhzxyGLdABKsJy
+AhdoKHHlsT5sR7jUnjluZWGFuxtwqpmo+ERZOW/PqqNYsQvEK2eI5QH/gM9
B2nwD1ZDS+gFL2Ab5PUzqvVlj0U1v6fceMdc7DxIxC8T7duY0IafK9jGMA4+
wHvFFKzmRdnfis0Do6Aw6yLR/HSojH8QOwHGwxLvkXpTD97AW/eV8wbXgHpf
HPZA+WjaSITs+E+wbaEflGNdNtqeanodvkF36O+1XwHNvAff4YZrp4f3cp3y
9J6eVy68bwh2GOyC3KwHYgdBFfyVwbSrnGqzrgnV8CfBGqgVzW+tvKJpSNqZ
Aj+hULTeJcApqBHtbDI89RiGeY4n4IxrTRrIEk0T0kJvfYN1q2jaV4/a4W/G
ToPp8NVrolp0C6Z9ndGeZkBauoWdEUxTHVn/8thmwXO4A7ODafov3IU50BOa
cr4ZTA02A03wG0frnf5Lxe8MmcE02B1/sWtrod6Jc9u/NTOYFu9j5wfTZFvW
JSHJc9IsH8NWDTbTB+BIsFlTz6uzf9JrqZnWXSENSnsZnou+OdNzUu4/XAsz
PDdpON1zTMDfHWw2B7s2zmGHBtOIYlUyvTzmfPj5o2lFM1IMf32wu0XPHA12
J+kuUk0ew1no6xrU3ZcjmrZ1Bz6E497rln72AtT1Z6RNxajYpNE6+GtVB5gM
q+CP90o1k1brRtuTZn9DSrTZ1wxfg/2uFc3MRe+ZeqU7uDR+/WharhPsWzHa
3aNvNtSsRttTjOpdpWh3h3r4HzLKn/8=
                    "]]}]}, {}, {}, {}, {}}, 
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwl0bkyQ2Ech+GTGjOIBjNIrBdhi4iSJEqqFEouxr7cgK0SsYQriH3nCszY
d6HxzCieeb/ff053Ipmx9GgoCIIR6j2q6WDJ7tQHfWSPAXtCn5gmYkdpYN1u
1BlN6b7mOCBtz+orcwzaZ7rJJ+d8scUuO6xyyw0J319rn/7qAj9U2WEqubKL
fHPBsNul5mn13tY2ndd3Pjil1+1E34h7r2iP1tJCMzGO3bu1ixo27CY91CE9
0heemWSZcvcKSlmzS7SMrHdSp/SOewr0u43rIu3edaH/f/IHuoI5cg==
                    "]], LineBox[CompressedData["
1:eJwt0Tkyg3Ecx+GXICioJAoplPYlRHAAJDTGPqPR6DiRJWJJRTiAfb+CfR/O
YHvMKD7zfH//dHlrZ+aH5wqCIJhV2rjju7Y04E6pTrvuGtZrzx7hAr/0rStV
eYsoqk13OT/Zz2v28YYBf7CoUfue+yq0HxjiAU80ZR9zW1mNu594qktdKOGt
UzF1KK4h7fhtXZP2G8tYqpzdw151qVtJbXgPc40TfGUJi/VsT/OF56qwz1jJ
aq3aRVxmXh961Ji3JTbykA08YhMzbGGrmtWuNq38/UUc1O3/d/kFwvsyNQ==

                    "]]}}], {}}, {
                  InsetBox["\<\"\[Mu] = \"\>", {-1.8, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["0.2`", {-1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {InsetBox[
                   SubscriptBox["C", "J"], {1.4, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["\<\"=\"\>", {1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["3.02`", {1.7, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {
                  {PointSize[0.05], PointBox[{-0.2, 0}]}, 
                  {PointSize[0.0125], PointBox[{0.8, 0}]}}, 
                 {PointSize[0.007], PointBox[{0.4463998339305619, 0}], 
                  PointBox[{1.2771956561278897`, 0}], 
                  PointBox[{-1.0806611991222994`, 0}], 
                  PointBox[
                   NCache[{0.3, Rational[1, 2] 3^Rational[1, 2]}, {0.3, 
                    0.8660254037844386}]], 
                  PointBox[
                   NCache[{0.3, Rational[-1, 2] 3^Rational[1, 2]}, {
                    0.3, -0.8660254037844386}]]}},
                AspectRatio->1,
                Axes->{False, False},
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                Frame->{{True, True}, {True, True}},
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLines->{None, None},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None, "TransparentPolygonMesh" -> 
                  True, "AxesInFront" -> True},
                PlotRange->{{-2, 2}, {-2, 2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.02], 
                   Scaled[0.02]}, {
                   Scaled[0.02], 
                   Scaled[0.02]}},
                Ticks->{Automatic, Automatic}], 200->
               GraphicsBox[{{GraphicsComplexBox[CompressedData["
1:eJxlV3tYlGUWpx5zFcRcb+BoUEY6lRe0ZitWPSpmxopN1KM+tTsL2hobPZrh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                   "], {{
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[0.3], EdgeForm[None], 
                    GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxNlmdsVmUYhp9DF6W0lFJ2qUILLbQogjJEhIoDEFFBUHDjQpGlhQJqRI3G
vRI1atzRaHDvrSGuHxpH3OuHe8Udt+J957lI+HHlnO98533f576f8X1DF6+Y
u7xbRPwlSsQqsVL0FxPFNqKHmCnGiwYxVGwrqsRq0SnmiXFiEPvsKIaIUrGX
GCMGiEZRJrqLtaJLzBdrRI2oF22in6gT+4lpYpQYKVpFL3G02EU0i8VismgS
w0RP1h4rWsQIcRJ79EZPuagQC7mvFIeKCWhu4D2/cxheWPNAvClB9wD0WN9g
9lqJH6VoqyOmVvTVoNua+xDbEtGXax36R4t21kxGq9dOQVMtMU0k1hb0W+PO
+FEtZpGPRvZq59xa9tniSQM5LUFjKQzh2Xbodb1Mxws/P1BsH5n7Mt4pJ9Zm
8lXG+d5vHbHVoHU+8fTAe+ditpiEnip0+vu9I+uviriHscdO7O+6GouWCuIY
zP1xogP9g4i5hPhaiWcAufS63cVUvnN8bZy1h9iNz45hFF76nB04y+ePJ85l
4kTytKsYvpX3Lexhj8cRz1JxAjmbgR7vuW9kTdTj0wS8auTdUvS1EW85nvmd
hXjjPMwhjlq0TWVPxzWF59Y0jft29vWeK9DfQeyzyYF7cR+8bOZzLzyejq4O
1rbh0wx0teFnP/I4C03WPRMvR5IPx7t/ZB1UEeMc4pyKR/XoXYTmAyL7scCj
efjgeOcS52rec207/weRzyPEgsj+9XU+92v5XI3PC9nzIWsuMjeHEEMl14OJ
Z8t3fu5aPjyyvhexj5+71zw3XY/u5SMje8Zz4Cg8dv/tGdmrzucx5NA16jni
uvIsWoX2eXz2/cmRc8czx7XjenMNukZdq64vz71lPHNOlvJuJ37Zq/WR/bwG
/1ZzjmtiEl4tR0P1VhpqON9xjGJNJx4uYE01+js5awlrrOsrcRU56sP5zrt7
3DXaQVzr2aeL+zWwjhjW853f+Ux8iI7jOc81+ZLYSE6aWFtNnK4D18RomXpX
ZL0vYX1fvusixi7e99qPxdV4PkRrH8Wv/uTIdfqRuDJyVt0o3ois2T/FH5G/
e8+IMUX2weuiscietI66IrX00PWTyD7uqfuaIuOr1vUC4uyj+xfx+X77XmQv
1hcZh2PYJN6L7NV7va7ImXUx6722t66fRtbY7aKqyJn1lP0rsk5vcyxF9vRj
oqXI+rgTH+3h+aKtyLPOFq1FzpQRuj4QOVvPFSOL7Hs/e5Xnb4u3Iv87nMEa
P38Fbdb1o/gh8jd/s7g5sneuFd9H9qr3fjpyf/txH2u/Q7+1N+v53ZHzrEn3
p0X2ZW2RXttnz4OHI/v+enFdZN9b0+ORup4XL0T285t4ZH9s5E3E5jw/G5nr
O/DX3l4oehVZq8N13RA5O4fp/tTIuj1FXERevhWnE7PzcCtn3cP6sXi/iVy/
Jq6JnLnviwcjZ/C7nO1zG/T+r5Hz8m/xT+ScKvT8nMjflS/FF5H/F7rpeUmR
M8s1+E5kHZ4pXo6ck7eI0iJ/J38WP0XOpP/Ev5H/Ad03z0X2ToXeLS/yf98T
4oPI+X6pc1LkXLvE8RY571x3Z0XW3mXil8hZ7HjLiozZcZ1HbFeQ44H459zb
w0cie9gxbMR3e16pa/ciZ5Jr/8nI+r9cDC5yNv4mfo+c787zZnJtL2/AT+fN
feXcfS2+ifx98mz4PLI3/wdhF9iG
                    "]], PolygonBox[CompressedData["
1:eJwt1Hdsz0EYx/E7ahYV4de0RfuLIhpbEFsoahWNIGrWitVG/GnEjPGHLfaI
ESFGJEZsYtbeMRJ7UzP2iPeT+/zxyve+4753z3PPXTQnLyu3kHOuF2JwFFvQ
Da3wFzPRHEMxEfnogNpYjNn6Nh0rsRZRdMZ5TEUjdMQcpHnnxnOtgLu4gwja
2DPelUci7QZYgrl61w63cAyt0R3P8RK9XehzBtsQj/b4gRlohhwcxHp0VUyV
GWs/1ybogiu4jFjN+Tg2IVNj3sBN1EAcTmERSukf1vceeugfs3BN/66OnViO
DNTDRVxCQxTHFOXMclUfO3ASbVEHZ3FOubd1m4TTijUBe3BVubc5fMBeNEZ/
7MYFdNKYm7WG6YopxYecW67zMB3fMBhNkcz7A2rnKpZdmqvFtAxvFVsSnuIZ
eoKu7joOIUtrUIBVyEZfrMA7F9a+EibjNfqgruXIhzna3EYgSnuC/j0Ob/BK
Y1uf+1qzOI35WDHY3K3my9Gep1zaHPdhNfopZ1/wyPKCgXiCEj6MXRPf8RVV
lKM1WKhvbQ/8wS+kYogLtfhbbavJDTZ3/teCa1UctrlwP4xrSxT2ITh7Z8/e
Y5oLtZKt2liqtbcasb11wq4u7LFPSOTZWK4D8BAfVQvJiOFdMQynXc2FWj+i
sTMV+2f1TVEs/1w4C1IV+08X9pblYJ1ybLkd5MJcbruwV9OU2wKtteX4Bba7
UNu2h5OYS0Uf+tqeylcN2NrbmVOEdxs1V8tZgg8xWSxjUIb70j6cLSNt3WmX
9aEdUS4W6FvLie2FeJ6NdmFPRGg/cKH2RqGoD3vY9q7lyM7Grajlwhlpfefr
W/tHLPclfagN+8bOIqtRq007k/4DluaVXg==
                    "]]}]}, {}, {}, {}, {}}, 
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwt0DdSQlEUgOHnEhAD2mGgc9yLrZ0LkAWAKPYGChOCCzBiYgOOCoqhdkSd
QTCiqBvwKyi++e85797mRSfiY5MdQRCM88w9nRbzGtZzLbHFgDmpZVK88c4r
K3wwzZB7u7rKHsPmGb0gTcx8qDdcc8cRt2TZIE+GP5745Yd+bxe1Tx+1xTfH
jNoVNUeTdb6YpcIVB0Tc29dLep0XtEcfdI1PCnTbdVF1XqbOCw22GfFtR09Y
YtA8paecsUnULqFzhJxr7f/8D4UsOcc=
                    "]], LineBox[CompressedData["
1:eJwt0MsygnEcx+GXQshh77yiNKZrsW/TBdRFOMsKe0IOV+AYMm7AOWOla4hy
zNOMxTOf3/c/tXnH0tnpTEsQBCmGHEd6zSoD9iBV9wavjNjHOq4z+k6NNz6o
M8sX33zyyw9zTPjfiW5yyykv3HHPLgm/Kegai8Tsc93jgH26vXVRcXdqhFHW
7WUm3Vf6TJkV+rz1E6WXHnLen1gibpf0kQcuSHq71B2KTNln2qqh5ocjLw22
mtOe1zbd1rB20M6CfcOw+/D/e/8Bj3syVQ==
                    "]]}}], {}}, {
                  InsetBox["\<\"\[Mu] = \"\>", {-1.8, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["0.2`", {-1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {InsetBox[
                   SubscriptBox["C", "J"], {1.4, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["\<\"=\"\>", {1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["3.01`", {1.7, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {
                  {PointSize[0.05], PointBox[{-0.2, 0}]}, 
                  {PointSize[0.0125], PointBox[{0.8, 0}]}}, 
                 {PointSize[0.007], PointBox[{0.4463998339305619, 0}], 
                  PointBox[{1.2771956561278897`, 0}], 
                  PointBox[{-1.0806611991222994`, 0}], 
                  PointBox[
                   NCache[{0.3, Rational[1, 2] 3^Rational[1, 2]}, {0.3, 
                    0.8660254037844386}]], 
                  PointBox[
                   NCache[{0.3, Rational[-1, 2] 3^Rational[1, 2]}, {
                    0.3, -0.8660254037844386}]]}},
                AspectRatio->1,
                Axes->{False, False},
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                Frame->{{True, True}, {True, True}},
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLines->{None, None},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None, "TransparentPolygonMesh" -> 
                  True, "AxesInFront" -> True},
                PlotRange->{{-2, 2}, {-2, 2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.02], 
                   Scaled[0.02]}, {
                   Scaled[0.02], 
                   Scaled[0.02]}},
                Ticks->{Automatic, Automatic}], 201->
               GraphicsBox[{{GraphicsComplexBox[CompressedData["
1:eJxlVntU1HUWJy31mAOui4bUsdUTOsuqEevsgkmXdZT11TbZbqsddo4vSqVQ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                   "], {{
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[0.3], EdgeForm[None], 
                    GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxNlllsVVUUhte+tKWFtvT2tpTS3k60lNKiRYSCKIiKiCJFFERERURxwALV
tgyaOEajcYxxiopGnKNGjQMqGE2M82yc9cU4T3GOQ9R/ZX0PPnw5++yzz95r
/Ws4p3nVusV9GTP7VQwTi0WtqBE9okGUiPliqqgTTaJRjBDVIokCMUWMEb7f
7qKePeeJyWK06BN51m8UQ6JX9IsykROrxRzRJRaK2WKimCDaRblYKfYQ48TR
YoZoERvEetEsVonxog17e/DF9+sQFWKJKBTFYjp7lIrlrG/ERrevUhwhpqHL
aPxI+DeWvWrRxX3fIjaLAXGcmMXZ6/E7KzpFFeOJXKvwNYcuuxKTDD41Y/8M
NPA1M/F1lDgN/SqxZRJ2lrOvr9+NeBZhazX+lDDv8d0FPxNn17D2UNFNvAtY
U8jZbdjm6+p5b0/RyvOl6F7MWQ2MS9G/jLMbeV6Bv1mejcMPPzfPOZvEIDGo
IQY+vz++u2/7omOGPTuwZwy+ZP4Xgwq062RurtiH+71ZU4Xfk/HdNZuK7SeJ
Ey1yqI2Y+Z77ib2IgWszhXPXiBMs6uYAYuNxOZC5PDpNQ6s88+7j7+ImscKi
vlzb4RZ5V4eG7Zybw+9Z+L6A2Ph4rTjFoj5Oxec5+Dob+32Pg9lnOX72ENuZ
7NOJVq7PBHz28z2X5qFZF3tXos1BxNj9no/d3cQsg70L2L+WuFYTi4XY6PV7
lEUOeW9ZZJFTHvNDLPJiBfMjidthFjnjc73Mu35L0bCQe8+1LGvc5mWsKSYm
yxh7PR5jkaNN4kiLPPa1h7On630smnl81xBL9+l4i3z1e8+HenSai66utedV
AzafjI9+9gCx9trvJ0bef7wuPJfKmC9Fs7XEdTXx9nO8L21Ah3UW+TQcjQbR
o58zKjmzmPkHXesUegzyrBAbp3Pu6byb4+r3Xejl/bwcvfvQvA878mg/xLmb
8a2Is7ZwXh3Pili7kXMrZNcdaNtCnFyPZ8SdFrk5wLsl7LmJfbr07j0W+diL
Rq5PM+MsOnrtdKDPEOcuwoZe9O3E/o/F1Ra95xNxHbH+Q/xpkcffimvQvl02
PIJGnRrfalFbt4tRKTS8TbxtUZ/dmnvCom6GabzVIt+aND4Df5s1PtOiPn4Q
91v0oxbNn2VRizvF+xb1/JbYxrnviUssajyXwh/35ULPhxS94GLXI8W7F/l7
KfpHVtfKFLnutn9KDpRrXJYiHz1WTxGvEZorSfE9L9V1ZIpvqdtblcJm33u7
xf7vih0WveFGcYNFLRaksM9te1W8ZtF3xmv+fIscPU9cSXzHpuit3jMmafyo
Re02aPwk+18qPrD4Pvp7tSne9Vi9QbxeFx9Z5PaL4kOLb8Sz4lqLfv8Ktjah
2U40z2h8M7G7Xvxo0Ue2kQceC6+5hyzq7lzxgkXNPi+es+gxD4iXLL5P/vxs
1rSmeObzj+Gn+/g4OeT5c4X4zaKXfSm+sPhPdJ/exC/PhXfIh7/FXxb/ZVvx
oRW/X8b3b8TXFv8RhXpelKIn/iP+teih34nvLXr0VaI+RY3d4ran+K6mFOKv
1OVyUZOiP3ptfWWRkx6fp4nR3Rb17LV8mahO0WfPQQvXwWvuXou6897gNeP1
soPYe9wvsKhJj+/D5JDnz10WdeU15f/Uv1h8Jz8Tn1t8h34WP1n8S95nUW9e
a/8B0sTVNA==
                    "]], PolygonBox[CompressedData["
1:eJwt1GdsT1EYx/FzqJaiQUurqlRVEFuIHaE2DSXUpvZsJN5I7Bk0RpBYESMk
ZsSImVg1Yu/xxt57x+b7c54Xn//533vPPfc8z3POScnOyRybzznXExHYhwLe
uYG0TTAReWiDGliBd6iLJEzGCbRGaXzADEShB6biFNqhDmbjD/qjoT2bjnrW
55mNqbEysV3fZT4TaBNxDmcRbe+8wCt0RQL+4jdS7RsfsQv1Lca5uIgOqIRL
2IMUu7cK79EdWbiCy4hBIzzGc5tbPO7gNuLQAltxFC1RC8sw3561QmFiOUjb
DIOwGovRG+WxBPPQFOnYbXPKshjO44L1VQ5+4BsqoC9+Wo6V2344gI3oZGNe
Ry5i7d4hrEdHm9NVXENli3ktIphzY9qKOIbjLqwFbv//mWO5GYANFkO6jVHO
hxwo9jGYhe821wZW2220kS7U+B4+Wa2SLZebUdNymkD/RbTDMQKf7Z7+90Jp
/ieij3KtGvkwZrK9U4rrhbRDMQwlub7rwlrWvdPWR8/a4yZuobnVOJJn+X3I
hfbIJDxBF5ujavHLcq+aJNH3IW0VjMINlOXeaNoMVOX/JtpqGI80rmfa3Mch
leudegc59u5SG0tjlOC6GKrzfwiK+pBz5XowHqAM1yNpO7uwV4v70Fd79ivu
q04urMFCPuwR7Y1svMVrF/ZeNxf2lveh1tpjmtsZy5XmGMWzaB/eTXNhbykm
xZJi3/pitdI3HyHGh7kqB8pVER/2hnK2HDtcODvaYo3FpFhUY63d/S6cVVrD
hy3HGVYzxb7XhbWmHORazpVr7YEpeGOx1UZBnq2zuWvNH8ECF9a6cvzUhTMg
3mo+zWqk2ujMe4ktLux9nUl59g2NrTNUa/2kxaI1H8e7sT6cXTpTdfasdOHs
1Bn0D3rbl8o=
                    "]]}]}, {}, {}, {}, {}}, 
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwl0DdSQlEUgOHHDjAhpaClA3uxtXMBsgHA1BsazDWY0wLMCIob0EEpVBQz
orXfDMU3/z3n3te82EhqaDQUBMEwYYe8HjLNDcecUKDPfVrPGOOdD96YZ4uE
N5t6zgLbxO3GtcgkA+Y9veKSWypcs8oKc/xR45cWUd/Naq/e6w9N9knaHegy
XyzxzRRlJuj3ZldLXBAxz2iP3ukin+zQbddF1TnHC680WGfQ3YYesUbMnNFH
nnjgmTpZTunwpjPU/s//IuM6Rw==
                    "]], LineBox[CompressedData["
1:eJwt0MkuQ3EUwOF7TTVbKyoWtCoSz2Jt1Qeol0BL2Ri2an4Cpa3hEcxDJd3g
IdTQ6iex+PI75/yTu7hjqfnZdBgEwRzbvDLkUNAJXdRPvqjxwzdLNPilTvj3
ETIS1xO95YYqd9xzwJT3fd1ghYS9pIc8sErS7UgH9F37tY9Rtuw5Js2X+kKF
NZ545oKY93N9ZMS8qcP6pr3aQ9k8o2e6R5Fp+6m2awet5O0tuqNtmtVO3dWI
dtPFsv2Ka44Zd1vQdQbNUT7+/3UT3qkxBg==
                    "]]}}], {}}, {
                  InsetBox["\<\"\[Mu] = \"\>", {-1.8, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["0.2`", {-1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {InsetBox[
                   SubscriptBox["C", "J"], {1.4, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["\<\"=\"\>", {1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["3.`", {1.7, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {
                  {PointSize[0.05], PointBox[{-0.2, 0}]}, 
                  {PointSize[0.0125], PointBox[{0.8, 0}]}}, 
                 {PointSize[0.007], PointBox[{0.4463998339305619, 0}], 
                  PointBox[{1.2771956561278897`, 0}], 
                  PointBox[{-1.0806611991222994`, 0}], 
                  PointBox[
                   NCache[{0.3, Rational[1, 2] 3^Rational[1, 2]}, {0.3, 
                    0.8660254037844386}]], 
                  PointBox[
                   NCache[{0.3, Rational[-1, 2] 3^Rational[1, 2]}, {
                    0.3, -0.8660254037844386}]]}},
                AspectRatio->1,
                Axes->{False, False},
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                Frame->{{True, True}, {True, True}},
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLines->{None, None},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None, "TransparentPolygonMesh" -> 
                  True, "AxesInFront" -> True},
                PlotRange->{{-2, 2}, {-2, 2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.02], 
                   Scaled[0.02]}, {
                   Scaled[0.02], 
                   Scaled[0.02]}},
                Ticks->{Automatic, Automatic}], 202->
               GraphicsBox[{{GraphicsComplexBox[CompressedData["
1:eJxlV2tQlOcVJkRtSoLNOF4YTHAMVrdo1cSssV5ybJboRA1ZLSZI7VdDI6hL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                   "], {{
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[0.3], EdgeForm[None], 
                    GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxNl3dsl1UUhs/XFiyz7Mq21EJBlgwZIoKKAypoxQEoKCKiYgGRvZeJK464
jRp34oxoHDEY94yJ4t4zzrj39n09TyN/PLn3u9/t+c55z7nn/lo1e0F9Q0lE
tCsiSjUeInYWlWIfMUB0EoNF18g980U3USbqRRNRLo4Qw0SVmC46CpmN9WKd
WCyGiO6imdgfu7a1XPQUPfhmZ+yOFr1FGzFP9BFtxRhRa7/FbvjrOJaKJWKy
WCAaxC7E1BH/14o1+LhCLBStiMvx7CTGi378zeH43YM4uuB/KZqUEHcv7OzK
N+3zUPRoiV8L8XkPUS0q0KWceDeJjfh1EjHX8q2OaL5FbBar+XYl7yuJ0/Np
aNRXTERHa7dMnI6+A4mlqZglZvJcRk5K2TOB9TbE1ZZ4qoh3ErG3Jp5q9rYh
dxXY7oFu1Wjk96vESmz4m4P57t5ipKhB40HEuoiY2qGHc+Qa2yuyDrxnX9Gf
+Z7E3QG/+/Bd6zcAzfcjTuvg2tydfBwvZkfmvj/fKCGOIcTSjL8pR4Ph6HCg
GEHsY8m353Mia6IleXaM7dFpFHus6zC0nStO2CF/o/HfuR0XWRtHoVcN3xyL
Hdf+ZOJ2XYxHs0FoVIKWY9DzRGz6+ejI8++zv81+FqmL83ZAZB3Y94Pw3zpP
xMde5NP+1zG3Jgfz3Jq81+Gzz+wUNGmLz+3Iz6GRtTqF9RaRde9zWkY80+P/
XnRY5PmdyrycfE5lbl2PxMc6tLMP7gkziHcGNgts1PO3M9DFe9y7jomsV58N
17dr4bjIs+S1DZF9bSZ6NRCf3x8rmkfWkWusO/tnse5456DJBOzapvPveuiN
3nNZm0b+nLtTInuHa2Me8w47PNsH97pTI8+c35/Mnj7s8XwctmrZOx9t65mX
kafaHfLWQI7c09ahietgIbEsYt6ecRE2TmPentHPrk3n3v2q8Y5ZjM31rDdl
XMwe+7AEm7a/ApteW4oPU5hP5m+XYacn+WpOzjz3WXf9riSOldhsjGkJNjfx
roZxFfM65pPQbTV+rmFehmYL0G0L7xrr0HU5HdawvwvaNmVtLfvXoUujJuvR
xTW1gZg24qt9G8lzDTFtRCv3IfevCmLZxPvl2LE+Ppub+e5q5k0Yt7C+hrnf
d9JhuiOyXw/R/O7InjpK86f5ZlvNL4jsMdeL68jJQK0/EtlbPxXPRvabwVp/
kjiGaf54ZP/7RlwTeW+M0PoDkT3vW3Ft5Fn7QdwaeY6aas/31MXb4gtidM97
KLJ/vItP9qer1rsVef4d0/PEZb9qivTtHjG0yBi3ErPnFRpvjrwDXxKVBX1Z
44+RNe/fG7573BtuRzvbr9LYpMg66aCxfZHnvnORMTvex9DCOrTQeGNkr7tF
fBzZr/8U96NJX+05I/LutL9byctr4vXI3tNa6+eh/4OiR5H9a4DGcyPvs7PF
W5H9oZ/Wz4y8U91Et6Hhe+L9yPvjHHFpZCyDtOf8yDvyFfFy5N3zqrg68n6+
WHye5uI5UVtkz3pBXBZ5/92Gjn2xXYVWv4mrInvJFeLFyN7m37xPUXvbxZ3Y
dw6focYc01nENbxIfa3tm+KNyHvgCd55/T97Rdq0xq4/6/y1+CryDrxIfBLZ
Y61feZEafik+irwfm2utWZG/qX8Xf0TehS211qrIO8yatSlStxvsY5G/HS4R
PYu8V1zL70TWs8/Qh+TxwsjzMxJdtxP7r+KXyP8DPsNX+3m5qC7y7nG9/EzN
XCl+ivzteVNkfbu2PyAex1Kqte8ie6nPdFmR56hEY1Fkvbu+fM7t26PUhOO6
K7JG/a2/qTPn4j7qzDX2cGQtDiXP95Lrv8Q/kXf4vxHV+2I=
                    "]], PolygonBox[CompressedData["
1:eJwt1Pdvj1EUx/F7q4oWQSVaqlptarSo2BGz1AixV5BSSkpo4hd/ghGRIMSK
kdgjKlaMIIIQO7bY+wfE3uv9yTk/vL73uc99vvc599xzn+zSiuGzE0III5GI
83iBgeiKragbQ8ilzcFxbPDn22Ih8hmfRVsN+3AZ3VCAZXqO8Tm0qViL/T5W
hI0I0eZqjGd4h8GojXPYhv7ogrPYgQHojOf+jlS/V4O5FtO2x2isx2+0QSPc
wHy0Qm/Mw3X0QhpWYqnP3QOHPeYin2Oz4uIdHWib4gBuoQ+SUJWxJAzhOgWX
sNyWGFpiAW6jL1p7Lv9ghOe0Fg+mRJt7DH7hB9IxzGP/6ddawz/89dxrjtO4
gu7ohDzmWk3bE9PxFE88t1rDHq2bZ8Z7jA342e2xKifKZc1osSinR3APxchA
JW56LidoDp7NwhSuR2lPuT5KOwkl+Ki8cW9qsBzlcr2KtgzT0IT+e6+FUtzB
MUz2nGnuFT6mdyzBI/QLVqOZjN+nTfZ33tW+c2+ix3wNFzHTc7IT9aLVVl6w
2ldMikVnQLW7i7ZFsBruGG3PtddzkUP/k/+3zHNZ6blQTjPoN0RhsBhSo+2J
9mIcmnF9gXYGytGc/mva+n6vgP4ir6UK7TP95Gi1nY0HeKi8+ZrX4ZDXlmry
AxKi7UUmPmvuaO/WmnRW9yI/2JlV7ZzSOr2GXuJVsG+BYvqC7xiqWvFcag3l
ntMTHrNizQp2ds8Eq0Wd4TqMbQn2LdE7qtPf5Gtph7d4g0HBvgEHPefKtc6A
cpke7SwXem2oxkq8RvTf7Rjrc3zFGo9Va/wW7Myn+Rr07NVgZ13/UW2e9FhU
o4n0q0TLnXKsb53OgGpf37zHvmatVTX4H4NpiIk=
                    "]]}]}, {}, {}, {}, {}}, 
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwt0L06wmEYwOF/dAyEUCNtXBeOw2pzADoLVLOW5HOW8k1xBhlIpNhZMPim
3IPhvn7v87zv9MZnk9NzoSAIZuhxKGiVJR64YJuIu6JeUWORL775JM8BE97t
a50VDhm1S+k1N1QYtCvrkLb0kTvu2WSDsLtuXpy7NESMrHlYn3WdwPlUpvRM
1/ilQ5sMTdIkvDnRWxoMmKP008eT3So/HDFpd6zL7DFu3tEx3dVzSoyY5/WN
HK988M4Cl/R6s/X/z39ODjel
                    "]], LineBox[CompressedData["
1:eJwl0Ekug3Ecx+G3i5qqFO0Big4LY8LCNbq1cwAugtaQGNZm7qBaipKUE6ga
E2pRDuBJuvjk+X3/ybt5kwtLucVQEATz6nC0OMwix7nCLu6xkz3q1qrdy6gi
2rf7mOcEL9jQs770oh819a1jPWhb65ryTYUnetWGpr2dMcE/xjmktHbtR90r
Y98xy09u6l0fqirl/ZZvGnXvcIS/PNWg+5pzvOGRrjRrlznDS9ZU0qRdYIwH
7OchB7jGJ9V1rjFvy9xS0h0Otf/zP5GjL/c=
                    "]]}}], {}}, {
                  InsetBox["\<\"\[Mu] = \"\>", {-1.8, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["0.2`", {-1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {InsetBox[
                   SubscriptBox["C", "J"], {1.4, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["\<\"=\"\>", {1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["2.9899999999999998`", {1.7, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {
                  {PointSize[0.05], PointBox[{-0.2, 0}]}, 
                  {PointSize[0.0125], PointBox[{0.8, 0}]}}, 
                 {PointSize[0.007], PointBox[{0.4463998339305619, 0}], 
                  PointBox[{1.2771956561278897`, 0}], 
                  PointBox[{-1.0806611991222994`, 0}], 
                  PointBox[
                   NCache[{0.3, Rational[1, 2] 3^Rational[1, 2]}, {0.3, 
                    0.8660254037844386}]], 
                  PointBox[
                   NCache[{0.3, Rational[-1, 2] 3^Rational[1, 2]}, {
                    0.3, -0.8660254037844386}]]}},
                AspectRatio->1,
                Axes->{False, False},
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                Frame->{{True, True}, {True, True}},
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLines->{None, None},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None, "TransparentPolygonMesh" -> 
                  True, "AxesInFront" -> True},
                PlotRange->{{-2, 2}, {-2, 2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.02], 
                   Scaled[0.02]}, {
                   Scaled[0.02], 
                   Scaled[0.02]}},
                Ticks->{Automatic, Automatic}], 203->
               GraphicsBox[{{GraphicsComplexBox[CompressedData["
1:eJxlV3tQlNcVJw3toMlGGgg1W6sRGUQ0DsZsTQ3x0CxJDTIGiZJoO6utLIMi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                   "], {{
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[0.3], EdgeForm[None], 
                    GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxNlndsVmUUh8+l1e+Dar/uWjtsaa1AoQoCLqog4vgQUZygIqCWViqFlhZM
XMFtHAGU4AAcGNQ4UNAE3DMad+KKI+699zb+juch7R9P7r3vPe/7/s54z711
czqnzR9gZt+KHDFJDBHF4hAxTJSKw8RuoloMFzsIn5cVuSIllojTxTxxkBgq
SkSz2FGkxVzRKqp4X8q+o8VgkRG9okdMFCeLCmzGiHpRgMYSNIwVDaJQNKI9
QXsZ+vZGdwVruu5t0ZrCxrWXo7OV/X2vKfhQSQxqxHbYtmC/K7HJE52iDZse
7gvxoZS9puFPA1qL8WUB8+vEEcTFfV4sOvDnKPYtZ04Jaw8gLwnPFYyliX8K
fdVoK2DtDFQxNkOMx89FopvnfLETtn6t5b5LLERThjzms/9wNOwldkFbu9iZ
mBQSgwJiMKSfH03Yu39D+8VvGDGsRXMG/0bgo689lrWryZn7O0ucRNynkzOP
x55iJJpnihOJ+zgxinH3aXfu3ddm4lqPrWs4ThzLO/d1D/TPEbOtr07H4O8o
9s5n7XHcNxGvBB/3wU9fr5HxkeTA7fcT+4qBxO9AYra/mCC2FwdY1PMg9p5I
fBZhU8d1PPY13HvcepmfRx4Otr46zpKXQ8Vk4n+MRY2WE/uprDcCO7fx83ik
RX34voejoYW5A7kezf0pFufWz+wUYt2Mruloayb+XgsnWNTx1rPahs1o8jsY
/2bgbxb9vr6fu5nY+jmdRc6yaMghl7P75dPrqp73rrWCGLcSc8/PqRY9pIrx
AvbMEhMfm4t9O5qLLHqU9yavt9N4V8TYfOLczjuv/Q7meH7KeM7F1udsY9Gr
O7j3OHQTJ9fZRR66eK7kfSc2HueFjPvYAvS0MJ7m2oVNG3ZFrNdCTlPoTLO+
12IdOe0lfq5xMTp7GM9jTfe5EJ+WYHObxyCJWutgfB77d7N+G2v93wtlu8bi
vE5Ag8fDv4cvW9+56WGvF8Uyixp7RVxjUUsviCst+lat1rzH4nx7fR1vUWOv
imvJUaNs7rc498t9XhL1UabrGRbnvEb3q9HmPt1u4dfN4gry/qtYadELGmRz
i0X/+ElcZVH/H4nLqYUbxBZidZ3wZuJ6Vok/LM7hJaI4ifou1bUkiR62Ad/c
r7Xoc20pXW+1OPefiHVoGKTxbyzq+U3xhsX/xe/iPIve5r6+jr+XitcsvgP5
mnuXxTm+1/PGvo+Lp4nnQ+IsizN7Ns9+/wV14LGq1LylFv3yTp+XRD58vQ3k
6EK0us4/xX3kZaN40qJuN4tN1M85W+d4HWjeuRbfkkfFYxb9er1rSaJ/Xey1
k0SPuECkk+hTvvb5rH+RyCTRmx4WT1mckefFcxa9/FnxjEW/9xzeRB4fFA9Y
9FSPzRPEx9d4hHXWUR9N+Of15z5eRn14bXwlvrTor0kSNe31fAd+uo9/i78s
eqTXjte018+74h2L/75/xT8WvTNHNrlJ9HqvwRvZ6y3xtsW36lPxuUUv/Ixc
eh7PFB9bfO8/FB9Y/JO+J963+A55bn8jv1+Llyx6jp+baurzburAbX4UP1j8
z15vcd689q62OEt+jjyf35PTn8UvFt+wFeI7i3+K/wDy/9cE
                    "]], PolygonBox[CompressedData["
1:eJwt1GdsT1EYx/HnX1VqU7So0WHUiJVQNISoEbVqbxoi6YvyTmJEBDFjb2JG
iRkjRoj5wowZe4u9Z+zxfXJ+Lz4599x77r3nPuMm5YzKzosys96IxgTER8yG
M8bgH8oxz2Fsgju4hbJoh+PYikS0wBJ8RzVUxX6sQg00xWQc01pfsw4pPH8M
Y3lsRkHmPbWn9f4c5nl+Hk8wW2trYyl2oxEycB0zEad3TsIXdEUDHMUZtEIs
ruEmMnXPWNzWt9XCDxxEErphOX6iMZJxFst0rTVWKGYeq+r4qD34u7vgLd6h
LYogim+LIIHjutiIWWiGOriKv8hGKlYrph7LmtiFA0hXDPYpJhna40mcRxsU
xxwUioTYxuMrPqOKYvQQ9z3n6KDcVmD9SOXYc7VWufCc5eMwmvs6lOb6FV+H
IfiFUpwbzNgdf1CG+VB9kx9P11o/V5L5ZcV2kO+Z+QntfYD2MlGx8z2dwgKM
QEu9a5ru9XcWY75d9/a3ULv30N5CDSdyfaVylYsY5kdUG718DfMZjMMs9IDX
4gbFzmsyLhJylKo1h1CAcz0Uk1iOpzL2QV+80jk/7oxLKMq8n2rCey9fsfQe
LMz8AmNFPcN7Y5P25j0yDg+UqzQkcP0NYyXF5BsWW+jFhriI13q3r5mHZ+iE
LLzHJwu1WtlCLa6xUGtek/PxEvW0p2Tet8fziNHYq3N+7D3jtfBbuU9RbT1G
Rws1tkV7yNIzoyOhJ7wXPIanlWPPrffsFOUsV+/8gIXaa33sUM491wMt9MZO
fXu6Yr1Naz3m5yz0sPeu98hdxTRNNXLDwj/B/wX+j3iE8Rb+Pf4Nc/HUQq96
D7/Acwv/To/pIpSIhL14j/0Hu3ON2A==
                    "]]}]}, {}, {}, {}, {}}, 
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwt0DlOQlEUgOEHOOAGlEaNETZkZc0CpEbUzsaJoXYGxw2Y4FQRsVAqERUV
FZwXwVdQfPnvOfcmL3kTydTUTCgIgmlGHTb1hHWGzWmts8QdDe6Z5ZEnHnim
SYZXWrzwzhtztFnhg1V2mPSNbS2zy7i5qGsMOh9qvx7ogF5ohUuuqXJFgZj7
f63xxy9Ddosa1VvN88MRCbtjzfHJN18scM48I97s6xmnRMx9hAlxY5elQ4m4
3Z4us8WYeaP3b7u8mjUe
                    "]], LineBox[CompressedData["
1:eJwt0Ms2glEAhuG/aSRKAzKoBi7IyLgLyCWErGIshEtwzGkxc2gZxAB1G8oh
Icdn0OBZ7/722qOdzs5M5UJBEEzT4o4BF9s6rrP6xDJtXnhmjg5vvFJmyPtd
HdQdjeilXnPFLTfUqfDJGUdkvD3UGgtM2JsaaFM2+CNhj7LkHNeG/vJDzF7U
EX3Qb74Ytksa1Xtdp8cxk+5OdI0D0va+prSqp+yRtOf1nRW6rPJBgXMu2GLM
27wWCTs/9v/2H9rBNjY=
                    "]]}}], {}}, {
                  InsetBox["\<\"\[Mu] = \"\>", {-1.8, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["0.2`", {-1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {InsetBox[
                   SubscriptBox["C", "J"], {1.4, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["\<\"=\"\>", {1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["2.98`", {1.7, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {
                  {PointSize[0.05], PointBox[{-0.2, 0}]}, 
                  {PointSize[0.0125], PointBox[{0.8, 0}]}}, 
                 {PointSize[0.007], PointBox[{0.4463998339305619, 0}], 
                  PointBox[{1.2771956561278897`, 0}], 
                  PointBox[{-1.0806611991222994`, 0}], 
                  PointBox[
                   NCache[{0.3, Rational[1, 2] 3^Rational[1, 2]}, {0.3, 
                    0.8660254037844386}]], 
                  PointBox[
                   NCache[{0.3, Rational[-1, 2] 3^Rational[1, 2]}, {
                    0.3, -0.8660254037844386}]]}},
                AspectRatio->1,
                Axes->{False, False},
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                Frame->{{True, True}, {True, True}},
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLines->{None, None},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None, "TransparentPolygonMesh" -> 
                  True, "AxesInFront" -> True},
                PlotRange->{{-2, 2}, {-2, 2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.02], 
                   Scaled[0.02]}, {
                   Scaled[0.02], 
                   Scaled[0.02]}},
                Ticks->{Automatic, Automatic}], 204->
               GraphicsBox[{{GraphicsComplexBox[CompressedData["
1:eJx1V31UlGUWZ+3o7qGmPKRmVFbmx+BmEjIbVu5VBnQxXGdZttCTLJqiHUw9
LHp2WM+mtI3FKhVMaIgUkoSkiMCG4ujN8APQRZSPQVSCgRnkQ2HeNW03lN3m
7u/hnPE0/zzn99773Od+3ztPL18XtXKEj49PwM98fH48f/lAVXenoYFD/PbH
2k03+PsK3+0WrUJhm2ACflz4FT5ZNmW81d5G3vwpb7x51GDtUvzA4AdOllNh
3Md33AfGfWDvE/YEij4Ee4AhHxjygSEfuNvDX8M1nu8D7OP5HbcBnxU6AV/0
4BaFn/TI76Srnu89DHnAkAeM+1PlnroPDP5G4Sfwg8/7xHvghz+AwQcM/tOi
P+E9YNgLjPeBIR/2w9/A8Dcw+GE/6LAX8QAGHXqDDgx50AfvA+M+sMWTN3ZO
ib/8XVFun8Kpgnnc0R/vF3LgQy9OijV2K6wXrPiR/8De+QN6nefdOiUf+QoM
O1AP58p3RumcTmqQU9GR76BDH7yH9/Fe67FNZ4aG+lV9ACOeiD8w5Ad5+E/y
Z74fROoPupX9wDke/kICHiP8Cp+Q9xWGfMQbGPaCH/Ymxt3ebLM4KFlOnu6x
q5Xw3fuEP2AP9M2W9wn6AcM/LvGHigcw6MhXYOiP95AfwKBDX+iv+tf/MezF
vZ86EXe8j3yFvsCgw35g5DviCftRL8CIJzDqBxj6AqOevPlhP+R5+wf1DH7o
C37kM/qLd79DfsO/yGfQvfup97wCHXmD+gMd74EO/wJ716N3vkJ/0IHhL8iH
P0GHPcg/YOiHeNUe/iFe+49b+a9w3/3PmBdqqj/G5LUv1p1yc8Vn4QUJ+tJ7
5mv4X5pD9TOG5++WC7XOzg0uxe89f2Nm/e6vtlHD/TYtqnGsdapD5U9h3+xx
5u3d6l7ZJa4w3Bye18e3dlaYfj1A+T5PWnJftvPGbfb9hoZ+TkkdnWtqbaVF
k059O0QOXn3pz+/k2g7Toqkv+JsXdtHhl/K/r06o5P1hpYUJVW7Kj7kSbDSX
U1Ry0iv6RRqNiOEke90FWjPzH8+Yr7tpzw4t1xRby3HFlUt04W6etWzMXP2M
Zj7UNbLUEN3Hh6btHSyqbqaL4+cMVi9zs09JmJ/5n5cpM2jDEdODbs4s3XTO
P9VJ0ct5nW1eH4e0W0sM1nO84PmCSv/UHp4wsmapva6WbK23nzBPd3JNSVx/
9ZfNNPEX/8qy+HVwztNJxwxrXCq/QfcXOo1qdIcYA5wUYszJsoR2EOSHinza
OcL1kSWoir/eNjfNEtpDEwPvWC2JLpUvsO91sY9gT63YQ2VzU9+yWa6q+Yb+
kEOvVZjSBjhxpy7bknhR9TPE5xuJD+M+6DUZb3yRUNCh6gf57Phk/uOxldf5
g+SjKTbLBdUPkQ8lkg9qX1m55WjD0NvXGPZ4z/s4yS/e44l3/T37zlK5T6BD
D/gbGPauDnvrVW1JL0E/+A/2oH/gXovYQ/AP/If82Sf5Q5m96V2dGxo5ddrA
3y3pvVSWfN/uhPcu8fjEAlf1ruuE/ImU/FH86cLP4H9K+Lm1yVpumuCgqGD/
uxk7+vkPZ+qKDdYDvKbozvPGR7v59wfuP+dfs5ejJ0xbbR+4purjNakPbti4
4d3c7C66Iidvnt96wJTTRZvevlnln9ql5K0QeQR5kSKPwJ8k/AR5OFGva6Ve
CfouEH0pIP+BpVrW8P4OjD7Q9u2eSF34pXv2o4NH4ubq9vYz6IgH6F8IncwP
PrFCy6rnr2a1nR+iXjWf10t8+cSWCKO+30Vt17uWaS2dfCRpVah+XZfqx+9H
FtiH7C7qzIvYZ/pVD2V57OlS/fabolUPW7fW85rdaY6hL4frJUvqhc7sbjDp
nE1qX8J+5TrTt92SODxfXn4v8ytTkUPVx+DsHxLtdQ613xT88XJeQoFT3Z/0
zounDUlutV9HePqfpvavtEdDFusma2qefTpzcIluslvd18t9Rn8slv7INT9f
+Wxs3kkeU+hIstvcqn4Winze1TQqQn+wlIMmlmdb/DQubs8471+TwdroI2Ot
L2iM/vqq9Fde8b52pzrhQzJlDsXowjVlT7rox5+Xf2LQHzxOBevXxmsLNJ4R
cHdyrLGKwmrHJtkDNUZ/Xi/9mcs8/LXUstn5iv4hTfkvT+zjsxEz9bH32Sn4
bydWaanD+2Kx+I+PL6r91BL1NXVPecTZedXFt2YtOGQqOkWRRnOY3ujioD89
tzfh2v/2keYx23KvdPCt+NVbbPMcdFdOdnyUvctS4iDfGVHx2hIHox/PkX6s
5LeLfIL8MJGv4hEs8Sa8Z5X3CPNsvswzcgc85qruvUrRfUUnDdEO1W9uSn4Q
9MMJ/UaIfirerZJvdDpr+Tir/QSnJDy8WGvpVvthTPvl7uqzvYT4PifxJcT3
hsSXEK/PJV6EeM2ReBH8Hyj+J8zHdJmPql7WS70w6sN7X96R4LfRPtqt8AXt
qQJTaw9jvlXJfGPYkyr28C3ZP9T/LdRvn9Sv2ldssl8w6tl7v4wTfzD8/7r4
X827TNlf1D40W/Yhwnwvk/lO6C/N0l9UXzPLvkToN977+rs5A9NjKztU/yqS
/qX28Wrxh8IZ4i9C/Y6W+h3+Py37HqEeI6Ue1b6dL/sfob6apL7U/hYt+yCd
Hvxwrd3UqPb1tdtWhBjNH1PP1mcbh+ia8t920Z9Bdwidbpf6vmT8dz3p4t70
sz7SSfW7VwbHPtZGvw2YN8VsHqDvzn/8G31/B+mazMf8fW8w8EjBij9K+Bny
xoo8/i8yyyzM
                   "], {{
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[0.3], EdgeForm[None], 
                    GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxNlndsl1UUhs/XAq1QoKVlFAqlUiyIUHEVagWLC5yIE1yIG5DKHk1UNGrc
K+49o0bj3tsojsQRd+KII27Fvef75jyN/PHkfr/73e/ec94z7q9hTseMBSUR
sVaUim3EBqJabCeaRI3YQYwS/cXOYqwYKkaLQcJ7TBXdRJkYIwaLcjFXHCXq
2GMA6zYWjaJKLBLzRIUYJ9YXfUWnOEYsECvFCtGOjTWc24Rdtr9ZjBCV4nBR
y/ym2FrLvG3tIRZzdgPnDMTm3bDDe+2EP0Pwexh2Dscn27kRevTi+8HoMB2b
GrGjFpsX8L4bv2t4v5doxY5S/PKaVaID7SaIFnRvIVYl2FGH78vFVvhlOzfj
3SRRz9r5YiT6zxJt+FbPN33ZawTP3nMZ6yazl+N0sJiNXlX4WokeY9GqFv27
fG3Cv2piWYJmG6LLTDS1nvuKfYjBEkZrvJTfrdg4Djutz0RRiMPEoZG5NpKx
y8Zm7NxCjBd9OG8oNm8iNmefifz28yFiDt/vTgwKxgk8D8Qu27kn84PWiZn9
3ZI16xEr69obv/xuCPFowx7n/jzsdz21Y/874gr8c1y2xhfnzVR0Poh3jtcU
vu2J9tsSk0rmvf9K1lmPvSPzciBx2z4yL+37HsTQcduR2PnMaZH1NY3fnncu
7IJPLXxfje+7RubqDOYL9pvGt63YYK2mE4NmbJyJnftF5rH3d806b8ag3yy0
bUe7nsT8ALTyuD/P/sb5Npi5AyNrwj3Bue48cx45r7ryyPnQlYOz0fmIyF7T
g3geSUynMl/K6HW1aDqKuNVhZyV7udac2+4b7lPOK/eCDta7Dpayv+vaedIv
sn96TXdxNO/68X4+se5gX+/jXriYNa3sW44Ok9DH4+R1tFrCubZrYWSeLOS3
z13GvhWcu4j97d9cYlGGDeVotZTzHa8V2DmPZ8faObOc2HpuJfP2ZRXnTmG+
fZ2ze+G3tRiJbd6ngW87saONdxXYuyz+vyM62f8NcUFknrwtLidWr4vzI2v9
R/EWtkxCR+fSzWJ0kXXzingZn3pprneRuf6QtSny7qrQ+Ghk/p/uM4vMs/Ii
z/NZffR8U2S93ui1Rfbcp8UpaP6MeIx91mKHbThV9C0y74drrC+yd/4pLsXm
W0VjkX35SbEmsqaOF49E5nmt3t8V2W+eEiezplrz/YuswwEab4us15oi9/Ka
C61fkXVyjXgQnX8TF0fW9bPiuci+/IU4N7IOrhSlRcb0enFeZB6+JF6MzKkX
xPOR/f5ucU9kD/hLnBR5511tP4rsa1Uaf4jMz7PEu5H96gxRV2TN/y7+iOxr
tzsORfaLy8TfkX3Ncb4Fncv0fEPknbAGjez7d+LbyL51gjiNc+8gfo7dv+Kf
yD70MPnh3PhevBlZg6+K1yLvgMfFE5F3/8fio8j/dJ+ITyP7uON5YmRMrZ/v
Emt4vzg78s77VfwS+b/vXrQbj43WyHYWbthF9ub7xJ2R9XKR+CnyTvU5P3PW
JZG5VU+cryPWH4gPI+8kn/8ANjjO1xLrc4i9n7vrzKsi7433xXuR/2FdK851
5/mx4svI3vqV+CbyXnEdrGaN8/e4yBz+XHwW+Z/368j89vyZYliRff8/jyHb
MA==
                    "]], PolygonBox[CompressedData["
1:eJwt1FdoljEUxvG8xbqroq3WWrscraJgXSgiihO31lm3rVIRVKR34kBx4kDc
ey/cigu8UPDCvXHi3rj3wvU/nOfiR5IvyfslOSdJzxubMyYmhJCLIriGkyiD
lriCq6q3wE5Ui0IYRZmMbTiGBqiM2/iHbjYOsxDL+BxKirAfmVQKKdPxFC/R
Hgm4gQ/ohCqYgctojjgcxSk0Qn3sQSW+N5ByEBba2mn3sd9xDufRFE20t7No
rD2WZOxWylrawxkcQrbGfMM01EVnbEQWc8ZTVsQrLFA9CzH0pWEE9Xo4rTOI
tOYTOkM7u4bYojXa2nphOo6rLw3bUYrJvYPvqQT14kjUmqfgIppZn8WQvvWU
PdEDX/Bda6+Kt3iDouiAHViMjqiN54qJxaIdFqFY5Guz/yxKfT5lBf2Hbawq
8ql2Ryr1eZTDg59BEu1blBkYiol4pm9n4q/FmTHDlDPJkeeQ5U5e8G/PVT1f
Y+foWzbnER4gHm2wBO+0lyTFagNlbPCY/cIPpKCLYvtTdYvxHdtS5Hupjk/4
jFaWK1husaZ/gL6xEr8Vq1T8weHgud0VE/BQa6uJ1ajM/CE6kzXBc8ZypQYu
YZXmWs6nRL6m6jrT9MjvnN21AptDe63mjsZM/Wb18thtsaLdP/iaJ+sbBcqB
dcoZyxW7o3ZXjgS/W3ZnNtm66R+nM3yBScFz3e5sefp2UdYJ/oYcCP5m2Fth
e/yKZcFzz8Y8Vg5Y7Nvins7Izqa1YvlEfRbTm/qPXMXgPcrR7hf8jbC3aKpi
Y29SBu2Pwd+OkbiAparbHbG3Z5/OplB72xz8rbA92l14Hfxu2J1IpH+FYjsY
cbRLR37X7E4mUI+P/G2yM7a3aK/G2pt0MPgbZW9TttY+m7Jv8D2UpX09eK7a
b3dxX2dhd+w/eiiN/g==
                    "]]}]}, {}, {}, {}, {}}, 
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwl0DlOQlEUgOFH4oyiW8CC6HasrF2AbkBEO2yYHFoRcdwA4NQZSFQqtXIG
BBWnHfAlFl/+e869ecWLzi3MzIeCIJjlhjUGLXb1kitKpClTpUaSfu+2tE/z
OqApveeRBxZ55oUnGrwSp8UbTTq0WeKDDO9kKTDl29taYYeYuag5Is4HGtYx
RjkzX3DOCnWu2WTS/Z/e8csPE3arOq63usE3h0zbHek6n3zRZZlTEkS92dcT
jhkx7+mwDoX+/20Psac2tg==
                    "]], LineBox[CompressedData["
1:eJwt0MsygnEYwOEvXYFyKueR6X6srLsA7sFxRrV2dgOJEFukMcMmauHQXVAU
oacZi2d+7/vNu/n+06nFuYVQEATzvPNExIdDTeiyNtmkwScfrNDmixZbDLnP
a1QHGeDafkuJNR6osMsPF5yQdFvQMuvM2g80rHXdp888xSRZ+4S+aqj3A4yT
MY7pi/7xy6g9rXF91j1i5lN9pEqNG+6545wzihwx7P5YR3Rbv9mhwyqXXJFj
xs2SbtBvfvt/2y4rnzRm
                    "]]}}], {}}, {
                  InsetBox["\<\"\[Mu] = \"\>", {-1.8, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["0.2`", {-1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {InsetBox[
                   SubscriptBox["C", "J"], {1.4, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["\<\"=\"\>", {1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["2.9699999999999998`", {1.7, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {
                  {PointSize[0.05], PointBox[{-0.2, 0}]}, 
                  {PointSize[0.0125], PointBox[{0.8, 0}]}}, 
                 {PointSize[0.007], PointBox[{0.4463998339305619, 0}], 
                  PointBox[{1.2771956561278897`, 0}], 
                  PointBox[{-1.0806611991222994`, 0}], 
                  PointBox[
                   NCache[{0.3, Rational[1, 2] 3^Rational[1, 2]}, {0.3, 
                    0.8660254037844386}]], 
                  PointBox[
                   NCache[{0.3, Rational[-1, 2] 3^Rational[1, 2]}, {
                    0.3, -0.8660254037844386}]]}},
                AspectRatio->1,
                Axes->{False, False},
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                Frame->{{True, True}, {True, True}},
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLines->{None, None},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None, "TransparentPolygonMesh" -> 
                  True, "AxesInFront" -> True},
                PlotRange->{{-2, 2}, {-2, 2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.02], 
                   Scaled[0.02]}, {
                   Scaled[0.02], 
                   Scaled[0.02]}},
                Ticks->{Automatic, Automatic}], 205->
               GraphicsBox[{{GraphicsComplexBox[CompressedData["
1:eJx1Vn9Q1GUaBy0qkMvM0PYQgwPbpEaMloKyZ0YiObiLTcka6/bSzLzD1BiP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                   "], {{
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[0.3], EdgeForm[None], 
                    GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJwBdQKK/SFib1JiAgAAAMwAAAADAAAAOiYSViQPDyMOESUCYGEKG1MOp3wW
gtIcN2E2a9UqEycEXl8QEiYDMzIhFygCGBoIFSkIMh8NKx4LOCsdHyANDRsO
XBwLDiINz81BHl4LhNQdVVwLwcA8ecIUe6gVfOQWXF0ckX0XyGgGx8k/ZcMn
eo0Uyn9AgJIZW1oFVV4Qha4d29pDHSsLiO8hhtgfzc5By6oZXVwKWlsVqoAZ
ITINMjMMWVgUNSkVMC8WAxMEAhIDUAcEJhMDJxQETj4GLxECWlAFDjYPX14e
YTcKJTkSJjsTQywiYFUPUzYOWhUIKh0LIBsNRC0jPgQHThcDKBYCTEstIy0O
JC4PIiwNFi8CLzABNzYJMzQMMDEBRS8BHCoLUlEZKRgIVFMbGhkIPCcTYWA2
SDIMLiMPLSIOAxcCLCENXlULJRICVWAKrH4Y37Uk02sqVVYPlYIcV1YQVlck
U1QJqXE1xMU9r3M4VlUQUFgF2W4gXFUKREwtQD8H8KQzLk0jq/0Y5aEw6epH
Pk4DT04GsLEeNlMJ1tdCsZgem44FmmIBpaY0GVEIn20MoG8QgZMbnWYGbp4g
3pkuUFEHcugJUVAIUVIHubo5dfVLTk8Xit8kdvdNWFAEYnABl6AQbXQMd7YR
3dxEPj8GaJ0G8bIh8/RK5qcW4ncR4ONFtYkkkOcoPz4H/awYsoghtngR+HZN
j3sV0a036NAJ0oMc2Icf1IUdUFoIwnoUWFkF4YtG7YYfL0URQ0ost2MlnJAo
RkUBK0IeBD4DanIJKT0Y6+5IMkgfLUsivr87SUgMFFgE7JZJN0cKNmAPvLs6
jJsFoqMxtBO+EQ==
                    "]], PolygonBox[CompressedData["
1:eJwt1GeoznEYxvH7yIi84NjHPI5NImRnr4PUSUmSMiM5hOIFEiU7eyQyIxlF
2St7ZCRkZsveW/he/a4Xn56n//P85n3d/+zB+XljCkREDxTESmRkRAziswr2
4zBaIRPTcBbt0B7z8Rf9URp7cBedUB1HcAJtUAp7cR+dkYOTmOyxtUOLRyzj
oxIGYhxGoC6aYSQueO0iyMcf9EMJLMYv5KECPuEjstEAl3DRv2VhqdfUWsUw
BAfQEjVxHMO8N51hOH6iDwrjEIailu9oAf5hAAphLh6iC7riBZ6jLOrgDK6g
g/ezFtNREdWwHhvQGI0wCfu8t5KYgDeuX3FMwRrPXQ5j8chrc8w46Jpm+oxb
sM5jm2ITNvt7E9zATFRGPezELrTws/EYjfp+thyv0d172ojVXltnOBYpE8pC
ayzBb/T1md/hLap6jleukWrTDaexHeXR1nd/1HOpBudxzrVRRqf6jrM8Rlk6
5bHK1FZsi5StMj7LTXT0mW5hd6Re0LMZuO67UEZn4bZrpT1fxTU0R1HMxgM0
RA1cjpTBLNd8FX6gt/9zD9/QK1KPfI3UU+qlnr6rUZ5bd6bsz/Hc6oEvkTKv
rOfiKZ5Fyo4y9x4fXFv1hHp3XqSsqoeV3YW+C2VYvaSeU6/leW8TvRft8Q4+
ey31/PdIPZ7jM6lXFkXKonrmCR5Hyq56Ygdeura6M717VkTqZb2D/gMg5IKB

                    "]]}]}, {}, {}, {}, {}}, 
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], 
                    LineBox[{167, 124, 228, 229, 161, 162, 163, 154, 98, 112, 
                    225, 139, 224, 227, 226, 119, 182, 120, 183, 99, 185, 186,
                     184, 188, 187, 100, 190, 191, 189, 193, 192, 101, 195, 
                    121, 194, 122, 141, 254, 140, 155, 142, 255, 143, 123, 
                    168, 169, 113, 103, 196, 197, 171, 253, 172, 126, 198, 
                    207, 205, 206, 204, 203, 170, 128, 146, 250, 105, 202, 
                    127, 199, 201, 200, 104, 157, 102, 249, 145, 125, 156, 
                    144, 231, 230, 167}], LineBox[CompressedData["
1:eJwt0MsyggEABeDfo3gkHqElqhmlPRLZprCJBXau1XsouqFsk+gqZrLoM2Px
zVmcmbM4i6HocmQhCIIlylzyRpcDAmVWbFFhmwdWqZLkkR2uuCbGGjXq3HDL
0d+cvUN5SpRf9nmlRJo2x/yQ4JsiLV6YssEXBZ55YsyEEUPu2KPPgDPOueCE
MHF65Hjnkw9SNNilSYQ8m2SYscI6He7//5sD4F46XQ==
                    "]]}}], {}}, {
                  InsetBox["\<\"\[Mu] = \"\>", {-1.8, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["0.2`", {-1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {InsetBox[
                   SubscriptBox["C", "J"], {1.4, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["\<\"=\"\>", {1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["2.96`", {1.7, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {
                  {PointSize[0.05], PointBox[{-0.2, 0}]}, 
                  {PointSize[0.0125], PointBox[{0.8, 0}]}}, 
                 {PointSize[0.007], PointBox[{0.4463998339305619, 0}], 
                  PointBox[{1.2771956561278897`, 0}], 
                  PointBox[{-1.0806611991222994`, 0}], 
                  PointBox[
                   NCache[{0.3, Rational[1, 2] 3^Rational[1, 2]}, {0.3, 
                    0.8660254037844386}]], 
                  PointBox[
                   NCache[{0.3, Rational[-1, 2] 3^Rational[1, 2]}, {
                    0.3, -0.8660254037844386}]]}},
                AspectRatio->1,
                Axes->{False, False},
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                Frame->{{True, True}, {True, True}},
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLines->{None, None},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None, "TransparentPolygonMesh" -> 
                  True, "AxesInFront" -> True},
                PlotRange->{{-2, 2}, {-2, 2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.02], 
                   Scaled[0.02]}, {
                   Scaled[0.02], 
                   Scaled[0.02]}},
                Ticks->{Automatic, Automatic}], 206->
               GraphicsBox[{{GraphicsComplexBox[CompressedData["
1:eJxlV39U09cVR+zmxMWuwiiHY9X2tC5DpUAXylk5Xrsw163KqOvqWlwqs/4q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                   "], {{
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[0.3], EdgeForm[None], 
                    GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxNlndsllUUxs9HS1u6BEEotNAWQSyIojiA1oWLqq1StCoItaWUXYwmRuJe
0bhn3Br3wBhMXFHjXlHj3nuPuDUajfN5cn4k/eOX9373u+O5zzn3vG9jz5qO
/kER8akoEruI8WKo2FI0iCoxVdSLSrFIbCHGiU4xRwwRE8Vw1lkq+kSbGCGK
RYlo5lnMPsMYP1ZsI0aL2aKFMZNFLetX8r/1NKLR2qext/dpEmMY383+3nMP
9qgTmzF2g44RaChCv9fcUUwSG4uDOGctGjdHx3KxTHSITcQoUSoWikPFSMaV
oXkUfR6zWPTg5U6ccwxeVjFnEut6/EqxREwRe+K/47FC7CCmiwViPrGaK/Yf
EJMJnMt+b8q5V+OJfV0lusQs/JiIHzPZswJ9k/F2ND5Y55Vet5B7dOJXtXhe
nCo2Elvjuz3v42yl+NfEmr2cqYI5jWh2nMejZ1uxndB2sT2/PWYGbffvHZm7
VWjcCp0TmDOI+DSjoYV2MX7ag3LmN+BPP371co5p+FRPLCrYfwbae/CugjWm
ss5YvHN7L/obBpyzCG92i4z9vMj8KsP73SPzsDUyV6p5tqLXsZ3NWTr4z3P3
YUw1591XDI68p+2Ree7nfrQdf+fPcM46lz771IZvrXhdRV83a85h7yHoP0DU
0N+JhuX8V8N5Ohl/SGT+1PI8mPG+dwcST3s2H+/t4QL6molrCc+FtB2fRcSi
Ha3W2UW/69hifvsejWS+z3gY/eN4+vcsPOxmT+fpzsTPsevDwzbaXsf54/tb
x5496Olh7+mMXcrceXhkH5fRrhnw2145V4YRa+ee88555HrgPC5HYwvnbWd9
62piHa/pu7Ura10gPoy8611os94p6Ldm5/BqzuK+lbR76a+kv39AXz9jrGsV
Hj4szozMscfEOXj/hDg7Mv+XsIb3nYlf9qqe/g21awX9z4pLiNff4vrInOli
nMdcKJ7kjK+K0zj7A+IhtD0qToh8D/wgTsHf48XvkXfjF3EH3v4kfo68V37+
SvtIsS6yLr0gDo/MlyOsvZD39QZRXUiP14jjGH+3eDCy3t0mbo+sZbfYj0LW
uKGF9MteHSPWE/dy9T8X1Ba1b4q8W97zssh930CH23+IqyNrW3EhvbAPrutX
RdbOd8S5ke+xM9BnbY+jwxqOEh9F5tfR4iT0PCVOjHzXnSX+jHwn3CWOjbzj
16DDGt4Sb0fWwXvERZF5/Wbk+8Z6vhf3Rtbcf8S/kTXiOvFXZN1Zjw5ruEL8
FlnjnCNFhcyTL8Tnkd8IX4kvI9+x70bmpXPyTnRb84vipcg7/744P/Ie/Uec
HKNvxNeR9Wmt+Cwyvs7xa1nzPOZ7rvPo8shcssfv4fM6csL5cHHkd1odvt7H
uQYXMu99lqfFM5H189bIXHGefCsujXwP2LMf8e1Gr13IOvux+CTyHeN8XItm
+1FaSE9uFiWFrKnO0+/Qdrp4JLJ2uX74jvl++d74O8B352RRVsjafT9xdUxf
ES9Hfnt+EJlDzp/XxOuRtel/qZTR7g==
                    "]], PolygonBox[CompressedData["
1:eJwt1Hloz3Ecx/H3d7ZhYo4cYWZorjXmGnKO0TZzr42l5F/liKUQkjuFCJOb
SWpk/kDO5Ijc95HcuY+cOYbnu8/rj0efz+/7/Xw/1/v9/qVMmDxyUoyZ5SMW
5/ESg5CMC3iNwWiOEziJ3qiLLagZmY2jbYCVeIi2aIRFOIZeyEJVxu6iTdMa
M7EPnZCEeZiBduiDPdiKauiATShHR6Tq3S+M0pgHuK+9NMRRzEICeuIgDiFT
z0qwFxmIx0YsRTe0wkd8QCK64wimgWNYVxzAEvW7oAKH0QOdUWZhcCHNGDzz
e+P3RNr2+InNOkuGxu6kKbLwTXV+z6cdi2IsxC20RB1U4X0ixtNv5ncQhRgm
65tXmqNYMYzo76etpTU8diU6u8fQ54qNwl35nOsVwyytuQy3dTf1cBenUB8D
MBU30B8t8AZrkYscxfYxBirGT3AWTfRsOe4pdj7ndvxT7NvgHd4rFh6DK7iE
2uiLm7iuu/E9TMcd7a01FuAiUhTTKbisb/3ZNyy2kNvD8BUb1B9qIVcrUWAh
Z/1su5GuM9ZgUwlRqJV05cIOxdpzYjbeIk8xOI0zFnK9MUq1pq8Vh0dYpXde
U0/xAtloinW64xzNOVdn9rN6jV5VTDwW/bDaQo56bmbq7q7pnd/hcws1maQ1
fmAOhmMEvuCz9jbEQm1/Ut9r/DuOW8gN/yaeu4iLQm56zZdrTp/La/g3Vlj4
rxhtofa8pryWvAbPISYKteM54rW+TWO95v/ij4Xc8Jh4ba3R3XiN/Qc3boIv

                    "]]}]}, {}, {}, {}, {}}, 
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwt0MsywgEUB+B/e2bqETxSHqEHUMhSFpSkrN09QLKpsTG6sERIF+kVyi25
7PoWFt/8Nud35syZi8XnF0JBEETJcMk7H4z55JQ9vthnwiY16qyRpMczV4Qt
vZZ5+uww4IUGBU6YNbciz9jmj2N+OaLEDym+qZKjywER/UO5RZksFS5Ypkic
VYaMOOeNV9a5YYNbEjS5545HHljkiTYt0nRYYsYNu///mwJySziz
                    "]], LineBox[CompressedData["
1:eJwt0EtKglEYgOG/UiuDgnbQloQ20AJsVqYOsg1Udpt6K61JF4guNNTU1tDN
MsvaQRf1ERo8vN8H53DgzC0sxuIjQRDM80uBPocckeObPD+sc88GDyzxxCaP
ZKlSY5VlnmlxS51RD+5roKVh9FTTfLHHJ7tUKDPlTJQ7c5cPJu1rOqFNfafD
uP1AIxqmYd5hzDxDiGv7DSlOSJDhgkvO2eKMK4pMu7eir8yat/WFN9okOeaP
3v9/DgAziDVC
                    "]]}}], {}}, {
                  InsetBox["\<\"\[Mu] = \"\>", {-1.8, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["0.2`", {-1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {InsetBox[
                   SubscriptBox["C", "J"], {1.4, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["\<\"=\"\>", {1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["2.95`", {1.7, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {
                  {PointSize[0.05], PointBox[{-0.2, 0}]}, 
                  {PointSize[0.0125], PointBox[{0.8, 0}]}}, 
                 {PointSize[0.007], PointBox[{0.4463998339305619, 0}], 
                  PointBox[{1.2771956561278897`, 0}], 
                  PointBox[{-1.0806611991222994`, 0}], 
                  PointBox[
                   NCache[{0.3, Rational[1, 2] 3^Rational[1, 2]}, {0.3, 
                    0.8660254037844386}]], 
                  PointBox[
                   NCache[{0.3, Rational[-1, 2] 3^Rational[1, 2]}, {
                    0.3, -0.8660254037844386}]]}},
                AspectRatio->1,
                Axes->{False, False},
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                Frame->{{True, True}, {True, True}},
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLines->{None, None},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None, "TransparentPolygonMesh" -> 
                  True, "AxesInFront" -> True},
                PlotRange->{{-2, 2}, {-2, 2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.02], 
                   Scaled[0.02]}, {
                   Scaled[0.02], 
                   Scaled[0.02]}},
                Ticks->{Automatic, Automatic}], 207->
               GraphicsBox[{{GraphicsComplexBox[CompressedData["
1:eJxlVglQ1GUUR0TDg8kjJ8O7MV01EdPFVOxpq045pJtZqDEbYpoKdngRXhjq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                   "], {{
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[0.3], EdgeForm[None], 
                    GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJwBLQLS/SFib1JiAgAAALQAAAADAAAANx0NFQcLOhgXIBACSDwILyARKRkK
Gw0BChULUlFFKhoLHQ4CIS8REQMFTkE1AhABAg4DAQ0CAxECExIGMRMGIREF
MiMVNQUDJhcJTUwSNCcJGSgJLSYJKxsBCRcKMCEFLhwBFxgKDR0CESACL0Qg
EB8BREMgDh4DCxoKChkJJRYIS0opMyUIFSMHGikKPioLHCsBHy4BTyIGGBUK
USQIJy0JIywHedsfUE9BOykaNjUDOTYDTDUGPT4LNUwFKDQJHTgOPz0MRTwH
HjkDTjYEPD0LNkAEFkgINUEGIEMQRkUHUEIPQkEEPEUIMkcjSEkMKUoZPEgM
UkYUPTwMO0spEkwGJFEUQlBBT1APRVEIQU4E13UcUVIUSUgWIjEGJDMIRlJF
Nk41Ik8PQU8GnHAZy8dJGDIV2YUnmWcSomEOqWsUTE0FPAsHlWQQ0n0iw4Aj
tHI/h9wogtUlwWoUtbZAX54NU58bwMJGxMVHlpcPzp0ag9YmdNcchtonhNkn
dtgcoaA3XsxKx8lJm8oWjI0svnsh0FMb2HQcpVUe3Igopnkfo6Q4k1wM23of
yJMMXbxDkWUwmFYimpsWWNQkaWgTic8qr646srE7fL4hZ34SsIcoumMPiokq
1IEktrhAxowst48E0XceubtCc9AbWq0mY5YPaKgTZb8w2oQnVtIi1lomVdEe
qlgkbZoW1VklWaslp5kSaqkUj3gEbqwXKuuW+g==
                    "]], 
                    PolygonBox[{{108, 130, 37, 51}, {157, 178, 59, 26}, {158, 
                    161, 55, 13}, {168, 167, 18, 19}, {112, 176, 40, 25}, {
                    127, 192, 70, 7}, {87, 145, 48, 5}, {141, 127, 7, 44}, {
                    122, 96, 46, 31}, {133, 142, 45, 39}, {117, 139, 43, 
                    28}, {126, 211, 77, 18}, {123, 144, 47, 33}, {151, 152, 
                    34, 15}, {136, 111, 52, 40}, {129, 108, 51, 36}, {91, 146,
                     50, 24}, {125, 102, 49, 34}, {96, 118, 28, 46}, {142, 
                    131, 38, 45}, {191, 124, 33, 48}, {84, 163, 56, 29}, {211,
                     87, 5, 77}, {144, 189, 68, 47}, {177, 205, 75, 59}, {197,
                     195, 35, 71}, {204, 156, 25, 74}, {194, 193, 20, 70}, {
                    146, 196, 71, 50}, {107, 170, 36, 20}, {100, 166, 31, 
                    16}, {148, 181, 64, 54}, {184, 183, 4, 64}, {119, 98, 57, 
                    30}, {187, 186, 15, 66}, {188, 149, 16, 67}, {189, 93, 67,
                     68}, {172, 175, 58, 23}, {102, 105, 19, 49}, {128, 198, 
                    44, 35}, {205, 94, 74, 75}, {160, 84, 29, 55}, {120, 185, 
                    66, 4}, {92, 180, 63, 12}, {173, 110, 23, 38}, {159, 95, 
                    13, 27}, {139, 115, 27, 43}, {98, 148, 54, 57}, {201, 200,
                     12, 73}, {171, 109, 22, 37}, {174, 91, 24, 58}, {202, 
                    203, 73, 22}, {97, 165, 30, 14}, {179, 113, 62, 61}, {164,
                     162, 14, 56}, {207, 206, 26, 42}, {113, 138, 42, 62}, {
                    114, 179, 61, 63}, {111, 134, 39, 
                    52}}]}]}, {}, {}, {}, {}}, 
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], 
                    LineBox[{215, 117, 139, 115, 208, 83, 159, 95, 158, 161, 
                    160, 84, 163, 164, 162, 97, 165, 85, 209, 119, 98, 148, 
                    181, 182, 184, 183, 143, 120, 185, 187, 186, 99, 150, 151,
                     152, 86, 210, 125, 102, 105, 104, 168, 167, 153, 103, 
                    126, 211, 87, 145, 101, 191, 124, 190, 123, 144, 189, 93, 
                    188, 149, 100, 166, 121, 219, 122, 96, 118, 216, 116, 
                    215}], LineBox[{195, 128, 198, 140, 141, 127, 192, 194, 
                    193, 106, 169, 107, 170, 88, 212, 129, 108, 130, 213, 89, 
                    171, 109, 154, 155, 202, 203, 199, 201, 200, 147, 92, 180,
                     114, 179, 113, 138, 137, 207, 206, 157, 178, 177, 205, 
                    94, 204, 156, 112, 176, 135, 220, 136, 111, 134, 218, 132,
                     217, 133, 142, 131, 214, 90, 173, 110, 172, 175, 174, 91,
                     146, 196, 197, 195}]}}], {}}, {
                  InsetBox["\<\"\[Mu] = \"\>", {-1.8, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["0.2`", {-1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {InsetBox[
                   SubscriptBox["C", "J"], {1.4, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["\<\"=\"\>", {1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["2.94`", {1.7, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {
                  {PointSize[0.05], PointBox[{-0.2, 0}]}, 
                  {PointSize[0.0125], PointBox[{0.8, 0}]}}, 
                 {PointSize[0.007], PointBox[{0.4463998339305619, 0}], 
                  PointBox[{1.2771956561278897`, 0}], 
                  PointBox[{-1.0806611991222994`, 0}], 
                  PointBox[
                   NCache[{0.3, Rational[1, 2] 3^Rational[1, 2]}, {0.3, 
                    0.8660254037844386}]], 
                  PointBox[
                   NCache[{0.3, Rational[-1, 2] 3^Rational[1, 2]}, {
                    0.3, -0.8660254037844386}]]}},
                AspectRatio->1,
                Axes->{False, False},
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                Frame->{{True, True}, {True, True}},
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLines->{None, None},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None, "TransparentPolygonMesh" -> 
                  True, "AxesInFront" -> True},
                PlotRange->{{-2, 2}, {-2, 2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.02], 
                   Scaled[0.02]}, {
                   Scaled[0.02], 
                   Scaled[0.02]}},
                Ticks->{Automatic, Automatic}], 208->
               GraphicsBox[{{GraphicsComplexBox[CompressedData["
1:eJxlVglM02cUJ7q5DKwaUNDOgGwEq2GKRjZ0ujft4kF0VpzZRNepk22KQ8M8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                   "], {{
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[0.3], EdgeForm[None], 
                    GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJwBNgLJ/SFib1JiAgAAALcAAAADAAAAHxACEQMFNAUDSTs0FQcLNxgXRTgI
KBoLGw0BHQ4CLB8RJxkKJBYIExIGS0o7AxECRkUWGBUKIBEFMTIBSEcSChUL
OAsHTUxALiIVLRMGT05CThgKJSoJCxoKKRsBKxwBDR0CDh4DPz4fER8CSiEG
FSIHTCMILyQIMCUJGSYJGicKQhkJHCkBMysBOigLICwRIS0GGC4VJjAJMQ0C
DTEBIy8IEDECMjEQAg4DPTIQHz4QNjUDHjYDRzQGSTUEQDgHODkLPDsESzwP
OToLOTgMNUk0LD8fOEAIQUAHQ0IJT0MXTUEUQ0QXOEUMFkUINEcFNDsGEkcG
RUYMR0gFGUIKO0kEycVGQU1ATE0USksPGE4XPEs7Qk4KQ09CMjMBNTQDTk8X
1HMcQEwII0wUIUoPnWUS1oQloG4ZoW8aol0NpWAOqmkUmWMQO0oGwX4i0Hoh
k3kghdclhtgmiMsnfcEilMIufowixcdGWrs+eb0glVgMxpUMvsBBg9YldNUc
ctQcZ2YTj14rv2gUUKMbXKINn8gWz3UenFMhnp8WmpsPvXggVJIFjY4q2Icm
p1IegsREkHYEgNMkWLMM1XIcpFEdzlAbVdIj0n8jU9Ah14MlWbYEX6UOioko
01Ykr643UaYda54WmLU1W3wHt7k8bK0XsIYmtpAEYpoPuGIPq1UjsYgntLI5
cc4byqAZUs8eic0oVqwkZXsSunc9aKoUZqkTqJ0SzKEa8DaYIA==
                    "]], 
                    PolygonBox[{{146, 147, 32, 5}, {115, 139, 41, 28}, {123, 
                    209, 72, 18}, {172, 107, 22, 36}, {127, 106, 47, 35}, {
                    120, 145, 44, 32}, {150, 151, 51, 50}, {129, 195, 67, 
                    9}, {132, 141, 42, 37}, {181, 89, 4, 53}, {122, 100, 45, 
                    33}, {194, 125, 34, 46}, {135, 109, 48, 38}, {124, 190, 
                    65, 7}, {87, 148, 46, 24}, {142, 129, 9, 42}, {140, 91, 7,
                     34}, {178, 112, 58, 57}, {205, 204, 26, 40}, {169, 168, 
                    18, 19}, {99, 186, 61, 16}, {187, 153, 16, 62}, {209, 84, 
                    5, 72}, {200, 201, 70, 22}, {145, 188, 63, 44}, {117, 97, 
                    54, 30}, {192, 191, 20, 65}, {93, 164, 29, 13}, {96, 167, 
                    30, 14}, {111, 177, 39, 26}, {173, 175, 55, 23}, {179, 
                    180, 57, 12}, {185, 184, 15, 60}, {188, 90, 62, 63}, {105,
                     171, 35, 20}, {106, 128, 36, 47}, {195, 130, 68, 67}, {
                    196, 108, 23, 68}, {163, 92, 13, 27}, {139, 113, 27, 
                    41}, {94, 116, 28, 43}, {119, 150, 50, 61}, {100, 103, 19,
                     45}, {166, 95, 14, 29}, {199, 198, 12, 70}, {155, 156, 
                    33, 15}, {118, 183, 60, 4}, {110, 176, 38, 25}, {112, 138,
                     40, 58}, {203, 202, 25, 39}, {174, 87, 24, 55}, {151, 
                    143, 43, 51}, {97, 152, 53, 54}, {109, 133, 37, 
                    48}}]}]}, {}, {}, {}, {}}, 
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], 
                    LineBox[{212, 115, 139, 113, 206, 80, 163, 92, 162, 93, 
                    164, 81, 166, 95, 165, 96, 167, 82, 207, 117, 97, 152, 
                    181, 89, 182, 144, 118, 183, 185, 184, 98, 154, 155, 156, 
                    83, 208, 122, 100, 103, 102, 169, 168, 157, 101, 123, 209,
                     84, 146, 147, 121, 189, 120, 145, 188, 90, 187, 153, 99, 
                    186, 119, 150, 151, 143, 94, 116, 213, 114, 212}], 
                    LineBox[{193, 126, 140, 91, 124, 190, 192, 191, 104, 170, 
                    105, 171, 85, 210, 127, 106, 128, 211, 86, 172, 107, 158, 
                    159, 200, 201, 197, 199, 198, 149, 88, 179, 180, 178, 112,
                     138, 137, 205, 204, 161, 111, 177, 136, 203, 202, 160, 
                    110, 176, 134, 216, 135, 109, 133, 215, 131, 214, 132, 
                    141, 142, 129, 195, 130, 196, 108, 173, 175, 174, 87, 148,
                     194, 125, 193}]}}], {}}, {
                  InsetBox["\<\"\[Mu] = \"\>", {-1.8, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["0.2`", {-1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {InsetBox[
                   SubscriptBox["C", "J"], {1.4, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["\<\"=\"\>", {1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["2.93`", {1.7, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {
                  {PointSize[0.05], PointBox[{-0.2, 0}]}, 
                  {PointSize[0.0125], PointBox[{0.8, 0}]}}, 
                 {PointSize[0.007], PointBox[{0.4463998339305619, 0}], 
                  PointBox[{1.2771956561278897`, 0}], 
                  PointBox[{-1.0806611991222994`, 0}], 
                  PointBox[
                   NCache[{0.3, Rational[1, 2] 3^Rational[1, 2]}, {0.3, 
                    0.8660254037844386}]], 
                  PointBox[
                   NCache[{0.3, Rational[-1, 2] 3^Rational[1, 2]}, {
                    0.3, -0.8660254037844386}]]}},
                AspectRatio->1,
                Axes->{False, False},
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                Frame->{{True, True}, {True, True}},
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLines->{None, None},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None, "TransparentPolygonMesh" -> 
                  True, "AxesInFront" -> True},
                PlotRange->{{-2, 2}, {-2, 2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.02], 
                   Scaled[0.02]}, {
                   Scaled[0.02], 
                   Scaled[0.02]}},
                Ticks->{Automatic, Automatic}], 209->
               GraphicsBox[{{GraphicsComplexBox[CompressedData["
1:eJxlVglQ1GUUJyupNTwYNSLRTNTNE8zN1MaH/j0IR90xrBlEjPIYWydL81jx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                   "], {{
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[0.3], EdgeForm[None], 
                    GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJwB/QEC/iFib1JiAgAAAKQAAAADAAAAHQ4CFAoGGBcKThUUGgwCExEJDQQD
QUAWMhUHLR0PDwMELB8NEQYKJhYJCREKMCERLxAFQBIJChcJKSUUEhMJPAsC
AgwDHA0DNRQGHCwNPioBFSkUDR8FKxwDKhkBMyQICxoCLiAFQzsiTEEWlZYn
ESEGMSMHNg0FDBsDNBgKHi0PGysDJCgIFyYJDx0CHy4FEzARFCUKGScBIC8F
QzEHkdkkIzIHHg8EDTYEODYFEDgFUE41NjcEOjkGPD0BUDsHRz0OPT4BNz8E
SUAIJ0UBQEkSQEEIQUIIFkAJDjwCO0MHRUQBREYLLUgdPEQLMUMiRDwBSkkI
KEoIFU4HNU4UO1A1TlAH1nwZrWIOOTUGAw8CQjMIJTQKwoghPTwO2JAkrnUW
sF0LsmAMertGSUsSbtVPr3YXzoUg0owj05IltXASnoIed7kYaNoQoHEzxpNM
n8Mwy8xNf8ocx64WUskbiJchZqM31dRPzGNNj9gke9YZfdcZWdMllMgmzVUg
mJkotFIbtlgT2mkQjsVLml4qylMc0IoieHcYamgQwYEesVEa13sZV9IjhM0g
h8Ihva0O0VcjUbMapGs5pYY6v8BIb7USvIBHVc4gqao/X7IMz1Yit5QmgsEe
yX4b2Y8kVtAii9EjXLALuK8Xic8idtyIGg==
                    "]], PolygonBox[{{166, 137, 34, 59}, {94, 125, 25, 42}, {
                    109, 115, 21, 50}, {91, 89, 37, 41}, {103, 162, 54, 56}, {
                    141, 196, 73, 74}, {172, 160, 51, 66}, {124, 149, 39, 
                    25}, {151, 90, 6, 33}, {134, 164, 57, 58}, {140, 109, 50, 
                    35}, {133, 101, 47, 32}, {138, 108, 49, 34}, {88, 159, 48,
                     19}, {114, 91, 41, 21}, {90, 165, 58, 6}, {144, 152, 40, 
                    36}, {195, 135, 33, 48}, {157, 158, 30, 4}, {83, 155, 44, 
                    28}, {126, 97, 43, 27}, {129, 156, 45, 30}, {131, 100, 46,
                     31}, {155, 84, 31, 44}, {101, 106, 16, 47}, {117, 198, 
                    76, 22}, {113, 145, 36, 51}, {163, 169, 63, 55}, {171, 
                    172, 66, 65}, {167, 168, 62, 61}, {93, 177, 26, 11}, {115,
                     110, 79, 21}, {84, 203, 77, 31}, {192, 190, 29, 72}, {
                    197, 111, 18, 75}, {161, 166, 59, 53}, {96, 180, 27, 
                    12}, {112, 182, 19, 18}, {118, 183, 38, 23}, {170, 157, 4,
                     63}, {150, 121, 69, 39}, {187, 92, 11, 70}, {98, 188, 71,
                     14}, {186, 122, 70, 68}, {190, 189, 14, 29}, {153, 141, 
                    74, 40}, {105, 103, 56, 16}, {108, 139, 35, 49}, {97, 127,
                     28, 43}, {107, 161, 53, 57}, {168, 154, 42, 62}, {99, 
                    131, 31, 77}, {128, 167, 61, 71}, {212, 114, 21, 79}, {
                    196, 142, 75, 73}, {100, 132, 32, 46}, {116, 120, 24, 
                    52}, {162, 102, 55, 54}, {146, 116, 52, 37}, {121, 186, 
                    68, 69}, {147, 171, 65, 76}, {200, 199, 22, 38}, {156, 
                    191, 72, 45}, {185, 184, 23, 24}, {179, 95, 12, 
                    26}}]}]}, {}, {}, {}, {}}, 
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], 
                    LineBox[{214, 124, 149, 150, 121, 186, 122, 187, 92, 176, 
                    93, 177, 81, 179, 95, 178, 96, 180, 82, 201, 126, 97, 127,
                     202, 83, 155, 84, 203, 204, 99, 131, 100, 132, 205, 85, 
                    206, 133, 101, 106, 104, 218, 105, 103, 162, 102, 163, 
                    169, 170, 157, 158, 130, 193, 129, 156, 191, 192, 190, 
                    189, 173, 98, 188, 128, 167, 168, 154, 94, 125, 215, 123, 
                    214}], LineBox[{194, 136, 151, 90, 165, 134, 164, 107, 
                    161, 166, 137, 207, 86, 208, 138, 108, 139, 209, 87, 210, 
                    140, 109, 115, 110, 213, 212, 114, 91, 89, 211, 146, 116, 
                    120, 119, 185, 184, 175, 118, 183, 148, 200, 199, 174, 
                    117, 198, 147, 171, 172, 160, 113, 145, 217, 143, 216, 
                    144, 152, 153, 141, 196, 142, 197, 111, 181, 112, 182, 88,
                     159, 195, 135, 194}]}}], {}}, {
                  InsetBox["\<\"\[Mu] = \"\>", {-1.8, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["0.2`", {-1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {InsetBox[
                   SubscriptBox["C", "J"], {1.4, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["\<\"=\"\>", {1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["2.92`", {1.7, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {
                  {PointSize[0.05], PointBox[{-0.2, 0}]}, 
                  {PointSize[0.0125], PointBox[{0.8, 0}]}}, 
                 {PointSize[0.007], PointBox[{0.4463998339305619, 0}], 
                  PointBox[{1.2771956561278897`, 0}], 
                  PointBox[{-1.0806611991222994`, 0}], 
                  PointBox[
                   NCache[{0.3, Rational[1, 2] 3^Rational[1, 2]}, {0.3, 
                    0.8660254037844386}]], 
                  PointBox[
                   NCache[{0.3, Rational[-1, 2] 3^Rational[1, 2]}, {
                    0.3, -0.8660254037844386}]]}},
                AspectRatio->1,
                Axes->{False, False},
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                Frame->{{True, True}, {True, True}},
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLines->{None, None},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None, "TransparentPolygonMesh" -> 
                  True, "AxesInFront" -> True},
                PlotRange->{{-2, 2}, {-2, 2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.02], 
                   Scaled[0.02]}, {
                   Scaled[0.02], 
                   Scaled[0.02]}},
                Ticks->{Automatic, Automatic}], 210->
               GraphicsBox[{{GraphicsComplexBox[CompressedData["
1:eJxlVgtMFHQYRzPaIGbmRXhDFxPxJEyHos45P5XSWT4uaz6ozsTHFFwaoAZh
KOhtYibmzVS0ApFMeUkgKqd/BRUOjxI9PVDEC+94CXJHusQhl97X7892srHb
777v+32P//e4gMh1C1b29/DwMD7/f/H55KzXLm3XWTHpzRyNWf1Q6BkTsP/r
la3WMNNLOHn5mtIwXbO4VBTkpzNbJIY8gTFBDgx/Y5mP4A8Y9sAerr/z+ioX
j11cdelXEfB1F75Nd12fbQL6wNB3xzcZS35gxAMMfmDk425/heMh8AODzz1e
93q7x+deX3c56gk+93rC/2jX9w2UvOrO47yMdtrksjNT07nECqezU0CeynKh
cNX/Eo0dODlQE94qYr78d4te2/gSNpXsX+Bjs0l9FcsJciPLJYYc/hvYv5Qj
X2DkF8r8sj+BkS/yd68H+OAP8SJfYMgRL+TAqD8w3hvx+Ja+8HdcoH7ob2DY
wx/sET/sUQ/YA+O9oX/RxXdN1g/zAgw+vC/4gMGH+MEHOfiAIUf/ynn9vx/g
D/0Ff8Cwd+9H9AP6xz1fYOjjfREf5gH8qDew+3wt2PhLj+Fdh3B6DS1VD7NI
Od5nu6JfnbW4Q+ZvdegL1L02ab9sSvnpMEUrwR7vETtzXJJeWy42fm/OCTM9
r19EdYm6t4YSvNZmRn/TRLobp9O1mWXi+PilO7SeHTTln9xxmhQLHVOPS8jo
6aDd3rvnqPK3Cst1sbrrqV0MXpG5uEuZSrpuc4/B2yGm5nQ+NDyopEO+bSei
/Rzi5N4VqdoYIzV11ryte80hOvt7Vigza6lGezQoPtwusiwRoZrwrUIzf7oi
PrdNJKuCZ6vS79M089p2w6I20bP3eIPzXiN9uM32yLDTJvy7Rm7QT6ij5PVn
HhsG20T16rHr9Z71FHg/4o5TWKU8geUE+xlsT+CfxPwE/wvZP10zFi7tUu6j
qECfp3nT+/bnZq43WedkJeln3pf7FPlUcz6yPvVcH0I99nM9qOBgpK/OXCP7
S96zw70VYXF2+Z4RKVufGU7YBfTd9/HEb+tGhHd3ihHbZ7cbovv2L/qxesrH
IzUpzQLxov8Gv98wID/AKvVhj36F/WW2l/n7Om0t1mIrwd79PrY8eWWyaky7
3GdjOD653+dxP1PlnsPfZSRepbO5A5x5XzfLfivkfhNF6tCftKE3KWu4MSd6
v12g/wq4/0TQOU1g/K6LFFd6LzT8QIvs32TuXwH+MuYX5xWzRmuGW6kxom2T
PrtZvHH9yM4MfyvFjPrgi66EZrF538y0jMS/ydLRvKzrtlXyr2V+gryW5QT7
KLYn8N9mfjlfX/F8EfL5lfOh9LIRdU7n5Zfug+dnoT9GH+uUePEq3XllVIeA
PuYXcjXLJe6NcNn31X/3mUJ1g1XiiYzFfHWWSlN+i6a9N2FHRqJNbGl5Jzd6
tYWiaqs/9TnaJ5/Ecrm/6nm/0Cr9jFmqfJO8L5g/f54/Al8k81FsyLrNem2R
yAvp/dMpHsj9bud+Eb/pkrbptRfk/QE/7g/6bxj3n9jgiu+UGDrPsidD1zc/
43l+qHjLzwqduUzeI+Om2gPawhtU+FfwNv0pu8xnIc+XvI9PYj9aaU7r+z2W
+tZyr/x+DjkPLQd/n6sa6JD6P7BcdOd4G5VVxZR9dIJJGeyQ89fO+mJOzkPv
/IALdKzhRlpGiEPy29kf3RpypSJMV0CngyLj9NmtBP0s1ifsz0ben4T8Azh/
gXxx/7objWvN6myBfYF75+cx+5nhql2gHqe4HvL+mLxupeib7GLUoNiLyqp0
gX0B+yFH0l/VLXogsB9jeD8KxH+B45f3Zw3fH5G9uH58eHyJvL9/BE8sV1ZV
UWLSo0plarPEcYzlfSWfWL/4uS2yf7K5fwj9gnuNeLGPEe8gjpdQD+xbyBVc
D8L9SuP7RXjPTH5PUpoKT4Yp7lL9MA9H3rJOceiTz0vUUxupaMm0kPAl7QJy
E8vl74drXE+Cfg7r03/8rQE/
                   "], {{
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[0.3], EdgeForm[None], 
                    GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJwB8QEO/iFib1JiAgAAAKAAAAADAAAAGQ4CSBQTTUwPIRsNFwwCNAsCIhkP
TA0EEhAJEwoGEAYKOTgVHhUJQUAMOBEJJRwQNTQOGA0DERIJJxQHLg0FLRMG
Hx0TSzIHSkk7CxcCMS0GDxkCDRsFEBwGEx0KSR4JFB8TQiADGCENGiIPGyMF
KSQFEiUQMyYHKicHHSgKIykFJioHQA8CS0gtDS4EMC4FLi8ENzAFIBgDQUID
Gg8EMjMHNTYBJDcFFTgJNDUBRTgIODkIPTwKOToISjwWPjQBPDsKKD0KOEUR
DEACTk1AQ0EMTkEDIkQZPz4BPEcWFEgHRkUIND4LEDsJLUgTO0kJD0wEPEo7
MkstDUwDTE0DTU4DDjQCQE0PQU5ASEsHpl4OX4Qjvnccp2sVqVoLHkkWZIkm
OxAKqGwWSUoWrWcRynsdg3Maq1wMW6sMacwUWakLs1kLiGQmu7xEc70auaYO
hWAktnBDh78lccgYdr4cYIYkd30cUckbimUnuJw1nZ42xaE5bctHj40rYZUv
mpsyrlMSmZcxaowoqk8XjY4ryFAYvXIazGgUsbQ+fMceVModwXpGkJEskpAs
oqM6r3wea8QVZq0RT6wXXrcOVpgGlmIwf10gl2MxyXQbwmYRxqcVsKgWUoIE
sm4/lZ8vwMNFexB7rQ==
                    "]], 
                    PolygonBox[{{87, 193, 70, 8}, {199, 198, 21, 30}, {101, 
                    105, 20, 39}, {99, 147, 45, 49}, {104, 88, 31, 20}, {85, 
                    178, 63, 1}, {122, 192, 69, 70}, {126, 143, 43, 1}, {142, 
                    85, 1, 43}, {132, 117, 41, 35}, {80, 128, 33, 24}, {114, 
                    129, 34, 26}, {130, 131, 26, 4}, {83, 135, 37, 18}, {139, 
                    146, 44, 8}, {121, 138, 39, 42}, {137, 121, 42, 38}, {88, 
                    84, 29, 31}, {191, 118, 28, 37}, {120, 136, 38, 51}, {123,
                     106, 40, 29}, {116, 95, 35, 27}, {111, 127, 32, 66}, {98,
                     148, 46, 48}, {159, 82, 4, 47}, {152, 153, 49, 6}, {155, 
                    120, 51, 50}, {134, 160, 55, 36}, {158, 126, 1, 54}, {147,
                     154, 50, 45}, {156, 157, 54, 53}, {163, 139, 8, 58}, {
                    103, 174, 18, 17}, {92, 182, 67, 12}, {203, 176, 22, 
                    71}, {112, 181, 65, 67}, {161, 162, 58, 57}, {108, 175, 
                    30, 22}, {140, 165, 61, 40}, {180, 179, 11, 62}, {196, 
                    197, 57, 21}, {164, 109, 71, 60}, {128, 81, 27, 33}, {125,
                     86, 6, 28}, {117, 133, 36, 41}, {110, 177, 62, 63}, {93, 
                    113, 24, 32}, {165, 164, 60, 61}, {172, 91, 12, 23}, {90, 
                    170, 23, 11}, {145, 87, 8, 44}, {195, 194, 17, 69}, {181, 
                    111, 66, 65}, {160, 150, 48, 55}, {183, 184, 53, 14}, {
                    188, 186, 25, 68}, {148, 97, 47, 46}, {129, 187, 68, 
                    34}, {186, 185, 14, 25}}]}]}, {}, {}, {}, {}}, 
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], 
                    LineBox[{93, 113, 200, 80, 128, 81, 201, 116, 95, 132, 
                    117, 133, 96, 134, 160, 150, 98, 148, 97, 149, 159, 82, 
                    130, 131, 115, 189, 114, 129, 187, 188, 186, 185, 166, 94,
                     183, 184, 156, 157, 158, 126, 143, 141, 142, 85, 178, 
                    110, 177, 180, 179, 89, 169, 90, 170, 79, 172, 91, 171, 
                    92, 182, 112, 181, 111, 127, 93}], 
                    LineBox[{190, 119, 125, 86, 152, 153, 151, 99, 147, 154, 
                    155, 120, 136, 100, 137, 121, 138, 101, 105, 204, 104, 88,
                     84, 202, 123, 106, 140, 165, 164, 109, 203, 176, 168, 
                    108, 175, 124, 199, 198, 167, 107, 196, 197, 161, 162, 
                    163, 139, 146, 144, 145, 87, 193, 122, 192, 195, 194, 102,
                     173, 103, 174, 83, 135, 191, 118, 190}]}}], {}}, {
                  InsetBox["\<\"\[Mu] = \"\>", {-1.8, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["0.2`", {-1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {InsetBox[
                   SubscriptBox["C", "J"], {1.4, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["\<\"=\"\>", {1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["2.91`", {1.7, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {
                  {PointSize[0.05], PointBox[{-0.2, 0}]}, 
                  {PointSize[0.0125], PointBox[{0.8, 0}]}}, 
                 {PointSize[0.007], PointBox[{0.4463998339305619, 0}], 
                  PointBox[{1.2771956561278897`, 0}], 
                  PointBox[{-1.0806611991222994`, 0}], 
                  PointBox[
                   NCache[{0.3, Rational[1, 2] 3^Rational[1, 2]}, {0.3, 
                    0.8660254037844386}]], 
                  PointBox[
                   NCache[{0.3, Rational[-1, 2] 3^Rational[1, 2]}, {
                    0.3, -0.8660254037844386}]]}},
                AspectRatio->1,
                Axes->{False, False},
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                Frame->{{True, True}, {True, True}},
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLines->{None, None},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None, "TransparentPolygonMesh" -> 
                  True, "AxesInFront" -> True},
                PlotRange->{{-2, 2}, {-2, 2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.02], 
                   Scaled[0.02]}, {
                   Scaled[0.02], 
                   Scaled[0.02]}},
                Ticks->{Automatic, Automatic}], 211->
               GraphicsBox[{{GraphicsComplexBox[CompressedData["
1:eJxlVn9MU1cUblAZmWs0SowSJXOZ7G3OH3N20Zl40C7EOYXqxpagqQuGTafT
zbmxMkWjrhoU4xwS7TYV/A9NYagopXLQEKVFM4Lgy/AnpS1ip31rxkRifJN3
912SQkKar+fc757v3POjk3M3Ls9LMJlM9c//Bz77PC8WO2MenjPmlF21PWKv
wAQ88aWmnqClbQjesXptnaWkmxvPpI0vUe9JDHuBwAQ7MO6bKfgI9wHjPHCr
Ye+g28bnA242Pv1DcLvAkg8Y54ERT7y/3/heY/jH5wP34Tww/OP1XBZ8NM34
/g7t+Oxmr7vsL8o38qBS+MKWK7oeZdiLhJ2TDf2NNHPUu6/arT286dPH273O
gMSwKwIT7MDgvyP4pR3vA4z3MBl/9V7oRT6BoS/eH3rH1Q3YKxh6EB8w7NB3
1OCrkHrBj/gQf9u5w8vNoZDMDzDsVwWW9yO/4AeGHfmAHRh6oQfxw37ReMcW
ij8PfbADo37j3xfxon6A4Y96Ah/eGzi+35APnEc9wx/1AIz3gz/0oF4RL/Th
/YGRH5mv/+MDjr8P7wv9sCO/eB/44z74I17EB//zLyw45ixvGDKvpqcGlipR
jT3njliUyjuSD/NmSlv175bkhzJ/wMjH1YqaZea8MIM/vp+XfP64Vd/WQ+CH
HfytvQcDvkiU2p6kzrZbGzjTMSbFPizKk064XnEUt1K/u1XVOUw5e+rSrA7m
nX3fNuv8kEZeTzzunHWP8mfuC/tOPiQl8PMfKf6dnFS8O6BXarzB0vi+OeSn
1OCFaLBd49Mf9L9tfaJSwpHAAusEjdesGcjLFq74+t8HvqkRLq5eddZmX00l
KQ23gyMi/IP+zSfmKV00113T7+7s4ZUVSlewV6Xc5Np6y5kQHx97cYP3xi3a
P+dEh/5aSNpzhJ1w/i1xnnBfubiPskcP5KFwyHydJPJLhUpnXswVkHbE/+yw
Eb/UO1zopSXmgTpxUE1BgsdWrxH0pwj9pKQva9H1QZy2d+ovzli5nN+jq7Ym
lqh+ieX++u3ZFcvmwfle+npxftmWqKyfj8T7MvTE75fcy6c1X6SboQd2e8t6
l9PeJfsT/jnCX+Zj0wqe5FgaIvijvhHPfhGPrLc3RD1Lfdgn0AeMetor6onf
aWixx1w36NLuoMc2X2PU1zZRX1yo+RcrlZdocVPBU3fnfa5KTBjvKG6iogMn
xzum3Zf1mlBp1CubsqovWTZ3UfnL2wLB7PucWLbvrr4qQOn5w/7xjQxLvoWC
j8C3Q/AR/OcIfwKfS/DJfskQ/UKIv17EL/fXx4d+fU+ZEZb7K1NguY/OJzWl
W2s1Bs5ImnfWkhyR77FpbPYVS9vg+6e+qWQoWSF5fr7wl/iM4KM/s7/o962r
5u/dTzOVLI3L+PRRZ6yKF7nai5yzBvdXmuDjqgOxLHOeSl9l3p7ouBbisZER
K9WWu5TbHPnQPGXQvkbYCXzpgo/Qv/tE/8r7N4v75fzdIPTQqGrrDPuw67Tw
6I9rY0WanEcdYh5xaYE3T7V55H5Gf3lEfzH6CfMFfBmCT/ZPo5iPdKr9wTq1
5YbcX5gfTjE/CHpzhF6at/Jmv29qQPojPswHW1/Y4XXWyP0NjP1hKq0dXqI2
ky0le4LjWjd/adTxNdlv2B/dvT/p7sndjPiwH+XvT9F/jHhgB/8iwU/gR3+C
/67gJ+QT+xP5mS3mC6UdMz/yraulXc5xAf35PqpckbnR6/RSx6PF36maxrmx
g3OVjbfINF2brYyKcm2hmlTZ2Umtu+q2lj2N8KFFe574ItV0YL2r3/13D8G/
b5rhT/D3C3+C/2Hhz7h/u7if/gM3XZBQ
                   "], {{
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[0.3], EdgeForm[None], 
                    GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJwBxAE7/iFib1JiAgAAAJEAAAADAAAARjkMSA4NKQsFEgsDPQ8KNhgDOQsE
RBoMEhkLGhMMGRQLPj0NDxUKMhYJEBcPFBsFIw8GFjAJMQ0KRxAPIgwCEygC
IScBQSYCLCMGJSEBFR4KGx8FSUYiQighJiICcb0TDz0GCxQFDhwNSkcjKSoE
KykFCykEIB0HJC8IPCsFQy4JLSQIQzAkmWQtDBMCFxUPOzoESTUDQjQCQDMK
NTYDMzEKNzgHSjcHDT0KPT4GKEICRT4NPj8GHkAKOToMNEECNEIhJkERLkMk
MEMJCzkDOjkEOkQMMTIJRkkDN0ojR0oHSDEJSy4Ou3kVHRAHQTQRGBIDLksJ
S0gJIkYMOUYDHEUNNUkiX4MbI0cPSEsOMUgNEEcHnWwzer4Wtk0RUYIEdYsf
sK88lKonraw7pJgsT30BVLsVlq4qZboOVYkIsrM/jHggpaY3oaI1vXITXZQn
t24RYJYquXQUZ7wQulMOvnsWaIoevGYQaZsvuE4Sn5MlULkUm7QvTbcRmGIs
flwYhYYcfUwBTFYBUlgIqZktiGMdiVIIl2Erd6c4gYAabbYRfHoWVp4Bk1ol
WKgIV6MGcLgSlSZnmg==
                    "]], 
                    PolygonBox[{{106, 146, 36, 48}, {89, 84, 21, 23}, {118, 
                    177, 62, 69}, {120, 136, 29, 32}, {94, 142, 33, 40}, {99, 
                    103, 16, 29}, {98, 144, 35, 44}, {78, 127, 25, 18}, {97, 
                    149, 41, 43}, {130, 173, 59, 4}, {116, 95, 27, 20}, {132, 
                    176, 60, 5}, {83, 133, 28, 14}, {135, 140, 32, 7}, {92, 
                    112, 18, 24}, {100, 145, 36, 45}, {115, 129, 26, 68}, {
                    127, 80, 20, 25}, {102, 89, 23, 16}, {91, 143, 34, 38}, {
                    162, 111, 54, 53}, {154, 101, 14, 46}, {142, 93, 39, 
                    33}, {170, 79, 1, 39}, {174, 81, 4, 42}, {149, 96, 42, 
                    41}, {114, 94, 40, 19}, {110, 91, 38, 17}, {139, 132, 5, 
                    31}, {108, 156, 49, 51}, {145, 154, 46, 36}, {156, 107, 
                    50, 49}, {146, 105, 47, 36}, {163, 164, 44, 6}, {180, 85, 
                    8, 47}, {143, 161, 53, 34}, {141, 160, 52, 33}, {123, 106,
                     48, 22}, {90, 141, 33, 37}, {144, 165, 55, 35}, {167, 
                    135, 7, 56}, {111, 126, 24, 54}, {172, 171, 58, 59}, {128,
                     113, 19, 26}, {121, 104, 30, 21}, {175, 151, 43, 60}, {
                    158, 159, 37, 1}, {107, 124, 22, 50}, {181, 157, 51, 
                    64}, {131, 117, 31, 27}, {134, 118, 69, 28}, {171, 115, 
                    68, 58}, {166, 119, 56, 55}, {138, 181, 64, 30}, {177, 
                    178, 63, 62}, {179, 87, 6, 63}, {168, 169, 45, 8}, {160, 
                    109, 17, 52}}]}]}, {}, {}, {}, {}}, 
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], 
                    LineBox[{90, 141, 160, 109, 182, 77, 183, 110, 91, 143, 
                    161, 162, 111, 126, 92, 112, 184, 78, 127, 80, 185, 116, 
                    95, 131, 117, 139, 132, 176, 175, 151, 97, 149, 96, 150, 
                    174, 81, 130, 173, 172, 171, 115, 129, 128, 113, 189, 114,
                     94, 142, 93, 148, 170, 79, 125, 76, 86, 158, 159, 147, 
                    90}], LineBox[{98, 144, 165, 166, 119, 167, 135, 140, 120,
                     136, 99, 103, 188, 102, 89, 84, 187, 121, 104, 138, 181, 
                    157, 108, 156, 107, 124, 122, 190, 123, 106, 146, 105, 
                    155, 180, 85, 137, 82, 88, 168, 169, 153, 100, 145, 154, 
                    101, 186, 83, 133, 134, 118, 177, 178, 179, 87, 163, 164, 
                    152, 98}]}}], {}}, {
                  InsetBox["\<\"\[Mu] = \"\>", {-1.8, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["0.2`", {-1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {InsetBox[
                   SubscriptBox["C", "J"], {1.4, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["\<\"=\"\>", {1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["2.9`", {1.7, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {
                  {PointSize[0.05], PointBox[{-0.2, 0}]}, 
                  {PointSize[0.0125], PointBox[{0.8, 0}]}}, 
                 {PointSize[0.007], PointBox[{0.4463998339305619, 0}], 
                  PointBox[{1.2771956561278897`, 0}], 
                  PointBox[{-1.0806611991222994`, 0}], 
                  PointBox[
                   NCache[{0.3, Rational[1, 2] 3^Rational[1, 2]}, {0.3, 
                    0.8660254037844386}]], 
                  PointBox[
                   NCache[{0.3, Rational[-1, 2] 3^Rational[1, 2]}, {
                    0.3, -0.8660254037844386}]]}},
                AspectRatio->1,
                Axes->{False, False},
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                Frame->{{True, True}, {True, True}},
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLines->{None, None},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None, "TransparentPolygonMesh" -> 
                  True, "AxesInFront" -> True},
                PlotRange->{{-2, 2}, {-2, 2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.02], 
                   Scaled[0.02]}, {
                   Scaled[0.02], 
                   Scaled[0.02]}},
                Ticks->{Automatic, Automatic}], 212->
               GraphicsBox[{{GraphicsComplexBox[CompressedData["
1:eJxlVQ9M1GUYZrKIKWgxnXTDjRYYi9zMdc6Z420RuLkkRi4aNVYpJGG22Ya7
EyhgXumCXB1/Yg1FxZ2HHI4J5nnwQSFxQIoIHEMguN0d3EFwHJQLzcvu3fPd
drCx3549z/v/e997/uPP07LWBAUFVT35//9rMq4t1XiMtCviSqYldV5EhXU7
bcrBVbj4YM5NpXZadF7bGqm1TEoMXs2YwAPD/3b2R9ADD/j4URr3fV2i1/ft
WYWHGEt/wLAHRnzgIN9fmwn1QA8Mf4gHe2DYB+YLXOPDenK05v/m9S4I4OLs
+38Zaudom083ITH404wFeOCNvv500vYNu2MyE53i2IcPvjJprBKDj2NM4IHh
f4LzIfQvsH7MB/6QP3jMF/kNXq9KC7fb5TxQP+wRr8PXv36J0V/4Bw+M9wCM
eH0cT74XzAP26Adw4HvE/MGjP8CB7xP5wj6wf4gHHOgvcJ6BPPoPHvHXh5n7
vN4xyeP9hZ6yBGvT52Q9xr2xdtuQQ/IJT5nVphCHfL9njlSvGBad0h/mo971
7Ebti/dI909panj4ND3M2PF9ru4Pcp2u2aDa/ye1n1qatCnNpLt9weo96xYZ
juNvhttLSV0d9Yvi01mR33JpzlZupd1Zzu80aU7hSrq0ZJgap6a7m7aoGuyS
38E8RZ8vTIprrPPv59fGxLjGCrrYs/m4Jd8t9zOI66PDHWp97syU1COfi5wP
xR/SnKjd8ztVU7oxtcwt55VRUvSvud4tzq68tmyebRboH/Z1pK5gXeNHbolT
lAURqoZZ2c+2sbCTpp1u+d6TXzhoUC7770EV91OgnsB7tH9xeq02fUYg/0A+
iXlCfpgH8knmfCQe5HzlfUngfGT/dNw/8fSPL33gUfxMhqbIIYXeP69jPC/6
+2SWWbHPQrF31Cme0QWRkPzMkPftESp567JRcX5BYP4enr/QZI9GaC2/Ul9d
4bw53imCPcEzNuUturapPiYz2Cnwfq7y+xHD5qaW1Bqr1Ge0L4U23p2iufSf
ehTVDumvk3mCvyvsj6C3sZ7gD3rUp+f6ZD1buB5CPSe4HjqSX1xWm2+V+497
WBb/zrlc3bQAj30Dr2Fe7nfKzcpIbaX/PbQvGD6z9NvpYVf/VaW2lUIOuGJV
DX6+m3nxakqF3VY+THlvFLcqDzlE14P31mk3j9CjojNq01aHyFnZY7E1T1BL
YmqFpsmvP8p6gn6Z9TKffZyPjL+G45Mn+3CRKXmA1L3rH5vf9+9HDe+HAF/I
vPimYFurUju86t428T0h7LOe95mQr4Hzlfu6k+8N6Qzf5ng0k/I+h/juTR8N
+OqYEY2h3a8n3vDfY9y/e9Fdz6lKpwXs8XsC+x62J9hjXrDvZXu5/+/y/st7
beR9JtSL+33h5ce3veI+RffWeX+4/uT379b4Jx71FLl6O8Zs5bOipHKxTalt
pqMVe78wJbukPpL1BL2V9XSuzv1lrUkvyqLq82ofLYiJmAOvJKoui/k7FfGJ
N+YkdjCWeg3rCfHyOJ74DyDrPy8=
                   "], {{
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[0.3], EdgeForm[None], 
                    GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJwNw4cuAwEAANDe3vtqdN11anvtlXLXUiNik6JESklEbbFii1UlCKHVxefy
kufOH83lQYvFcvYf+m9opM7gGgHRFEYKgEvCbAIZ8OExnTJZxsmiLRygkABP
gIQIt4pEmxtIGErSVIUWQLTDfCvRaSPv7oNSE8ZZAbaZYWSc8EAdLsxDwF4P
7FYA2kFRPqxZZppozEfhyTCaCILBEBjRoGgEonSc0RE9higG2RWjln4kQgP9
HZiji9IMMNJJxtoRLUKqJrOa4a1tQDyA+/yYyiBDG3YziYaTam2aCyaUxqLE
mmglJ1+fqEYCXF6xlhfE33lh7lfIr9m+PuMbh/bcvrxzhO6OOFPrUE9ZnLzx
v116S938Zi/8k5Uei+HvPvp41zn7ENraduyNuepp7v2jPduQZurc60s0XeMu
h70DBSRT4k8H3cXn8NmFp3CF3E4FzlPQwSZcHWdHv+mJKttfkZ920D8h+EUo

                    "]], 
                    PolygonBox[{{86, 137, 47, 52}, {94, 95, 16, 2}, {68, 116, 
                    34, 35}, {75, 122, 36, 38}, {71, 89, 19, 30}, {83, 66, 24,
                     17}, {72, 64, 23, 14}, {64, 62, 20, 23}, {110, 109, 4, 
                    27}, {108, 107, 8, 20}, {85, 67, 27, 18}, {88, 93, 22, 
                    19}, {140, 106, 30, 49}, {78, 91, 21, 15}, {99, 135, 45, 
                    3}, {57, 96, 25, 16}, {61, 102, 28, 12}, {96, 58, 18, 
                    25}, {66, 79, 15, 24}, {118, 117, 3, 34}, {114, 129, 42, 
                    32}, {107, 142, 50, 8}, {111, 112, 29, 6}, {120, 121, 32, 
                    5}, {132, 131, 6, 42}, {92, 76, 39, 21}, {126, 80, 41, 
                    40}, {122, 74, 37, 36}, {103, 86, 52, 28}, {139, 63, 5, 
                    48}, {60, 136, 35, 4}, {137, 138, 48, 47}, {65, 113, 31, 
                    33}, {93, 70, 12, 22}, {69, 73, 14, 29}, {76, 115, 33, 
                    39}, {141, 124, 38, 50}, {84, 98, 26, 51}, {97, 82, 17, 
                    26}, {133, 84, 51, 44}, {123, 140, 49, 37}, {134, 133, 44,
                     45}, {127, 94, 2, 41}, {113, 125, 40, 
                    31}}]}]}, {}, {}, {}, {}}, 
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], 
                    LineBox[{148, 78, 91, 92, 76, 115, 65, 113, 125, 126, 80, 
                    127, 94, 95, 81, 143, 57, 96, 58, 144, 85, 67, 100, 110, 
                    109, 101, 60, 136, 119, 68, 116, 118, 117, 59, 99, 135, 
                    134, 133, 84, 98, 97, 82, 152, 83, 66, 79, 149, 77, 148}],
                     LineBox[{121, 114, 129, 130, 132, 131, 104, 111, 112, 
                    105, 69, 73, 147, 72, 64, 62, 146, 90, 108, 107, 142, 141,
                     124, 75, 122, 74, 123, 140, 106, 71, 89, 151, 87, 150, 
                    88, 93, 70, 145, 61, 102, 103, 86, 137, 138, 139, 63, 128,
                     120, 121}]}}], {}}, {
                  InsetBox["\<\"\[Mu] = \"\>", {-1.8, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["0.2`", {-1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {InsetBox[
                   SubscriptBox["C", "J"], {1.4, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["\<\"=\"\>", {1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["2.89`", {1.7, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {
                  {PointSize[0.05], PointBox[{-0.2, 0}]}, 
                  {PointSize[0.0125], PointBox[{0.8, 0}]}}, 
                 {PointSize[0.007], PointBox[{0.4463998339305619, 0}], 
                  PointBox[{1.2771956561278897`, 0}], 
                  PointBox[{-1.0806611991222994`, 0}], 
                  PointBox[
                   NCache[{0.3, Rational[1, 2] 3^Rational[1, 2]}, {0.3, 
                    0.8660254037844386}]], 
                  PointBox[
                   NCache[{0.3, Rational[-1, 2] 3^Rational[1, 2]}, {
                    0.3, -0.8660254037844386}]]}},
                AspectRatio->1,
                Axes->{False, False},
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                Frame->{{True, True}, {True, True}},
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLines->{None, None},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None, "TransparentPolygonMesh" -> 
                  True, "AxesInFront" -> True},
                PlotRange->{{-2, 2}, {-2, 2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.02], 
                   Scaled[0.02]}, {
                   Scaled[0.02], 
                   Scaled[0.02]}},
                Ticks->{Automatic, Automatic}], 213->
               GraphicsBox[{{GraphicsComplexBox[CompressedData["
1:eJxlVW1MW2UULh8hpGsnIibYMcQ5ZpPNbeKqRjDH2IYYhK0SFtBkXWBDy0fC
nAZCRSWtK8lM/bFcs2SCrmPOOFmXLLAoXPaGWaUMAwMcKLhCs3IphbX16uZi
CFV7ct4mhYTcPHnOx3POec/pEzVN5bXJCoXC8d///1+xX+mwy/3wQmaPacYY
Yjkqz7Jf98sGbD1SN6ATlpi7d0e2MLPAMfEWxEA8YYq/F+MB2ROejPGzcDv2
DbLR2PfGBnwLMY9HmPwJU37CitjfNZHqIXvCFI/ykT9h8k/US/iLGL4I0mDb
cDQaZoStb83dczlX4emYnZdj4k8iZsQTJt6L8YDqT9RP/c2K9dPN8xNP8yF/
0kv2FH8oVu9NjqkfFI94wjQ/6g/xex96cbtJv8x56j/xWuR5/MT6yJ8w2ZN/
Yr8SeeoP8dSfovTCPl3WHOeTg2+UaMOTG95zXkfGA1f1Ctd/aFOPSqiM8/dC
ihsaWeL+ie+7sOzZiehHQZ4v8b2P2arqRCkMRd980Gv0ToGywH22wbwE7dXd
pxrM89B8WGicOSaB9WSG0+j1wqVz6tMNgVUQvr0/oDMMw52C1PWR6giblFoM
6sUuyLbs/tvlW2EpckrAr/sRetJHnjTZljk+jxheSyo8Imt6+TxSK7tP2+Xz
oDpTdye6J8L3JRvrh3Ck6ntjro/bU/55zA/pL+/eoR8Zh1xD8gmxKMLrn25c
2K89HGHro63XdUI3o37T/uSPW/bLs2GOt3+yWKw+scrf61LFAYVQGd9HPfaT
kf7Ee/CZs8Y8czPASG8i70AeSA/Ng/LnYH6Ot6I+vt/zqIf3KwP7xT7dUtxp
L78CM/Wax4Sy+DwycB5wcFeSQdsxDRXnPJtaW8PsUk2Z1983CyXXlM9pm0KM
5tuH82Vr7btsYvEQ3P9j4SVtdJnR+8jE98HW3y2xij/5QNzmyDfZAizvYUWZ
tskHVtMzVfKbQVba/OXayE4f/OOMTEdhiccLYTwgXkYeKF4vxgOKZ8F4QPVN
YX28nlKsB6ieV7AeaLky0WU/7uP7RJj2g+ZhyXveo6uI8Hm7L159XV0rQXtH
l01MG4KPL9si/to4/zPyzPC4o01MuwWh39LkkZ1LrLNsCLThXyHQ4xbspyRG
+/Mh7g9zHXr0fWfbbcjKPGrQHoj7S+gP5L+A/lxfM+rjetpRD+TE+jMBaVf/
ivjz4+9/G75/RrwSeX4/pnHfWd3mrUflM1Mb7udBvC9AelWol+/jXbw30DKe
PqgpGQNXwDysqQ/we/ve8UyPRhlgxF9Ant/DRuT5fk7ifgLpofsL+utPmfTD
/P4Spvv6e0b/A1fSHBQN2oSGqhDbJ40WmFJ8ULp6+Wtj7gr78wdTs2j/DtYK
dSXqr4Lcfh/aA9kb0B78WxSvqhc/Z1mPrHqie8Js4B1zm1PsZK4xT7lcf5fj
C4i5vQrt+e/p2/nHNguVElD+1KJYfvYvSumkPw==
                   "], {{
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[0.3], EdgeForm[None], 
                    GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJwNw2kzAgEAAND2vu8tard7247dciQyPjgHRSKGEYmoyRFGjuQYVEjTf9ab
ed7STa4EWiyW2iA0aGgkIcI0hTkkLGaqjIxrBGSyTFCnFBJwETBPgDqD20WC
cEGkAFBuzO3BQg6MtxM/8+xH3WtEQWEYYIcYyYZZfYDPCUQNhbMCTgXwuvFh
Doj6wSGZoXQ8ECYZHYkEKT2IaAaoGCRroqrJ+KOKGUMJDfxd4TwhbC/Fr3+G
b6uqFiADGqQyiJvCbTR2feGqPqvfOXl7x3r/4G9nxJMFtpOg+2vC36bUuEEW
7zzNItpd5loj/H5aeH0J9LJSsoFMN9HLcejiynU+48ydyadTeOZQPCjDhTic
H4USR3SxgpYLcOUYLc05vjYiqRaf7gtjbfHtPTjboRd+2OVfLl6DH5789SXv
eB563AVXu9xEEtnqSdk/afJb/gddKT53
                    "]], 
                    PolygonBox[{{127, 98, 26, 40}, {109, 110, 30, 4}, {111, 
                    112, 28, 5}, {113, 67, 32, 31}, {129, 61, 10, 41}, {121, 
                    140, 46, 28}, {96, 97, 14, 6}, {119, 118, 2, 35}, {61, 89,
                     17, 10}, {62, 130, 42, 11}, {69, 105, 29, 34}, {48, 124, 
                    37, 3}, {114, 127, 40, 32}, {55, 128, 33, 8}, {103, 116, 
                    35, 27}, {123, 76, 41, 37}, {59, 103, 27, 29}, {84, 69, 
                    34, 21}, {75, 60, 24, 17}, {71, 83, 21, 15}, {68, 113, 31,
                     33}, {100, 99, 8, 20}, {65, 58, 23, 14}, {140, 57, 6, 
                    46}, {58, 54, 20, 23}, {64, 81, 19, 26}, {78, 125, 39, 
                    42}, {108, 107, 3, 30}, {60, 72, 15, 24}, {88, 49, 18, 
                    25}, {94, 62, 11, 12}, {47, 88, 25, 16}, {85, 63, 12, 
                    22}, {92, 91, 4, 18}, {86, 87, 16, 2}, {126, 52, 5, 39}, {
                    80, 85, 22, 19}}]}]}, {}, {}, {}, {}}, 
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], 
                    LineBox[{136, 71, 83, 84, 69, 105, 59, 103, 116, 117, 119,
                     118, 86, 87, 73, 131, 47, 88, 49, 132, 77, 92, 91, 101, 
                    93, 51, 109, 110, 106, 108, 107, 50, 90, 48, 124, 123, 76,
                     129, 61, 89, 74, 141, 75, 60, 72, 137, 70, 136}], 
                    LineBox[{112, 104, 121, 140, 57, 122, 95, 102, 96, 97, 66,
                     135, 65, 58, 54, 134, 82, 100, 99, 55, 128, 115, 68, 113,
                     67, 114, 127, 98, 64, 81, 139, 79, 138, 80, 85, 63, 133, 
                    53, 94, 62, 130, 78, 125, 126, 52, 56, 120, 111, 
                    112}]}}], {}}, {
                  InsetBox["\<\"\[Mu] = \"\>", {-1.8, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["0.2`", {-1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {InsetBox[
                   SubscriptBox["C", "J"], {1.4, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["\<\"=\"\>", {1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["2.88`", {1.7, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {
                  {PointSize[0.05], PointBox[{-0.2, 0}]}, 
                  {PointSize[0.0125], PointBox[{0.8, 0}]}}, 
                 {PointSize[0.007], PointBox[{0.4463998339305619, 0}], 
                  PointBox[{1.2771956561278897`, 0}], 
                  PointBox[{-1.0806611991222994`, 0}], 
                  PointBox[
                   NCache[{0.3, Rational[1, 2] 3^Rational[1, 2]}, {0.3, 
                    0.8660254037844386}]], 
                  PointBox[
                   NCache[{0.3, Rational[-1, 2] 3^Rational[1, 2]}, {
                    0.3, -0.8660254037844386}]]}},
                AspectRatio->1,
                Axes->{False, False},
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                Frame->{{True, True}, {True, True}},
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLines->{None, None},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None, "TransparentPolygonMesh" -> 
                  True, "AxesInFront" -> True},
                PlotRange->{{-2, 2}, {-2, 2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.02], 
                   Scaled[0.02]}, {
                   Scaled[0.02], 
                   Scaled[0.02]}},
                Ticks->{Automatic, Automatic}], 214->
               GraphicsBox[{{GraphicsComplexBox[CompressedData["
1:eJxlVG1sU2UUHizyMRYhRXRcFwOJzCJB6o8RPiYHvcNMfmCdfETCasDMOEtg
QQyW7IfAbJQEP0i3GDRAgxuzkU4aPpJ28LJ00m0EGGNzZnNsM4vd1nV3uUgi
Rp1yT56z5O7Hzc2T57znPOdz8a69xaXTMzIyKv7/Hv0bolnH/GaUVjl+8HS5
x1RudvPwYH6HYPAuxgQeuN3iu6nX+o+oG9a/VTDs7XwnY3kPDHvgk9Y/RIff
7XkQDo4KPspYAUMvMPQhHvgnLP9N9PuVisTEhCF6YA/+HvOE/GF/4J2yWH6g
S+LD3o6hF/Z2jHjwj/fAiI/6HLbeJSW+a+6aZz36sGq8kJcT6GoTLP2x8U7G
4u8g+xM94Jdbuu4JBo/64b09X/QX+pEveHu/wUMf/KEfwOVW/ARdmPdBo9aa
knygB3qRb56Fb9HOBv153ZcWfbCHP/AVq1ZW+s0+qS8w6oN6bv5t3b/hgUlc
frEwpm00KDX21Tmv80eKLPsmqoUMlXPqp7va+3coWnSurOGSoSoTJQX66rt0
65NnjvsdQyrzanZz/u5+0rcfmROYSKqcxO2bWmsTbd5Kp/2OcfXz6I3K4N9n
KezbVuPeN6o21e9cqj/sJS1/Zc/gh6NqrOBrjxm9TqVP7zkUHBwWXMKY4M/N
/mS+ihLmga6McbU8N3eJJ/7LlH46v4hWeevSqmND7f3wwJUp/XzoaF7rXJEi
8Ogn/NnvwSL2R8inlvOh7em37rd4L9GhjvWLPEdStCf2qA/HaF1mZrHZnRb+
M+YV+FeZVzVv95zx1nXSP7GLMS3LUKh/iOtP4B8wL/7t9yHy3NzXTb8h/qEf
fIh5uR9/zq5eGJg5rua9ce2x+mBc+gX+D+YJPOqPeYjwPFB/X7DMPNhGu99c
Mx6+Y9C+rC9X6L7J+wJ+P/Oyzx/xvKnQ2Q1/hRd303efvlblHUqruEvbYmoN
dPL77BmBp1KCqxkT7L9le9nniFHvNk9M3p9p863+Sr8LeV5EH+4R8q0+f/xJ
X8mwii4Ivayv7pd5cb7UV+U3O2WfMA+uEjJb5iTFHvOD+XbwfNNl36kab10H
ubUtC303k2rW+hfy9Jbb1FYYGRhsGZJ67OB9lPp/znoI+3ad943wvpnfE/Rh
v2X+WZ/EL+L4hH1dy/tKrmVNm5x7++mVF+vi2tERqWeU66muzd5fbJ7onXIf
yyPtHwcLRgS/x5hgb7+HjaUqxxM3FOJt5Hiqff6sWvfjv9K0yyNh94yk+g/+
Qik9
                   "], {{
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[0.3], EdgeForm[None], 
                    GraphicsGroupBox[{
                    PolygonBox[{{41, 7, 6}, {48, 42, 21}, {45, 27, 5}, {12, 
                    13, 1}, {23, 10, 9}, {31, 10, 8}, {28, 7, 5}, {47, 16, 
                    15}, {20, 7, 2}, {46, 44, 41}, {25, 12, 1}, {30, 29, 7}, {
                    17, 8, 4}, {14, 11, 3}, {18, 26, 3}, {10, 23, 4}, {35, 20,
                     2}, {47, 21, 1}, {7, 20, 5}, {22, 17, 3}, {17, 18, 3}, {
                    19, 16, 1}, {43, 37, 21}, {23, 24, 4}, {40, 23, 9}, {38, 
                    22, 3}, {17, 22, 8}, {21, 25, 1}, {42, 43, 21}, {33, 32, 
                    9}, {71, 72, 11}, {10, 33, 9}, {20, 36, 5}, {22, 39, 8}, {
                    32, 34, 9}, {42, 46, 41}, {7, 41, 2}, {43, 42, 6}, {46, 
                    42, 15}, {11, 38, 3}, {37, 43, 6}, {41, 44, 2}, {42, 41, 
                    6}, {8, 10, 4}, {44, 46, 15}, {7, 29, 6}, {100, 60, 6}, {
                    28, 30, 7}, {27, 28, 5}, {112, 113, 32}, {42, 48, 15}, {
                    47, 48, 21}, {48, 47, 15}, {124, 103, 27}, {16, 47, 1}, {
                    88, 85, 17}, {65, 118, 36}, {58, 75, 12}, {123, 56, 45}, {
                    68, 120, 39}, {69, 96, 24}, {62, 86, 18}, {73, 71, 11}, {
                    98, 99, 26}, {104, 105, 9}, {117, 64, 35}, {79, 80, 13}, {
                    119, 66, 37}, {74, 58, 12}, {54, 91, 2}, {84, 57, 16}, {
                    82, 81, 14}, {78, 52, 4}, {89, 63, 19}, {91, 76, 2}, {83, 
                    90, 15}, {121, 70, 40}, {49, 124, 27}, {52, 87, 4}, {115, 
                    116, 34}, {111, 110, 31}, {113, 50, 32}, {103, 102, 27}, {
                    61, 109, 8}, {55, 107, 29}, {59, 101, 5}}], 
                    PolygonBox[{{105, 121, 40, 9}, {97, 74, 12, 25}, {64, 92, 
                    20, 35}, {96, 78, 4, 24}, {109, 111, 31, 8}, {77, 82, 14, 
                    3}, {102, 106, 28, 27}, {87, 88, 17, 4}, {80, 53, 1, 
                    13}, {108, 55, 29, 30}, {90, 122, 44, 15}, {101, 123, 45, 
                    5}, {75, 79, 13, 12}, {85, 62, 18, 17}, {106, 108, 30, 
                    28}, {95, 69, 24, 23}, {66, 93, 21, 37}, {120, 61, 8, 
                    39}, {56, 49, 27, 45}, {94, 68, 39, 22}, {51, 114, 33, 
                    10}, {116, 104, 9, 34}, {114, 112, 32, 33}, {118, 59, 5, 
                    36}, {72, 67, 38, 11}, {50, 115, 34, 32}, {99, 77, 3, 
                    26}, {122, 54, 2, 44}, {92, 65, 36, 20}, {86, 98, 26, 
                    18}, {93, 97, 25, 21}, {57, 83, 15, 16}, {76, 117, 35, 
                    2}, {63, 84, 16, 19}, {70, 95, 23, 40}, {67, 94, 22, 
                    38}, {81, 73, 11, 14}, {110, 51, 10, 31}, {107, 100, 6, 
                    29}, {53, 89, 19, 1}, {60, 119, 37, 
                    6}}]}]}, {}, {}, {}, {}}, 
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], 
                    LineBox[{57, 83, 90, 122, 54, 91, 76, 117, 64, 92, 65, 
                    118, 59, 101, 123, 56, 49, 124, 103, 102, 106, 108, 55, 
                    107, 100, 60, 119, 66, 93, 97, 74, 58, 75, 79, 80, 53, 89,
                     63, 84, 57}], 
                    LineBox[{112, 113, 50, 115, 116, 104, 105, 121, 70, 95, 
                    69, 96, 78, 52, 87, 88, 85, 62, 86, 98, 99, 77, 82, 81, 
                    73, 71, 72, 67, 94, 68, 120, 61, 109, 111, 110, 51, 114, 
                    112}]}}], {}}, {
                  InsetBox["\<\"\[Mu] = \"\>", {-1.8, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["0.2`", {-1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {InsetBox[
                   SubscriptBox["C", "J"], {1.4, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["\<\"=\"\>", {1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["2.87`", {1.7, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {
                  {PointSize[0.05], PointBox[{-0.2, 0}]}, 
                  {PointSize[0.0125], PointBox[{0.8, 0}]}}, 
                 {PointSize[0.007], PointBox[{0.4463998339305619, 0}], 
                  PointBox[{1.2771956561278897`, 0}], 
                  PointBox[{-1.0806611991222994`, 0}], 
                  PointBox[
                   NCache[{0.3, Rational[1, 2] 3^Rational[1, 2]}, {0.3, 
                    0.8660254037844386}]], 
                  PointBox[
                   NCache[{0.3, Rational[-1, 2] 3^Rational[1, 2]}, {
                    0.3, -0.8660254037844386}]]}},
                AspectRatio->1,
                Axes->{False, False},
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                Frame->{{True, True}, {True, True}},
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLines->{None, None},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None, "TransparentPolygonMesh" -> 
                  True, "AxesInFront" -> True},
                PlotRange->{{-2, 2}, {-2, 2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.02], 
                   Scaled[0.02]}, {
                   Scaled[0.02], 
                   Scaled[0.02]}},
                Ticks->{Automatic, Automatic}], 215->
               GraphicsBox[{{GraphicsComplexBox[CompressedData["
1:eJxlVGtIk1EYHgZR3hIZIbOEQa5RakJ9VP55k6/SwHJ0+6EyNC8YUmpF4Y8u
FI4IlcjZvWjRjZzzx0RzLU/m0mklI5Wlm+uHlru6+rxkMlq203sE/fHx8fA8
57zv+5znHOmx8oPFYSKR6PjC9+9vNITXqgQD7IjVKq2KSbIu0uwa5wYZRj6V
YkAe8ecQPwKjob+bfAj9+xhG/VJ+iGK2HjHqEaMe+0GM9c8VHn/Nqa1wrcQ2
o9N4iTi03rQMX6aY6RHjfKhHPnVN2gYl7yKdLbI4tdXCMJt/CS+nmO2PODnU
p4NhnBfrYX3sB3nEuD/qcX7EFaF6PdASc7pT0udh/aBfWB/7lYVwPxQY+U18
lY/5g3rcD/nrs032YFDPeMRL82BYGRZXVetkfr5RiRWCsMjnHnAE628t4JOz
6fLmNvh4L1rOt0+SSXFdkZAzAJaofRpFxyQZyK/2j89YQNZ+7RW3zUWunqyu
L3M6IKzg02r1Lyc50/g5RcnrISPm20Ehxwf71/ccEkbsIPGWVhi/e0h0TWau
cNcMKVvuXtLkuRmWUcz8ndZHJCi7Fv13zq1Ik29Z9N9LecB62bQe2Vq2tl/y
eBBM6QMKQbVwX/7PY6LzAPJGyrP8XrjT3sQd9pPRyPFuTtwJcR1df+q3+8ns
jYw+SV83JNvzsoUcPzvfs1QPqI+hekB9ItUD+mem/sG8NrKZU/eDsS5pI7/T
z87jPT0PgryJ8izPhfR8iKFzdUAnHQZtw+abZaU+0vo7YZuSfwtT0srMqKce
hj0UA+qfUD28DNcPB5uHlt3PhieDjxUOH+vnB/WbvE5+IamKaluW70D0lLc3
wk0sNcXxSt7B3g88H2W83cCNTzAe3wvMQyzNAwRETdO9jUMgjNp2ybOdxBxf
18odHoFV+ucy5dgEiT115azVYoEvJ0oHgrB4v9/RPLN+pmk/gPlMoPkEXG+h
61l+jtL+WH03rQ9YX0TrA+Z7Pj+UbziSWPlTJ/0Kxtv3fb2NLijJqk7mNTbY
rX0WofZMMH/xPqK/D6i/JD9/rtCqsDE/9ySVnzeqTMw/vO9jDy9e1ATczH98
b1CPfqLeRvWA+6N+w15vhjzbBAW99UXWOTd7f1Y82qTjxH6C85joPATnyaLz
sH7wfvwFkK6S1A==
                   "], {{
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[0.3], EdgeForm[None], 
                    GraphicsGroupBox[{
                    PolygonBox[{{27, 7, 6}, {25, 15, 3}, {28, 27, 6}, {33, 14,
                     1}, {15, 12, 3}, {16, 10, 9}, {10, 22, 9}, {21, 10, 8}, {
                    18, 7, 5}, {13, 24, 5}, {7, 27, 2}, {18, 20, 7}, {51, 35, 
                    1}, {33, 34, 14}, {53, 36, 3}, {34, 28, 14}, {26, 16, 
                    9}, {12, 15, 8}, {10, 16, 4}, {7, 19, 6}, {14, 17, 1}, {
                    20, 19, 7}, {13, 7, 2}, {32, 30, 27}, {30, 32, 11}, {28, 
                    32, 27}, {48, 94, 24}, {62, 58, 12}, {27, 30, 2}, {28, 34,
                     11}, {34, 33, 11}, {74, 46, 6}, {57, 55, 11}, {91, 89, 
                    23}, {40, 63, 1}, {93, 66, 13}, {7, 13, 5}, {12, 8, 4}, {
                    8, 10, 4}, {72, 73, 17}, {29, 28, 6}, {28, 29, 14}, {32, 
                    28, 11}, {96, 67, 14}, {77, 78, 9}, {87, 88, 22}, {52, 92,
                     2}, {43, 104, 31}, {89, 90, 23}, {38, 53, 3}, {68, 99, 
                    15}, {97, 49, 25}, {98, 47, 8}, {80, 79, 18}, {54, 39, 
                    4}, {39, 61, 4}, {59, 38, 3}, {55, 64, 11}, {42, 81, 
                    19}, {100, 50, 26}, {103, 43, 31}, {35, 40, 1}, {70, 54, 
                    4}, {47, 83, 8}, {85, 84, 21}, {46, 95, 6}, {65, 52, 2}, {
                    58, 60, 12}, {69, 71, 16}, {63, 56, 1}, {45, 75, 5}, {41, 
                    65, 2}, {36, 44, 3}}], 
                    PolygonBox[{{84, 37, 10, 21}, {99, 98, 8, 15}, {88, 86, 9,
                     22}, {83, 85, 21, 8}, {76, 80, 18, 5}, {50, 69, 16, 
                    26}, {86, 91, 23, 9}, {71, 70, 4, 16}, {73, 51, 1, 17}, {
                    67, 72, 17, 14}, {104, 76, 5, 31}, {44, 97, 25, 3}, {60, 
                    59, 3, 12}, {75, 103, 31, 5}, {92, 93, 13, 2}, {90, 77, 9,
                     23}, {81, 74, 6, 19}, {82, 42, 19, 20}, {79, 82, 20, 
                    18}, {66, 48, 24, 13}, {101, 96, 14, 29}, {102, 41, 2, 
                    30}, {94, 45, 5, 24}, {64, 102, 30, 11}, {56, 105, 33, 
                    1}, {49, 68, 15, 25}, {37, 87, 22, 10}, {78, 100, 26, 
                    9}, {95, 101, 29, 6}, {61, 62, 12, 4}, {105, 57, 11, 
                    33}}]}]}, {}, {}, {}, {}}, 
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], 
                    LineBox[{57, 55, 64, 102, 41, 65, 52, 92, 93, 66, 48, 94, 
                    45, 75, 103, 43, 104, 76, 80, 79, 82, 42, 81, 74, 46, 95, 
                    101, 96, 67, 72, 73, 51, 35, 40, 63, 56, 105, 57}], 
                    LineBox[{50, 69, 71, 70, 54, 39, 61, 62, 58, 60, 59, 38, 
                    53, 36, 44, 97, 49, 68, 99, 98, 47, 83, 85, 84, 37, 87, 
                    88, 86, 91, 89, 90, 77, 78, 100, 50}]}}], {}}, {
                  InsetBox["\<\"\[Mu] = \"\>", {-1.8, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["0.2`", {-1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {InsetBox[
                   SubscriptBox["C", "J"], {1.4, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["\<\"=\"\>", {1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["2.86`", {1.7, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {
                  {PointSize[0.05], PointBox[{-0.2, 0}]}, 
                  {PointSize[0.0125], PointBox[{0.8, 0}]}}, 
                 {PointSize[0.007], PointBox[{0.4463998339305619, 0}], 
                  PointBox[{1.2771956561278897`, 0}], 
                  PointBox[{-1.0806611991222994`, 0}], 
                  PointBox[
                   NCache[{0.3, Rational[1, 2] 3^Rational[1, 2]}, {0.3, 
                    0.8660254037844386}]], 
                  PointBox[
                   NCache[{0.3, Rational[-1, 2] 3^Rational[1, 2]}, {
                    0.3, -0.8660254037844386}]]}},
                AspectRatio->1,
                Axes->{False, False},
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                Frame->{{True, True}, {True, True}},
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLines->{None, None},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None, "TransparentPolygonMesh" -> 
                  True, "AxesInFront" -> True},
                PlotRange->{{-2, 2}, {-2, 2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.02], 
                   Scaled[0.02]}, {
                   Scaled[0.02], 
                   Scaled[0.02]}},
                Ticks->{Automatic, Automatic}], 216->
               
               GraphicsBox[{{{}, {}}, {
                  InsetBox["\<\"\[Mu] = \"\>", {-1.8, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["0.2`", {-1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {InsetBox[
                   SubscriptBox["C", "J"], {1.4, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["\<\"=\"\>", {1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["2.85`", {1.7, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {
                  {PointSize[0.05], PointBox[{-0.2, 0}]}, 
                  {PointSize[0.0125], PointBox[{0.8, 0}]}}, 
                 {PointSize[0.007], PointBox[{0.4463998339305619, 0}], 
                  PointBox[{1.2771956561278897`, 0}], 
                  PointBox[{-1.0806611991222994`, 0}], 
                  PointBox[
                   NCache[{0.3, Rational[1, 2] 3^Rational[1, 2]}, {0.3, 
                    0.8660254037844386}]], 
                  PointBox[
                   NCache[{0.3, Rational[-1, 2] 3^Rational[1, 2]}, {
                    0.3, -0.8660254037844386}]]}},
                AspectRatio->1,
                Axes->{False, False},
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                Frame->{{True, True}, {True, True}},
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLines->{None, None},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None, "TransparentPolygonMesh" -> 
                  True, "AxesInFront" -> True},
                PlotRange->{{-2, 2}, {-2, 2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.02], 
                   Scaled[0.02]}, {
                   Scaled[0.02], 
                   Scaled[0.02]}},
                Ticks->{Automatic, Automatic}], 217->
               
               GraphicsBox[{{{}, {}}, {
                  InsetBox["\<\"\[Mu] = \"\>", {-1.8, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["0.2`", {-1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {InsetBox[
                   SubscriptBox["C", "J"], {1.4, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["\<\"=\"\>", {1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["2.84`", {1.7, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {
                  {PointSize[0.05], PointBox[{-0.2, 0}]}, 
                  {PointSize[0.0125], PointBox[{0.8, 0}]}}, 
                 {PointSize[0.007], PointBox[{0.4463998339305619, 0}], 
                  PointBox[{1.2771956561278897`, 0}], 
                  PointBox[{-1.0806611991222994`, 0}], 
                  PointBox[
                   NCache[{0.3, Rational[1, 2] 3^Rational[1, 2]}, {0.3, 
                    0.8660254037844386}]], 
                  PointBox[
                   NCache[{0.3, Rational[-1, 2] 3^Rational[1, 2]}, {
                    0.3, -0.8660254037844386}]]}},
                AspectRatio->1,
                Axes->{False, False},
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                Frame->{{True, True}, {True, True}},
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLines->{None, None},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None, "TransparentPolygonMesh" -> 
                  True, "AxesInFront" -> True},
                PlotRange->{{-2, 2}, {-2, 2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.02], 
                   Scaled[0.02]}, {
                   Scaled[0.02], 
                   Scaled[0.02]}},
                Ticks->{Automatic, Automatic}], 218->
               
               GraphicsBox[{{{}, {}}, {
                  InsetBox["\<\"\[Mu] = \"\>", {-1.8, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["0.2`", {-1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {InsetBox[
                   SubscriptBox["C", "J"], {1.4, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["\<\"=\"\>", {1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["2.83`", {1.7, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {
                  {PointSize[0.05], PointBox[{-0.2, 0}]}, 
                  {PointSize[0.0125], PointBox[{0.8, 0}]}}, 
                 {PointSize[0.007], PointBox[{0.4463998339305619, 0}], 
                  PointBox[{1.2771956561278897`, 0}], 
                  PointBox[{-1.0806611991222994`, 0}], 
                  PointBox[
                   NCache[{0.3, Rational[1, 2] 3^Rational[1, 2]}, {0.3, 
                    0.8660254037844386}]], 
                  PointBox[
                   NCache[{0.3, Rational[-1, 2] 3^Rational[1, 2]}, {
                    0.3, -0.8660254037844386}]]}},
                AspectRatio->1,
                Axes->{False, False},
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                Frame->{{True, True}, {True, True}},
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLines->{None, None},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None, "TransparentPolygonMesh" -> 
                  True, "AxesInFront" -> True},
                PlotRange->{{-2, 2}, {-2, 2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.02], 
                   Scaled[0.02]}, {
                   Scaled[0.02], 
                   Scaled[0.02]}},
                Ticks->{Automatic, Automatic}], 219->
               
               GraphicsBox[{{{}, {}}, {
                  InsetBox["\<\"\[Mu] = \"\>", {-1.8, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["0.2`", {-1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {InsetBox[
                   SubscriptBox["C", "J"], {1.4, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["\<\"=\"\>", {1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["2.82`", {1.7, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {
                  {PointSize[0.05], PointBox[{-0.2, 0}]}, 
                  {PointSize[0.0125], PointBox[{0.8, 0}]}}, 
                 {PointSize[0.007], PointBox[{0.4463998339305619, 0}], 
                  PointBox[{1.2771956561278897`, 0}], 
                  PointBox[{-1.0806611991222994`, 0}], 
                  PointBox[
                   NCache[{0.3, Rational[1, 2] 3^Rational[1, 2]}, {0.3, 
                    0.8660254037844386}]], 
                  PointBox[
                   NCache[{0.3, Rational[-1, 2] 3^Rational[1, 2]}, {
                    0.3, -0.8660254037844386}]]}},
                AspectRatio->1,
                Axes->{False, False},
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                Frame->{{True, True}, {True, True}},
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLines->{None, None},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None, "TransparentPolygonMesh" -> 
                  True, "AxesInFront" -> True},
                PlotRange->{{-2, 2}, {-2, 2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.02], 
                   Scaled[0.02]}, {
                   Scaled[0.02], 
                   Scaled[0.02]}},
                Ticks->{Automatic, Automatic}], 220->
               
               GraphicsBox[{{{}, {}}, {
                  InsetBox["\<\"\[Mu] = \"\>", {-1.8, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["0.2`", {-1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {InsetBox[
                   SubscriptBox["C", "J"], {1.4, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["\<\"=\"\>", {1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["2.81`", {1.7, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {
                  {PointSize[0.05], PointBox[{-0.2, 0}]}, 
                  {PointSize[0.0125], PointBox[{0.8, 0}]}}, 
                 {PointSize[0.007], PointBox[{0.4463998339305619, 0}], 
                  PointBox[{1.2771956561278897`, 0}], 
                  PointBox[{-1.0806611991222994`, 0}], 
                  PointBox[
                   NCache[{0.3, Rational[1, 2] 3^Rational[1, 2]}, {0.3, 
                    0.8660254037844386}]], 
                  PointBox[
                   NCache[{0.3, Rational[-1, 2] 3^Rational[1, 2]}, {
                    0.3, -0.8660254037844386}]]}},
                AspectRatio->1,
                Axes->{False, False},
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                Frame->{{True, True}, {True, True}},
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLines->{None, None},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None, "TransparentPolygonMesh" -> 
                  True, "AxesInFront" -> True},
                PlotRange->{{-2, 2}, {-2, 2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.02], 
                   Scaled[0.02]}, {
                   Scaled[0.02], 
                   Scaled[0.02]}},
                Ticks->{Automatic, Automatic}], 221->
               
               GraphicsBox[{{{}, {}}, {
                  InsetBox["\<\"\[Mu] = \"\>", {-1.8, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["0.2`", {-1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {InsetBox[
                   SubscriptBox["C", "J"], {1.4, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["\<\"=\"\>", {1.6, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["2.8`", {1.7, 1.8}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], 
                    ImageScaled[{0, 0.5}]]]}, {
                  {PointSize[0.05], PointBox[{-0.2, 0}]}, 
                  {PointSize[0.0125], PointBox[{0.8, 0}]}}, 
                 {PointSize[0.007], PointBox[{0.4463998339305619, 0}], 
                  PointBox[{1.2771956561278897`, 0}], 
                  PointBox[{-1.0806611991222994`, 0}], 
                  PointBox[
                   NCache[{0.3, Rational[1, 2] 3^Rational[1, 2]}, {0.3, 
                    0.8660254037844386}]], 
                  PointBox[
                   NCache[{0.3, Rational[-1, 2] 3^Rational[1, 2]}, {
                    0.3, -0.8660254037844386}]]}},
                AspectRatio->1,
                Axes->{False, False},
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                Frame->{{True, True}, {True, True}},
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLines->{None, None},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None, "TransparentPolygonMesh" -> 
                  True, "AxesInFront" -> True},
                PlotRange->{{-2, 2}, {-2, 2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.02], 
                   Scaled[0.02]}, {
                   Scaled[0.02], 
                   Scaled[0.02]}},
                Ticks->{Automatic, Automatic}]}, Dynamic[$CellContext`i895$$],
               
               Alignment->Automatic,
               BaseStyle->"ListAnimateCore",
               ImageSize->All,
               TransitionDirection->Horizontal,
               TransitionDuration->0.5,
               TransitionEffect->Automatic],
              Identity,
              Editable->True,
              Selectable->True],
             ImageMargins->10],
            Deployed->False,
            StripOnInput->False,
            ScriptLevel->0,
            GraphicsBoxOptions->{PreserveImageOptions->True},
            Graphics3DBoxOptions->{PreserveImageOptions->True}],
           Identity,
           Editable->False,
           Selectable->False],
          Alignment->{Left, Center},
          Background->GrayLevel[1],
          Frame->1,
          FrameStyle->GrayLevel[0, 0.2],
          ItemSize->Automatic,
          StripOnInput->False]}
       },
       AutoDelete->False,
       GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Top}}},
       GridBoxDividers->{"Columns" -> {{False}}, "Rows" -> {{False}}},
       GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
       
       GridBoxSpacings->{"Columns" -> {
           Offset[0.7], {
            Offset[0.5599999999999999]}, 
           Offset[0.7]}, "Rows" -> {
           Offset[0.4], {
            Offset[0.8]}, 
           Offset[0.4]}}],
      DefaultBaseStyle->{},
      FrameMargins->{{5, 5}, {5, 5}}],
     BaselinePosition->Automatic,
     ImageMargins->0],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    SynchronousInitialization->True,
    UndoTrackedVariables:>{Typeset`show$$, Typeset`bookmarkMode$$},
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "ListAnimate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellChangeTimes->{{3.853509262284336*^9, 3.8535092900396767`*^9}, {
   3.853509336810869*^9, 3.853509355481805*^9}, 3.8535093869977407`*^9, 
   3.853522380356346*^9, 3.853655886503827*^9, 3.853655971295321*^9, 
   3.8536560206423388`*^9, 3.853656054223008*^9, 3.853656102770506*^9, 
   3.853656516800475*^9, 3.8536567081799307`*^9, 3.853657605901196*^9, 
   3.853657773749321*^9, {3.853657865357464*^9, 3.853657892698367*^9}, 
   3.853659262673709*^9, 3.8536592991262817`*^9, 3.853659382806651*^9, {
   3.853659985988247*^9, 3.853659998731196*^9}, 3.8536600312564077`*^9, 
   3.853660092324524*^9, 3.853661296491994*^9, 3.853661437605319*^9, 
   3.853662119277986*^9, 3.853665024851183*^9, 3.890915203979096*^9},
 CellLabel->"Out[5]=",ExpressionUUID->"cb3401c3-e229-435b-be2c-e168828401f3"]
}, Open  ]],

Cell["Now generate and the plot for Fig.3.2a.", "Text",
 CellFrame->True,
 CellChangeTimes->{{3.85262176468622*^9, 3.8526217661887817`*^9}, {
  3.853052679072712*^9, 3.853052704798706*^9}, {3.853052739710747*^9, 
  3.8530527427191877`*^9}, {3.8530528820446367`*^9, 3.853052888291986*^9}, {
  3.853055142588128*^9, 3.853055147300077*^9}, {3.85350507280801*^9, 
  3.8535052184222*^9}, {3.853661821516285*^9, 3.853661934631201*^9}, {
  3.853661965040538*^9, 3.853661968528668*^9}, {3.853662178057679*^9, 
  3.853662182259986*^9}, {3.853662278482994*^9, 3.8536623009341516`*^9}, {
  3.853663168966022*^9, 3.853663270909032*^9}, {3.853663327908791*^9, 
  3.853663356156335*^9}, {3.8536634214515543`*^9, 3.853663539018478*^9}, {
  3.8536636280261993`*^9, 3.8536637410405416`*^9}, {3.853664484906479*^9, 
  3.853664603898616*^9}, {3.853664674731799*^9, 3.853664803240361*^9}, {
  3.85366489150301*^9, 3.85366492231796*^9}},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"0ce94a10-0aec-4123-87f6-3ec62225a8c2"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"CJzv", "[", 
  RowBox[{"0.2", ",", "3.9", ",", "False"}], "]"}]], "Input",
 CellChangeTimes->{{3.853508849286537*^9, 3.85350887184579*^9}, {
  3.8535089295419197`*^9, 3.8535089358995333`*^9}, {3.853522419774879*^9, 
  3.853522420494005*^9}, {3.853661419786763*^9, 3.853661421302827*^9}},
 CellLabel->"In[6]:=",ExpressionUUID->"66966bf6-024b-4dd0-8251-823144798b9e"],

Cell[BoxData[
 GraphicsBox[{{GraphicsComplexBox[CompressedData["
1:eJx1Wnl8zFf3tjWWmlS9ahmaoqRjK9WMWtoeNbU0qEEUKUNrKUbLa0k7qL2j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     "], {{
       {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], 
        Opacity[0.3], EdgeForm[None], 
        GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxNmgn411P2x++9H7vKksk2KFJZUkQqSqWQFEpZopKyFBUyRUhCKkQjW7Jm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           "]], PolygonBox[CompressedData["
1:eJwtl3m0TmUYxc9532uKkjljXUOEpMxTmSNCVzJFLkKmmyGVDKUQpULTakZF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           "]]}]}, {}, {}, {}, {}}, 
      {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], 
       LineBox[CompressedData["
1:eJwl1FVsVFEUBdChxd2Da3ES3N3d3aG480WCu0NxtwR3+CTBXX5wJ7i7u60b
Plb32WfedGbe3DZ37NCWQ+JFIpFCflSLjkTaRkUiK0hGVf2dfM85aug1aWf+
QHbOU8uuNu3NH8nBBerYJZd15Xq5gQ700e94vY3me/Kb/M5XctGN+a7pKjeT
m+70tbvv+i3mh7K/3tOcl14M0B/ZbzM/kYP0vuZ89GOw/tR+h/mFHKYPMO9i
JwOZajdIFuIil7jMS9f/koW5wlVS884+ueek4IZ+k7ThPthns8vO3fA5Sc8X
+7x2MeG96o/JyE/7AnYFeR7eX3hN/toXC/fd/IrX4T0yx26KPMThcK8ZH74H
mYl4jNRnhftPAybo9WVmohilz5MNacJEvbHMQjSj9cWyKSdIyDi75rKkfCtL
yOL0JpuegLHm5fIsZ0hKZbsqVKS1XkkmkRVkK1lOtpTlZWJZVraQpWQZSpNI
P8VploXv3G6pPElPc1YZK9/IZixhjB5fHqcRi5hnt1AeC+csXKcvkPWYG+hx
8iizWazPCeecmcTpM+QRpoXfqU+XBzlAhBF2k2XVcJbCZw9nR3akA/v0/eGe
M1z/5XveG/4GZAb5gPvk9FgOPtmn029zi1R2KXlvn0a/zrVwXvgTzop9SlmE
3xRlD7vD5wzngJ/mgvygAP0ZGs6f56YwryU/Q+ye2W0392aK3keuIYaB+mOP
bzX3YLIeK1eTh376A49vMndmkt5FrmQVHekUPiuf+MJn7nrOOlnd9W2i/v9/
+gcga5YY
        "]], 
       LineBox[{851, 847, 849, 848, 718, 501, 716, 715, 717, 634, 854, 856, 
        855, 568, 641, 915, 640, 805, 571, 739, 806, 572, 885, 506, 695, 569, 
        694, 635, 907, 636, 734, 733, 566, 633, 906, 632, 692, 565, 691, 630, 
        905, 631, 564, 794, 563, 795, 498, 882, 629, 672, 850, 851}], 
       LineBox[CompressedData["
1:eJwl0DszQ0EYBuBNDolQEIlbJ1oSoTGjEaVLFIbKJeglQmaSBoWCQuUf+AnM
KPhBaNBSyHjOKJ553293Z8/sKRw1NuuJEEKNhWQI55xFIXxbfNZ/Zdt8pS/x
yo55l332mGaGN3s1OSYP5CFFKuZ3Svqy7Miue1/0C27Nl/KeRVrmH/tP+rY+
zgQj8d2MssGj/TW5ziotc1XOx2/gRj+VD5xwZ27KOfr1shyQX77VJzP0kibF
p/WELDkX4rfIOtf6sRzkw5mmuaHPktR7iFghyzBD5MmxRYEpJqP///4HaOgk
Wg==
        "]]}}], {}}, {
    InsetBox["\<\"\[Mu] = \"\>", {-1.8, 1.8}, NCache[
     ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
    InsetBox["0.2`", {-1.6, 1.8}, NCache[
     ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]]}, {InsetBox[
     SubscriptBox["C", "J"], {1.4, 1.8}, NCache[
     ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
    InsetBox["\<\"=\"\>", {1.6, 1.8}, NCache[
     ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
    InsetBox["3.9`", {1.7, 1.8}, NCache[
     ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]]}, {
    {PointSize[0.05], PointBox[{-0.2, 0}]}, 
    {PointSize[0.0125], PointBox[{0.8, 0}]}}},
  AspectRatio->1,
  Axes->{False, False},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{True, True}, {True, True}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  Method->{
   "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "ScalingFunctions" -> 
    None, "TransparentPolygonMesh" -> True, "AxesInFront" -> True},
  PlotRange->{{-2, 2}, {-2, 2}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.02], 
     Scaled[0.02]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{
  3.8535089369608107`*^9, 3.8535223823384447`*^9, 3.853522421165449*^9, 
   3.8536614553431063`*^9, 3.853662121509818*^9, {3.853664348984117*^9, 
   3.853664361613908*^9}, 3.853665027134296*^9, 3.8909152067848*^9},
 CellLabel->"Out[6]=",ExpressionUUID->"fc7cc044-0de5-441f-9dc1-6df14083c29f"]
}, Open  ]],

Cell["Now generate and the plot for Fig.3.2b.", "Text",
 CellFrame->True,
 CellChangeTimes->{{3.85262176468622*^9, 3.8526217661887817`*^9}, {
  3.853052679072712*^9, 3.853052704798706*^9}, {3.853052739710747*^9, 
  3.8530527427191877`*^9}, {3.8530528820446367`*^9, 3.853052888291986*^9}, {
  3.853055142588128*^9, 3.853055147300077*^9}, {3.85350507280801*^9, 
  3.8535052184222*^9}, {3.853661821516285*^9, 3.853661934631201*^9}, {
  3.853661965040538*^9, 3.853661968528668*^9}, {3.853662178057679*^9, 
  3.853662182259986*^9}, {3.853662278482994*^9, 3.8536623009341516`*^9}, {
  3.853663168966022*^9, 3.853663270909032*^9}, {3.853663327908791*^9, 
  3.853663356156335*^9}, {3.8536634214515543`*^9, 3.853663539018478*^9}, {
  3.8536636280261993`*^9, 3.8536637410405416`*^9}, {3.853664484906479*^9, 
  3.853664603898616*^9}, {3.853664674731799*^9, 3.853664803240361*^9}, {
  3.85366489150301*^9, 3.853664937405468*^9}},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"205ab852-4340-4991-9511-740d2720b898"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"CJzv", "[", 
  RowBox[{"0.2", ",", "3.7", ",", "False"}], "]"}]], "Input",
 CellChangeTimes->{{3.853508849286537*^9, 3.85350887184579*^9}, {
  3.8535089295419197`*^9, 3.8535089358995333`*^9}, {3.853522419774879*^9, 
  3.8535224285267076`*^9}, {3.853661426461885*^9, 3.853661428286519*^9}},
 CellLabel->"In[7]:=",ExpressionUUID->"f3cd2f6d-3749-4b94-8768-21d4ccfae98d"],

Cell[BoxData[
 GraphicsBox[{{GraphicsComplexBox[CompressedData["
1:eJx1Wnt4zEf3j8tDG120FA3VUo2Ie3S1WpywquqWbWgRrMrbKKKo1iWaF0WW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     "], {{
       {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], 
        Opacity[0.3], EdgeForm[None], 
        GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxNmgn4l1MWx99730jZDSqikorSoiLaQyRtiqREIilhKCVrUtFGwtirkSaN
LZpEilCyjWXGOsbYxz6MwYxhNOfj+/09v57nf55z3vPe997z3vee71l+/0Yj
zx54Vi6K4tqyKOKv+DrokaBrgr4NWsu9oG+C1gTND+qaiqJL0NUhbwi+Puj8
oBuCfhP0ZuifDF4j+LZB2xWStwja3nzLoLNjTLOgt0LewbqaQT1C1525Qt41
qHbQ1kHdkuRdgupYt01QXXPWqrfZmruZs+bu5qxT33zHoLtjzouCLgg6LOjQ
oBtDf0jwnYM3DGpUSGbde0M/JeiSoMa2D1v2NseWJubY0tQcW5qZY8s+5tiy
r/keQTcHNQjaL2gvr8kaLa3Hng1Bd/Adgn4sZEeboJ5Jz7QO+tk27R/UK8mO
dkGbbF/boFVJNrUPOsD2YdeB5tj1WtDjQbcEdbCuedDbtrFj0OUxz9SgViF3
sh5754euT9DCkI9KWgebayat141vmLRe96ABSWv0CPoh6D9BBwXdFnRw0KFB
h1lm3Z7mrHl70G+DOgctj3mODN4vaFDISzxnGXIOOiTkRZ6vV6Gxlbl7mzP3
tjH2veBHBP3OY/sWes/Kuejv53nu9aBngpby3eLZZ4P/PmjHkHdgL0IeHPzY
oDtD/tg2DgmaEbrpQQNCPt565j4+dEOC7mIfgt8a9EHIDwZfGTQrqG5QnaDB
ob/b840KWp0012lBoz3v0KCFoV8Q9FHIxwUfGHxEIf/DL/CT34Z+UdBnIS8J
fkfQlyE/EfzxoIlB65KeOzPoLM9xctDZ5iODfm1+StB9QfcGnRr0h3h2RdCE
oKFJNp4btDbJ1vFBE2z36UHnmY8Jmmg+NmiS+RlB55uPC1oc89we9EXIk63D
zgs2s/dCc+w9KWnNS4Iu3Wz9Keasf5k568/yPXTXsw9B94c827qppom2cZrt
w5arYuyYpPWnW4ddo9kT2zAuaf6ZQfWTbLoy6HLPx1wVPAXj5ng97oPZ1/l7
vhC00vO8yLmx7S8FrbK9Lwc95DlWF8J+YkE7MC7Jxrmem/f4U9DD1s2J+yOT
vnMXYz8Y/RvHBDCa+EA8AKNr2F4wmnhyrd+DmDPf96+LscOC7imqsaGm93Kq
95c1wEXwkVjRzXjNenV8rxIPKvGhru9VYkO9ohobdiuqsYFrYsINhTCZ2ICe
eEF8IDY08NrgbSU+wBt67ca+V4kNjYtqbNi7qMaGJkU1NjQtqrGhWVGNDVwT
b/a1PcSfmwrh8K2FYkYLPwOutrcd4BQ43NPYjH3Ei9a2jRjRxrYRF/a3bcSL
traNGNHOtlViA2s08Nz72cYOvjfdmNPf98BmMPpvhWIG2E2s6OTniQ/Ehi4h
T0uKJQsKxYiufhdiRDevS4zo7rWYC6wGu4kVPWxHJTZwb5Ax//BC8aGnbeIZ
cLtXUcV9rhdbZtz7hfD/qEIxpW9RjRe8Hxi91DLPHGucPzbkTwrh+3Eex56A
y2DyqKKK+csKYTIYDxafVAjfRxTC5VuN0+DpAuMleLrCmA+uvhH0XCHsr8Tp
5l4T/ARbZxlXWWulcR08vd24DoYuMl6CrXcY48+wLeAkuPm4cX9cUcV67oHr
YAD2VLB4ktcHP8cXVRyfUFRx/LyiiuNcD3M8OKeoxg/W+D17lZQvsvZkr1HB
cfBzpDGV8XOTsGl5IWwG3y+2HWDpJUUV3y8tqvjONTHoXO8bdoF7U73eNF+z
/nRfjzFGYsPVSfj+QCE8B7uvKITnV3qtShya7PXA45lef7avWW+Or9snYfEf
Qm6QhOngeMMkTAfHGyVhOjh+blLuDCaB33Nt5z3EEePaXkm4D47fGfLkoHmF
8BccBpOfTooFldwdrCam3MU+B13va2IN+PzrpJoAbN5YyDfwi8cK5dRgxvpC
PoZ/rSt0XjmrHSyT7z1ZKOfDRw83HoBfTxXK2/DBG5NwD4x51Wtw3Tv0Rybl
nHynud7Hd20Ta/eP+/2ScuiBwY9OyhGfLpTn4ed/tq1gRmdzcAOsA4uxmX1k
P8Hk+4LPtj8vDT4pKWe7MikHxJfxeXwUTCAHwmfwl+etBxdeCfqj78E5v/jA
iTHPcOcYp4EhzhVO8Vnj3I/1GZnuM/Sgz9VZoT8zKQ+Y7fMyy/vykHVzfRbm
+DyQB5AD8P0f2excrNnsLKzd7Ps/6jNws78F3/omf+PmPgvkxgP8bZ8ohN+L
/L0P9R6v99molVTndPU3ecrffbG/I+dq56Rvxvdij5/1PnOOHvdZYl+f857f
lHRu3t5sf9lb8o3nvf/s2QveN/bpRe/VQTGmg/2tY/CDN/O3l7yHnYlr9qsm
SXlSZV9f9t7e7rPFuxK7X/We3edvf6/37DW/B+/6uvcPG9/wO/2lUK4Vy/zi
b8jkPtTg3KOm/2uh/InvsoNlcpjvfQ89NTjyVkEfFoo9A/1t2Cdi6TuF4vfB
3kPkFv6G71h/C/6YqvES3sd64ijxt22S/bzHCK9FDNk1aW3Wvc3yIN8j9hEH
/m4ZPfUL18f4uxJn8a0H8I+k608LxWDuf14o3g0rVMv8I/iJhWoc7p1QKB4R
+4hF3CcmDvc1MjHtdM8zxmsxP2dvD+M8+I7ffFXIb/CVfxVVX/muqPrK995/
9vLf3k/OK3lMpQZGPsT8B8u72WbehbyNfI5c7ifLbcy5bm3+P8vkdj/7OXK7
TdZxiJDJ+fD1fxby9U2+R16YkuS2toOcChtrJNXV6FokXSOj2yKpdsant0zy
Xc4FdXUfz1F6zHZJemTyPPK/9uZbJeEAvJbl2taTF5ILkiMeYL6N9XCuu/vZ
mtYTg/le5AAtk9ZmXbCYnApsJocjlxtsvqPlnSxjf6uk6z4+a+AR56GPnznK
77q9x/DcrzwPvpK9LmvW9br1LDOmTdL1YJ/J3ZPO7WA/g41gHv6D75CHghMD
/H6cS3IP4sQov+/eSTnBVYXiBPI0c+6BV+BH0yQMQdfEevCD/AsM2SdJBjfI
zbgmHwDPmifFAHT7Wv9fnw/OBueipd8djN8vKRazT628V2BA6yR/Z8/aeB/A
j/2TMB2b2/ldiHvI083bW3+A5UrudGASvoPj4Dl4Py8pd6GGBMvB9kpO1dE6
8BtsB+/JncB6dOQ71L0VDEZO5l0tk4cxN/UiORuxhPXJ0ahduU8+Ql5CHXRN
Ug5Hncl9+qG1CsVUdA09hlr0V4VyK+QG5odZDy5Q+zUqlEchgwNHJF239n3k
Vh7DPfItcijqwErth9zEnHvgwHzL7Ty+t/UPs09JdV0/c3y2b1K918Vj+vhZ
OPcqfcJ+HnOH94VnqeOOScrTwEfqQPye3A25h3Vc4+9LfK+H+UDrmYO5iEfZ
cg+fge7e598l1XIVDEDGl+GDLT+VVK+NCPnapDyPa3I/ajnqODj9u6M9Zojl
NcEfSapzTkiqec6xj1Kn4KfcG2799ZapSeAnWv9Y8Ef9zBrPM8pjhnr8nkk4
QGw6OakWog6Cc00++UuPLqluIp9Evsg6rsktT7V8kcdwTd7J2qM85zC/zz1+
l9OsPz2pFrrCuDTa7wjnHvjEGtRR1EXkscgzrON6ut93hN/rDOtneDzX+PiU
QrUWGE++S9470/ws7wO4Rd4DdpH7IINt9GTPS8ormONMj6dXeZ7PwzlJWME5
gXN9tf0Sn8WXx1vGB+Fc4+vkMdTvp3idCV6rm+es7bPHPWyhhqAGB/P5nYKa
a6dCPdhJPmPUbfTZwGryP2R6XfN8Dz3P0cMCt+/yvMxJTsP81NP8jsP40ns1
zvvGc/TCqHEutowNcK4rNdAlHrPMdrJWfT+PnvyFGAD+8xsKz+wZ8tow8NGs
nGljUn+B94I/YXmS5Ymmx20znGfW+eyv8bmH8K9K33utZXSrLa/2mFHWr7FM
3va094GeJXIN656xHr7eMnyDZfz/Kdt8vsfwLbbxXNv6WeZ60vu9IVXHPmM9
Po3N440zGz3nOs8P5hzvdxji93vUfrHRYyo9Gjj9BjAWvK5gNfJCn+F5Ps/E
DuJK5Sxf4zPc3WM4p+wnvSRyYfp49Os6G+vAuONM4CE5CTUx4+k7oZuZVKth
DzEAvKdfQt8EX17mZxjPOz3m9zrJ7zje2IUeHb7yC14XwmdkfId8iVyf3B2c
Yg0wht9NmH+YseUqrwvW0S8C3+BzLS/3NRjZye/M+z5k+9vZF+62X9SLg1C3
VK6xc/BdS+HvLsG/TsLA3UPerVQuUCd492ycDrl+qbyjQfA9S+UavCMYBF58
GmNPyKqZ38bOrFjZOMY+lJVv9Ah+cRb+fRuKZqWw7rbQNS2FefuE/N+s2vrn
4M2zctnTgv+UVVcfFHyHUnjeKeT7s/ajdej2L5WfYcsbtod1pmWtRX66wt/l
lNB9llXD7xdj/pxV63zC+SpVh0/weLCRXJr6ijqOeg65r88Y8bWCYUvtF9Rc
9CzmGevAIHJO8k9y02b+5vf5uzPmLn+vC/3tLrA/3mlfBp/ol+1pGcwC46ZY
Rs/Z5RxQpzTzuuAe/WH6xb3sKyvtLyv8HdmTyrv1M19umfpype1c5fnb+byt
8lqMvd97sszveL2fe9DPNvPzTe1PD9oPW/kM03vnXS5L6tNc5nfjvR6J7/Nc
0r6+EPKLSTXrs8H/lXTGBof+sqxc8ZtQNCqVb78Wul2zejwXBu+aFd9XB98y
6xutyDqjnM9JwTtn5SGvBP9TVqx4Keb8LgmXeoduetb3Oi747Cwf7BJ8apZ/
L+UsZ/UaONfNfLZfiTn+nVRfL2L+pP5K/5BnZL3vy6H7Pgnr3gj+VlYdPT7L
Bzj/b4b+3axa+PXgx2T1P7oFvzwr99g29mB5Fva0CL4pq3bZJfirWfFvQfCF
WXs+hftZfaD++EWS/CJ+l5XX7wVOlKrD/hq6N7Nq+p2Dv5zVOxgbvGUWdu4d
Y5uUqt++Dd3XWXXwQPbP6/YNvm1W7G4bfN8szNw6eI2sfKZPzHF41ndfHLxR
Vj4+OvTH+t2HBt8tK46cHHzvrLy7fvCPs+q8GjF+WVa/pinfNqvO2x67svKi
noz12RgQ4wdl9e+eC14zq2fSCztL1ZOfh9wgq5dWN/hfsnocc4I3tB4/4vcM
ejXUkvSV6DfRQ+J3lJG+Tw+I/g89KfqAfGv6K+iZg3yD30LIl+gP8XvJWOMV
85C/fWn9cMuMP8O6xdbzOw42DPL6C/3sF7YDG6jb+f2MOp64yu9hnPMFvsZ3
+c3oiqRvTSwlplJToONe5f8HmGeobVli+/kGrMsekC/xvqM8dkaqxuhrPed/
Yi+bZPVHPvI7YD8+Rl/vveAHxv3WWZjcqlRsIC4MDc4/FtGfGBe8VVbc3y70
25fqZQwJfnpWX5jY8oDjyyfB98jqDR8YY87NqvevC94xq1e6U+gPtkyM6mA/
/cB2nhz8YXwrq59B3/cm4wB1Or9PV/Jl5GzdDZapoai7wKURlslDmIsxzHGz
52VOakl6OtSV9PRYi/4pulusf9vj+c3iPd+jB/JdLPiux1RiDD3zr0LfOKvX
RVw9wrG1VvCjsjAfvxxu33w7+DvGLjhYhoyfHWlfw+8H2PfB1D7GVfz+UPs+
WHKO8QRfnGV/BP9eTcJAsPNo4ydxYEjWOQWPJxuTf8IPss7Se8E/YGOT4gn4
AraAc/2MdXzn+f7WXeP+RVn9mx4hH1Kqd9M5+C1ZsWYJmJr0205HzkOpHnOn
4F1K9X04m2f6fHYI3UGl+kftgm9dyu8uifu9S/Xru5WKT8Sme4K3LYUHG0N+
Oquf2z5025Ty601J18gHBL82q493DZiX1H9+Pyt+sG9Xhzwmy0+JpeRtxFNy
w5uz8sPPOJNZNf6XId+YVUf/PfjuWT3WD5P2l709H1zPymPfIUZn9TrqZMVj
YvENwb9Iyml3zIox7HnzWL9FqZ7dhKxxjHk++B+zetas/3mSDcTqiVl+QTwh
nhFTiGPEMOIXcfj7LJz4MSv/I/cjVhyfFS8+DF4vq69MDvtWUh47MytHJD8E
G+YZH4jP22XF6GfRZf1/4pgYe2JWH5H4MyIrBrF/nybt4Z5ZmAKevB+6H5N6
OMS9U7NiH3Hjc8eOS7POBOeBHKR2Vh4ytlR+TG78WlKswi+ODL4q63ce8gJi
5BNgQsg9S/UTPzImgocfJ50bzgxnmfyJ8/yBMZH3LfH3Uj1HzsU/ks5G5ryU
+v8yzu+9WWf4Z59p5IQvl+pvgqnnZeFqm9CVpTB8q1LnlbMKpoKnYGlt/Cbr
d4aaIbfL6kGTx12Qlcv9j7OcFb9OyvoG7P+6kB/L+h/SLUNXq1Qv+4nQPZn1
uwK5wBalYhExgWSbuLAh5PVZ/2fKWf4q6Tx/EfKXWb8fkCOQR5In3I1PZ/3O
88/gf0vq7Y/O+k58ox9C17JUf5k86JusXOj/V33LIw==
           "]], PolygonBox[CompressedData["
1:eJwtl3m0T1Ucxc85V6HEUhSZS8KrPK8iIcoUkplEolRKSJrLqlatpEFF41oa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           "]]}]}, {}, {}, {}, {}}, 
      {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], 
       LineBox[CompressedData["
1:eJwl1EVzFVEQBtBHcJfgBJdgOwoLGjxoCLDCvYoq3J3CYYe7LoEN7u7u8gdw
d5fTxeLk6+6ZeXNn5lYqDxqdNSpbIpFI8edwUiKxkWrZE4nqtFG3JSdHyMVR
rjr3uDzBMU5xkmvmZ+RZTnOec1w3vygvcYErXOaG+bU4Hr9J7phx07yz+7dT
52ETNfSfzFPlfH17aqo7yFoyr+zEGHVHuYDODNV3kQXJZKy+m1xId4bps2Qx
NrOFrdxxr8Xygcx0Tg/1UpZQV39X3ovzKMF9evOEcjwmhacM4hvV+RrPwvdY
G3+ozW/q8JfR8S7co16883g28lCfFWYrSYs16xvLBM+sM1nfRL2bPUxkpNkE
uYZXzumnb6aey1RG6afIdbx1fKC+hXoezdUzZJO4hqZs0H9wXmV1FSrRymw2
s+ioz+CguqKsEN+I7PHN5AFZXqbE9yUp9pjcH+9Nlo19RzZ9a7lPlpGlSY97
0TLWyF7H0pkZ71j/3rpKxXF9cVmSErwzX2/2Rg7QT49nYxr99a/N16pfyr76
yeqmTKKP/oX5avVz2Vs/Xt2IIuqGsqhMi2/BKn1D2YgGjNMvZ1nsDdfvkjvZ
EfuI4Yxw3jD5K/Y0P0jlJ4N5QYX4xvHuYh2xLh5RKvYoJXlIz/hNv9dLbmdb
vAtux351/6/MUSfTLfaxflHsQXUdbsXzcDOej67B/LbzvlBIP0RfWBYggy5x
nWOfyRdr1ueXOeIb0kl/xbGPVFUfSvr/v+YfnrOEYg==
        "]], LineBox[CompressedData["
1:eJwl0rVOBGEUBtBZpEFboIEFGgpc3gOXBA0Fbm9AjSzvgBfIyxBscQgFrsHh
TChO7ne/f2aymZ1oz2jdSCQIghiHCUFwwBE7yn0zzi5Z7LGtr00MgiZ5khb6
7M3mFNPkcUUub66Pcy3fsMAiH7oTZuUzs8Uz+uQ5YvQzqBswixlnwj5mpphV
5hoV8o/7K81U1nUbjMqX+l+q5DTS2XSWYWZSLddQyjCtunPXfzFoH7IPmSUE
cgIRLpy3mSP6MlbCa+yllFNGIkmsOks2v91THv5eiuilWX+q/2TZvsQrLxzr
mpx3y4V00Wg/0j/Jz9zzyAOH+juzgFvy6Qzfo3s6zHfnxfK8HKWdBvuBfkbe
N+vtbXJO+C6os+/pz+VsTsL/itPwm9Afm1uR/+/mDxLqTio=
        "]]}}], {}}, {
    InsetBox["\<\"\[Mu] = \"\>", {-1.8, 1.8}, NCache[
     ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
    InsetBox["0.2`", {-1.6, 1.8}, NCache[
     ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]]}, {InsetBox[
     SubscriptBox["C", "J"], {1.4, 1.8}, NCache[
     ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
    InsetBox["\<\"=\"\>", {1.6, 1.8}, NCache[
     ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
    InsetBox["3.7`", {1.7, 1.8}, NCache[
     ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]]}, {
    {PointSize[0.05], PointBox[{-0.2, 0}]}, 
    {PointSize[0.0125], PointBox[{0.8, 0}]}}},
  AspectRatio->1,
  Axes->{False, False},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{True, True}, {True, True}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  Method->{
   "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "ScalingFunctions" -> 
    None, "TransparentPolygonMesh" -> True, "AxesInFront" -> True},
  PlotRange->{{-2, 2}, {-2, 2}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.02], 
     Scaled[0.02]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.853522428955022*^9, 3.8536614612022247`*^9, 
  3.853662121605934*^9, 3.853665027252273*^9, 3.890915206894611*^9},
 CellLabel->"Out[7]=",ExpressionUUID->"63139915-66c6-4bb0-8e4b-d0c4a81bff69"]
}, Open  ]]
},
CellGrouping->Manual,
WindowSize->{982, 648},
WindowMargins->{{79, Automatic}, {Automatic, 32}},
FrontEndVersion->"13.2 for Mac OS X x86 (64-bit) (November 18, 2022)",
StyleDefinitions->"Default.nb",
ExpressionUUID->"bddbfbc5-6667-4051-a3d5-0cca79b12b53"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[558, 20, 387, 8, 53, "Text",ExpressionUUID->"6e0b646a-4282-44bb-8438-edf0f956b79a"],
Cell[948, 30, 228, 4, 67, "Section",ExpressionUUID->"64a886da-fb90-4218-9aec-9c7c4677de10"],
Cell[1179, 36, 1009, 21, 72, "Text",ExpressionUUID->"fcfaeef7-9023-4cdf-905a-4ab0a651e4f0"],
Cell[2191, 59, 1304, 29, 145, "Text",ExpressionUUID->"0d9a5a7d-b3a0-4afe-ba0a-9d017a279b2e"],
Cell[3498, 90, 5589, 157, 346, "Input",ExpressionUUID->"678bc441-9b7e-4718-83d3-5d40f8f8781e"],
Cell[9090, 249, 784, 16, 53, "Text",ExpressionUUID->"e869e382-39d5-48dd-815b-0348c126775d"],
Cell[9877, 267, 255, 4, 30, "Input",ExpressionUUID->"e445a296-8c34-42c9-8735-6191acbcbf72"],
Cell[10135, 273, 1685, 40, 122, "Text",ExpressionUUID->"ed59d7a2-3bf5-4ff1-9a83-1961704d0a53"],
Cell[11823, 315, 6173, 143, 220, "Input",ExpressionUUID->"7431dd3e-676f-4bef-befb-caef1062bcaf"],
Cell[17999, 460, 1287, 22, 99, "Text",ExpressionUUID->"c5367ab1-de0c-4f31-97c0-7402b306af75"],
Cell[19289, 484, 1173, 21, 30, "Input",ExpressionUUID->"5d375416-a2b6-4b75-a64e-5288c03af743"],
Cell[CellGroupData[{
Cell[20487, 509, 260, 4, 30, "Input",ExpressionUUID->"51f1a70d-47d9-4d3e-bf66-f809b969292d"],
Cell[20750, 515, 4391570, 74496, 454, "Output",ExpressionUUID->"cb3401c3-e229-435b-be2c-e168828401f3"]
}, Open  ]],
Cell[4412335, 75014, 1008, 15, 53, "Text",ExpressionUUID->"0ce94a10-0aec-4123-87f6-3ec62225a8c2"],
Cell[CellGroupData[{
Cell[4413368, 75033, 389, 6, 30, "Input",ExpressionUUID->"66966bf6-024b-4dd0-8251-823144798b9e"],
Cell[4413760, 75041, 20741, 360, 378, "Output",ExpressionUUID->"fc7cc044-0de5-441f-9dc1-6df14083c29f"]
}, Open  ]],
Cell[4434516, 75404, 1009, 15, 53, "Text",ExpressionUUID->"205ab852-4340-4991-9511-740d2720b898"],
Cell[CellGroupData[{
Cell[4435550, 75423, 391, 6, 30, "Input",ExpressionUUID->"f3cd2f6d-3749-4b94-8768-21d4ccfae98d"],
Cell[4435944, 75431, 19723, 341, 401, "Output",ExpressionUUID->"63139915-66c6-4bb0-8e4b-d0c4a81bff69"]
}, Open  ]]
}
]
*)

